(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    426808,       7954]
NotebookOptionsPosition[    381534,       7318]
NotebookOutlinePosition[    381874,       7333]
CellTagsIndexPosition[    381831,       7330]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["IUU Fishing: Economic Effects of IUU Imports on U.S. Commercial \
Fishers\n",
  FontSize->36],
 StyleBox["Species: Cod and Pollock",
  FontSize->24],
 StyleBox["\n",
  FontSize->18],
 StyleBox["Model Release",
  FontSize->18,
  FontSlant->"Italic"]
}], "Title",
 CellChangeTimes->{{3.7159437701501894`*^9, 3.715943776742571*^9}, {
   3.7160177883406353`*^9, 3.716017799612287*^9}, {3.716044926298222*^9, 
   3.7160449278653135`*^9}, {3.7167127367223215`*^9, 3.716712737322365*^9}, {
   3.716716446852584*^9, 3.716716448548705*^9}, {3.717141741657609*^9, 
   3.717141743761731*^9}, {3.717937945363772*^9, 3.7179379529402757`*^9}, {
   3.7185331704286838`*^9, 3.7185331826684923`*^9}, {3.7185539001319838`*^9, 
   3.7185539082355175`*^9}, {3.7847892842210164`*^9, 
   3.7847892988406277`*^9}, {3.787835927539494*^9, 3.7878359285709715`*^9}, {
   3.7879338873743715`*^9, 3.7879338874784536`*^9}, {3.791201099377099*^9, 
   3.7912011013376207`*^9}, 3.7954520024204845`*^9, {3.798810740721634*^9, 
   3.798810744523918*^9}, {3.799789945142694*^9, 3.7997899492227287`*^9}, {
   3.7998541778687954`*^9, 3.7998541814351215`*^9}, {3.8016687240812187`*^9, 
   3.8016687246281986`*^9}, {3.8017788040189447`*^9, 
   3.8017788092541156`*^9}, {3.819664877798711*^9, 3.819664951849766*^9}, {
   3.8199010796026187`*^9, 
   3.8199010810067167`*^9}},ExpressionUUID->"a4eccb85-2d0b-4e19-9d2b-\
957174bcb5a9"],

Cell[TextData[{
 StyleBox["Read Me :",
  FontWeight->"Bold"],
 "\nThis model accompanies the USITC report, ",
 StyleBox["Seafood Obtained via Illegal, Unreported, and Unregulated Fishing: \
U.S. Imports and Economic Impact on U.S. Commercial Fisheries",
  FontSlant->"Italic"],
 ", Inv. 332-575. The report includes a quantitative analysis of the economic \
impact of IUU imports on U.S. commercial fishers and U.S. commercial fishing \
production, trade, and prices. Economic effects are modeled by species, with \
each species-level model customized to fit the unique features of the U.S. \
domestic industry. Consumers of seafood products choose between domestic \
marine-capture sources, imports, and in some models, domestic aquaculture \
products. Imports include both legal and IUU sources that enter the U.S. at \
the same price, so consumers cannot distinguish an IUU from non-IUU product. \
2018 data is used to establish an initial equilibrium with imports of IUU \
products included in the baseline. The model then removes the IUU imports, as \
estimated in chapter 3, and solves for a new equilibrium absent those \
products. \n\nIn the cod and pollock model, products are differentiated at \
the regional level. The four domestic varieties in the model are Atlantic \
cod, Pacific cod, Atlantic pollock, and Alaskan pollock. The two import \
sources are imported cod and imported pollock. The cod and pollock model \
includes cross-species substitution, so changes in the price of a pollock \
variety impacts the price of the cod varieties. Annual catch limits (ACLs) \
are enforced in the model so modeled increases in domestic landings cannot \
exceed their legal limits. Catch limits are modeled as a vertical asymptote \
directly in the supply equation and not as a constraint.\n\nThere are two \
markets modeled: unprocessed and processed products. Landings of cod and \
pollock flow to three destinations: the unprocessed market, the processed \
market, or are exported outside the country. The price of the processed cod \
and pollock is a constant markup over the price of the unprocessed cod and \
pollock, so increases in domestic prices of landed fish affect the price of \
processing. Initial consumption of unprocessed products, before the policy \
change was implemented, was calculated as a residual using 2018 conversion \
factors from NOAA.\n\nData inputs in the simulation are in the BLUE-shaded \
cells (with sources for the input data listed in the cell above). Outputs are \
in the GREEN-shaded cells. The white cells are intermediate calculations. \n\n\
Note: p_xDU is the price of the unprocessed product sold to consumers. q_xDU \
is the quantity of landings, not the unprocessed quantity sold to U.S. \
consumers. The unprocessed quantity sold to U.S. consumers must exclude \
exports and processed product * conversion rate."
}], "Text",
 CellChangeTimes->{{3.8151793544957237`*^9, 3.8151793654382553`*^9}, {
   3.815180147319877*^9, 3.8151801612046986`*^9}, 3.8193117353392124`*^9, {
   3.819364667233782*^9, 3.819364673128374*^9}, {3.819364986036234*^9, 
   3.81936502379967*^9}, {3.8193652789237294`*^9, 3.819365313721591*^9}, {
   3.819365363147914*^9, 3.819365382037648*^9}, {3.8193654602015305`*^9, 
   3.8193655738330727`*^9}, {3.819365634647441*^9, 3.8193657347144046`*^9}, {
   3.8193659700247307`*^9, 3.819365970554162*^9}, 3.8193660018247957`*^9, {
   3.819366258029726*^9, 3.819366301792824*^9}, {3.819366347287284*^9, 
   3.819366415704628*^9}, {3.8193664545638943`*^9, 3.819366511109967*^9}, {
   3.819366610713606*^9, 3.8193669391806083`*^9}, {3.8193669763456044`*^9, 
   3.8193670889590435`*^9}, {3.819367863082618*^9, 3.8193678631977077`*^9}, {
   3.819400007994233*^9, 3.819400030667904*^9}, {3.819400277598463*^9, 
   3.8194002936449785`*^9}, {3.8194011542913923`*^9, 
   3.8194012480694838`*^9}, {3.8194013222643557`*^9, 
   3.8194013264886327`*^9}, {3.8194013868456955`*^9, 
   3.8194013890784397`*^9}, {3.819401463985852*^9, 3.819401508238408*^9}, {
   3.8194019318657284`*^9, 3.8194019329005365`*^9}, {3.819665080356598*^9, 
   3.8196650954828777`*^9}, {3.8196652430795116`*^9, 3.819665263767852*^9}, {
   3.8196694045310993`*^9, 3.819669946270366*^9}, {3.819669976834861*^9, 
   3.8196705383246193`*^9}, {3.819670606948246*^9, 3.819670798460183*^9}, {
   3.819670860785177*^9, 3.8196709679574733`*^9}, {3.8196710056524982`*^9, 
   3.819671491943797*^9}, 3.819671563400182*^9, {3.819672484886944*^9, 
   3.8196724859338183`*^9}, {3.8199011533041058`*^9, 
   3.8199012321717076`*^9}, {3.8199021437167053`*^9, 3.819902144786538*^9}, {
   3.819904727337638*^9, 3.8199047710337067`*^9}, {3.820012303009897*^9, 
   3.820012307046046*^9}, {3.820012457109111*^9, 3.820012461730715*^9}, {
   3.821228471311254*^9, 3.821228478115568*^9}, {3.821228583604739*^9, 
   3.8212286069008274`*^9}, {3.821254034767659*^9, 3.8212540557230434`*^9}, {
   3.8212540945664053`*^9, 3.8212541288301916`*^9}, {3.821254184887725*^9, 
   3.8212542155085*^9}, {3.8250758438958745`*^9, 3.825075844469709*^9}, {
   3.8253277506309185`*^9, 3.825327757146022*^9}, 3.825327793842675*^9, {
   3.8253514416382155`*^9, 3.8253514421366067`*^9}, {3.825352514221091*^9, 
   3.825352516102563*^9}},
 FontSize->12,
 Background->GrayLevel[
  0.85],ExpressionUUID->"989c9ad2-a2af-449a-afa1-29cf4dade7a1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ClearAll", "[", "f", "]"}], ";"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.791207469588732*^9, 3.7912074737709374`*^9}, 
   3.821254324938466*^9},ExpressionUUID->"0c777ea8-191a-4659-be18-\
f91ea0d0ffda"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1. Model Parameters",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.795452962713849*^9}, {
  3.8196715794204283`*^9, 
  3.8196715805723763`*^9}},ExpressionUUID->"e96e59ff-4f99-46b0-8141-\
97bb85c5e783"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.1 Within-Species Elasticity of Substitution", \
"Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.819814333471882*^9, 
   3.8198143380684657`*^9}},ExpressionUUID->"c256c105-36d6-45fc-b20a-\
98c412f36db1"],

Cell[TextData[StyleBox["Source: USITC\[CloseCurlyQuote]s econometric \
estimation using the trade cost method in Riker (2020). More information can \
be found in the technical appendix (appendix I). ",
 FontSize->12]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, 3.819672507377739*^9},
 FontSlant->"Italic",ExpressionUUID->"c8dbdd23-6753-4a73-a058-2ad0c1c2ca24"],

Cell[TextData[{
 StyleBox["Unprocessed cod:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across varieties of unprocessed cod",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, 3.8196721378915873`*^9, 3.819672507377739*^9, {
   3.8198159346525345`*^9, 
   3.8198159348206663`*^9}},ExpressionUUID->"076a7c86-bfad-4b97-9f02-\
1dd5b6e20e72"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmacu", " ", "=", "4.706"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.812465279359131*^9, 
   3.8124653094376397`*^9}, {3.81292590136325*^9, 3.812925939936266*^9}, 
   3.812926311880746*^9, 3.812926544214137*^9, 3.8196717219763446`*^9, {
   3.819671819711873*^9, 3.819671820331375*^9}, {3.81967192002273*^9, 
   3.8196719205252266`*^9}, 3.819672507377739*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[606]:=",ExpressionUUID->"0d44e1c6-e9d4-484e-888a-97e11d7e3438"],

Cell[TextData[{
 StyleBox["Processed cod:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across varieties of processed cod",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, {3.819671893067898*^9, 3.819671897578418*^9}, 
   3.819672140510911*^9, 3.819672507377739*^9, {3.819815937731935*^9, 
   3.8198159380872116`*^9}},ExpressionUUID->"f80f2a91-0269-4b6d-b654-\
41d20c061408"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmacp", " ", "=", "4.706"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.812465279359131*^9, 
   3.8124653094376397`*^9}, {3.81292590136325*^9, 3.812925939936266*^9}, 
   3.812926311880746*^9, 3.812926544214137*^9, 3.8196717219763446`*^9, {
   3.819671819711873*^9, 3.819671820331375*^9}, {3.8196719225732403`*^9, 
   3.8196719232829375`*^9}, {3.8196720421319466`*^9, 3.819672045351909*^9}, 
   3.8196725073787403`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[607]:=",ExpressionUUID->"96eac114-d508-47c3-a547-88d986993fd6"],

Cell[TextData[{
 StyleBox["Unprocessed pollock:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across varieties of unprocessed \
pollock",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, {3.819671936331724*^9, 3.819671945519664*^9}, {
   3.8196721436817226`*^9, 3.8196721441060996`*^9}, 3.8196725073787403`*^9, {
   3.819815940459058*^9, 
   3.819815940775304*^9}},ExpressionUUID->"115496dd-3e15-4302-b34d-\
38dbfa1c913f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmapu", " ", "=", "11.615"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.812465279359131*^9, 
   3.8124653094376397`*^9}, {3.81292590136325*^9, 3.812925939936266*^9}, 
   3.812926311880746*^9, 3.812926544214137*^9, 3.8196717219763446`*^9, {
   3.819671819711873*^9, 3.819671820331375*^9}, {3.81967192002273*^9, 
   3.8196719205252266`*^9}, {3.8196719531120205`*^9, 3.8196719544513116`*^9}, 
   3.819672048699986*^9, 3.8196725073787403`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[608]:=",ExpressionUUID->"4be3573e-d8f2-4658-b33e-9898019bab51"],

Cell[TextData[{
 StyleBox["Processed pollock:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across  varieties of processed pollock",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, {3.819671893067898*^9, 3.819671897578418*^9}, {
   3.819671939798108*^9, 3.819671949320351*^9}, 3.819672147266903*^9, 
   3.8196725073787403`*^9, {3.8198159429560013`*^9, 
   3.81981594314715*^9}},ExpressionUUID->"4417c30d-6b58-4c3d-875e-\
1a5431be8326"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmapp", " ", "=", "11.615"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.812465279359131*^9, 
   3.8124653094376397`*^9}, {3.81292590136325*^9, 3.812925939936266*^9}, 
   3.812926311880746*^9, 3.812926544214137*^9, 3.8196717219763446`*^9, {
   3.819671819711873*^9, 3.819671820331375*^9}, {3.8196719225732403`*^9, 
   3.8196719232829375`*^9}, {3.8196719574161687`*^9, 
   3.8196719583610797`*^9}, {3.8196720511122026`*^9, 3.8196720517818174`*^9}, 
   3.8196725073787403`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[609]:=",ExpressionUUID->"503f6090-0640-4711-a500-4cdc6ff03744"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.2 Cross-Species Elasticity of Substitution", \
"Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, 3.8196725148810096`*^9, {
   3.8198143408736553`*^9, 
   3.819814345001872*^9}},ExpressionUUID->"8cc2fe1d-8e5a-4354-94e7-\
906d2436cbeb"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate and Interviews with \
Industry Participants.",
 FontSize->12]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725148810096`*^9, 3.820012465372556*^9, {3.8200125245600863`*^9, 
   3.8200125375572243`*^9}},
 FontSlant->"Italic",ExpressionUUID->"cdcb8fff-7373-4897-9aef-c2ad1a3fe6f9"],

Cell[TextData[{
 StyleBox["Unprocessed:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across unprocessed cod and pollock",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, {3.819672030964613*^9, 3.8196720315651684`*^9}, {
   3.819672128429147*^9, 3.819672157389882*^9}, 3.8196725148810096`*^9, {
   3.8198159557829914`*^9, 
   3.819815955882069*^9}},ExpressionUUID->"c6e279f6-9736-4fcc-8934-\
b5137f5d9e74"],

Cell[BoxData[
 RowBox[{
  RowBox[{"betau", " ", "=", "5.0"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.812465279359131*^9, 
   3.8124653094376397`*^9}, {3.81292590136325*^9, 3.812925939936266*^9}, 
   3.812926311880746*^9, 3.812926544214137*^9, 3.8196717219763446`*^9, {
   3.819671819711873*^9, 3.819671820331375*^9}, {3.81967192002273*^9, 
   3.8196719205252266`*^9}, {3.819672064642597*^9, 3.819672075061104*^9}, 
   3.8196725148810096`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[610]:=",ExpressionUUID->"5e3a3f8d-ab24-4fc7-84cf-fa63d9a5a902"],

Cell[TextData[{
 StyleBox["Processed:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across processed cod and pollock",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, {3.819671893067898*^9, 3.819671897578418*^9}, {
   3.8196720341255374`*^9, 3.8196720347751384`*^9}, {3.8196721610431147`*^9, 
   3.8196721644200883`*^9}, 3.8196725148810096`*^9, {3.8198159580197334`*^9, 
   3.81981595815784*^9}},ExpressionUUID->"361d8506-8032-4acc-a1e9-\
75993f05cd7a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"betap", " ", "=", "5.0"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.812465279359131*^9, 
   3.8124653094376397`*^9}, {3.81292590136325*^9, 3.812925939936266*^9}, 
   3.812926311880746*^9, 3.812926544214137*^9, 3.8196717219763446`*^9, {
   3.819671819711873*^9, 3.819671820331375*^9}, {3.8196719225732403`*^9, 
   3.8196719232829375`*^9}, {3.819672069645162*^9, 3.8196720784491777`*^9}, 
   3.8196725148810096`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[611]:=",ExpressionUUID->"0fa79466-5a43-4fd1-8cdc-aaf9f2f03649"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.3 Industry Price Elasticity of Demand", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, 3.8196725271002216`*^9, {3.819814291546197*^9, 
   3.819814297331707*^9}, {3.8198143479321556`*^9, 
   3.8198143530561504`*^9}},ExpressionUUID->"5a591766-6aa5-4ae8-916e-\
39c5cc13291f"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate.",
 FontSize->12]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725271002216`*^9, 3.820012468652115*^9, {3.8200125463901167`*^9, 
   3.8200125607253003`*^9}},
 FontSlant->"Italic",ExpressionUUID->"a4ee10a5-85bd-414a-8f53-f222a94c0077"],

Cell[TextData[StyleBox["Unprocessed",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.8016643815964966`*^9, 3.80166438203933*^9}, {
   3.8031104952208443`*^9, 3.8031105339530745`*^9}, {3.803118428298416*^9, 
   3.8031184400395803`*^9}, 3.8033028142898912`*^9, {3.80571075980079*^9, 
   3.8057107601133404`*^9}, {3.8196721218802958`*^9, 
   3.8196721245096445`*^9}, {3.8196721773104386`*^9, 3.8196721827752504`*^9}, 
   3.8196725271002216`*^9},ExpressionUUID->"684e65e8-9bca-49aa-b764-\
11c8a8b5a33f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"etau", "=", " ", 
   RowBox[{"-", "1.0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, 
   3.8016643791586046`*^9, {3.801780399382991*^9, 3.8017804002581425`*^9}, 
   3.803110491929274*^9, {3.819672112733116*^9, 3.819672113234567*^9}, 
   3.819672527101222*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[612]:=",ExpressionUUID->"ef4b557b-29d1-4476-9b9e-94d8b8493206"],

Cell[TextData[StyleBox["Processed",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.8016643815964966`*^9, 
   3.8016643912751904`*^9}, {3.8031105485584755`*^9, 
   3.8031105510724382`*^9}, {3.805710761160388*^9, 3.805710761519824*^9}, {
   3.819672173174797*^9, 3.8196721856998253`*^9}, 
   3.819672527101222*^9},ExpressionUUID->"3076b012-20e5-472e-bde1-\
5dd2b3b3d83e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"etap", "=", " ", 
   RowBox[{"-", "1.0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016643791586046`*^9, 3.801664387008879*^9}, {3.80178040319617*^9, 
   3.801780404211971*^9}, {3.819672116662634*^9, 3.819672117252161*^9}, 
   3.819672527101222*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[613]:=",ExpressionUUID->"fa127d8a-314c-4b5d-8a5a-0f0e64bdc4f5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.4 Illegal Imports Replacement Rates", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, {3.81967219811668*^9, 3.819672213143815*^9}, 
   3.819672537084565*^9, {3.819814300125886*^9, 3.8198143058253307`*^9}, {
   3.8198143561535683`*^9, 
   3.8198143611354523`*^9}},ExpressionUUID->"91661e8c-c0ed-4882-bca2-\
19a13bc2ecdc"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate.  Further discussion on \
qualitative factors and rate determination can be found in appendix I of the \
USITC\[CloseCurlyQuote]s report.",
 FontSize->12]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196723427492237`*^9, 3.8196725370855665`*^9, {3.819815993710532*^9, 
   3.819815996531728*^9}, {3.8198381383987584`*^9, 3.819838144753663*^9}, {
   3.8198382402870555`*^9, 3.8198383754614663`*^9}, 3.8200124721278267`*^9, {
   3.820012579354833*^9, 3.8200125899691114`*^9}},
 FontSlant->"Italic",ExpressionUUID->"60a7fe40-f7b5-4a10-9768-1065cca22926"],

Cell[TextData[{
 StyleBox["Unprocessed cod: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of unprocessed cod "
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 
   3.8198159740712395`*^9}},ExpressionUUID->"6a97488f-358d-4c62-9acd-\
ba969ebf779f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"replcu", " ", "=", " ", "0.30"}], ";"}], " "}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662885297171*^9}, {3.8016683902542915`*^9, 
   3.801668392194314*^9}, {3.801668476343513*^9, 3.8016684764529057`*^9}, {
   3.8016685159337964`*^9, 3.801668531426852*^9}, 3.801692415143248*^9, {
   3.8016926196184893`*^9, 3.801692619774764*^9}, {3.801780289233728*^9, 
   3.8017802906278515`*^9}, 3.8033028464480004`*^9, 3.8033032141861067`*^9, {
   3.80339474346602*^9, 3.803394743762943*^9}, {3.8033948509102745`*^9, 
   3.80339485100404*^9}, 3.803397269400152*^9, {3.8046038093026843`*^9, 
   3.8046038096653833`*^9}, {3.804603880729575*^9, 3.8046038809014807`*^9}, 
   3.8046052143817463`*^9, 3.804605769353428*^9, 3.8046060008512077`*^9, 
   3.804866379055114*^9, {3.805710377856019*^9, 3.8057103914376774`*^9}, {
   3.805711240432749*^9, 3.8057112422299185`*^9}, {3.8057120940105977`*^9, 
   3.805712095698372*^9}, 3.8057123504557796`*^9, {3.8057129616740913`*^9, 
   3.805712961861622*^9}, {3.8066685135679045`*^9, 3.806668513630415*^9}, {
   3.806668595147448*^9, 3.8066685952568417`*^9}, {3.8076519450967417`*^9, 
   3.80765195323995*^9}, {3.807869848345052*^9, 3.8078698484857006`*^9}, {
   3.8078714434863243`*^9, 3.8078714436113443`*^9}, {3.8078727623105955`*^9, 
   3.8078727624512444`*^9}, {3.810032008126135*^9, 3.810032008214203*^9}, {
   3.812465354396778*^9, 3.8124653598310223`*^9}, {3.819672243345023*^9, 
   3.8196722438965015`*^9}, 3.8196725370855665`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[614]:=",ExpressionUUID->"e71883ba-93a1-4219-bd68-67879f88fe63"],

Cell[TextData[{
 StyleBox["Unprocessed pollock: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of unprocessed pollock"
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628701371517`*^9}, {
   3.805710429493208*^9, 3.8057104321811438`*^9}, {3.805710734678847*^9, 
   3.8057107349757705`*^9}, {3.8196722529563255`*^9, 
   3.8196722643091063`*^9}, {3.819672307734372*^9, 3.8196723084239616`*^9}, 
   3.8196725370855665`*^9, {3.819815976503132*^9, 
   3.819815976630231*^9}},ExpressionUUID->"59afd0a7-9f2f-4726-ba40-\
c1fa575b6f1b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"replpu", " ", "=", " ", "0.30"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662888928058*^9}, {3.8016683952885675`*^9, 
   3.8016683957417665`*^9}, {3.801668478875883*^9, 3.801668478985276*^9}, {
   3.8016685230652122`*^9, 3.8016685337553577`*^9}, 3.8016924179886847`*^9, {
   3.801692616946184*^9, 3.8016926170868325`*^9}, {3.801780293582797*^9, 
   3.8017802946923575`*^9}, 3.8033028505850444`*^9, {3.8033032081382475`*^9, 
   3.8033032184211392`*^9}, 3.80339474828187*^9, {3.803394853256654*^9, 
   3.8033948533973007`*^9}, 3.8033972714877625`*^9, {3.804603806973976*^9, 
   3.804603807239648*^9}, {3.8046038827508574`*^9, 3.8046038829383917`*^9}, 
   3.8046052160695047`*^9, 3.8046057712913*^9, 3.8046060025233717`*^9, 
   3.8048663806022468`*^9, {3.8057103980169125`*^9, 3.805710398345093*^9}, {
   3.8057112446053076`*^9, 3.8057112448866034`*^9}, 3.805712097948737*^9, 
   3.8057123523154583`*^9, {3.8057129647996054`*^9, 3.80571296495588*^9}, 
   3.806668518168937*^9, {3.8066685975853558`*^9, 3.8066685977260046`*^9}, {
   3.807651961116261*^9, 3.8076519615850897`*^9}, {3.807869850567688*^9, 
   3.807869850708336*^9}, {3.8078714460179815`*^9, 3.8078714461586285`*^9}, {
   3.8078727652329583`*^9, 3.807872765389233*^9}, {3.8100320108532343`*^9, 
   3.8100320109513097`*^9}, 3.812465365897767*^9, {3.8196722684356613`*^9, 
   3.819672268927085*^9}, 3.8196725370855665`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[615]:=",ExpressionUUID->"8416828b-6e0d-4043-b421-691ce31c4cb1"],

Cell[TextData[{
 StyleBox["Processed cod: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of processed cod"
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710433790786*^9, 
   3.805710437603905*^9}, {3.8057107324441094`*^9, 3.805710732725405*^9}, {
   3.819672274047496*^9, 3.819672305331317*^9}, 3.8196725370855665`*^9, {
   3.8198159811547527`*^9, 
   3.81981598144698*^9}},ExpressionUUID->"4d8eece9-6cfb-428f-9fbc-\
50d134b9d515"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"replcp", " ", "=", "0.30"}], ";"}], " "}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662885297171*^9}, {3.8016683902542915`*^9, 
   3.801668392194314*^9}, {3.801668476343513*^9, 3.8016684764529057`*^9}, {
   3.8016685159337964`*^9, 3.801668531426852*^9}, {3.801692415143248*^9, 
   3.8016924248624325`*^9}, {3.801692611397209*^9, 3.8016926116003666`*^9}, {
   3.801779929551795*^9, 3.801779950134696*^9}, {3.803302853421974*^9, 
   3.8033028537657795`*^9}, {3.80330322051523*^9, 3.803303220687134*^9}, 
   3.8033947500948496`*^9, {3.8033948561181407`*^9, 3.8033948562370405`*^9}, 
   3.8033972740577445`*^9, {3.8046038041607537`*^9, 3.8046038044733067`*^9}, {
   3.8046038847668276`*^9, 3.8046038849543595`*^9}, 3.8046052174603443`*^9, 
   3.804605774073084*^9, 3.804606004086141*^9, 3.804866382852615*^9, {
   3.8057104019550767`*^9, 3.8057104022363744`*^9}, {3.8057112475432887`*^9, 
   3.805711247840214*^9}, 3.805712100199108*^9, 3.805712354331415*^9, {
   3.8057129673156385`*^9, 3.805712967456286*^9}, 3.8066685202004204`*^9, {
   3.806668599945153*^9, 3.806668600070174*^9}, {3.807651964866882*^9, 
   3.807651965429476*^9}, {3.8078698530055957`*^9, 3.807869853161872*^9}, {
   3.8078714491290703`*^9, 3.8078714492384624`*^9}, {3.8078727674364467`*^9, 
   3.807872767592723*^9}, {3.810032012871787*^9, 3.8100320130199013`*^9}, 
   3.812465369578644*^9, {3.819672284919863*^9, 3.8196722854302998`*^9}, 
   3.8196725370855665`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[616]:=",ExpressionUUID->"8ff6efc0-70fd-4c16-8f32-5cdad2a49b1b"],

Cell[TextData[{
 StyleBox["Processed pollock: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of processed pollock"
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628701371517`*^9}, {
   3.805710439713628*^9, 3.8057104440224447`*^9}, {3.8057107302249937`*^9, 
   3.8057107306625676`*^9}, {3.8196722892615757`*^9, 3.819672323331709*^9}, 
   3.8196725370855665`*^9, {3.8198159861786695`*^9, 
   3.819815988172221*^9}},ExpressionUUID->"120fd5b4-8c0c-44d8-a469-\
6a2922165a8f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"replpp", " ", "=", "  ", "0.30"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662888928058*^9}, {3.8016683952885675`*^9, 
   3.8016683957417665`*^9}, {3.801668478875883*^9, 3.801668478985276*^9}, {
   3.8016685230652122`*^9, 3.8016685337553577`*^9}, {3.8016924179886847`*^9, 
   3.801692428818405*^9}, {3.801692613897611*^9, 3.8016926140538864`*^9}, {
   3.8017799323647537`*^9, 3.801779958807993*^9}, {3.8033028561853733`*^9, 
   3.803302856451042*^9}, {3.8033032230937805`*^9, 3.80330322328131*^9}, 
   3.8033947515484324`*^9, {3.803394858820182*^9, 3.8033948589608297`*^9}, 
   3.8033972759582095`*^9, {3.804603811290928*^9, 3.8046038121817093`*^9}, {
   3.8046038868767943`*^9, 3.8046038870330772`*^9}, 3.8046052202578444`*^9, 
   3.804605775850915*^9, 3.804606005727049*^9, 3.804866384462251*^9, {
   3.8057104054094224`*^9, 3.805710405659464*^9}, {3.8057112505281506`*^9, 
   3.8057112508250732`*^9}, 3.805712102239932*^9, 3.805712356097327*^9, {
   3.8057129692859*^9, 3.805712969395293*^9}, 3.806668521919453*^9, {
   3.8066686022892947`*^9, 3.806668602429942*^9}, 3.807651969173785*^9, {
   3.8078698628353577`*^9, 3.807869862913496*^9}, {3.807871451410687*^9, 
   3.8078714515044527`*^9}, {3.8078727695930567`*^9, 
   3.8078727697024555`*^9}, {3.8100320154837976`*^9, 3.8100320156889696`*^9}, 
   3.8124653720515747`*^9, {3.819672333150078*^9, 3.8196723336414948`*^9}, 
   3.819672537086567*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[617]:=",ExpressionUUID->"ee491d5d-6374-49c8-9dc2-6c962d060566"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.5 Price Elasticity of Supply", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, {3.81967219811668*^9, 3.819672213143815*^9}, {
   3.819672363407755*^9, 3.819672372555518*^9}, 3.8196725593450384`*^9, {
   3.8198143101346893`*^9, 3.8198143131120086`*^9}, {3.8198143634432487`*^9, 
   3.8198143660582876`*^9}},ExpressionUUID->"ce987dca-5020-49fc-bb30-\
d5047dbabafb"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate and Interviews with \
Industry Participants.",
 FontSize->12]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725593450384`*^9, 3.8200124748939843`*^9, {3.8200126204719076`*^9, 
   3.820012620846199*^9}},
 FontSlant->"Italic",ExpressionUUID->"b39bcd75-3fe8-4aec-ab68-5fc748e511d8"],

Cell[TextData[StyleBox["U.S. landings of Pacific Cod",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9},ExpressionUUID->"960b6700-ec19-44ba-a95d-\
a47902d54cf3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ecb", " ", "=", "5.0"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.819672390113366*^9, 3.819672390250481*^9}, {3.8196725458248267`*^9, 
   3.8196725593450384`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[618]:=",ExpressionUUID->"0e61cea0-3282-45a7-bd8e-9e8e785d69eb"],

Cell[TextData[StyleBox["U.S. landings of Atlantic Cod",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7958646707227635`*^9, 
   3.7958646736180162`*^9}, {3.795864762086362*^9, 3.7958647626868277`*^9}, {
   3.798809612069295*^9, 3.79880961487617*^9}, {3.7997909064733047`*^9, 
   3.799790955552968*^9}, {3.8057105020839667`*^9, 3.8057105023652625`*^9}, 
   3.8057107234738903`*^9, {3.8196723996063604`*^9, 3.8196724038779583`*^9}, 
   3.8196725593450384`*^9},ExpressionUUID->"93ca01ee-3d72-4044-9963-\
44f54d0ee87f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eca", "=", " ", "5.0"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954546660574617`*^9, 
   3.7954546662656245`*^9}, {3.7958646824799027`*^9, 3.795864682863202*^9}, 
   3.795864757863079*^9, {3.79880990826432*^9, 3.7988099095174437`*^9}, {
   3.799098740375763*^9, 3.7990987673140197`*^9}, {3.799098812176347*^9, 
   3.7990988123634944`*^9}, 3.799098864657674*^9, {3.7990993552277937`*^9, 
   3.7990993554819937`*^9}, {3.799408887788796*^9, 3.79940888802398*^9}, {
   3.7994090198228416`*^9, 3.799409019930927*^9}, {3.799409723417536*^9, 
   3.7994097235536423`*^9}, {3.7997909162405777`*^9, 3.799790920850731*^9}, {
   3.7997909900806766`*^9, 3.7997909905963883`*^9}, 3.7997992100669823`*^9, {
   3.7998571692574015`*^9, 3.7998571695386934`*^9}, {3.7998576532739134`*^9, 
   3.7998576534301877`*^9}, {3.800142102859764*^9, 3.8001421029665775`*^9}, {
   3.800171512114951*^9, 3.8001715415935645`*^9}, 3.801663011160782*^9, {
   3.801780330020153*^9, 3.80178033011392*^9}, {3.8017804152151375`*^9, 
   3.80178041540267*^9}, {3.80339258789618*^9, 3.803392588036828*^9}, {
   3.810032839092947*^9, 3.810032839210039*^9}, {3.8100328768867517`*^9, 
   3.810032876964813*^9}, {3.819672549873184*^9, 3.8196725593450384`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[619]:=",ExpressionUUID->"56e55b30-89a1-4886-a913-0a728e7e84b9"],

Cell[TextData[StyleBox["U.S. landings of Alaskan Pollock",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7958646707227635`*^9, 
   3.7958646736180162`*^9}, {3.795864762086362*^9, 3.7958647626868277`*^9}, {
   3.798809612069295*^9, 3.79880961487617*^9}, {3.7997909064733047`*^9, 
   3.7997909128493814`*^9}, {3.7997910033329134`*^9, 
   3.7997910169789658`*^9}, {3.8057105036779757`*^9, 3.805710504006154*^9}, 
   3.8057107207859545`*^9, {3.8196724094226274`*^9, 3.819672415713926*^9}, 
   3.8196725593450384`*^9},ExpressionUUID->"25e03036-c666-4483-9a60-\
4b8de3ccf145"],

Cell[BoxData[
 RowBox[{
  RowBox[{"epw", "=", " ", "5.0"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954546660574617`*^9, 
   3.7954546662656245`*^9}, {3.7958646824799027`*^9, 3.795864682863202*^9}, 
   3.795864757863079*^9, {3.79880990826432*^9, 3.7988099095174437`*^9}, {
   3.799098740375763*^9, 3.7990987673140197`*^9}, {3.799098812176347*^9, 
   3.7990988123634944`*^9}, 3.799098864657674*^9, {3.7990993552277937`*^9, 
   3.7990993554819937`*^9}, {3.799408887788796*^9, 3.79940888802398*^9}, {
   3.7994090198228416`*^9, 3.799409019930927*^9}, {3.799409723417536*^9, 
   3.7994097235536423`*^9}, {3.7997909162405777`*^9, 3.799790920850731*^9}, 
   3.799791023479783*^9, 3.799799208160386*^9, {3.7998571720547523`*^9, 
   3.7998571723228827`*^9}, {3.7998576561193357`*^9, 3.79985765627561*^9}, {
   3.8001421051244326`*^9, 3.8001421052345715`*^9}, {3.800171514485777*^9, 
   3.8001715390023975`*^9}, 3.801663013083213*^9, {3.801780332567486*^9, 
   3.801780332661253*^9}, {3.80178041740302*^9, 3.8017804176061773`*^9}, {
   3.803392590521613*^9, 3.8033925907872806`*^9}, {3.8033972613669577`*^9, 
   3.80339726175926*^9}, {3.8035120082976303`*^9, 3.8035120083757677`*^9}, {
   3.8196725522061186`*^9, 3.8196725593450384`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[620]:=",ExpressionUUID->"5903b0ce-f117-49f8-a777-07431c955931"],

Cell[TextData[StyleBox["U.S. landings of Atlantic Pollock",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7958646707227635`*^9, 
   3.7958646736180162`*^9}, {3.795864762086362*^9, 3.7958647626868277`*^9}, {
   3.798809612069295*^9, 3.79880961487617*^9}, {3.7997909064733047`*^9, 
   3.7997909128493814`*^9}, {3.79979100613026*^9, 3.799791007564617*^9}, {
   3.805710505037571*^9, 3.805710505412632*^9}, {3.8057107159414115`*^9, 
   3.805710716941574*^9}, {3.8196724199685087`*^9, 3.8196724252359447`*^9}, 
   3.8196725593450384`*^9},ExpressionUUID->"68204397-1371-435b-af3b-\
a76ba499f904"],

Cell[BoxData[
 RowBox[{
  RowBox[{"epa", "=", "5.0"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954546660574617`*^9, 
   3.7954546662656245`*^9}, {3.7958646824799027`*^9, 3.795864682863202*^9}, 
   3.795864757863079*^9, {3.79880990826432*^9, 3.7988099095174437`*^9}, {
   3.799098740375763*^9, 3.7990987673140197`*^9}, {3.799098812176347*^9, 
   3.7990988123634944`*^9}, 3.799098864657674*^9, {3.7990993552277937`*^9, 
   3.7990993554819937`*^9}, {3.799408887788796*^9, 3.79940888802398*^9}, {
   3.7994090198228416`*^9, 3.799409019930927*^9}, {3.799409723417536*^9, 
   3.7994097235536423`*^9}, {3.7997909162405777`*^9, 3.799790920850731*^9}, 
   3.7997910270742493`*^9, 3.799799206128768*^9, {3.7998571757575684`*^9, 
   3.79985717608576*^9}, {3.799857659149685*^9, 3.799857659259077*^9}, {
   3.800142107684913*^9, 3.8001421077808733`*^9}, 3.8001437600516357`*^9, 
   3.8001438254796968`*^9, {3.8001715172149286`*^9, 3.8001715369855385`*^9}, 
   3.8016630151148024`*^9, {3.801780334692868*^9, 3.8017803347866364`*^9}, {
   3.8017804193564806`*^9, 3.8017804195752687`*^9}, {3.803392592834691*^9, 
   3.8033925929284563`*^9}, {3.819672554304859*^9, 3.8196725593460393`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[621]:=",ExpressionUUID->"187aeac4-0a18-4a09-9eed-f30313a792d3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.6 Conversion Factors", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, {3.81967219811668*^9, 3.819672213143815*^9}, {
   3.819672363407755*^9, 3.819672372555518*^9}, {3.8196724504932003`*^9, 
   3.8196724570907135`*^9}, 3.8196725668572683`*^9, {3.819814317458398*^9, 
   3.8198143176155205`*^9}, {3.819814368847461*^9, 3.819814369193731*^9}, {
   3.8199024597734833`*^9, 
   3.819902461929121*^9}},ExpressionUUID->"cb23405b-de33-496e-8c8d-\
49a4fe2c6b7e"],

Cell[TextData[StyleBox["Source: Conversion factors were obtained from NOAA \
Fisheries",
 FontSize->12]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725593450384`*^9, 3.8198384238111687`*^9, {3.819839089463401*^9, 
   3.8198391080298843`*^9}, {3.8198393115996747`*^9, 3.819839330504422*^9}},
 FontSlant->"Italic",ExpressionUUID->"d3597c75-e2e2-4f10-86ad-5b9a7071fc9a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cr", " ", "=", " ", "1.39"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954546660574617`*^9, 
   3.7954546662656245`*^9}, {3.7958646824799027`*^9, 3.795864682863202*^9}, 
   3.795864757863079*^9, {3.79880990826432*^9, 3.7988099095174437`*^9}, {
   3.799098740375763*^9, 3.7990987673140197`*^9}, {3.799098812176347*^9, 
   3.7990988123634944`*^9}, 3.799098864657674*^9, {3.7990993552277937`*^9, 
   3.7990993554819937`*^9}, {3.799408887788796*^9, 3.79940888802398*^9}, {
   3.7994090198228416`*^9, 3.799409019930927*^9}, {3.799409723417536*^9, 
   3.7994097235536423`*^9}, {3.7997909162405777`*^9, 3.799790920850731*^9}, 
   3.7997910270742493`*^9, 3.799799206128768*^9, {3.7998571757575684`*^9, 
   3.79985717608576*^9}, {3.799857659149685*^9, 3.799857659259077*^9}, {
   3.800142107684913*^9, 3.8001421077808733`*^9}, 3.8001437600516357`*^9, 
   3.8001438254796968`*^9, {3.8001715172149286`*^9, 3.8001715369855385`*^9}, 
   3.8016630151148024`*^9, {3.801780334692868*^9, 3.8017803347866364`*^9}, {
   3.8017804193564806`*^9, 3.8017804195752687`*^9}, {3.803392592834691*^9, 
   3.8033925929284563`*^9}, {3.804603742628921*^9, 3.8046037444417477`*^9}, 
   3.8196725668582687`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[622]:=",ExpressionUUID->"58804126-1412-43db-bc71-7a15e6e4ea36"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2. Data Inputs",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.795452962713849*^9}, {
  3.8196715794204283`*^9, 3.8196715805723763`*^9}, {3.819672652231064*^9, 
  3.819672658049889*^9}},ExpressionUUID->"3bff5bdf-b9e3-4e90-b493-\
eafdaf8b8442"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.1 U.S. Landings Quantities and Prices", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672709332239*^9}, 
   3.819814602882104*^9},ExpressionUUID->"63910411-53e3-4690-898a-\
c7f3d58e4156"],

Cell[TextData[StyleBox["Source: National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries).\
\[NonBreakingSpace]Fisheries of the United States 2018. Current Fishery \
Statistics No. 2018. U.S. Department of Commerce. Silver Spring MD:\
\[NonBreakingSpace]NOAA,\[NonBreakingSpace]February 2020. \
https://www.fisheries.noaa.gov/resource/document/fisheries-united-states-2018-\
report.\[NonBreakingSpace]",
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, 
   3.819814602882104*^9, {3.8198155788251867`*^9, 3.8198155811910124`*^9}},
 FontSize->12,ExpressionUUID->"25666e5b-dc9d-4eac-a5c5-b2cb1597a376"],

Cell[TextData[StyleBox["Alaskan Pollock",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.7997922037144547`*^9, 
   3.799792207899268*^9}, {3.805710690264936*^9, 3.8057106905149765`*^9}, {
   3.819814387925336*^9, 3.819814398951932*^9}, 
   3.819814602882104*^9},ExpressionUUID->"f0b2e34b-bfe7-48ba-a942-\
d73266fd09be"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qpwd0", " ", "=", "1525855000"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.804605480596161*^9, 3.8046054851906567`*^9}, 
   3.805710242934682*^9, {3.8198144014718995`*^9, 3.81981440431211*^9}, 
   3.819814602882104*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[623]:=",ExpressionUUID->"400c8e39-93cb-4fef-a9fb-41930d195d3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ppwd0", " ", "=", "0.2957"}], ";"}], "  ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8124656198692536`*^9, 
   3.8124656226444206`*^9}, {3.8198144068991303`*^9, 3.8198144199593086`*^9}, 
   3.819814602882104*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[624]:=",ExpressionUUID->"cfe43c25-be78-4227-bac0-674e47880d70"],

Cell[TextData[StyleBox["Atlantic Pollock",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791178502163*^9}, {3.799792213481472*^9, 
   3.799792218529134*^9}, {3.805710687655131*^9, 3.8057106879051714`*^9}, {
   3.8198144362520094`*^9, 3.8198144386769032`*^9}, 
   3.819814602882104*^9},ExpressionUUID->"bcc913a9-8045-4166-8ce8-\
85640c3ec833"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qpad0", " ", "=", "3074000"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8046054937386274`*^9, 3.804605496332412*^9}, 
   3.8198144441701856`*^9, 3.8198146028831053`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[625]:=",ExpressionUUID->"d09dd51b-82ec-49d3-8302-dd49184416cc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ppad0", " ", "=", "1.7339"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.812465640260192*^9, 3.812465643882024*^9}, 
   3.8198144479171085`*^9, 3.8198146028831053`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[626]:=",ExpressionUUID->"bbe25b2d-bbf5-45c8-98c1-b268a76c3c79"],

Cell[TextData[StyleBox["Pacific Cod",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.79979222101047*^9}, {
   3.8057106849671946`*^9, 3.8057106852328625`*^9}, {3.819814508187276*^9, 
   3.8198145096193905`*^9}, 
   3.8198146028831053`*^9},ExpressionUUID->"28deb856-a428-42d4-96bb-\
906498681a27"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qcbd0", " ", "=", "232578000"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, 
   3.799799229666746*^9, {3.801662420395461*^9, 3.8016624244586344`*^9}, {
   3.804605503505072*^9, 3.804605506364913*^9}, 3.8198145192539024`*^9, 
   3.8198146028831053`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[627]:=",ExpressionUUID->"a6284bc6-b3b5-4538-8fac-ffe370475df7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pcbd0", " ", "=", "1.0280"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.812465669710205*^9, 3.812465672626487*^9}, 
   3.819814525224556*^9, 3.8198146028831053`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[628]:=",ExpressionUUID->"f518a895-fc64-4c1b-8016-df1a33c9f6f1"],

Cell[TextData[StyleBox["Atlantic Cod",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.7997912085469627`*^9}, {3.7997922230140877`*^9, 
   3.799792223514166*^9}, {3.8057106828574705`*^9, 3.8057106831387672`*^9}, {
   3.8198145127218103`*^9, 3.819814514223981*^9}, 
   3.8198146028831053`*^9},ExpressionUUID->"ff8117d2-a6f1-4ee9-8557-\
c454d0886015"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qcad0", " ", "=", "976000"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, 
   3.7997992314252977`*^9, {3.801662432069269*^9, 3.8016624339758315`*^9}, {
   3.8046055112250767`*^9, 3.8046055130534925`*^9}, 3.819814520519888*^9, 
   3.8198146028831053`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[629]:=",ExpressionUUID->"08566025-7eee-454b-b072-70e11923a542"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pcad0", " ", "=", "4.8945"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.81246567649451*^9, 3.8124656790835323`*^9}, 3.8198145267737675`*^9, 
   3.8198146028831053`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[630]:=",ExpressionUUID->"780be44e-d362-41c6-bc75-eb26841e8c10"],

Cell[BoxData[
 RowBox[{
  RowBox[{"shrca", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"qcad0", "/", 
     RowBox[{"(", 
      RowBox[{"qcad0", "+", "qcbd0"}], ")"}]}], "]"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7998005293549185`*^9, 3.7998005547170005`*^9}, {
   3.7998024244256325`*^9, 3.79980246747289*^9}, {3.799881817375252*^9, 
   3.7998818186939316`*^9}, 3.7998818979089775`*^9, {3.801693253795901*^9, 
   3.801693262790891*^9}, 3.801779857081294*^9, 3.8198146028841057`*^9},
 CellLabel->
  "In[631]:=",ExpressionUUID->"4efaff18-5f26-453e-89e9-fb6591dd7d2f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.2 U.S. Processing Production Quantities and \
Prices", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672733348008*^9}, {
   3.8196727961837325`*^9, 3.8196728038250227`*^9}, 
   3.819814751753172*^9},ExpressionUUID->"0e9f0534-43ec-432b-935c-\
097a2e6c4178"],

Cell[TextData[StyleBox["Source: National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries).\
\[NonBreakingSpace]Fisheries of the United States 2018. Current Fishery \
Statistics No. 2018. U.S. Department of Commerce. Silver Spring MD:\
\[NonBreakingSpace]NOAA,\[NonBreakingSpace]February 2020. \
https://www.fisheries.noaa.gov/resource/document/fisheries-united-states-2018-\
report.\[NonBreakingSpace] ",
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, {
  3.819814602882104*^9, 3.819814670599902*^9}, {3.8198147375350885`*^9, 
  3.819814751753172*^9}, {3.8198155956591797`*^9, 3.8198155972494073`*^9}},
 FontSize->12,ExpressionUUID->"7fa61df1-1cc7-44b8-9339-1e77aab25d94"],

Cell[TextData[StyleBox["Processed Alaskan Pollock",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9},ExpressionUUID->"4ce2cc24-0690-4af8-bc7c-\
58b9e47b8097"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qpwpd0", " ", "=", "200304000"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799792269024434*^9, 3.7997922702746286`*^9}, {3.799792391615404*^9, 
   3.7997923949440475`*^9}, 3.799799234779944*^9, {3.799802378003236*^9, 
   3.799802397414998*^9}, {3.799880426054372*^9, 3.7998804263057685`*^9}, {
   3.799880719684866*^9, 3.7998807350717306`*^9}, {3.799880780414199*^9, 
   3.799880820290639*^9}, {3.7998810830787735`*^9, 3.79988108723232*^9}, {
   3.801688363756626*^9, 3.8016883672428007`*^9}, {3.8016919446668773`*^9, 
   3.801691953962931*^9}, {3.8017771151212883`*^9, 3.8017771205284348`*^9}, {
   3.803124717120387*^9, 3.8031247175847473`*^9}, 3.8031247776456175`*^9, {
   3.804605529215213*^9, 3.8046055295590215`*^9}, 3.819814751753172*^9, {
   3.819814845146987*^9, 3.819814846254856*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[632]:=",ExpressionUUID->"fb154a27-7923-4181-bb99-8c4111e6cec7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ppwpd0", " ", "=", " ", "3.0378"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7997924489509325`*^9, 3.7997924690976133`*^9}, 
   3.799799251628475*^9, 3.7998024891341224`*^9, 3.7998523918364997`*^9, {
   3.799881274751879*^9, 3.7998812960566254`*^9}, {3.8016920460131855`*^9, 
   3.8016920481385403`*^9}, {3.8124661048213615`*^9, 3.812466105391805*^9}, 
   3.8198147517541723`*^9, {3.819814848928937*^9, 3.8198148514919386`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[633]:=",ExpressionUUID->"aacd9766-9a85-4a37-a3d8-4308b11c83a1"],

Cell[TextData[StyleBox["Processed Atlantic Pollock",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.7998811930966015`*^9, 
   3.7998811938750515`*^9}, {3.8057105325875816`*^9, 3.8057105329626427`*^9}, 
   3.8057106033749714`*^9, {3.8057106785442705`*^9, 3.8057106788255663`*^9}, {
   3.81981469765099*^9, 3.8198147027319517`*^9}, 
   3.8198147517541723`*^9},ExpressionUUID->"5b73b9ab-13cf-48f7-9d78-\
99d5d583aeaa"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qpapd0", " ", "=", "358000"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799792269024434*^9, 3.7997922702746286`*^9}, {3.799792391615404*^9, 
   3.7997923949440475`*^9}, 3.799799234779944*^9, {3.799802378003236*^9, 
   3.799802397414998*^9}, {3.799880426054372*^9, 3.7998804263057685`*^9}, {
   3.799880719684866*^9, 3.7998807350717306`*^9}, {3.799880780414199*^9, 
   3.799880820290639*^9}, {3.7998810830787735`*^9, 3.7998811148576927`*^9}, {
   3.801688375385357*^9, 3.801688378226203*^9}, {3.801691962386196*^9, 
   3.8016919651053944`*^9}, {3.801777139834798*^9, 3.8017771401629763`*^9}, {
   3.803120577836057*^9, 3.8031205795053616`*^9}, {3.803124808381603*^9, 
   3.8031248105042596`*^9}, {3.803124897746336*^9, 3.803124899974074*^9}, {
   3.8046055240240593`*^9, 3.8046055244928885`*^9}, 3.8198147517541723`*^9, {
   3.8198148535885706`*^9, 3.819814854906596*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[634]:=",ExpressionUUID->"51cf68ff-7d6d-4258-b370-c883d69bded9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ppapd0", " ", "=", " ", "7.7067"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7997924489509325`*^9, 3.7997924690976133`*^9}, 
   3.799799251628475*^9, 3.7998024891341224`*^9, 3.7998523918364997`*^9, {
   3.799881274751879*^9, 3.7998813121663556`*^9}, {3.801692053420714*^9, 
   3.8016920567650166`*^9}, {3.8124661119699154`*^9, 3.812466112707488*^9}, 
   3.8198147517541723`*^9, {3.8198148569161673`*^9, 3.8198148597934537`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[635]:=",ExpressionUUID->"3f2cd940-518b-4740-abd1-69f0eb20150d"],

Cell[TextData[StyleBox["Processed Atlantic Cod",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.7997912085469627`*^9}, {3.7997922230140877`*^9, 
   3.7997922655238886`*^9}, 3.7998804358996754`*^9, {3.799881196859279*^9, 
   3.799881205080474*^9}, {3.7998816736394157`*^9, 3.7998816746548605`*^9}, {
   3.805710604703316*^9, 3.805710605078379*^9}, {3.8057106755437775`*^9, 
   3.80571067577819*^9}, {3.819814707897979*^9, 3.819814712237364*^9}, 
   3.8198147517541723`*^9},ExpressionUUID->"4b0869e3-12bf-46f3-97ff-\
d8b6e056e331"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qcapd0", " ", "=", 
    RowBox[{"28288000", " ", "shrca"}]}], " ", ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997923139581275`*^9, 3.7997923140987744`*^9}, {3.799792408287326*^9, 
   3.799792410381402*^9}, 3.7997992364364944`*^9, {3.799802406167694*^9, 
   3.7998024102621355`*^9}, {3.7998804294776783`*^9, 
   3.7998804834951377`*^9}, {3.7998808621419783`*^9, 3.799880868339183*^9}, {
   3.7998816774812517`*^9, 3.7998816859971795`*^9}, {3.7998817802792935`*^9, 
   3.799881811438492*^9}, {3.801688385195972*^9, 3.801688391243819*^9}, {
   3.8016919709344873`*^9, 3.8016919746538486`*^9}, {3.801777043819872*^9, 
   3.8017770523212748`*^9}, 3.8031205841019506`*^9, 3.80312415027405*^9, {
   3.8031245937351065`*^9, 3.8031245945357327`*^9}, 3.803511923961904*^9, {
   3.8046055340494003`*^9, 3.8046055342994423`*^9}, 3.8198147517541723`*^9, {
   3.8198148616548615`*^9, 3.8198148636784368`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[636]:=",ExpressionUUID->"6067bc99-e1a2-406a-b269-01a61d357bb6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pcapd0", " ", "=", " ", "11.7518"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7997924714261017`*^9, 3.799792481884165*^9}, 
   3.7997992535336423`*^9, {3.799802478866764*^9, 3.7998024836019382`*^9}, 
   3.799852394780935*^9, {3.7998525724342146`*^9, 3.7998526503267426`*^9}, {
   3.7998813212529206`*^9, 3.7998813258942003`*^9}, 3.7998817507197275`*^9, {
   3.8016920680715156`*^9, 3.8016920698999405`*^9}, {3.8124661187341695`*^9, 
   3.812466120013163*^9}, 3.8198147517541723`*^9, {3.8198148665686927`*^9, 
   3.8198148690025873`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[637]:=",ExpressionUUID->"889c4ac7-296b-4a31-aec4-ecc1be450169"],

Cell[TextData[StyleBox["Processed Pacific Cod",
 FontWeight->"Bold",
 FontColor->GrayLevel[0]]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.7997912085469627`*^9}, {3.7997922230140877`*^9, 
   3.7997922655238886`*^9}, 3.7998804358996754`*^9, {3.799881196859279*^9, 
   3.799881205080474*^9}, {3.7998816736394157`*^9, 3.7998816954360437`*^9}, {
   3.8057106063598375`*^9, 3.8057106067348986`*^9}, {3.805710672762074*^9, 
   3.8057106730121164`*^9}, {3.8198147170781364`*^9, 3.819814719802264*^9}, 
   3.8198147517541723`*^9},ExpressionUUID->"b2439711-a2cd-49da-ad65-\
bf6d0aca1022"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qcbpd0", " ", "=", 
    RowBox[{"28288000", 
     RowBox[{"(", 
      RowBox[{"1", "-", "shrca"}], ")"}]}]}], ";"}], "  ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997923139581275`*^9, 3.7997923140987744`*^9}, {3.799792408287326*^9, 
   3.799792410381402*^9}, 3.7997992364364944`*^9, {3.799802406167694*^9, 
   3.7998024102621355`*^9}, {3.7998804294776783`*^9, 
   3.7998804834951377`*^9}, {3.7998808621419783`*^9, 3.799880868339183*^9}, {
   3.7998816774812517`*^9, 3.7998817043568497`*^9}, {3.799881785405162*^9, 
   3.7998818139856668`*^9}, 3.801688397791747*^9, {3.8016919795529437`*^9, 
   3.801691981772059*^9}, {3.801777084237687*^9, 3.8017770921608734`*^9}, 
   3.803120587208376*^9, {3.803124569866482*^9, 3.803124576250463*^9}, 
   3.8035119270570507`*^9, 3.8046055381282034`*^9, 3.8198147517551727`*^9, {
   3.8198148714865274`*^9, 3.819814872984693*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[638]:=",ExpressionUUID->"b7e85291-6808-40e4-8abd-95af24383ed5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pcbpd0", " ", "=", " ", "2.47"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7997924714261017`*^9, 3.799792481884165*^9}, 
   3.7997992535336423`*^9, {3.799802478866764*^9, 3.7998024836019382`*^9}, 
   3.799852394780935*^9, {3.7998525724342146`*^9, 3.7998526503267426`*^9}, {
   3.7998813212529206`*^9, 3.7998813258942003`*^9}, {3.7998817507197275`*^9, 
   3.799881761697983*^9}, {3.801692074385059*^9, 3.8016920756196404`*^9}, {
   3.8016933530355854`*^9, 3.8016934051010036`*^9}, 3.8016934685216002`*^9, {
   3.801777626073676*^9, 3.801777627073843*^9}, {3.8017779733758173`*^9, 
   3.801777976610858*^9}, {3.801779494150278*^9, 3.801779495791156*^9}, {
   3.8017795343161173`*^9, 3.8017795359101133`*^9}, {3.803398336960243*^9, 
   3.803398363858056*^9}, {3.8057102649652634`*^9, 3.805710283318344*^9}, {
   3.8057103180908623`*^9, 3.80571035706662*^9}, {3.8196729752408686`*^9, 
   3.8196729755541463`*^9}, 3.8198147517551727`*^9, {3.8198148750973434`*^9, 
   3.819814879543807*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[639]:=",ExpressionUUID->"6363b9cc-dee9-4996-aa99-2a636ee3de52"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.3 Import Quantities and Prices", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672733348008*^9}, {
   3.819672809477676*^9, 3.8196728096938534`*^9}, 
   3.8198152044580364`*^9},ExpressionUUID->"e69dc710-53d9-4a72-a0d8-\
b568d6d6d7a1"],

Cell[TextData[StyleBox["Source: IUU Estimate Database as described in Chapter \
3 of the report. Note that  Alaskan pollock refers to Walleye pollock in the \
database, and Pacific cod refers to Pacific/Greenland cod in the database.",
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, 
   3.819814602882104*^9, {3.8198147741606445`*^9, 3.8198147935287457`*^9}, 
   3.8198152044580364`*^9, 3.820012478192554*^9, {3.8208559831037273`*^9, 
   3.8208560402321887`*^9}},
 FontSize->12,ExpressionUUID->"ef22ff47-6cc0-48cf-8c4a-99a89ebfb93a"],

Cell[TextData[StyleBox["Unprocessed Pollock",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 
   3.8198152044580364`*^9},ExpressionUUID->"abfd6d65-a0da-4d04-93c3-\
174769637def"],

Cell["Total imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9},ExpressionUUID->"0d85f90c-ac64-477f-9323-\
d0a42a6e7ba4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qput0", " ", "=", 
    StyleBox["1977996",
     FontColor->GrayLevel[0]]}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8046039123652368`*^9, 3.804603914540886*^9}, {
   3.8124654816862574`*^9, 3.812465486588089*^9}, {3.816981771103471*^9, 
   3.8169817785926394`*^9}, {3.8169818981380587`*^9, 
   3.8169819030766554`*^9}, {3.8188021021160808`*^9, 3.818802107025921*^9}, {
   3.819814805624173*^9, 3.81981483497906*^9}, 3.8198152044590373`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[640]:=",ExpressionUUID->"ae10a51e-203c-49fc-b34c-3bab85f2f593"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pput0", " ", "=", "2.54326"}], ";", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.8016627089120474`*^9, 3.801662709002471*^9}, {3.8046040287922363`*^9, 
   3.804604030120595*^9}, {3.8124660581911383`*^9, 3.8124660601196365`*^9}, {
   3.8169821398255515`*^9, 3.816982143913066*^9}, {3.8169821863873167`*^9, 
   3.816982207204776*^9}, {3.8169823558876905`*^9, 3.8169823664016337`*^9}, {
   3.818802332379305*^9, 3.8188023436961*^9}, {3.819814809008814*^9, 
   3.819814841082823*^9}, 3.8198152044590373`*^9, {3.8199016440767956`*^9, 
   3.8199016575892267`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[641]:=",ExpressionUUID->"5d0f8d58-2d52-4700-ab9a-726ed981e429"],

Cell["Illegal imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.819815110759081*^9, 3.819815113016839*^9}, 
   3.8198152044590373`*^9},ExpressionUUID->"6d44007d-99b4-4071-a6b1-\
aa3ec7cc1229"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qpui0", " ", "=", " ", 
    StyleBox["174230",
     FontColor->GrayLevel[0]]}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.8046039783483834`*^9, 
   3.8046039803956065`*^9}, {3.8124655398867464`*^9, 
   3.8124655416581273`*^9}, {3.8169818294075313`*^9, 
   3.8169818368032446`*^9}, {3.8169821006579924`*^9, 
   3.8169821019296923`*^9}, {3.818802212214912*^9, 3.81880221711372*^9}, {
   3.8198150584172697`*^9, 3.8198150633331027`*^9}, 3.8198152044590373`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[642]:=",ExpressionUUID->"ef17bc6d-a4c5-40a9-85a0-e1e90d4683ba"],

Cell[TextData[StyleBox["Unprocessed Cod",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, {3.799791442102678*^9, 
   3.7997914423839736`*^9}, 3.804605550505267*^9, {3.8057106190037317`*^9, 
   3.8057106196913433`*^9}, {3.8057106669798803`*^9, 
   3.8057106672611766`*^9}, {3.8198148962738523`*^9, 3.819814898232377*^9}, 
   3.8198152044590373`*^9},ExpressionUUID->"d9aa3b4d-191b-46e8-b6d9-\
0c7164d1e004"],

Cell["Total imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044590373`*^9},ExpressionUUID->"408ab314-0451-41ed-9556-\
fc7dbbd186b7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcut0", " ", "=", 
   StyleBox["5792445",
    FontColor->GrayLevel[0]]}], ";", " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8046039190851774`*^9, 3.804603922839331*^9}, {3.8124654945172863`*^9, 
   3.812465497212391*^9}, {3.816981783346347*^9, 3.816981792103532*^9}, 
   3.816981994288682*^9, {3.818802130299121*^9, 3.818802134059061*^9}, {
   3.8198149029140277`*^9, 3.819814910052597*^9}, 3.8198152044590373`*^9, {
   3.81990163739664*^9, 3.819901639617354*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[643]:=",ExpressionUUID->"9485f714-e9cc-42a5-989a-eec3da2d3d9d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcut0", " ", "=", "4.67084"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.7998573699300957`*^9, 
   3.7998573819982357`*^9}, {3.8046040386678905`*^9, 3.804604039199233*^9}, {
   3.8124660658711042`*^9, 3.8124660662443943`*^9}, {3.8169821476757746`*^9, 
   3.8169821512609663`*^9}, {3.816982251348691*^9, 3.8169822650244017`*^9}, {
   3.8188023707831526`*^9, 3.818802382903573*^9}, {3.8198149072854366`*^9, 
   3.819814914425006*^9}, 3.8198152044590373`*^9, {3.81990161867719*^9, 
   3.8199016317512817`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[644]:=",ExpressionUUID->"578b9a02-f6f7-480e-8b1c-cd3f8f9ad6f1"],

Cell["Illegal imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.819815041376981*^9, 3.8198150451809483`*^9}, 
   3.819815204460038*^9},ExpressionUUID->"391bbfc6-c5be-459d-b82b-\
c63a1a8779ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcui0", " ", "=", 
   StyleBox["352828",
    FontColor->GrayLevel[0]]}], ";", " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8046039854431744`*^9, 3.80460398691218*^9}, {
   3.812465548541509*^9, 3.812465550776257*^9}, {3.8169818411553097`*^9, 
   3.816981846586728*^9}, {3.81698205102682*^9, 3.8169820546969395`*^9}, {
   3.8188022359773808`*^9, 3.81880224018365*^9}, {3.8198150942522073`*^9, 
   3.819815105014597*^9}, 3.819815204460038*^9, {3.819901613241995*^9, 
   3.8199016142317586`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[645]:=",ExpressionUUID->"5869e936-4b85-417d-9535-9acd134d3627"],

Cell[TextData[StyleBox["Processed Pollock",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791338157285*^9}, 3.804605547395372*^9, {
   3.805710620691506*^9, 3.805710620988428*^9}, {3.8057106642882338`*^9, 
   3.805710664585157*^9}, {3.8198149192787905`*^9, 3.819814921523547*^9}, 
   3.819815204460038*^9},ExpressionUUID->"4d9c96b8-8274-40c3-81d2-\
979c7c1881f1"],

Cell["Total imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.8198151315232687`*^9, 3.8198151329824047`*^9}, 
   3.819815204460038*^9},ExpressionUUID->"4d62d6cc-3a72-4947-b2c6-\
fbcbb1fc7529"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qppt0", " ", "=", 
    StyleBox["48591750",
     FontColor->GrayLevel[0]]}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913515716534`*^9}, 3.799792288313766*^9, {3.8016884220357356`*^9, 
   3.8016884253643956`*^9}, {3.8046039389524016`*^9, 
   3.8046039418457108`*^9}, {3.8124655048753805`*^9, 
   3.8124655090376344`*^9}, {3.8169817988835173`*^9, 
   3.8169818081789436`*^9}, {3.816981924749666*^9, 3.8169819273655467`*^9}, {
   3.818802155094507*^9, 3.818802159210717*^9}, {3.819814930560585*^9, 
   3.8198149365052185`*^9}, 3.819815204460038*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[646]:=",ExpressionUUID->"92f3b465-0c73-4bf9-aeac-06ed8b0e44c5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pppt0", " ", "=", "2.86468"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913515716534`*^9}, {3.7997919991389465`*^9, 3.7997920268172665`*^9}, 
   3.799792434087906*^9, {3.804604049772217*^9, 3.8046040503816953`*^9}, {
   3.8124660758348446`*^9, 3.8124660782267027`*^9}, {3.816982158096963*^9, 
   3.816982170548552*^9}, {3.8169822219718466`*^9, 3.8169822292938223`*^9}, {
   3.818802421369469*^9, 3.8188024299611464`*^9}, {3.8198149336389832`*^9, 
   3.8198149404092636`*^9}, 3.819815204460038*^9, {3.8199015942753544`*^9, 
   3.8199016053729205`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[647]:=",ExpressionUUID->"bc60f9f2-e26c-4d4b-a631-d2c52a006534"],

Cell["Illegal imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.819815127875423*^9, 3.819815129626787*^9}, 
   3.819815204460038*^9},ExpressionUUID->"763c99c5-8380-4785-aa0e-\
8f9905c3e59d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qppi0", " ", "=", 
    StyleBox["6889089",
     FontColor->GrayLevel[0]]}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.799791406352083*^9, 3.7997914064927316`*^9}, {3.799791653997706*^9, 
   3.799791655624315*^9}, 3.8001412247486925`*^9, {3.801688058660629*^9, 
   3.801688077723925*^9}, {3.804603993788782*^9, 3.8046039968677073`*^9}, {
   3.8124655584172287`*^9, 3.8124655624433727`*^9}, {3.8169818526124725`*^9, 
   3.816981860199212*^9}, {3.816982116814834*^9, 3.81698212041835*^9}, {
   3.818802257480093*^9, 3.8188022606945915`*^9}, {3.8198151515628924`*^9, 
   3.81981516017451*^9}, 3.819815204460038*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[648]:=",ExpressionUUID->"79e20383-f91e-4c86-8cec-44a95e8a738c"],

Cell[TextData[StyleBox["Processed Cod",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791338157285*^9}, {3.799791446150216*^9, 
   3.799791446431512*^9}, 3.804605544582402*^9, {3.80571062222301*^9, 
   3.805710622644954*^9}, {3.8057106609126854`*^9, 3.805710661240864*^9}, {
   3.8198149248181086`*^9, 3.8198149263372912`*^9}, 
   3.8198152044610386`*^9},ExpressionUUID->"7990c4b7-1e23-4d49-9783-\
a426c382c49c"],

Cell["Total imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.8198151365121584`*^9, 3.8198151384376574`*^9}, 
   3.8198152044610386`*^9},ExpressionUUID->"6f0804f9-7bb4-4335-88a0-\
104570b45a16"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcpt0", "=", "67589782"}], ";", " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913515716534`*^9}, {3.7997914806575565`*^9, 3.799791492285414*^9}, 
   3.799792292892344*^9, {3.801688433507552*^9, 3.801688437008115*^9}, {
   3.804603947099145*^9, 3.8046039562887535`*^9}, {3.8124655157929125`*^9, 
   3.8124655229304905`*^9}, {3.816981811913853*^9, 3.8169818203009863`*^9}, {
   3.8169819589867783`*^9, 3.8169819667592106`*^9}, {3.816982004142314*^9, 
   3.8169820215614166`*^9}, {3.818802177920258*^9, 3.818802182171562*^9}, {
   3.8198149772369733`*^9, 3.8198150093710303`*^9}, 3.8198152044610386`*^9, {
   3.819901572777761*^9, 3.8199015805367503`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[649]:=",ExpressionUUID->"56b39f13-016a-4733-8a4d-8ef9518d0c53"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcpt0", " ", "=", "8.11826"}], ";", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913515716534`*^9}, {3.7997914806575565`*^9, 3.799791492285414*^9}, {
   3.799792003015487*^9, 3.799792003234271*^9}, {3.7997920449299383`*^9, 
   3.7997920464949055`*^9}, 3.799792437885373*^9, {3.799852641934455*^9, 
   3.799852655952694*^9}, {3.799881262629506*^9, 3.7998812710976224`*^9}, {
   3.8004562427355976`*^9, 3.800456245750654*^9}, {3.800456291422464*^9, 
   3.8004562921410713`*^9}, {3.8004563286768365`*^9, 3.8004563320167737`*^9}, 
   3.8016881243469477`*^9, {3.804604059746694*^9, 3.8046040607937403`*^9}, {
   3.8124660857795696`*^9, 3.812466086713295*^9}, {3.8169821739815874`*^9, 
   3.8169821785743933`*^9}, {3.8169822815085115`*^9, 3.816982299269012*^9}, {
   3.818802459812347*^9, 3.818802474052415*^9}, 3.8198149809528728`*^9, {
   3.819815011532714*^9, 3.819815014412961*^9}, 3.8198152044610386`*^9, {
   3.8199015545627007`*^9, 3.819901583172785*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[650]:=",ExpressionUUID->"48fd1397-4f17-42ba-b7bd-d46d9f217762"],

Cell["Illegal imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.799061046869288*^9, 3.799061055183115*^9}, {
   3.799791360292451*^9, 3.7997914000229187`*^9}, {3.799791698056525*^9, 
   3.7997916983378224`*^9}, 3.800141223496544*^9, 3.8033920720709105`*^9, {
   3.8057107024394817`*^9, 3.8057107029396887`*^9}, {3.8198151442031507`*^9, 
   3.8198151475787854`*^9}, 
   3.8198152044610386`*^9},ExpressionUUID->"df318f12-7498-42c0-8dd0-\
12c54a37ad50"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcpi0", " ", "=", 
   StyleBox["4781077",
    FontColor->GrayLevel[0]]}], 
  StyleBox[";",
   FontColor->GrayLevel[0]], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914162581167`*^9, 3.7997914186669765`*^9}, {3.7997917068141403`*^9, 
   3.79979170801746*^9}, {3.8001412144983597`*^9, 3.800141217590801*^9}, {
   3.8016880669070473`*^9, 3.801688073925213*^9}, {3.8046040016031804`*^9, 
   3.804604005635125*^9}, {3.8124655668948507`*^9, 3.8124655696530104`*^9}, {
   3.816981863852321*^9, 3.8169818729943438`*^9}, {3.8169820690740356`*^9, 
   3.816982073395441*^9}, {3.8188022947970963`*^9, 3.818802304204407*^9}, {
   3.819815164863166*^9, 3.8198151738381667`*^9}, 3.8198152044610386`*^9, {
   3.819901541073289*^9, 3.819901548813263*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[651]:=",ExpressionUUID->"df31cb57-f8ab-4714-a3aa-5b59ffcdf3bf"],

Cell["Calculation of legal imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.799061046869288*^9, 3.799061055183115*^9}, {
  3.799791360292451*^9, 3.7997914000229187`*^9}, {3.799791698056525*^9, 
  3.7997916983378224`*^9}, {3.7997917503203683`*^9, 3.799791755353649*^9}, {
  3.800692812549324*^9, 3.800692822846528*^9}, {3.8198151796337233`*^9, 
  3.8198152044610386`*^9}},ExpressionUUID->"cd6f868f-52a1-4b7d-bdd8-\
1e0c25075729"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qpul0", " ", "=", " ", 
   RowBox[{"qput0", "-", "qpui0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, 3.8198152044610386`*^9, 
   3.819900420957785*^9},
 CellLabel->
  "In[652]:=",ExpressionUUID->"411685ec-4e7e-4e82-ae79-6c9d904a1b83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcul0", " ", "=", " ", 
   RowBox[{"qcut0", "-", "qcui0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, 3.819815204462039*^9, 3.819900428496666*^9},
 CellLabel->
  "In[653]:=",ExpressionUUID->"34e10a13-0897-4126-a042-cb29ac11441b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qppl0", " ", "=", " ", 
   RowBox[{"qppt0", "-", "qppi0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7997918179770885`*^9, 3.7997918312292595`*^9}, 
   3.7997923001747293`*^9, 3.800692828471694*^9, 3.8017798658828244`*^9, 
   3.803120623507723*^9, 3.819815204462039*^9, 3.8199004297906733`*^9},
 CellLabel->
  "In[654]:=",ExpressionUUID->"e91a2bc8-f2fb-43cf-90ba-a764f6838fda"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcpl0", " ", "=", " ", 
   RowBox[{"qcpt0", "-", "qcpi0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.799791850128228*^9, 3.799791866761145*^9}, 
   3.7997923042534895`*^9, 3.8006928304556694`*^9, 3.8017798680081725`*^9, 
   3.803120625625375*^9, 3.8198152044630404`*^9, 3.81990043127083*^9},
 CellLabel->
  "In[655]:=",ExpressionUUID->"4f533b92-d636-4a31-8784-e9c28f54a747"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.4 Export Quantities", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672744603273*^9}, {
   3.8196728121258554`*^9, 3.8196728122829847`*^9}, {3.819815211108224*^9, 
   3.8198152128205585`*^9}, 
   3.81981526037964*^9},ExpressionUUID->"bc1a7e40-e010-4455-b1a8-\
8088fcf682e9"],

Cell[TextData[StyleBox["Source:National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries). NOAA US \
Trade in Fishery Products database. Accessed September 1, 2020. \
https://foss.nmfs.noaa.gov/apexfoss/f?p=215:2:14884747663545::NO",
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, 
   3.819814602882104*^9, {3.8198147741606445`*^9, 3.8198147935287457`*^9}, {
   3.819815219280593*^9, 3.81981526037964*^9}, {3.819815772355571*^9, 
   3.8198157737996855`*^9}},
 FontSize->12,ExpressionUUID->"67e30bef-4e5d-49ab-97aa-093bdc9c34be"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qpae0", " ", "=", "446433"}], " ", ";", " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, 3.819815260380641*^9, {
   3.8199015183327355`*^9, 3.8199015212179623`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[656]:=",ExpressionUUID->"d36c758b-7ed8-4713-92ae-51ee7315a7bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qpwe0", " ", "=", "  ", "55839578"}], ";", " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, 3.819815260380641*^9, {
   3.8199015237999554`*^9, 3.819901525223054*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[657]:=",ExpressionUUID->"f5a00f2e-1382-4412-b39c-d22462e02472"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcae0", " ", "=", " ", "284184"}], ";", " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792955827648*^9, 3.799792956327729*^9}, {3.799793048492208*^9, 
   3.799793051930266*^9}, {3.7997930925641108`*^9, 3.7997930962990923`*^9}, 
   3.819815260380641*^9, {3.819901526886338*^9, 3.8199015283574734`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[658]:=",ExpressionUUID->"fbaebb24-5110-4256-8b52-1343c623e9e1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcbe0", " ", "=", "  ", "67720141"}], ";", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.799792959531374*^9, 3.799792983083268*^9}, {
   3.7997930698720045`*^9, 3.7997930885634565`*^9}, 3.819815260380641*^9, 
   3.819901531849169*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[659]:=",ExpressionUUID->"6f5eed8c-63d2-4535-ac6e-c3514f953153"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qpwpe0", " ", "=", "140548922"}], ";", " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7997929394661226`*^9, 3.799792944620593*^9}, {
   3.7997931490817285`*^9, 3.799793155770315*^9}, {3.7998828158392553`*^9, 
   3.799882830965019*^9}, {3.8017771283785605`*^9, 3.8017771482124414`*^9}, 
   3.803124169569406*^9, {3.803124239399731*^9, 3.8031243160082026`*^9}, 
   3.8031247487750883`*^9, {3.803125543052536*^9, 3.8031255434658537`*^9}, {
   3.803302940873972*^9, 3.803302945108673*^9}, {3.8033924434552145`*^9, 
   3.803392470522688*^9}, 3.819815260380641*^9, 3.819901532984045*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[660]:=",ExpressionUUID->"f0aeeadb-9112-4d7d-8f18-afea7fe425a9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qpape0", " ", "=", "37556"}], ";", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7997929394661226`*^9, 3.799792944620593*^9}, {
   3.7997931490817285`*^9, 3.799793155770315*^9}, {3.7998828158392553`*^9, 
   3.7998828459385138`*^9}, {3.8017771339263506`*^9, 3.8017771492751193`*^9}, 
   3.803124337926504*^9, {3.8031248426803646`*^9, 3.803124843610093*^9}, 
   3.80312555389789*^9, 3.803302950328277*^9, 3.803392473398443*^9, 
   3.819815260380641*^9, 3.8199015341319304`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[661]:=",ExpressionUUID->"6962a6b9-e0ac-4c9b-9753-e8666aa02ab4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcape0", "=", 
   RowBox[{"5239167", " ", "shrca"}]}], ";", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7997929394661226`*^9, 3.799792944620593*^9}, {
   3.7997931490817285`*^9, 3.799793155770315*^9}, {3.7998828158392553`*^9, 
   3.799882830965019*^9}, {3.8017771283785605`*^9, 3.8017771482124414`*^9}, 
   3.803124169569406*^9, {3.803124239399731*^9, 3.8031243160082026`*^9}, {
   3.803124370423156*^9, 3.8031243833669486`*^9}, {3.8031248699166193`*^9, 
   3.8031248831679583`*^9}, 3.8031249330258665`*^9, 3.819815260380641*^9, 
   3.8199015352998323`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[662]:=",ExpressionUUID->"63517908-303c-475f-8788-8ff7fb76652c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcbpe0", "=", 
   RowBox[{"5239167", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "shrca"}], ")"}]}]}], ";", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7997929394661226`*^9, 3.799792944620593*^9}, {
   3.7997931490817285`*^9, 3.799793155770315*^9}, {3.7998828158392553`*^9, 
   3.799882830965019*^9}, {3.8017771283785605`*^9, 3.8017771482124414`*^9}, 
   3.803124169569406*^9, {3.803124239399731*^9, 3.8031243160082026`*^9}, {
   3.803124390752714*^9, 3.8031244017833185`*^9}, {3.803124859236284*^9, 
   3.803124864295233*^9}, 3.803124933032872*^9, 3.8198152603816414`*^9, 
   3.8199015362435603`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[663]:=",ExpressionUUID->"7a2ac05e-8641-442a-a784-960f3adc8917"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.5 Catch Limits", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672709332239*^9}, {
   3.819672747951029*^9, 3.819672752938134*^9}, {3.819672814932173*^9, 
   3.8196728150802965`*^9}, 
   3.8198153194016666`*^9},ExpressionUUID->"ef609090-ec87-41c8-918d-\
9597042e4d9e"],

Cell[TextData[StyleBox["Alaskan Pollock",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.819815276384116*^9, 3.819815279760747*^9}, 
   3.8198153194026575`*^9},
 FontWeight->"Plain",ExpressionUUID->"92736aaf-d483-45eb-82e1-160907cba390"],

Cell[TextData[StyleBox["Source: National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries).\
\[NonBreakingSpace]\[OpenCurlyDoubleQuote]Alaska Groundfish Harvest \
Specifications.\[CloseCurlyDoubleQuote] Accessed November 19, 2020. \
https://www.fisheries.noaa.gov/alaska/sustainable-fisheries/alaska-groundfish-\
harvest-specifications.",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934406567`*^9},ExpressionUUID->"cab97767-d8b3-4d1d-b168-\
70d85c29c904"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qpwcap", " ", "=", "2762265000"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, 3.8198153194026575`*^9, {3.8198157017941046`*^9, 
   3.8198157031381426`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[664]:=",ExpressionUUID->"802c6b9b-1962-431d-b17b-a621193520c7"],

Cell[TextData[StyleBox["Atlantic Pollock",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.8198152840110598`*^9, 
  3.8198153194026575`*^9}},ExpressionUUID->"77fb6752-3ecc-4981-970f-\
f1131d135c0d"],

Cell[TextData[StyleBox["Source: National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries). \
\[OpenCurlyDoubleQuote]Northeast Multispecies (Groundfish); Fishing Year 2018 \
Regulations,\[CloseCurlyDoubleQuote] April 30, 2018. \
https://www.fisheries.noaa.gov/bulletin/northeast-multispecies-groundfish-\
fishing-year-2018-regulations.",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, {
   3.819815631970208*^9, 3.8198156353818417`*^9}, 
   3.8198156934416575`*^9},ExpressionUUID->"ddb64eed-93ed-43e7-ae85-\
696d399a6748"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qpacap", " ", "=", " ", "38204000"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.799792068000595*^9, 3.7997920933105726`*^9}, {
   3.799792144996316*^9, 3.7997921479198933`*^9}, {3.810031927990462*^9, 
   3.810031930736575*^9}, 3.8198153194026575`*^9, 3.819815707344389*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[665]:=",ExpressionUUID->"514171d9-80b4-4e7a-919e-9bd5f5c7fd21"],

Cell[TextData[StyleBox["Pacific Cod",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.8198152953278866`*^9, 
  3.8198153194026575`*^9}},ExpressionUUID->"8243c38e-7aa2-4bce-8747-\
84889a6704f6"],

Cell[TextData[StyleBox["Source: National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries).\
\[NonBreakingSpace]\[OpenCurlyDoubleQuote]Alaska Groundfish Harvest \
Specifications.\[CloseCurlyDoubleQuote] Accessed November 19, 2020. \
https://www.fisheries.noaa.gov/alaska/sustainable-fisheries/alaska-groundfish-\
harvest-specifications.",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934416575`*^9},ExpressionUUID->"23ef4638-3216-45cd-855f-\
05309bf17b5c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qcbcap", " ", "=", " ", "242721000"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.7997920728919544`*^9, 3.799792095608039*^9}, {
   3.799792157072194*^9, 3.79979216018829*^9}, 3.8198153194026575`*^9, 
   3.8198157084232216`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[666]:=",ExpressionUUID->"1e47603f-a95b-446e-b5c4-6a45ff2fc269"],

Cell[TextData[StyleBox["Atlantic Cod",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.819815304260852*^9, 
  3.8198153194026575`*^9}},ExpressionUUID->"1b3d8f66-b8e7-4521-86e1-\
e074a5e020f4"],

Cell[TextData[StyleBox["Source: National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries). \
\[OpenCurlyDoubleQuote]Northeast Multispecies (Groundfish); Fishing Year 2018 \
Regulations,\[CloseCurlyDoubleQuote] April 30, 2018. \
https://www.fisheries.noaa.gov/bulletin/northeast-multispecies-groundfish-\
fishing-year-2018-regulations.",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, {
   3.819815631970208*^9, 3.8198156353818417`*^9}, 
   3.8198156934416575`*^9},ExpressionUUID->"c94e0dde-adc4-4f43-a901-\
94d3cd4cef0f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qcacap", " ", "=", "2185000"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.7997920812213774`*^9, 3.799792098202193*^9}, {
   3.79979216439207*^9, 3.7997921660797377`*^9}, {3.8100318724877462`*^9, 
   3.8100318786905203`*^9}, 3.819815319403659*^9, 3.819815709437004*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[667]:=",ExpressionUUID->"e8a3d92a-44ce-4bb7-9c7f-5ccd52441f93"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.6 Import Market Share Statistics", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.8199018381766195`*^9, 3.8199018609792204`*^9}, 
   3.819901901056156*^9, 
   3.8199024672872863`*^9},ExpressionUUID->"ecc674be-2e1c-452c-a8cc-\
30a51a736b3a"],

Cell["Imports percent in market for unprocessed pollock", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.812493252545861*^9, 3.812493267125186*^9}, 
   3.819901901056156*^9},ExpressionUUID->"585e23f8-311d-4da1-8618-\
19a30ab95a1b"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"100", " ", 
   RowBox[{"qput0", "/", 
    RowBox[{"(", 
     RowBox[{"qput0", "+", 
      RowBox[{"(", 
       RowBox[{"qpad0", "-", "qpae0", "-", 
        RowBox[{"cr", " ", "qpapd0"}]}], ")"}], "+", 
      RowBox[{"(", 
       RowBox[{"qpwd0", "-", "qpwe0", "-", 
        RowBox[{"cr", " ", "qpwpd0"}]}], ")"}]}], ")"}]}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.8057137573931575`*^9, 3.8057137986588917`*^9}, {
   3.805713880865735*^9, 3.8057139232047353`*^9}, {3.805713955494152*^9, 
   3.805713994400984*^9}, {3.80571402653207*^9, 3.8057140411814327`*^9}, {
   3.8057140889120064`*^9, 3.8057141170538964`*^9}, {3.812493001065504*^9, 
   3.812493058053774*^9}, {3.812493141588666*^9, 3.812493240581567*^9}, {
   3.819900100195793*^9, 3.819900100566081*^9}, 3.819901901056156*^9},
 CellLabel->
  "In[668]:=",ExpressionUUID->"867a6866-4e2b-4a27-a4f0-9c73447e4c1e"],

Cell[BoxData["0.16542566432411157`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{3.812493241875573*^9, 3.812820882013611*^9, 
  3.8129260018614616`*^9, 3.812926325264162*^9, 3.812926559255845*^9, 
  3.812974791911354*^9, 3.812975024753261*^9, 3.8129752818769703`*^9, 
  3.8141738481940594`*^9, 3.815473675375866*^9, 3.815476519655034*^9, 
  3.815773856423957*^9, 3.816982402388836*^9, 3.8188024944812927`*^9, 
  3.819900188348629*^9, 3.819901798795222*^9, 3.819901901056156*^9, 
  3.819902161567612*^9},
 CellLabel->
  "Out[668]=",ExpressionUUID->"7ed354c5-408f-4fa0-b552-bef70dc46d9c"],

Cell["Imports percent in market for unprocessed cod", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.812493252545861*^9, 3.812493274509923*^9}, 
   3.819901901057156*^9},ExpressionUUID->"34949613-6719-4ddb-8899-\
464d23dfd0f7"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"100", " ", 
   RowBox[{"qcut0", "/", 
    RowBox[{"(", 
     RowBox[{"qcut0", "+", 
      RowBox[{"(", 
       RowBox[{"qcad0", "-", "qcae0", "-", 
        RowBox[{"cr", " ", "qcapd0"}]}], ")"}], "+", 
      RowBox[{"(", 
       RowBox[{"qcbd0", "-", "qcbe0", "-", 
        RowBox[{"cr", " ", "qcbpd0"}]}], ")"}]}], ")"}]}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.8057137573931575`*^9, 3.8057137986588917`*^9}, {
   3.805713880865735*^9, 3.8057139232047353`*^9}, {3.805713955494152*^9, 
   3.805713994400984*^9}, {3.80571402653207*^9, 3.8057140411814327`*^9}, {
   3.8057140889120064`*^9, 3.8057141170538964`*^9}, {3.812493001065504*^9, 
   3.812493058053774*^9}, {3.812493141588666*^9, 3.812493240581567*^9}, {
   3.812493276726645*^9, 3.8124932980922422`*^9}, {3.819900103077036*^9, 
   3.819900103479349*^9}, 3.819901901057156*^9},
 CellLabel->
  "In[669]:=",ExpressionUUID->"26a50155-6ae7-4e2c-a4d6-b4a54b066f7a"],

Cell[BoxData["4.387491308253637`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{3.812493241875573*^9, 3.8124933000287466`*^9, 
  3.8128208820976763`*^9, 3.8129260020346212`*^9, 3.812926325372246*^9, 
  3.8129265593579245`*^9, 3.8129747919894915`*^9, 3.812975024972048*^9, 
  3.8129752819936886`*^9, 3.8141738483034554`*^9, 3.815473675438376*^9, 
  3.815476519764428*^9, 3.815773856528038*^9, 3.8169824024028473`*^9, 
  3.8188024944993057`*^9, 3.8199001884387207`*^9, 3.8199017988642745`*^9, 
  3.819901901057156*^9, 3.819902161690708*^9},
 CellLabel->
  "Out[669]=",ExpressionUUID->"a71f7f39-063b-4637-9307-a41d00bc9482"],

Cell["Imports percent in market for processed pollock", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.812493252545861*^9, 3.812493274509923*^9}, {
   3.8124933181087914`*^9, 3.812493320294489*^9}, 
   3.819901901057156*^9},ExpressionUUID->"2912fc0f-6769-4b6d-8fb5-\
510eb8fef073"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"100", " ", 
   RowBox[{"qppt0", "/", 
    RowBox[{"(", 
     RowBox[{"qppt0", "+", 
      RowBox[{"(", 
       RowBox[{"qpwpd0", "-", "qpwpe0"}], ")"}], "+", 
      RowBox[{"(", 
       RowBox[{"qpapd0", "-", "qpape0"}], ")"}]}], ")"}]}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.8057137573931575`*^9, 3.8057137986588917`*^9}, {
   3.805713880865735*^9, 3.8057139232047353`*^9}, {3.805713955494152*^9, 
   3.805713994400984*^9}, {3.80571402653207*^9, 3.8057140411814327`*^9}, {
   3.8057140889120064`*^9, 3.8057141170538964`*^9}, {3.812493001065504*^9, 
   3.812493058053774*^9}, {3.812493141588666*^9, 3.812493240581567*^9}, {
   3.812493276726645*^9, 3.8124933617466908`*^9}, {3.819900105575987*^9, 
   3.8199001071942463`*^9}, 3.819901901057156*^9},
 CellLabel->
  "In[670]:=",ExpressionUUID->"1d1bdaad-6da2-4b5e-8a55-ef38be123e6b"],

Cell[BoxData["44.716085262543444`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{3.812493241875573*^9, 3.8124933000287466`*^9, 
  3.8124933632098274`*^9, 3.812820882186745*^9, 3.8129260021797132`*^9, 
  3.812926325488336*^9, 3.8129265594840236`*^9, 3.8129747921301384`*^9, 
  3.8129750251908336`*^9, 3.81297528212379*^9, 3.814173848381591*^9, 
  3.8154736755009437`*^9, 3.815476519873821*^9, 3.815773856639125*^9, 
  3.816982402415857*^9, 3.818802494517351*^9, 3.819900188524766*^9, 
  3.8199017989403334`*^9, 3.819901901057156*^9, 3.8199021617887845`*^9},
 CellLabel->
  "Out[670]=",ExpressionUUID->"b907d402-1b32-4f5b-8c1c-bc2447ae6208"],

Cell["Imports percent in market for processed cod", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.812493252545861*^9, 3.812493274509923*^9}, {
   3.8124933181087914`*^9, 3.812493320294489*^9}, {3.812493449426803*^9, 
   3.8124934496439714`*^9}, 
   3.819901901057156*^9},ExpressionUUID->"bfd0c625-22b9-4f6a-ba27-\
62de0d411881"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"100", " ", 
   RowBox[{"qcpt0", "/", 
    RowBox[{"(", 
     RowBox[{"qcpt0", "+", 
      RowBox[{"(", 
       RowBox[{"qcapd0", "-", "qcape0"}], ")"}], "+", 
      RowBox[{"(", 
       RowBox[{"qcbpd0", "-", "qcbpe0"}], ")"}]}], ")"}]}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.8057137573931575`*^9, 3.8057137986588917`*^9}, {
   3.805713880865735*^9, 3.8057139232047353`*^9}, {3.805713955494152*^9, 
   3.805713994400984*^9}, {3.80571402653207*^9, 3.8057140411814327`*^9}, {
   3.8057140889120064`*^9, 3.8057141170538964`*^9}, {3.812493001065504*^9, 
   3.812493058053774*^9}, {3.812493141588666*^9, 3.812493240581567*^9}, {
   3.812493276726645*^9, 3.812493408250825*^9}, {3.8199001092168274`*^9, 
   3.819900109656169*^9}, 3.819901901057156*^9},
 CellLabel->
  "In[671]:=",ExpressionUUID->"092486ad-0785-496d-8f30-411c9c10a6b0"],

Cell[BoxData["74.570625334467`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{3.812493241875573*^9, 3.8124933000287466`*^9, 
  3.8124933632098274`*^9, 3.8124934109339013`*^9, 3.8128208822888246`*^9, 
  3.8129260023418417`*^9, 3.812926325598421*^9, 3.8129265595831013`*^9, 
  3.812974792255158*^9, 3.8129750254096193`*^9, 3.812975282238879*^9, 
  3.8141738484441004`*^9, 3.8154736755946517`*^9, 3.8154765199832144`*^9, 
  3.81577385674821*^9, 3.8169824024314356`*^9, 3.818802494535336*^9, 
  3.819900188612835*^9, 3.819901799022397*^9, 3.819901901057156*^9, 
  3.819902161876854*^9},
 CellLabel->
  "Out[671]=",ExpressionUUID->"b55a2f64-a90e-4206-ab8b-52f958adba9a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3. Calibration",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.7954529786642447`*^9}, {
  3.79545386036082*^9, 3.7954538618860044`*^9}, {3.819900448697421*^9, 
  3.8199004491007357`*^9}},ExpressionUUID->"799a58ab-534e-47a3-9fca-\
de06a3bd41fb"],

Cell["\<\
Baseline values of unprocessed and processed apparent consumption and imports\
\>", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7954541868300085`*^9, 3.7954542200368147`*^9}, {
  3.795455624690459*^9, 3.7954556275947175`*^9}, {3.795532637283266*^9, 
  3.7955326380308447`*^9}, {3.799794880332456*^9, 3.79979488120757*^9}, {
  3.801667655660522*^9, 3.801667670402505*^9}, {3.8199000703965473`*^9, 
  3.8199001199411907`*^9}},ExpressionUUID->"d34b8fec-59f2-4b2d-bfaf-\
10e9b93c4791"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vput0", "=", 
   RowBox[{"qput0", " ", "pput0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9},
 CellLabel->
  "In[672]:=",ExpressionUUID->"9d5a52cf-3316-4cb2-80ab-9c9bede1d617"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vcut0", "=", 
   RowBox[{"qcut0", " ", "pcut0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9},
 CellLabel->
  "In[673]:=",ExpressionUUID->"563be225-6049-49ee-806a-d676b042abd2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vpwd0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qpwd0", "-", "qpwe0", "-", 
      RowBox[{"cr", " ", "qpwpd0"}]}], ")"}], " ", "ppwd0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804603754600464*^9, 3.804603754913022*^9}},
 CellLabel->
  "In[674]:=",ExpressionUUID->"a3ab304f-2aee-4fbd-bfd7-6f5a12f02f88"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vpad0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qpad0", "-", "qpae0", "-", 
      RowBox[{"cr", " ", "qpapd0"}]}], ")"}], " ", "ppad0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8046037570406218`*^9, 3.8046037577317767`*^9}},
 CellLabel->
  "In[675]:=",ExpressionUUID->"3f3f71a9-fce2-4be4-b505-60d2d9a2083c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vcbd0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qcbd0", "-", "qcbe0", "-", 
      RowBox[{"cr", " ", "qcbpd0"}]}], ")"}], " ", "pcbd0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, {3.7997935193419185`*^9, 3.7997935195779734`*^9}, {
   3.799793571467828*^9, 3.7997935835593176`*^9}, {3.7997993095983105`*^9, 
   3.7997993168045464`*^9}, {3.8016676842325277`*^9, 3.80166769934836*^9}, {
   3.801667745181138*^9, 3.8016677629844112`*^9}, {3.80166816262614*^9, 
   3.8016681681426163`*^9}, {3.8016885866439004`*^9, 3.8016885916605005`*^9}, 
   3.803118503382021*^9, {3.8046037601643963`*^9, 3.8046037605457106`*^9}},
 CellLabel->
  "In[676]:=",ExpressionUUID->"8d56dae7-fd14-4978-b7e8-1a8ba1c95d3d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vcad0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qcad0", "-", "qcae0", "-", 
      RowBox[{"cr", " ", "qcapd0"}]}], ")"}], " ", "pcad0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, {3.799793521922104*^9, 3.7997935221096344`*^9}, {
   3.7997935881069307`*^9, 3.799793591388714*^9}, {3.799799311443593*^9, 
   3.7997993201980343`*^9}, {3.8016677038958864`*^9, 3.801667715945263*^9}, {
   3.8016677474939504`*^9, 3.80166777028357*^9}, {3.801668171081812*^9, 
   3.8016681747386255`*^9}, {3.8016885953049803`*^9, 3.8016885989175997`*^9}, 
   3.8031185033880258`*^9, {3.804603762780484*^9, 3.8046037632649455`*^9}},
 CellLabel->
  "In[677]:=",ExpressionUUID->"2dba8ce9-5754-49de-ac08-6a28a3d86633"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vppt0", "=", 
   RowBox[{"qppt0", " ", "pppt0"}]}], ";"}]], "Input",
 CellChangeTimes->{3.8031185120447807`*^9},
 CellLabel->
  "In[678]:=",ExpressionUUID->"235d8191-f491-418f-822d-bfa5f085049a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vcpt0", "=", 
   RowBox[{"qcpt0", " ", "pcpt0"}]}], ";"}]], "Input",
 CellChangeTimes->{3.803118512050785*^9},
 CellLabel->
  "In[679]:=",ExpressionUUID->"7bb5a92c-72b9-4951-9702-47267eff001b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vpwpd0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qpwpd0", "-", "qpwpe0"}], ")"}], " ", "ppwpd0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.79988156801017*^9, 3.799881571821947*^9}, {
   3.801691688906353*^9, 3.801691698588906*^9}, 3.801691845215163*^9, 
   3.801692128906493*^9, 3.8017809797143607`*^9, 3.8031185120567904`*^9, {
   3.8031209259216876`*^9, 3.803120940523736*^9}, {3.8031210069961033`*^9, 
   3.8031210166413345`*^9}, {3.803124435875923*^9, 3.8031244441954145`*^9}, 
   3.8031245014350805`*^9},
 CellLabel->
  "In[680]:=",ExpressionUUID->"4be17dd9-1a35-446f-80bc-e5bce12e0aa8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vpapd0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qpapd0", "-", "qpape0"}], ")"}], " ", "ppapd0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7998815768222446`*^9, 3.7998815804159784`*^9}, {
   3.801691703136535*^9, 3.8016917107294073`*^9}, 3.8017809824335594`*^9, 
   3.8031185120627947`*^9, {3.803124448731954*^9, 3.8031244577369814`*^9}, 
   3.803124501442086*^9},
 CellLabel->
  "In[681]:=",ExpressionUUID->"0d488b17-f9ca-4f04-bb1e-e440e9a83cfd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vcapd0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qcapd0", "-", "qcape0"}], ")"}], " ", "pcapd0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7998819765383406`*^9, 3.799881980428629*^9}, {
   3.8016917149207926`*^9, 3.801691723547223*^9}, 3.801693202228036*^9, 
   3.8017770131063023`*^9, 3.801780985121503*^9, 3.8031185120687995`*^9, {
   3.8031244607983737`*^9, 3.8031245014480906`*^9}},
 CellLabel->
  "In[682]:=",ExpressionUUID->"864c3a74-b660-4086-b1a5-7b36cf5edea5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vcbpd0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qcbpd0", "-", "qcbpe0"}], ")"}], " ", "pcbpd0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.799881985241749*^9, 3.7998819901504602`*^9}, {
   3.8016917276432786`*^9, 3.801691739692149*^9}, 3.801693200337099*^9, 
   3.8017770151066356`*^9, 3.801780988528309*^9, 3.8031185120758047`*^9, {
   3.8031244749804387`*^9, 3.8031245014550962`*^9}},
 CellLabel->
  "In[683]:=",ExpressionUUID->"2f875836-a088-442e-bc28-48601d7a2159"],

Cell[BoxData[
 StyleBox[
  RowBox[{"3.1", " ", 
   StyleBox[
    RowBox[{
     StyleBox["S", "Subsection",
      FontSize->18,
      FontWeight->"Plain"], "upply"}]], " ", "Parameters"}], "Subsection",
  FontSize->18,
  FontWeight->"Plain"]], "Input",
 CellChangeTimes->{{3.819902497376732*^9, 
  3.819902510893259*^9}},ExpressionUUID->"2fc5f281-f54b-4ec7-93d8-\
bec79dce8a7d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ecad", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"eca", " ", 
     FractionBox["qcad0", 
      RowBox[{"(", 
       RowBox[{"qcacap", "-", "qcad0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, 3.8199001327661963`*^9},
 CellLabel->
  "In[684]:=",ExpressionUUID->"251b4ab0-22c0-46e3-b8e5-e9aa3e6836c2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ecbd", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"ecb", " ", 
     FractionBox["qcbd0", 
      RowBox[{"(", 
       RowBox[{"qcbcap", "-", "qcbd0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.799794502386656*^9, 
   3.799794515963153*^9}, {3.7997993513036356`*^9, 3.799799355601262*^9}, 
   3.7998576885097065`*^9, {3.8016630709045205`*^9, 3.8016630794114227`*^9}, {
   3.8016631654131823`*^9, 3.801663168038622*^9}, 3.8199001345545883`*^9},
 CellLabel->
  "In[685]:=",ExpressionUUID->"99815906-5027-4fb5-8dce-9c0abc30321c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"epad", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"epa", " ", 
     FractionBox["qpad0", 
      RowBox[{"(", 
       RowBox[{"qpacap", "-", "qpad0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.79979452629371*^9, 3.7997945444643707`*^9}, {
   3.7997993584923925`*^9, 3.7997993618692937`*^9}, 3.7998576901512136`*^9, {
   3.8016630727215548`*^9, 3.8016630817804527`*^9}, {3.8016631711953993`*^9, 
   3.8016631744459434`*^9}, 3.8199001361568394`*^9},
 CellLabel->
  "In[686]:=",ExpressionUUID->"55c252f7-7837-4dde-9c45-c2035e0188c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"epwd", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"epw", " ", 
     FractionBox["qpwd0", 
      RowBox[{"(", 
       RowBox[{"qpwcap", "-", "qpwd0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.799794502386656*^9, 
   3.79979455845814*^9}, {3.799799363853321*^9, 3.7997993674755945`*^9}, 
   3.799857692191049*^9, {3.801663074768772*^9, 3.8016630841245947`*^9}, {
   3.8016631779309072`*^9, 3.801663181040802*^9}, 3.8199001378321457`*^9},
 CellLabel->
  "In[687]:=",ExpressionUUID->"53354d98-ccf5-449d-86e2-ae59f439ea18"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"acad", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qcacap", "-", "qcad0"}], ")"}], " ", 
    SuperscriptBox["pcad0", "ecad"]}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, 
   3.8199001415560503`*^9},
 CellLabel->
  "In[688]:=",ExpressionUUID->"84a21240-2395-4207-a627-0bd1de0b1bd2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"acbd", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qcbcap", "-", "qcbd0"}], ")"}], " ", 
    SuperscriptBox["pcbd0", "ecbd"]}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.7997946151056967`*^9}, {3.799799378681633*^9, 3.7997993956355505`*^9}, {
   3.801663097924847*^9, 3.8016630980811234`*^9}, 3.8031140548556347`*^9, 
   3.8199001429411283`*^9},
 CellLabel->
  "In[689]:=",ExpressionUUID->"b66c027d-500d-44bd-8465-5da959225730"],

Cell[BoxData[
 RowBox[{
  RowBox[{"apad", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qpacap", "-", "qpad0"}], ")"}], " ", 
    SuperscriptBox["ppad0", "epad"]}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.7997945886688633`*^9}, {3.79979462057537*^9, 3.79979463229694*^9}, {
   3.799799388195778*^9, 3.7997993969781623`*^9}, {3.801663095393174*^9, 
   3.8016630955025673`*^9}, 3.8031140567631397`*^9, 3.8199001445103564`*^9},
 CellLabel->
  "In[690]:=",ExpressionUUID->"8bf8f110-2810-47e4-abd8-a9befc05e97a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"apwd", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qpwcap", "-", "qpwd0"}], ")"}], " ", 
    SuperscriptBox["ppwd0", "epwd"]}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.7997945886688633`*^9}, {3.799794637375922*^9, 3.799794653902481*^9}, {
   3.7997993979001985`*^9, 3.799799406449299*^9}, {3.801663091798997*^9, 
   3.801663092532092*^9}, 3.8031140598876066`*^9, 3.8199001458003607`*^9},
 CellLabel->
  "In[691]:=",ExpressionUUID->"f58825e8-1641-460f-89c2-c1bda2d705d5"]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  RowBox[{"3.2", " ", "Demand", " ", "Parameters"}], "Subsection",
  FontSize->18,
  FontWeight->"Plain"]], "Input",
 CellChangeTimes->{{3.819902513379201*^9, 
  3.8199025199032784`*^9}},ExpressionUUID->"a7690091-e227-4455-a6af-\
7b439871af2e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bcbd", " ", "=", 
   RowBox[{
    FractionBox["vcbd0", "vcad0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pcbd0", "pcad0"], ")"}], 
     RowBox[{"sigmacu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, 3.819900150238908*^9},
 CellLabel->
  "In[692]:=",ExpressionUUID->"1bd69a31-8d5e-4be7-ac7b-526a6a7dc4b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bcut", " ", "=", 
   RowBox[{
    FractionBox["vcut0", "vcad0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pcut0", "pcad0"], ")"}], 
     RowBox[{"sigmacu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.799795426030717*^9, 3.79979544031664*^9}, 
   3.7997954921582737`*^9, {3.7997960450377007`*^9, 3.7997960531797004`*^9}, {
   3.7997971177756605`*^9, 3.7997971227764397`*^9}, {3.7997994245887856`*^9, 
   3.799799426057785*^9}, {3.7998564898096313`*^9, 3.799856490528511*^9}, 
   3.799856619219349*^9, 3.8004555804607058`*^9, {3.800635752727919*^9, 
   3.8006357536516323`*^9}, 3.801778511172927*^9, 3.803114045680392*^9, 
   3.819900151756089*^9},
 CellLabel->
  "In[693]:=",ExpressionUUID->"dc072c2e-dd27-47ff-83b5-729f3420970e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pcad0", 
       RowBox[{"1", "-", "sigmacu"}]], "+", 
      RowBox[{"bcbd", " ", 
       SuperscriptBox["pcbd0", 
        RowBox[{"1", "-", "sigmacu"}]]}], "+", 
      RowBox[{"bcut", " ", 
       SuperscriptBox["pcut0", 
        RowBox[{"1", "-", "sigmacu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmacu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, 
   3.8199001535584984`*^9},
 CellLabel->
  "In[694]:=",ExpressionUUID->"bfe09279-c02a-4e14-b37a-2ead85213dd7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bpwd", " ", "=", 
   RowBox[{
    FractionBox["vpwd0", "vpad0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["ppwd0", "ppad0"], ")"}], 
     RowBox[{"sigmapu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997954134038706`*^9}, {3.79979604041403*^9, 3.7997960550706444`*^9}, {
   3.799797125683171*^9, 3.7997971410148478`*^9}, {3.7997994301678534`*^9, 
   3.7997994436279955`*^9}, {3.799856493280625*^9, 3.799856494030761*^9}, {
   3.7998565746240835`*^9, 3.799856578577899*^9}, 3.799856619219349*^9, 
   3.8004555940395327`*^9, {3.800635732710503*^9, 3.800635759446048*^9}, 
   3.8017785065784388`*^9, 3.803114041553134*^9, 3.819900154762436*^9},
 CellLabel->
  "In[695]:=",ExpressionUUID->"eddc8647-ebe7-40a4-a643-b409f1d084b9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bput", " ", "=", 
   RowBox[{
    FractionBox["vput0", "vpad0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pput0", "ppad0"], ")"}], 
     RowBox[{"sigmapu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.799795449255145*^9, 3.7997954942679777`*^9}, {
   3.799796037476034*^9, 3.7997960560239305`*^9}, {3.79979712746467*^9, 
   3.799797142452572*^9}, {3.7997994467066402`*^9, 3.799799449800912*^9}, {
   3.7998564963106856`*^9, 3.799856497048479*^9}, {3.79985658832145*^9, 
   3.799856619219349*^9}, 3.8004556056408834`*^9, {3.8006358190409975`*^9, 
   3.800635827353882*^9}, 3.801778504765647*^9, 3.803114039656637*^9, 
   3.819900156467764*^9},
 CellLabel->
  "In[696]:=",ExpressionUUID->"8aabf531-3737-44f4-9f4a-d8228f49d1bb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ppu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["ppad0", 
       RowBox[{"1", "-", "sigmapu"}]], "+", 
      RowBox[{"bpwd", " ", 
       SuperscriptBox["ppwd0", 
        RowBox[{"1", "-", "sigmapu"}]]}], "+", 
      RowBox[{"bput", " ", 
       SuperscriptBox["pput0", 
        RowBox[{"1", "-", "sigmapu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmapu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795761331473*^9, 3.7997958196402683`*^9}, {
   3.7997970184990273`*^9, 3.799797020958833*^9}, {3.799799472226812*^9, 
   3.7997994757274027`*^9}, {3.7998558920843744`*^9, 3.799855894631646*^9}, 
   3.800635715523387*^9, {3.80063638910196*^9, 3.8006363925496497`*^9}, 
   3.8016652596658087`*^9, 3.8017784996710777`*^9, 3.803114037829194*^9, 
   3.8199001577897987`*^9},
 CellLabel->
  "In[697]:=",ExpressionUUID->"35dd4b8a-00c6-48ab-97e6-0783217197b1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bpu", " ", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vpad0", "+", "vpwd0", "+", "vput0"}], 
     RowBox[{"vcad0", "+", "vcbd0", "+", "vcut0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Ppu0", "Pcu0"], ")"}], 
     RowBox[{"betau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799856599558881*^9, 3.799856611046138*^9}, 
   3.800455613261757*^9, {3.8006360373929*^9, 3.8006360688935366`*^9}, {
   3.800636178928644*^9, 3.800636218883496*^9}, 3.8016605474816732`*^9, 
   3.801688828191676*^9, 3.80177849607675*^9, 3.8031140358696475`*^9, 
   3.8199001589456983`*^9},
 CellLabel->
  "In[698]:=",ExpressionUUID->"118d54ab-c2a3-4606-809f-4033f4bf6a48"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pu0", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pcu0", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bpu", " ", 
       SuperscriptBox["Ppu0", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958373159857`*^9}, {3.7998802231121106`*^9, 
   3.7998802231121106`*^9}, {3.8006360114543343`*^9, 3.8006360139698973`*^9}, 
   3.8006362338215733`*^9, 3.8006473259792037`*^9, {3.801660472029422*^9, 
   3.8016604811122656`*^9}, {3.8016888318797884`*^9, 3.8016888367788754`*^9}, 
   3.8017784927793455`*^9, 3.8031140341853185`*^9, 3.8199001607170796`*^9},
 CellLabel->
  "In[699]:=",ExpressionUUID->"50bd11cc-cd2a-48a5-b26d-654657e589b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bcpt", " ", "=", " ", 
   RowBox[{
    FractionBox["vcpt0", "vcapd0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pcpt0", "pcapd0"], ")"}], 
     RowBox[{"sigmacp", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998820832936077`*^9, 3.7998821082451005`*^9}, {
   3.7998823611862755`*^9, 3.799882363477393*^9}, 3.800455608478097*^9, 
   3.8006358723089266`*^9, 3.801778490310198*^9, 3.8031140322537932`*^9, 
   3.819900161848964*^9},
 CellLabel->
  "In[700]:=",ExpressionUUID->"56b63af6-500f-447d-ba85-8ed829f874bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bcbpd", " ", "=", " ", 
   RowBox[{
    FractionBox["vcbpd0", "vcapd0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pcbpd0", "pcapd0"], ")"}], 
     RowBox[{"sigmacp", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799882262895549*^9, 3.799882305365795*^9}, 
   3.800455623246277*^9, {3.8006359017647343`*^9, 3.8006359029655447`*^9}, 
   3.8017784884505243`*^9, 3.803114030246209*^9, 3.8199001634582167`*^9},
 CellLabel->
  "In[701]:=",ExpressionUUID->"165a5eb4-6be8-421b-bc30-a8601059fa40"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcp0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pcapd0", 
       RowBox[{"1", "-", "sigmacp"}]], "+", " ", 
      RowBox[{"bcbpd", " ", 
       SuperscriptBox["pcbpd0", 
        RowBox[{"1", "-", "sigmacp"}]]}], "+", " ", 
      RowBox[{"bcpt", " ", 
       SuperscriptBox["pcpt0", 
        RowBox[{"1", "-", "sigmacp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmacp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997958509960957`*^9, 3.7997958511523705`*^9}, {3.7997958825974145`*^9, 
   3.7997959023410273`*^9}, 3.799797010160509*^9, 3.799799480071886*^9, {
   3.7998823985570292`*^9, 3.799882443902623*^9}, {3.8006358549642*^9, 
   3.800635865222805*^9}, 3.8031140276891904`*^9, 3.819900164684173*^9},
 CellLabel->
  "In[702]:=",ExpressionUUID->"1db1b605-38f2-4865-81d9-83fb4ce5459c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bppt", " ", "=", " ", 
   RowBox[{
    FractionBox["vppt0", "vpapd0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pppt0", "ppapd0"], ")"}], 
     RowBox[{"sigmapp", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799882129238101*^9, 3.7998821369837103`*^9}, {
   3.799882317882104*^9, 3.799882320618568*^9}, 3.8004556160095005`*^9, {
   3.800635927888948*^9, 3.800635947304262*^9}, 3.801778484934334*^9, 
   3.8031140249670415`*^9, 3.8199001664135237`*^9},
 CellLabel->
  "In[703]:=",ExpressionUUID->"6d56b8bf-eb10-44eb-bd20-616bfb3793c8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bpwpd", " ", "=", " ", 
   RowBox[{
    FractionBox["vpwpd0", "vpapd0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["ppwpd0", "ppapd0"], ")"}], 
     RowBox[{"sigmapp", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799882211768346*^9, 3.7998822353007016`*^9}, {
   3.7998823129287024`*^9, 3.7998823153201027`*^9}, 3.8004556183690677`*^9, {
   3.800635974312439*^9, 3.8006359958912935`*^9}, 3.800636402407304*^9, 
   3.801778482995308*^9, {3.8031140196928787`*^9, 3.803114021256112*^9}, 
   3.8199001674813547`*^9},
 CellLabel->
  "In[704]:=",ExpressionUUID->"0c5a1fc9-a17f-4162-b95a-a57947163dce"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ppp0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["ppapd0", 
       RowBox[{"1", "-", "sigmapp"}]], "+", 
      RowBox[{"bpwpd", " ", 
       SuperscriptBox["ppwpd0", 
        RowBox[{"1", "-", "sigmapp"}]]}], "+", 
      RowBox[{"bppt", " ", 
       SuperscriptBox["pppt0", 
        RowBox[{"1", "-", "sigmapp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmapp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795761331473*^9, 3.7997958196402683`*^9}, {
   3.79979585405903*^9, 3.7997958543403263`*^9}, {3.7997959103580055`*^9, 
   3.7997959279447947`*^9}, 3.7997970242528243`*^9, 3.799799484307913*^9, 
   3.799882405401167*^9, {3.799882457325137*^9, 3.799882481014284*^9}, {
   3.8006359530147996`*^9, 3.800635962782674*^9}, 3.8031140177723627`*^9, 
   3.8199001694558935`*^9},
 CellLabel->
  "In[705]:=",ExpressionUUID->"f8185cd5-d52f-42fa-966e-684c811d7782"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bpp", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vpapd0", "+", "vpwpd0", "+", "vppt0"}], 
     RowBox[{"vcapd0", "+", "vcbpd0", "+", "vcpt0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Ppp0", "Pcp0"], ")"}], 
     RowBox[{"betap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, 3.819900170587779*^9},
 CellLabel->
  "In[706]:=",ExpressionUUID->"8015aced-4496-4f5f-ad9f-c35b0f5b0126"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pp0", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pcp0", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bpp", " ", 
       SuperscriptBox["Ppp0", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, 
   3.819900172121973*^9},
 CellLabel->
  "In[707]:=",ExpressionUUID->"d7ddb0c5-7c39-4b8b-9840-c5616c2a57a2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ku", "=", 
   FractionBox[
    RowBox[{"qcut0", " ", 
     SuperscriptBox["Pu0", 
      RowBox[{
       RowBox[{"-", "etau"}], "-", "betau"}]], " ", 
     SuperscriptBox["Pcu0", 
      RowBox[{"betau", "-", "sigmacu"}]], " ", 
     SuperscriptBox["pcut0", "sigmacu"]}], "bcut"]}], ";"}]], "Input",
 CellChangeTimes->{{3.800140454488206*^9, 3.800140523176643*^9}, {
   3.800455058428173*^9, 3.800455063959334*^9}, {3.8006362513154964`*^9, 
   3.800636260384779*^9}, 3.8006363054963803`*^9, 3.800647348889147*^9, 
   3.8006960898303185`*^9, 3.800804256877533*^9, {3.8008043645295997`*^9, 
   3.800804364685875*^9}, {3.8008068728494596`*^9, 3.800806875974489*^9}, {
   3.8016604841908655`*^9, 3.8016604867536297`*^9}, {3.801663391117081*^9, 
   3.801663391882834*^9}, 3.801664413638791*^9, {3.8016647577403903`*^9, 
   3.801664759459405*^9}, {3.8016648404783707`*^9, 3.8016648805396347`*^9}, {
   3.801665135307444*^9, 3.801665211909813*^9}, 3.8016653900835795`*^9, {
   3.8016670898715615`*^9, 3.8016670989043036`*^9}, {3.80168887262052*^9, 
   3.8016888744489493`*^9}, {3.8016889608852425`*^9, 3.801689010426876*^9}, {
   3.8017784454569283`*^9, 3.801778458163327*^9}, 3.801778528743101*^9, {
   3.8017814934521255`*^9, 3.8017814938740683`*^9}, {3.8031140023071547`*^9, 
   3.803114014512789*^9}, {3.8031260626605997`*^9, 3.8031261061075296`*^9}, 
   3.8199001731487722`*^9},
 CellLabel->
  "In[708]:=",ExpressionUUID->"0f3e7553-f6e2-4c16-ad42-a622b32f2bcb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kp", "=", 
   FractionBox[
    RowBox[{"qcpt0", " ", 
     SuperscriptBox["Pp0", 
      RowBox[{
       RowBox[{"-", "etap"}], "-", "betap"}]], " ", 
     SuperscriptBox["Pcp0", 
      RowBox[{"betap", "-", "sigmacp"}]], " ", 
     SuperscriptBox["pcpt0", "sigmacp"]}], "bcpt"]}], ";"}]], "Input",
 CellChangeTimes->{{3.801689038848219*^9, 3.8016890477090626`*^9}, 
   3.80177853075905*^9, 3.8031139983340187`*^9, {3.8031261513407984`*^9, 
   3.80312624801073*^9}, {3.8031284224239283`*^9, 3.8031284235638275`*^9}, 
   3.8199001741535597`*^9},
 CellLabel->
  "In[709]:=",ExpressionUUID->"3ef16ad7-9288-471b-b407-adece8171bc8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4. New Equilibrium Calculation",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.7954529786642447`*^9}, {
  3.79545386036082*^9, 3.7954538618860044`*^9}, {3.795525436722562*^9, 
  3.795525448873003*^9}, {3.819900451316465*^9, 
  3.819900451678748*^9}},ExpressionUUID->"6efe3518-2c63-42f3-8971-\
bde633ae5275"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pcad", 
       RowBox[{"1", "-", "sigmacu"}]], "+", 
      RowBox[{"bcbd", " ", 
       SuperscriptBox["pcbd", 
        RowBox[{"1", "-", "sigmacu"}]]}], "+", 
      RowBox[{"bcut", " ", 
       SuperscriptBox["pcut", 
        RowBox[{"1", "-", "sigmacu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmacu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
  3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
  3.799799466116406*^9}, {3.799883841391208*^9, 3.7998838442227187`*^9}, {
  3.799883947798026*^9, 3.799883969766282*^9}},
 CellLabel->
  "In[710]:=",ExpressionUUID->"aa8d578c-5b5a-45ae-83be-ba8751860eb4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ppu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["ppad", 
       RowBox[{"1", "-", "sigmapu"}]], "+", 
      RowBox[{"bpwd", " ", 
       SuperscriptBox["ppwd", 
        RowBox[{"1", "-", "sigmapu"}]]}], "+", 
      RowBox[{"bput", " ", 
       SuperscriptBox["pput", 
        RowBox[{"1", "-", "sigmapu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmapu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795761331473*^9, 3.7997958196402683`*^9}, {
   3.7997970184990273`*^9, 3.799797020958833*^9}, {3.799799472226812*^9, 
   3.7997994757274027`*^9}, {3.7998558920843744`*^9, 3.799855894631646*^9}, {
   3.799883848610205*^9, 3.799883853329248*^9}, {3.799883950068345*^9, 
   3.799883971329658*^9}, 3.80063632845203*^9},
 CellLabel->
  "In[711]:=",ExpressionUUID->"0fd66d5b-dd6a-4f0a-b82d-c0927a6d29fb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcapd", "=", 
   FractionBox[
    RowBox[{"pcad", " ", "pcapd0"}], "pcad0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031106027958107`*^9, 3.8031106200452766`*^9}, 
   3.8031139807171125`*^9},
 CellLabel->
  "In[712]:=",ExpressionUUID->"4d3a58b9-84d8-4177-9dd1-24446efe7c35"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcbpd", "=", 
   FractionBox[
    RowBox[{"pcbd", " ", "pcbpd0"}], "pcbd0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.803110624774968*^9, 3.8031106479980693`*^9}, 
   3.803113983334178*^9},
 CellLabel->
  "In[713]:=",ExpressionUUID->"802af631-5e9c-4f44-8dae-f13bf930810d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ppapd", "=", 
   FractionBox[
    RowBox[{"ppad", " ", "ppapd0"}], "ppad0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.803110651421729*^9, 3.8031106663813496`*^9}, {
  3.803113985789116*^9, 3.8031139892208242`*^9}},
 CellLabel->
  "In[714]:=",ExpressionUUID->"d6f6c8e7-6f57-4e9b-9f70-fc156e1ed5c0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ppwpd", "=", 
   FractionBox[
    RowBox[{"ppwd", " ", "ppwpd0"}], "ppwd0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031106707467413`*^9, 3.8031106892230964`*^9}, 
   3.803113991247425*^9},
 CellLabel->
  "In[715]:=",ExpressionUUID->"af8364b8-7c21-4147-80b1-1df6901268b2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pu", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pcu", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bpu", " ", 
       SuperscriptBox["Ppu", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
  3.7997958259222507`*^9, 3.7997958373159857`*^9}, {3.7998802231121106`*^9, 
  3.7998802231121106`*^9}, {3.799883951419473*^9, 3.7998839722424846`*^9}, {
  3.800636334220508*^9, 3.800636359859481*^9}},
 CellLabel->
  "In[716]:=",ExpressionUUID->"2df0c153-d783-43ec-bb5f-1245fe3caf68"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcp", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pcapd", 
       RowBox[{"1", "-", "sigmacp"}]], "+", 
      RowBox[{"bcbpd", " ", 
       SuperscriptBox["pcbpd", 
        RowBox[{"1", "-", "sigmacp"}]]}], "+", 
      RowBox[{"bcpt", " ", 
       SuperscriptBox["pcpt", 
        RowBox[{"1", "-", "sigmacp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmacp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997958509960957`*^9, 3.7997958511523705`*^9}, {3.7997958825974145`*^9, 
   3.7997959023410273`*^9}, 3.799797010160509*^9, 3.799799480071886*^9, {
   3.7998823985570292`*^9, 3.799882443902623*^9}, {3.799883856794115*^9, 
   3.799883859756853*^9}, {3.7998839526633596`*^9, 3.799883974178073*^9}, {
   3.8006481684928246`*^9, 3.8006481883364725`*^9}},
 CellLabel->
  "In[717]:=",ExpressionUUID->"5914bcc6-5e47-452d-ae70-a78ec9af93a0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ppp", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["ppapd", 
       RowBox[{"1", "-", "sigmapp"}]], "+", 
      RowBox[{"bpwpd", " ", 
       SuperscriptBox["ppwpd", 
        RowBox[{"1", "-", "sigmapp"}]]}], "+", 
      RowBox[{"bppt", " ", 
       SuperscriptBox["pppt", 
        RowBox[{"1", "-", "sigmapp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmapp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795761331473*^9, 3.7997958196402683`*^9}, {
   3.79979585405903*^9, 3.7997958543403263`*^9}, {3.7997959103580055`*^9, 
   3.7997959279447947`*^9}, 3.7997970242528243`*^9, 3.799799484307913*^9, 
   3.799882405401167*^9, {3.799882457325137*^9, 3.799882481014284*^9}, {
   3.7998838626717834`*^9, 3.7998838670329533`*^9}, {3.799883954037471*^9, 
   3.799883975427908*^9}, 3.8006363544681597`*^9},
 CellLabel->
  "In[718]:=",ExpressionUUID->"7e387e4e-35a0-4e83-b5c5-ced9406f2ab4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pp", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pcp", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bpp", " ", 
       SuperscriptBox["Ppp", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
  3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
  3.7998825043579335`*^9}, {3.7998839553184*^9, 3.7998839762741423`*^9}, {
  3.8006363432890615`*^9, 3.8006363491003437`*^9}},
 CellLabel->
  "In[719]:=",ExpressionUUID->"f10a4f32-6691-49e0-827e-d253aea0766f"],

Cell[TextData[StyleBox["Equilibrium equations",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8199002458925085`*^9, 
  3.819900248916869*^9}},ExpressionUUID->"75f96c3d-f0f4-4f9c-9665-\
d923a4e53876"],

Cell["\<\
Supply (landings) of Atlantic cod = exports + consumer demand for unprocessed \
fish + consumer demand for processed fish\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800413034212*^9}, 3.799855091636346*^9, {
   3.799884003726459*^9, 3.7998840232612796`*^9}, {3.800099320730234*^9, 
   3.800099324730491*^9}, {3.8199002189164705`*^9, 3.819900263780464*^9}, {
   3.819901722054987*^9, 3.8199017301532373`*^9}, {3.819901765100212*^9, 
   3.8199017660459433`*^9}},ExpressionUUID->"a73e3fe0-db97-486d-b715-\
1d3b31d8449a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E1", "=", 
   RowBox[{
    RowBox[{"qcacap", "-", 
     RowBox[{"acad", " ", 
      SuperscriptBox["pcad", 
       RowBox[{"-", "ecad"}]]}]}], "\[Equal]", 
    RowBox[{
     RowBox[{"cr", " ", "qcape0"}], "+", "qcae0", "+", 
     RowBox[{"ku", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"betau", "+", "etau"}]], " ", 
      SuperscriptBox["Pcu", 
       RowBox[{"sigmacu", "-", "betau"}]], " ", 
      SuperscriptBox["pcad", 
       RowBox[{"-", "sigmacu"}]]}], "+", 
     RowBox[{"cr", " ", "kp", " ", 
      SuperscriptBox["Pp", 
       RowBox[{"betap", "+", "etap"}]], " ", 
      SuperscriptBox["Pcp", 
       RowBox[{"sigmacp", "-", "betap"}]], " ", 
      SuperscriptBox["pcapd", 
       RowBox[{"-", "sigmacp"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.804603786234771*^9, 3.8046037866410913`*^9}, {
   3.8046038467049193`*^9, 3.8046038469549537`*^9}},
 CellLabel->
  "In[720]:=",ExpressionUUID->"7054bfa1-6724-4536-94f8-428722fa9818"],

Cell["\<\
Supply (landings) of Pacific cod = exports + consumer demand for unprocessed \
fish + consumer demand for processed fish\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, 3.7998551408332973`*^9, 3.79988408694286*^9, 
   3.8000993330278635`*^9, {3.819900258131054*^9, 3.819900269287757*^9}, {
   3.8199017334547853`*^9, 
   3.8199017623901205`*^9}},ExpressionUUID->"96ffae92-0cfd-45d5-9cfd-\
a3dd0c38ff9b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E2", "=", 
   RowBox[{
    RowBox[{"qcbcap", "-", 
     RowBox[{"acbd", " ", 
      SuperscriptBox["pcbd", 
       RowBox[{"-", "ecbd"}]]}]}], "\[Equal]", 
    RowBox[{
     RowBox[{"cr", " ", "qcbpe0"}], "+", "qcbe0", "+", 
     RowBox[{"ku", " ", "bcbd", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"betau", "+", "etau"}]], " ", 
      SuperscriptBox["Pcu", 
       RowBox[{"sigmacu", "-", "betau"}]], " ", 
      SuperscriptBox["pcbd", 
       RowBox[{"-", "sigmacu"}]]}], "+", 
     RowBox[{"cr", " ", "kp", " ", "bcbpd", " ", 
      SuperscriptBox["Pp", 
       RowBox[{"betap", "+", "etap"}]], " ", 
      SuperscriptBox["Pcp", 
       RowBox[{"sigmacp", "-", "betap"}]], " ", 
      SuperscriptBox["pcbpd", 
       RowBox[{"-", "sigmacp"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803110859746442*^9, 3.8031109696673613`*^9}, 
   3.803113635301572*^9, {3.8031141261759324`*^9, 3.8031141263200455`*^9}, {
   3.8031256027615337`*^9, 3.8031256163970385`*^9}, 3.8031284453850527`*^9, {
   3.804603788719593*^9, 3.80460378920405*^9}, {3.804603849611679*^9, 
   3.80460385011143*^9}},
 CellLabel->
  "In[721]:=",ExpressionUUID->"ca132e8b-97e1-4b30-963a-ef271fc37fca"],

Cell["\<\
Supply (landings) of Atlantic pollock = exports + consumer demand for \
unprocessed fish + consumer demand for processed fish\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800413034212*^9}, {3.7998008528936787`*^9, 
   3.799800853846959*^9}, 3.7998551363638153`*^9, 3.7998840884898434`*^9, 
   3.8000993366813097`*^9, {3.819900274223605*^9, 3.8199002847438126`*^9}, {
   3.8199017384196177`*^9, 
   3.8199017587363005`*^9}},ExpressionUUID->"36be4f30-6b3d-4bb6-ba05-\
5f631c9e769d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E3", "=", 
   RowBox[{
    RowBox[{"qpacap", "-", 
     RowBox[{"apad", " ", 
      SuperscriptBox["ppad", 
       RowBox[{"-", "epad"}]]}]}], "\[Equal]", 
    RowBox[{
     RowBox[{"cr", " ", "qpape0"}], "+", "qpae0", "+", " ", 
     RowBox[{"ku", " ", "bpu", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"betau", "+", "etau"}]], " ", 
      SuperscriptBox["Ppu", 
       RowBox[{"sigmapu", "-", "betau"}]], " ", 
      SuperscriptBox["ppad", 
       RowBox[{"-", "sigmapu"}]]}], "+", 
     RowBox[{"cr", " ", "kp", " ", "bpp", " ", 
      SuperscriptBox["Pp", 
       RowBox[{"betap", "+", "etap"}]], " ", 
      SuperscriptBox["Ppp", 
       RowBox[{"sigmapp", "-", "betap"}]], " ", 
      SuperscriptBox["ppapd", 
       RowBox[{"-", "sigmapp"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803110988392722*^9, 3.8031110939670534`*^9}, 
   3.803125576387216*^9, {3.8031256752003384`*^9, 3.8031256904912405`*^9}, {
   3.804603792142338*^9, 3.80460379257992*^9}, {3.804603851973323*^9, 
   3.804603852364014*^9}},
 CellLabel->
  "In[722]:=",ExpressionUUID->"d0db1933-af5c-479a-bd96-4f2a868289a9"],

Cell["\<\
Supply (landings) of Alaskan pollock = exports + consumer demand for \
unprocessed fish + consumer demand for processed fish\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, 
   3.7998551317693195`*^9, 3.7998840907263556`*^9, 3.80009934008679*^9, {
   3.8199017471813817`*^9, 
   3.8199017776859274`*^9}},ExpressionUUID->"5bce048f-2e4b-44f4-b547-\
0f9537bd8e95"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E4", "=", 
   RowBox[{
    RowBox[{"qpwcap", "-", 
     RowBox[{"apwd", " ", 
      SuperscriptBox["ppwd", 
       RowBox[{"-", "epwd"}]]}]}], "\[Equal]", 
    RowBox[{
     RowBox[{"cr", " ", "qpwpe0"}], "+", "qpwe0", "+", 
     RowBox[{"ku", " ", "bpwd", " ", "bpu", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"betau", "+", "etau"}]], " ", 
      SuperscriptBox["Ppu", 
       RowBox[{"sigmapu", "-", "betau"}]], " ", 
      SuperscriptBox["ppwd", 
       RowBox[{"-", "sigmapu"}]]}], "+", 
     RowBox[{"cr", " ", "kp", " ", "bpp", " ", "bpwpd", " ", 
      SuperscriptBox["Pp", 
       RowBox[{"betap", "+", "etap"}]], " ", 
      SuperscriptBox["Ppp", 
       RowBox[{"sigmapp", "-", "betap"}]], " ", 
      SuperscriptBox["ppwpd", 
       RowBox[{"-", "sigmapp"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803113311147688*^9, 3.803113465283148*^9}, 
   3.8031136392176266`*^9, {3.80312570470531*^9, 3.8031257096051273`*^9}, {
   3.80312845780886*^9, 3.803128476928952*^9}, {3.8046037947367907`*^9, 
   3.8046037951274824`*^9}, {3.804603854583156*^9, 3.8046038550207334`*^9}},
 CellLabel->
  "In[723]:=",ExpressionUUID->"f35fcdc3-ebb1-4d2b-a054-a2ede2c86ca9"],

Cell["\<\
Supply of imported unprocessed product = Demand for imported unprocessed \
product\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 
  3.7998012380597954`*^9}},ExpressionUUID->"f2222292-c02a-4dff-bfb0-\
5253e658f6aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E5", "=", 
   RowBox[{
    RowBox[{"qcul0", "+", 
     RowBox[{"replcu", " ", "qcui0"}]}], "\[Equal]", 
    RowBox[{"ku", " ", "bcut", " ", 
     SuperscriptBox["Pu", 
      RowBox[{"betau", "+", "etau"}]], " ", 
     SuperscriptBox["Pcu", 
      RowBox[{"sigmacu", "-", "betau"}]], " ", 
     SuperscriptBox["pcut", 
      RowBox[{"-", "sigmacu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9},
 CellLabel->
  "In[724]:=",ExpressionUUID->"791f993f-332f-45c9-b74d-5610bfc47b08"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E6", "=", 
   RowBox[{
    RowBox[{"qpul0", "+", 
     RowBox[{"replpu", " ", "qpui0"}]}], "\[Equal]", 
    RowBox[{"ku", " ", "bput", " ", "bpu", " ", 
     SuperscriptBox["Pu", 
      RowBox[{"betau", "+", "etau"}]], " ", 
     SuperscriptBox["Ppu", 
      RowBox[{"sigmapu", "-", "betau"}]], " ", 
     SuperscriptBox["pput", 
      RowBox[{"-", "sigmapu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031136449380817`*^9, 3.8031136900322046`*^9}},
 CellLabel->
  "In[725]:=",ExpressionUUID->"62f1499c-24cc-425f-9324-f3be4945ab76"],

Cell["\<\
Supply of imported processed product = Demand for imported processed product\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.7998012380597954`*^9}, {3.799884418200181*^9, 
  3.799884420684106*^9}},ExpressionUUID->"aee4aa60-9cad-4f3f-8312-\
69ed87061370"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E7", "=", 
   RowBox[{
    RowBox[{"qcpl0", "+", 
     RowBox[{"replcp", " ", "qcpi0"}]}], "\[Equal]", 
    RowBox[{"kp", " ", "bcpt", " ", 
     SuperscriptBox["Pp", 
      RowBox[{"betap", "+", "etap"}]], " ", 
     SuperscriptBox["Pcp", 
      RowBox[{"sigmacp", "-", "betap"}]], " ", 
     SuperscriptBox["pcpt", 
      RowBox[{"-", "sigmacp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}},
 CellLabel->
  "In[726]:=",ExpressionUUID->"dc442f99-2bf6-4cb3-b474-ca34a001692e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E8", "=", 
   RowBox[{
    RowBox[{"qppl0", "+", 
     RowBox[{"replpp", " ", "qppi0"}]}], "\[Equal]", 
    RowBox[{"kp", " ", "bppt", " ", "bpp", " ", 
     SuperscriptBox["Pp", 
      RowBox[{"betap", "+", "etap"}]], " ", 
     SuperscriptBox["Ppp", 
      RowBox[{"sigmapp", "-", "betap"}]], " ", 
     SuperscriptBox["pppt", 
      RowBox[{"-", "sigmapp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311376378687*^9, 3.803113811874564*^9}},
 CellLabel->
  "In[727]:=",ExpressionUUID->"3fc77d92-ac80-4744-8d45-862d3d502330"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "E1", ",", "E2", ",", "E3", ",", "E4", ",", "E5", ",", "E6", ",", "E7", 
     ",", "E8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pcad", ",", "pcad0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pcbd", ",", "pcbd0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ppad", ",", "ppad0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ppwd", ",", "ppwd0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pcut", ",", "pcut0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pput", ",", "pput0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pcpt", ",", "pcpt0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pppt", ",", "pppt0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799801050741409*^9, 3.7998010802456255`*^9}, {
   3.799801592828159*^9, 3.799801634478999*^9}, {3.7998017203390927`*^9, 
   3.799801763344025*^9}, 3.7998021088038597`*^9, {3.799855159502365*^9, 
   3.799855165706504*^9}, {3.801692496821689*^9, 3.801692518577862*^9}, {
   3.801780123825697*^9, 3.8017801628874054`*^9}, {3.80178020897694*^9, 
   3.8017802303410735`*^9}},
 CellLabel->
  "In[728]:=",ExpressionUUID->"6340c5ef-1fdf-4a1b-8913-8de97b421861"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"pcad", "\[Rule]", "4.902237782508801`"}], ",", 
   RowBox[{"pcbd", "\[Rule]", "1.0297157491394147`"}], ",", 
   RowBox[{"ppad", "\[Rule]", "1.7377641573055906`"}], ",", 
   RowBox[{"ppwd", "\[Rule]", "0.29614758494652527`"}], ",", 
   RowBox[{"pcut", "\[Rule]", "4.7217105807272395`"}], ",", 
   RowBox[{"pput", "\[Rule]", "2.5613977407136233`"}], ",", 
   RowBox[{"pcpt", "\[Rule]", "8.31757404943533`"}], ",", 
   RowBox[{"pppt", "\[Rule]", "2.923148139467935`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.799801093763195*^9, {3.7998016669393826`*^9, 3.799801696037279*^9}, {
   3.7998020915809345`*^9, 3.7998021123826103`*^9}, 3.799848486496959*^9, 
   3.7998493720505886`*^9, 3.7998495460808*^9, 3.7998495827852774`*^9, 
   3.7998508673590183`*^9, 3.7998510911466*^9, 3.799855179569358*^9, 
   3.7998552583267956`*^9, 3.7998567268243713`*^9, {3.799856759244939*^9, 
   3.799856772042405*^9}, 3.7998571935896273`*^9, {3.799857408768899*^9, 
   3.799857480047553*^9}, 3.7998575201979704`*^9, {3.799857622049017*^9, 
   3.7998576645100875`*^9}, 3.79985775764964*^9, 3.801660629881942*^9, {
   3.8016608170671644`*^9, 3.8016608355867376`*^9}, 3.801662762470487*^9, 
   3.8016634601520014`*^9, 3.8016642619493084`*^9, {3.8016643116509943`*^9, 
   3.801664333932659*^9}, 3.8016644580255985`*^9, 3.801665331312312*^9, 
   3.801665396193937*^9, 3.8016654271062555`*^9, {3.8016667203770294`*^9, 
   3.801666749521549*^9}, 3.8016667847731276`*^9, {3.8016669582001734`*^9, 
   3.8016669828621435`*^9}, 3.8016671121408663`*^9, 3.8016672254654093`*^9, 
   3.801667395428297*^9, 3.80166758146786*^9, 3.8016677818030624`*^9, {
   3.801667840912076*^9, 3.8016678618370447`*^9}, 3.801667932293232*^9, {
   3.8016681816615696`*^9, 3.801668203237288*^9}, {3.8016682671629763`*^9, 
   3.8016682942170086`*^9}, {3.801668343478133*^9, 3.8016683689058094`*^9}, 
   3.8016684195854483`*^9, 3.80166845156184*^9, 3.801668485767635*^9, 
   3.8016685398657312`*^9, 3.8016925768886733`*^9, 3.801692636059538*^9, 
   3.8016927417751255`*^9, 3.8016929474960947`*^9, 3.8016929983449326`*^9, 
   3.8016932252114334`*^9, 3.801693280035522*^9, 3.8016933902548666`*^9, 
   3.8016934841659365`*^9, 3.801776978095092*^9, 3.8017771960401382`*^9, 
   3.801777268025716*^9, 3.8017776446912208`*^9, 3.801778000507889*^9, 
   3.8017780698584113`*^9, {3.8017783088964415`*^9, 3.8017783339791546`*^9}, 
   3.801778651168253*^9, 3.801778711918086*^9, 3.801779136145438*^9, 
   3.801779246660454*^9, 3.801779504151821*^9, 3.801779547429063*^9, 
   3.8017796194290113`*^9, 3.8017797077018986`*^9, {3.80177977559*^9, 
   3.801779815288269*^9}, 3.801779851625734*^9, 3.80177989780993*^9, {
   3.801779938679492*^9, 3.8017799660435505`*^9}, {3.801780135110194*^9, 
   3.8017801586198745`*^9}, {3.8017802243244615`*^9, 3.8017802522196016`*^9}, 
   3.801780304944173*^9, 3.8017803423973784`*^9, {3.8017804415010777`*^9, 
   3.8017804699602876`*^9}, 3.8017805380749445`*^9, 3.801780578325031*^9, 
   3.801780663659497*^9, 3.8017811746938562`*^9, 3.8017812140865235`*^9, 
   3.8017819858354435`*^9, 3.801782032443123*^9, 3.8017820849493985`*^9, {
   3.801782213935169*^9, 3.80178224451851*^9}, 3.8030750831535826`*^9, 
   3.8030751502423997`*^9, 3.8030752588381195`*^9, 3.8030754031084967`*^9, 
   3.8030755051341305`*^9, 3.803113961115629*^9, 3.8031140809962687`*^9, 
   3.8031141435171995`*^9, 3.803114190749054*^9, 3.803114297354243*^9, 
   3.8031143933221292`*^9, 3.8031185684207845`*^9, 3.803118637884*^9, 
   3.8031187017608566`*^9, {3.803118746858054*^9, 3.8031187687481422`*^9}, 
   3.803118808171912*^9, 3.803120592520523*^9, 3.8031206304842153`*^9, 
   3.803124415843292*^9, 3.803124516631939*^9, 3.803124909992894*^9, 
   3.8031249912032137`*^9, 3.803125758705367*^9, 3.8031262530557327`*^9, 
   3.8031284818508377`*^9, 3.8031286688237686`*^9, 3.8032924984470205`*^9, 
   3.803303070796772*^9, 3.80330326390864*^9, 3.8033104006597986`*^9, 
   3.8033128919827037`*^9, 3.803313218397664*^9, 3.803391638515458*^9, 
   3.8033920558162465`*^9, 3.803392119387043*^9, 3.803392510423015*^9, 
   3.8033926215275464`*^9, 3.8033941576111856`*^9, 3.803394789895152*^9, 
   3.803394900344415*^9, 3.8033973159164147`*^9, 3.803397430778718*^9, 
   3.803398053956446*^9, 3.803398418579626*^9, 3.8033985809918175`*^9, 
   3.803509619550227*^9, 3.803510328359913*^9, 3.8035117198427258`*^9, 
   3.8035121794354076`*^9, 3.804603820795101*^9, 3.8046038642413425`*^9, 
   3.8046044008062897`*^9, 3.804605229103111*^9, 3.804605784575312*^9, 
   3.8046060131572914`*^9, 3.804866391822832*^9, 3.805710250373438*^9, 
   3.805710948561816*^9, 3.805711259513997*^9, 3.8057121097268*^9, 
   3.805712152359662*^9, 3.805712363301628*^9, 3.8057129770059104`*^9, 
   3.8066681631384044`*^9, 3.806668530561516*^9, 3.8066686097280264`*^9, 
   3.8078698717429132`*^9, 3.807871458509446*^9, 3.8078721625787716`*^9, 
   3.8078727771724367`*^9, 3.8100320296547036`*^9, 3.810032112597678*^9, 
   3.8100328479359207`*^9, 3.8100328847079196`*^9, 3.8124653826998963`*^9, 
   3.8124662292410145`*^9, 3.812466529716219*^9, 3.812492958145162*^9, 
   3.812820885963686*^9, 3.812926006957427*^9, 3.8129263307774506`*^9, 
   3.8129265645129375`*^9, 3.812974798365485*^9, 3.8129750343098884`*^9, 
   3.8129752870320563`*^9, 3.8141738520853243`*^9, 3.8154736786889157`*^9, 
   3.8154765234525356`*^9, 3.8157738601036425`*^9, 3.8169824031537533`*^9, 
   3.818802495513115*^9, 3.819900313583306*^9, 3.8199017995518055`*^9, 
   3.8199021624142714`*^9},
 CellLabel->
  "Out[728]=",ExpressionUUID->"4998d516-9158-4ff2-9055-0f4b9d004cea"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcad1", " ", "=", " ", 
   RowBox[{"pcad", "/.", "%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}},
 CellLabel->
  "In[729]:=",ExpressionUUID->"946f9cfe-6f47-48dd-8266-de1998056519"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcbd1", " ", "=", " ", 
   RowBox[{"pcbd", "/.", "%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}},
 CellLabel->
  "In[730]:=",ExpressionUUID->"43559586-6a2c-42e9-a31e-8d54a991c323"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ppad1", " ", "=", " ", 
   RowBox[{"ppad", "/.", "%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}},
 CellLabel->
  "In[731]:=",ExpressionUUID->"fe6319c4-183f-4cb1-8921-13252519ec27"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ppwd1", " ", "=", " ", 
   RowBox[{"ppwd", "/.", "%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799848561374796*^9, 3.799848566658134*^9}},
 CellLabel->
  "In[732]:=",ExpressionUUID->"bc2bf2dc-1d05-4fe9-9efe-2172e9675c5a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcut1", " ", "=", " ", 
   RowBox[{"pcut", "/.", "%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485695648746`*^9, 3.799848575519005*^9}},
 CellLabel->
  "In[733]:=",ExpressionUUID->"e6a552d1-cf06-4d90-935d-feefd60c255d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pput1", " ", "=", " ", 
   RowBox[{"pput", "/.", "%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799848577628736*^9, 3.7998485880523696`*^9}},
 CellLabel->
  "In[734]:=",ExpressionUUID->"a6404b66-6b0d-45b1-9391-804c29018842"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcpt1", " ", "=", " ", 
   RowBox[{"pcpt", "/.", "%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8016925260790687`*^9, 3.8016925348573046`*^9}},
 CellLabel->
  "In[735]:=",ExpressionUUID->"a134f14b-cc5d-4e74-b79f-e0f1ea953b32"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pppt1", " ", "=", " ", 
   RowBox[{"pppt", "/.", "%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.801692537607747*^9, 3.8016925471090755`*^9}},
 CellLabel->
  "In[736]:=",ExpressionUUID->"a3935f56-7f28-4cc4-b0c6-cecdf51079f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcapd1", "=", 
   FractionBox[
    RowBox[{"pcad1", " ", "pcapd0"}], "pcad0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.803113854588833*^9, 3.803113870126218*^9}, {
  3.803114384386155*^9, 3.8031143878348455`*^9}},
 CellLabel->
  "In[737]:=",ExpressionUUID->"91bd7d00-1d82-44fa-9b43-aa2c00886121"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcbpd1", "=", 
   FractionBox[
    RowBox[{"pcbd1", " ", "pcbpd0"}], "pcbd0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031138806095605`*^9, 3.8031138969815903`*^9}},
 CellLabel->
  "In[738]:=",ExpressionUUID->"c6382e9b-f16f-45a4-8818-5c66c4a53a51"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ppapd1", "=", 
   FractionBox[
    RowBox[{"ppad1", " ", "ppapd0"}], "ppad0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031139113360133`*^9, 3.803113924432436*^9}, 
   3.8031142851327047`*^9, 3.8031286620785046`*^9},
 CellLabel->
  "In[739]:=",ExpressionUUID->"2eef2dd1-4242-4d28-9088-8ba13709e6c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ppwpd1", "=", 
   FractionBox[
    RowBox[{"ppwd1", " ", "ppwpd0"}], "ppwd0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031139294894605`*^9, 3.803113946139711*^9}},
 CellLabel->
  "In[740]:=",ExpressionUUID->"70209f65-ab01-40c7-a573-6d42b6ba8db8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pcad1", 
       RowBox[{"1", "-", "sigmacu"}]], "+", 
      RowBox[{"bcbd", " ", 
       SuperscriptBox["pcbd1", 
        RowBox[{"1", "-", "sigmacu"}]]}], "+", 
      RowBox[{"bcut", " ", 
       SuperscriptBox["pcut1", 
        RowBox[{"1", "-", "sigmacu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmacu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799006779924*^9, 
   3.7997990177856345`*^9}, {3.7997996118326197`*^9, 3.799799614692478*^9}, {
   3.7998491146327343`*^9, 3.799849121727642*^9}, 3.8001436087352085`*^9, 
   3.8017786973363285`*^9},
 CellLabel->
  "In[741]:=",ExpressionUUID->"fc95c1e6-633a-4511-a3f9-d176ef1fdd31"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ppu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["ppad1", 
       RowBox[{"1", "-", "sigmapu"}]], "+", 
      RowBox[{"bpwd", " ", 
       SuperscriptBox["ppwd1", 
        RowBox[{"1", "-", "sigmapu"}]]}], "+", 
      RowBox[{"bput", " ", 
       SuperscriptBox["pput1", 
        RowBox[{"1", "-", "sigmapu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmapu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795761331473*^9, 3.7997958196402683`*^9}, {
   3.7997970184990273`*^9, 3.799797020958833*^9}, {3.7997990216457844`*^9, 
   3.799799029585249*^9}, {3.7997996186775255`*^9, 3.7997996218667617`*^9}, {
   3.799849126446944*^9, 3.7998491325573177`*^9}, {3.7998567518331766`*^9, 
   3.7998567533334293`*^9}, 3.8001436065038085`*^9, {3.800655774107869*^9, 
   3.800655775412724*^9}, 3.801778699039727*^9},
 CellLabel->
  "In[742]:=",ExpressionUUID->"c0e293fb-b689-4d8a-8e4b-1a11368dcbba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pu1", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pcu1", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bpu", " ", 
       SuperscriptBox["Ppu1", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958373159857`*^9}, {3.7997990343001633`*^9, 
   3.799799037441419*^9}, {3.7998020660126486`*^9, 3.7998020682630568`*^9}, {
   3.799802145143566*^9, 3.799802147409587*^9}, {3.799849136948657*^9, 
   3.7998491404336023`*^9}, {3.79988022321935*^9, 3.79988022321935*^9}, 
   3.8001436051244516`*^9, {3.800655787912216*^9, 3.8006557929372635`*^9}, 
   3.801778701415109*^9},
 CellLabel->
  "In[743]:=",ExpressionUUID->"0246d465-db44-4b41-93d2-8a4ab521c5d2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcp1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pcapd1", 
       RowBox[{"1", "-", "sigmacp"}]], "+", " ", 
      RowBox[{"bcbpd", " ", 
       SuperscriptBox["pcbpd1", 
        RowBox[{"1", "-", "sigmacp"}]]}], "+", " ", 
      RowBox[{"bcpt", " ", 
       SuperscriptBox["pcpt1", 
        RowBox[{"1", "-", "sigmacp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmacp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997958509960957`*^9, 3.7997958511523705`*^9}, {3.7997958825974145`*^9, 
   3.7997959023410273`*^9}, 3.799797010160509*^9, 3.799799480071886*^9, {
   3.7998823985570292`*^9, 3.799882443902623*^9}, {3.799883856794115*^9, 
   3.799883859756853*^9}, {3.7998839526633596`*^9, 3.799883974178073*^9}, {
   3.7998850031936626`*^9, 3.7998850126359525`*^9}, 3.800143603546193*^9, 
   3.801778704040531*^9},
 CellLabel->
  "In[744]:=",ExpressionUUID->"9d35a1f8-79b4-4ca5-a2ba-98cd853fc1a6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ppp1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["ppapd1", 
       RowBox[{"1", "-", "sigmapp"}]], "+", 
      RowBox[{"bpwpd", " ", 
       SuperscriptBox["ppwpd1", 
        RowBox[{"1", "-", "sigmapp"}]]}], "+", 
      RowBox[{"bppt", " ", 
       SuperscriptBox["pppt1", 
        RowBox[{"1", "-", "sigmapp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmapp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795761331473*^9, 3.7997958196402683`*^9}, {
   3.79979585405903*^9, 3.7997958543403263`*^9}, {3.7997959103580055`*^9, 
   3.7997959279447947`*^9}, 3.7997970242528243`*^9, 3.799799484307913*^9, 
   3.799882405401167*^9, {3.799882457325137*^9, 3.799882481014284*^9}, {
   3.7998838626717834`*^9, 3.7998838670329533`*^9}, {3.799883954037471*^9, 
   3.799883975427908*^9}, {3.799885004762644*^9, 3.7998850200269156`*^9}, 
   3.800143600438214*^9, {3.8006557824694614`*^9, 3.800655784444539*^9}, 
   3.801778706526594*^9},
 CellLabel->
  "In[745]:=",ExpressionUUID->"10aff98a-4857-41ac-bede-105e8cb621c5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pp1", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pcp1", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bpp", " ", 
       SuperscriptBox["Ppp1", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.7998839553184*^9, 3.7998839762741423`*^9}, {
   3.7998850065730867`*^9, 3.79988502354272*^9}, 3.800143601813506*^9, {
   3.800655802484022*^9, 3.800655807457328*^9}, 3.8017787086988187`*^9},
 CellLabel->
  "In[746]:=",ExpressionUUID->"7eb3f504-88f5-427e-a252-e664984961bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcad1", "=", 
   RowBox[{"qcacap", "-", 
    RowBox[{"acad", " ", 
     SuperscriptBox["pcad1", 
      RowBox[{"-", "ecad"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}},
 CellLabel->
  "In[747]:=",ExpressionUUID->"da2c9595-e3fc-4efc-8340-7fcfa41ee32f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcbd1", " ", "=", " ", 
   RowBox[{"qcbcap", "-", 
    RowBox[{"acbd", " ", 
     SuperscriptBox["pcbd1", 
      RowBox[{"-", "ecbd"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033940178763266`*^9, 3.803394028348838*^9}},
 CellLabel->
  "In[748]:=",ExpressionUUID->"c290c976-f5e3-49dc-963f-e8722bd80e20"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qpad1", " ", "=", " ", 
   RowBox[{"qpacap", "-", 
    RowBox[{"apad", " ", 
     SuperscriptBox["ppad1", 
      RowBox[{"-", "epad"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033940407098055`*^9, 3.803394050857397*^9}},
 CellLabel->
  "In[749]:=",ExpressionUUID->"32873a83-47cb-406a-a308-fda2fe93d096"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qpwd1", " ", "=", " ", 
   RowBox[{"qpwcap", "-", 
    RowBox[{"apwd", " ", 
     SuperscriptBox["ppwd1", 
      RowBox[{"-", "epwd"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033940622133217`*^9, 3.803394067980044*^9}},
 CellLabel->
  "In[750]:=",ExpressionUUID->"392881df-afab-4cc6-9d89-7dcceec768ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcut1", " ", "=", " ", 
   RowBox[{"qcul0", "+", 
    RowBox[{"replcu", " ", "qcui0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}},
 CellLabel->
  "In[751]:=",ExpressionUUID->"968cd914-3f2c-4fc0-8be1-87db76fa5032"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qput1", "=", 
   RowBox[{"qpul0", "+", 
    RowBox[{"replpu", " ", "qpui0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}},
 CellLabel->
  "In[752]:=",ExpressionUUID->"5d201a59-15f3-4a9f-b1d9-6ab7b8e60249"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcpt1", "=", 
   RowBox[{"qcpl0", "+", 
    RowBox[{"replcp", " ", "qcpi0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941238041935`*^9, 3.8033941294194355`*^9}, {
  3.803394480868445*^9, 3.803394480977838*^9}},
 CellLabel->
  "In[753]:=",ExpressionUUID->"f24cfdc7-08f2-44bc-bea0-c6332a30c99f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qppt1", " ", "=", " ", 
   RowBox[{"qppl0", "+", 
    RowBox[{"replpp", " ", "qppi0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394138561163*^9, 3.8033941407021356`*^9}, {
  3.8033944838222632`*^9, 3.8033944839785385`*^9}},
 CellLabel->
  "In[754]:=",ExpressionUUID->"feffc2a7-9dec-48a2-9dc1-d09d88885cf1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcapd1", " ", "=", " ", 
   RowBox[{"qcape0", "+", 
    RowBox[{"kp", " ", 
     SuperscriptBox["Pp1", 
      RowBox[{"betap", "+", "etap"}]], " ", 
     SuperscriptBox["Pcp1", 
      RowBox[{"sigmacp", "-", "betap"}]], " ", 
     SuperscriptBox["pcapd1", 
      RowBox[{"-", "sigmacp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}},
 CellLabel->
  "In[755]:=",ExpressionUUID->"c5d80009-058b-43b9-95a0-97be06ff345a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcbpd1", " ", "=", " ", 
   RowBox[{"qcbpe0", "+", 
    RowBox[{"kp", " ", "bcbpd", " ", 
     SuperscriptBox["Pp1", 
      RowBox[{"betap", "+", "etap"}]], " ", 
     SuperscriptBox["Pcp1", 
      RowBox[{"sigmacp", "-", "betap"}]], " ", 
     SuperscriptBox["pcbpd1", 
      RowBox[{"-", "sigmacp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033943324638443`*^9, 3.8033943445730357`*^9}, {
  3.803394430310149*^9, 3.803394434130881*^9}},
 CellLabel->
  "In[756]:=",ExpressionUUID->"05682ff6-110c-4854-9b88-b875f516b0b2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qpapd1", " ", "=", " ", 
   RowBox[{"qpape0", "+", 
    RowBox[{"kp", " ", "bpp", " ", 
     SuperscriptBox["Pp1", 
      RowBox[{"betap", "+", "etap"}]], " ", 
     SuperscriptBox["Ppp1", 
      RowBox[{"sigmapp", "-", "betap"}]], " ", 
     SuperscriptBox["ppapd1", 
      RowBox[{"-", "sigmapp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033943587257233`*^9, 3.803394372228799*^9}, {
  3.8033944224956007`*^9, 3.8033944274032774`*^9}},
 CellLabel->
  "In[757]:=",ExpressionUUID->"c09042e5-a5a6-4a4c-ad37-d566df5a5ae3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qpwpd1", " ", "=", " ", 
   RowBox[{"qpwpe0", "+", 
    RowBox[{"kp", " ", "bpp", " ", "bpwpd", " ", 
     SuperscriptBox["Pp1", 
      RowBox[{"betap", "+", "etap"}]], " ", 
     SuperscriptBox["Ppp1", 
      RowBox[{"sigmapp", "-", "betap"}]], " ", 
     SuperscriptBox["ppwpd1", 
      RowBox[{"-", "sigmapp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033943864272594`*^9, 3.803394417619938*^9}},
 CellLabel->
  "In[758]:=",ExpressionUUID->"af293642-5d60-446c-b59f-4f464d139757"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5. Results",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.7954529786642447`*^9}, {
  3.79545386036082*^9, 3.7954538618860044`*^9}, {3.795525436722562*^9, 
  3.795525448873003*^9}, {3.7998486591642857`*^9, 3.799848659976923*^9}, {
  3.8199004535482035`*^9, 
  3.8199004539735346`*^9}},ExpressionUUID->"d008b414-03c7-4600-8da5-\
347b8bf4e0ea"],

Cell[TextData[StyleBox["Atlantic Cod",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8046046204400043`*^9, 
  3.804604624049837*^9}},ExpressionUUID->"2391fa81-ec42-46b0-85cb-\
d4028e06387d"],

Cell["\<\
Percent change in domestic price of unprocessed Atlantic cod \
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8046046966461973`*^9, 3.8046047073861494`*^9}, {
  3.8199003775169024`*^9, 3.8199003785667257`*^9}, {3.8199004862318125`*^9, 
  3.8199004862778473`*^9}},ExpressionUUID->"37b6f62e-ab42-474a-883b-\
a789278bd2e7"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pcad1", "-", "pcad0"}], ")"}], "100"}], "pcad0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}},
 CellLabel->
  "In[759]:=",ExpressionUUID->"7851d6b9-66dd-4b24-bb64-9b1361450660"],

Cell[BoxData["0.15809137825725644`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8046038211389136`*^9, 
   3.8046038645853767`*^9, 3.804604401165724*^9, 3.804605229446913*^9, 
   3.8046057848747063`*^9, 3.8046060134614897`*^9, 3.804866392244777*^9, 
   3.805710250717248*^9, 3.8057109488743687`*^9, 3.8057112598265476`*^9, 
   3.8057121100549784`*^9, 3.8057121526722145`*^9, 3.8057123636141787`*^9, 
   3.8057129773497157`*^9, 3.8066682022868166`*^9, 3.8066685308740683`*^9, 
   3.806668610024968*^9, 3.807869872071093*^9, 3.8078714588219967`*^9, 
   3.807872162906949*^9, 3.807872777500616*^9, 3.81003203001398*^9, 
   3.81003211293394*^9, 3.810032848244164*^9, 3.8100328850341763`*^9, 
   3.812465383069228*^9, 3.812466229571271*^9, 3.812466530082505*^9, 
   3.8124929585354652`*^9, 3.8128208863229647`*^9, 3.812926007376754*^9, 
   3.81292633116378*^9, 3.8129265649452734`*^9, 3.812974825713497*^9, 
   3.8129750348255973`*^9, 3.812975287419358*^9, 3.8141738524447594`*^9, 
   3.815473679017158*^9, 3.815476523796341*^9, 3.8157738604869413`*^9, 
   3.8169824034299135`*^9, 3.8188024958883977`*^9, 3.8199005819694843`*^9, 
   3.8199006634960723`*^9, 3.81990074258776*^9, 3.8199008214272537`*^9, 
   3.819900902931822*^9, 3.81990179988207*^9, 3.8199021627615423`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[759]=",ExpressionUUID->"cf25cff5-9b3b-4f68-90ba-fd2363d52d7f"]
}, Open  ]],

Cell["\<\
Percent change in quantity of domestic Atlantic cod landings \
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.8046046995216045`*^9, 3.804604703694878*^9}, 3.806668743684885*^9, {
   3.819900389236043*^9, 3.819900391396731*^9}, {3.8199004886977377`*^9, 
   3.8199004888728743`*^9}},ExpressionUUID->"ff34ab77-1d9f-4ec0-ba1d-\
cae076d2ebb1"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qcad1", "-", "qcad0"}], ")"}], "100"}], "qcad0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}},
 CellLabel->
  "In[760]:=",ExpressionUUID->"12284875-4e6e-4aaf-8a4e-b74c3485c4eb"],

Cell[BoxData["0.7873200235863076`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8046038222328577`*^9, 
   3.8046038657105713`*^9, 3.8046044024449606`*^9, 3.804605229556306*^9, 
   3.8046057849684734`*^9, 3.804606013558566*^9, 3.8048663923229156`*^9, 
   3.8057102508110113`*^9, 3.8057109489993877`*^9, 3.8057112599359407`*^9, 
   3.8057121101487436`*^9, 3.8057121527659807`*^9, 3.805712363707944*^9, 
   3.8057129774434805`*^9, 3.8066682024274654`*^9, 3.8066685309834614`*^9, 
   3.806668610134344*^9, 3.807869872164859*^9, 3.807871458915761*^9, 
   3.8078721630007143`*^9, 3.8078727775943823`*^9, 3.8100320301010475`*^9, 
   3.810032113032015*^9, 3.8100328483402395`*^9, 3.8100328851352563`*^9, 
   3.812465383157254*^9, 3.8124662296663446`*^9, 3.812466530182583*^9, 
   3.8124929586265354`*^9, 3.812820886430048*^9, 3.8129260074908433`*^9, 
   3.812926331294853*^9, 3.812926565063365*^9, 3.8129748272189984`*^9, 
   3.812975034966245*^9, 3.8129752875594664`*^9, 3.8141738525541534`*^9, 
   3.815473679110861*^9, 3.815476523905734*^9, 3.815773860592023*^9, 
   3.8169824034449253`*^9, 3.8188024959074287`*^9, 3.8199005821015873`*^9, 
   3.8199006636382074`*^9, 3.819900742704851*^9, 3.8199008215483475`*^9, 
   3.81990090308394*^9, 3.8199017999561176`*^9, 3.8199021628476086`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[760]=",ExpressionUUID->"6f9ae369-6a3d-4cc4-8aed-f8b0392a77a6"]
}, Open  ]],

Cell["Percent change in price of processed Atlantic cod", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8033936664064026`*^9, 3.8033936721582303`*^9}, {
  3.8199004908924456`*^9, 
  3.8199004910715857`*^9}},ExpressionUUID->"5b25d0db-0b8a-4f08-8076-\
8a19a2fd0c65"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pcapd1", "-", "pcapd0"}], ")"}], "100"}], "pcapd0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.8017816087605777`*^9, 3.801781612667471*^9}},
 CellLabel->
  "In[761]:=",ExpressionUUID->"fd15cdf5-0467-4432-8576-ed1b9313284c"],

Cell[BoxData["0.15809137825725778`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781686455918*^9, {3.8017819965104704`*^9, 3.801782034552845*^9}, 
   3.8017820874654408`*^9, {3.801782229172226*^9, 3.8017822467376547`*^9}, 
   3.803075086080212*^9, 3.803075153145689*^9, 3.8030752591243453`*^9, 
   3.8030754033466825`*^9, 3.803075505373317*^9, 3.8031139637947545`*^9, 
   3.8031140836953993`*^9, 3.803114146227328*^9, 3.803114191017263*^9, 
   3.8031142975744133`*^9, 3.803114393543301*^9, 3.8031185691253357`*^9, 
   3.8031186380991683`*^9, 3.8031187019770246`*^9, {3.8031187472733793`*^9, 
   3.803118768971317*^9}, 3.8031188083770723`*^9, 3.8031205930009003`*^9, 
   3.8031206307033415`*^9, 3.80312441657086*^9, 3.8031245168360987`*^9, 
   3.803124910209062*^9, 3.8031249914423995`*^9, 3.8031257589755774`*^9, 
   3.8031262532759066`*^9, 3.803128482627451*^9, 3.8031286690289297`*^9, 
   3.803292498709256*^9, 3.803303079060638*^9, 3.8033032710035477`*^9, 
   3.803310406129446*^9, 3.8033128973951197`*^9, 3.803313223742484*^9, 
   3.8033916448025074`*^9, 3.8033920589956923`*^9, 3.8033921241673546`*^9, 
   3.803392515954962*^9, 3.803392626340601*^9, 3.8033944542881565`*^9, 
   3.8033947945221324`*^9, 3.803394907338005*^9, 3.803397321476366*^9, 
   3.803397437963311*^9, 3.803398062208243*^9, 3.8033984284560237`*^9, 
   3.8033985864454236`*^9, 3.803509620331604*^9, 3.8035103291881723`*^9, 
   3.803511720717868*^9, 3.803512180248054*^9, 3.8046038216546288`*^9, 
   3.8046038650854626`*^9, 3.8046044017595735`*^9, 3.8046052296500683`*^9, 
   3.8046057850622406`*^9, 3.8046060136446342`*^9, 3.8048663923854284`*^9, 
   3.805710250873522*^9, 3.8057109490931525`*^9, 3.805711260029706*^9, 
   3.805712110242509*^9, 3.8057121528597465`*^9, 3.8057123638017087`*^9, 
   3.805712977537246*^9, 3.806668202489976*^9, 3.8066685310772266`*^9, 
   3.8066686102281103`*^9, 3.8078698722273693`*^9, 3.8078714590095263`*^9, 
   3.807872163094479*^9, 3.8078727776881714`*^9, 3.8100320301811085`*^9, 
   3.8100321131260886`*^9, 3.810032848437316*^9, 3.8100328852293453`*^9, 
   3.812465383242321*^9, 3.812466229758417*^9, 3.8124665302736535`*^9, 
   3.8124929587126026`*^9, 3.8128208865461383`*^9, 3.812926007602947*^9, 
   3.81292633141995*^9, 3.812926565166459*^9, 3.8129748287074375`*^9, 
   3.812975035126184*^9, 3.812975287675557*^9, 3.8141738526635466`*^9, 
   3.815473679204626*^9, 3.815476524015129*^9, 3.8157738606921*^9, 
   3.816982403459937*^9, 3.818802495925437*^9, 3.8199005821636353`*^9, 
   3.8199006637212496`*^9, 3.8199007427839255`*^9, 3.819900821643422*^9, 
   3.819900903181016*^9, 3.819901800032176*^9, 3.8199021629326754`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[761]=",ExpressionUUID->"30f1172e-0484-4074-8fc8-09085f91e2e1"]
}, Open  ]],

Cell["Percent change in quantity of processed Atlantic cod", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.8033936664064026`*^9, 3.8033936721582303`*^9}, 
   3.803394622455228*^9, {3.819900494156994*^9, 
   3.8199004942860937`*^9}},ExpressionUUID->"c8d7b42c-adef-4dde-b31f-\
3325d779b26d"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qcapd1", "-", "qcapd0"}], ")"}], "100"}], "qcapd0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.8017816087605777`*^9, 3.801781612667471*^9}, {3.803393908063157*^9, 
  3.803393912095255*^9}},
 CellLabel->
  "In[762]:=",ExpressionUUID->"09104b58-19e4-45a6-ae58-5e9b94d8a8d3"],

Cell[BoxData["4.68659352223486`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781686455918*^9, {3.8017819965104704`*^9, 3.801782034552845*^9}, 
   3.8017820874654408`*^9, {3.801782229172226*^9, 3.8017822467376547`*^9}, 
   3.803075086080212*^9, 3.803075153145689*^9, 3.8030752591243453`*^9, 
   3.8030754033466825`*^9, 3.803075505373317*^9, 3.8031139637947545`*^9, 
   3.8031140836953993`*^9, 3.803114146227328*^9, 3.803114191017263*^9, 
   3.8031142975744133`*^9, 3.803114393543301*^9, 3.8031185691253357`*^9, 
   3.8031186380991683`*^9, 3.8031187019770246`*^9, {3.8031187472733793`*^9, 
   3.803118768971317*^9}, 3.8031188083770723`*^9, 3.8031205930009003`*^9, 
   3.8031206307033415`*^9, 3.80312441657086*^9, 3.8031245168360987`*^9, 
   3.803124910209062*^9, 3.8031249914423995`*^9, 3.8031257589755774`*^9, 
   3.8031262532759066`*^9, 3.803128482627451*^9, 3.8031286690289297`*^9, 
   3.803292498709256*^9, 3.803303079060638*^9, 3.8033032710035477`*^9, 
   3.803310406129446*^9, 3.8033128973951197`*^9, 3.803313223742484*^9, 
   3.8033916448025074`*^9, 3.8033920589956923`*^9, 3.8033921241673546`*^9, 
   3.803392515954962*^9, 3.803392626340601*^9, 3.8033944644746213`*^9, 
   3.803394804727141*^9, 3.803394918197935*^9, 3.8033973323841686`*^9, 
   3.8033974505721855`*^9, 3.803398076276987*^9, 3.8033984436264896`*^9, 
   3.8033985982731886`*^9, 3.8035096214255314`*^9, 3.803510330250845*^9, 
   3.803511721796172*^9, 3.803512181310714*^9, 3.804603822748577*^9, 
   3.804603866257539*^9, 3.804604403007551*^9, 3.804605229743833*^9, 
   3.80460578514038*^9, 3.8046060137357054`*^9, 3.804866392463561*^9, 
   3.8057102509516835`*^9, 3.8057109491712904`*^9, 3.805711260107843*^9, 
   3.8057121103206463`*^9, 3.805712152953512*^9, 3.805712363895487*^9, 
   3.8057129776153836`*^9, 3.8066682025837407`*^9, 3.806668531155365*^9, 
   3.8066686103375034`*^9, 3.807869872305507*^9, 3.807871459103292*^9, 
   3.8078721631882524`*^9, 3.8078727777819138`*^9, 3.8100320302631717`*^9, 
   3.8100321132161584`*^9, 3.81003284853039*^9, 3.810032885320402*^9, 
   3.8124653833263865`*^9, 3.8124662298504877`*^9, 3.812466530376734*^9, 
   3.812492958796668*^9, 3.8128208866752386`*^9, 3.812926007704019*^9, 
   3.8129263315340395`*^9, 3.81292656527553*^9, 3.812974828910594*^9, 
   3.8129750352512045`*^9, 3.812975287796651*^9, 3.8141738527729397`*^9, 
   3.8154736792983923`*^9, 3.8154765241245337`*^9, 3.815773860787174*^9, 
   3.8169824034755306`*^9, 3.818802495943428*^9, 3.819900582239718*^9, 
   3.819900663813321*^9, 3.8199007428729815`*^9, 3.81990082173149*^9, 
   3.819900903272086*^9, 3.8199018001012297`*^9, 3.81990216301574*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[762]=",ExpressionUUID->"19f0fbd2-ebf5-432e-a372-04164aadf0a4"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.805710969379385*^9, 3.8057109987355022`*^9}, {
  3.8066681143865623`*^9, 
  3.8066681171079936`*^9}},ExpressionUUID->"0f1ee070-f371-4b9c-a9d8-\
df760d997372"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "sigmacu"}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pcad1", " ", 
      RowBox[{"(", 
       RowBox[{"qcad1", "-", "qcae0", "-", 
        RowBox[{"cr", " ", "qcapd1"}]}], ")"}]}], " ", "-", " ", 
     RowBox[{"pcad0", " ", 
      RowBox[{"(", 
       RowBox[{"qcad0", "-", "qcae0", "-", 
        RowBox[{"cr", " ", "qcapd0"}]}], ")"}]}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8057110160869064`*^9, 3.805711037809208*^9}, {
  3.806668127326375*^9, 3.8066681479729257`*^9}, {3.8066682146950364`*^9, 
  3.8066682329291153`*^9}, {3.819900571434268*^9, 3.81990057400127*^9}},
 CellLabel->
  "In[763]:=",ExpressionUUID->"ed2ff5df-b3e3-4f0f-9c11-eedff7bc11c7"],

Cell[BoxData["850.0702115017413`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAuILPAURF6PeOE4pbisG0Xeczt4F0T7Nio9BdMKK+r8g
OmqjmdclIC2nF7p1Scwbx9+2MTtBtMjP9HsgWvys7wsQfeMYT9n7uDeO2edS
bT4AaQu2zCkgeiKrzUMQPenzKWP+5DeOafZadiCa6bHwLBA9zXvtPBB9hfNt
zOb0N452XvuOgWjHH35vQLSW+Z3LB4D0hZQbnxIy3jh6vvnpNgVIF1uU5oPo
SbJrekC01+qdsmuANF9XjjmI/q3zNwxEi9jMmfw1C2g+z1vHglyg+X/alxYC
6a81c64w5b1xfLMq/0NAwRvHviv/lp8sfuO4QurUlYelbxz//PhzD0QHXbz3
AkRfsdz1CUT/m/f6D4iOambNfQSkMzSTZ4FoAPGHujY=
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[763]=",ExpressionUUID->"4a1bed63-2cd5-4b93-a1ef-2027aeb2fb32"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.8057110007983437`*^9, 3.805711013680259*^9}, {
  3.8066681201084914`*^9, 
  3.8066681227808113`*^9}},ExpressionUUID->"e1d25baf-bfd9-4939-8f65-\
b660f344b49a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "sigmacp"}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pcapd1", " ", 
      RowBox[{"(", 
       RowBox[{"qcapd1", "-", "qcape0"}], ")"}]}], " ", "-", " ", 
     RowBox[{"pcapd0", " ", 
      RowBox[{"(", 
       RowBox[{"qcapd0", "-", "qcape0"}], ")"}]}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.805711055988307*^9, 3.8057110748240037`*^9}, {
  3.805711898591284*^9, 3.8057118991382484`*^9}, {3.8128208587004614`*^9, 
  3.8128209009483523`*^9}, {3.8199005765492597`*^9, 3.819900579456525*^9}},
 CellLabel->
  "In[764]:=",ExpressionUUID->"84671d5d-f841-4fec-93a6-edc2ed8d29a5"],

Cell[BoxData["14236.97592818995`"], "Output",
 CellChangeTimes->{
  3.8057110769337215`*^9, 3.805711260279746*^9, 3.8057119011854553`*^9, 
   3.805712110508177*^9, 3.805712153125415*^9, 3.805712364067377*^9, 
   3.805712977802915*^9, 3.806668202740017*^9, 3.8066685314054055`*^9, 
   3.8066686105250344`*^9, 3.8078698724774113`*^9, 3.807871459275194*^9, 
   3.8078721633757744`*^9, 3.807872777969445*^9, 3.8100320304222937`*^9, 
   3.8100321134123106`*^9, 3.8100328487135344`*^9, 3.810032885504548*^9, 
   3.8124653834925165`*^9, 3.812466230037634*^9, 3.8124665305588756`*^9, 
   3.8124929589667997`*^9, {3.812820886852376*^9, 3.812820902886858*^9}, 
   3.8129260079101715`*^9, 3.812926331784235*^9, 3.8129265654846926`*^9, 
   3.812974830318672*^9, 3.812975035548171*^9, 3.812975288020648*^9, 
   3.814173852991766*^9, 3.8154736795015507`*^9, 3.8154765243589344`*^9, 
   3.81577386098833*^9, 3.816982403503625*^9, 3.818802495982478*^9, 
   3.8199005823928533`*^9, 3.8199006639984665`*^9, 3.8199007430551243`*^9, 
   3.8199008219076276`*^9, 3.81990090345423*^9, 3.8199018002423534`*^9, 
   3.8199021631968884`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[764]=",ExpressionUUID->"15336d4c-3826-45c9-bcb6-6cb976473127"]
}, Open  ]],

Cell["Change in landings (in kg)", "Text",
 CellChangeTimes->{{3.819900952887789*^9, 
  3.819900960483714*^9}},ExpressionUUID->"7ec1e3b2-57ae-44a5-98a3-\
a8cf6e08a231"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qcad1", "-", "qcad0"}], "]"}]], "Input",
 CellChangeTimes->{{3.815476427014724*^9, 3.815476443439314*^9}, {
  3.8199008732036376`*^9, 3.8199008757966595`*^9}},
 CellLabel->
  "In[765]:=",ExpressionUUID->"cba0527c-b7a4-4a87-97f4-76bc6e0dcbd9"],

Cell[BoxData["7684.243430202361`"], "Output",
 CellChangeTimes->{3.815476454519267*^9, 3.815476527453224*^9, 
  3.8157738641578035`*^9, 3.816982403977318*^9, 3.8188024966029406`*^9, 
  3.8199005849097795`*^9, 3.8199006665774746`*^9, 3.819900745490025*^9, 
  3.8199008243775563`*^9, 3.819900906029239*^9, 3.8199018003143945`*^9, 
  3.819902163279977*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[765]=",ExpressionUUID->"53056330-d7a6-44f9-9c08-a46cbc7f2de9"]
}, Open  ]],

Cell[TextData[StyleBox["Pacific Cod",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8046046370991073`*^9, 
  3.8046046475539503`*^9}},ExpressionUUID->"19487b4b-48d9-4364-8515-\
371dbb67b929"],

Cell["Percent change in domestic price of unprocessed pacific cod", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.804604729546218*^9, 3.8046047322026463`*^9}, {3.819900506953974*^9, 
  3.8199005078376675`*^9}},ExpressionUUID->"fc388840-19e8-4dd3-9747-\
f8ff5f18cc62"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pcbd1", "-", "pcbd0"}], ")"}], "100"}], "pcbd0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}},
 CellLabel->
  "In[766]:=",ExpressionUUID->"c01ee3c4-d5c4-4b0f-ad48-10861ea850e0"],

Cell[BoxData["0.166901667258233`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8046038212326803`*^9, 
   3.804603864679143*^9, 3.804604401275117*^9, 3.8046052298219705`*^9, 
   3.8046057852185197`*^9, 3.8046060138247757`*^9, 3.804866392541699*^9, 
   3.8057102510298033`*^9, 3.805710949265055*^9, 3.8057112603735113`*^9, 
   3.80571211061757*^9, 3.80571215321918*^9, 3.8057123641611423`*^9, 
   3.805712977912307*^9, 3.8066682028181553`*^9, 3.8066685315147977`*^9, 
   3.8066686106188*^9, 3.807869872555549*^9, 3.8078714593689594`*^9, 
   3.8078721634695396`*^9, 3.8078727780632105`*^9, 3.8100320305013556`*^9, 
   3.810032113504382*^9, 3.8100328488096094`*^9, 3.810032885595619*^9, 
   3.8124653835755816`*^9, 3.812466230133708*^9, 3.812466530646944*^9, 
   3.812492959052868*^9, 3.8128208869444475`*^9, 3.8129260080112514`*^9, 
   3.8129263319013414`*^9, 3.812926565589774*^9, 3.812974831897044*^9, 
   3.8129750356887755`*^9, 3.8129752881300697`*^9, 3.8141738531323757`*^9, 
   3.8154736795953164`*^9, 3.815476524468328*^9, 3.8157738612105017`*^9, 
   3.816982403532648*^9, 3.8188024960194964`*^9, 3.819900582471875*^9, 
   3.8199006640905848`*^9, 3.8199007431321836`*^9, 3.8199008219936943`*^9, 
   3.8199009035453014`*^9, 3.8199018004055395`*^9, 3.8199021633650117`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[766]=",ExpressionUUID->"64cdbd3a-b197-44c7-9ed9-0cb6e1b12e5c"]
}, Open  ]],

Cell["Percent change in quantity of domestic pacific cod landings", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.8046047488810186`*^9, 
  3.804604752662994*^9}, {3.8066687340726943`*^9, 3.806668736652461*^9}, {
  3.819900534312313*^9, 
  3.819900535147965*^9}},ExpressionUUID->"7abf6cfa-d615-4f2a-b170-\
479ece4c4f53"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qcbd1", "-", "qcbd0"}], ")"}], "100"}], "qcbd0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}},
 CellLabel->
  "In[767]:=",ExpressionUUID->"3b33f5e5-576c-4782-ba04-8feac09ec40f"],

Cell[BoxData["0.7589494897133006`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804603822310999*^9, 
   3.8046038658043375`*^9, 3.8046044025231*^9, 3.8046052299157333`*^9, 
   3.804605785296659*^9, 3.8046060139118447`*^9, 3.8048663926198363`*^9, 
   3.805710251107937*^9, 3.805710949343193*^9, 3.8057112604672766`*^9, 
   3.8057121106957073`*^9, 3.8057121533129454`*^9, 3.8057123642705355`*^9, 
   3.805712977990444*^9, 3.806668202896293*^9, 3.8066685316085625`*^9, 
   3.8066686107125654`*^9, 3.807869872649315*^9, 3.807871459447097*^9, 
   3.807872163563305*^9, 3.807872778141349*^9, 3.8100320305804167`*^9, 
   3.81003211359245*^9, 3.8100328489026833`*^9, 3.8100328856876917`*^9, 
   3.8124653836626496`*^9, 3.8124662302257795`*^9, 3.8124665307360125`*^9, 
   3.8124929591389337`*^9, 3.8128208870305147`*^9, 3.8129260081383505`*^9, 
   3.8129263320294275`*^9, 3.812926565695856*^9, 3.8129748335640917`*^9, 
   3.8129750358137956`*^9, 3.8129752882550607`*^9, 3.814173853241769*^9, 
   3.815473679704709*^9, 3.815476524577721*^9, 3.815773861308578*^9, 
   3.8169824035486603`*^9, 3.818802496039526*^9, 3.8199005825499363`*^9, 
   3.8199006641826105`*^9, 3.819900743225257*^9, 3.819900822080762*^9, 
   3.8199009036374006`*^9, 3.81990180047752*^9, 3.8199021634480762`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[767]=",ExpressionUUID->"67ddc40c-6cb6-47ee-ad48-9a53fe751954"]
}, Open  ]],

Cell["Percent change in price of processed pacific cod", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.803393677315529*^9, 
  3.803393682613264*^9}},ExpressionUUID->"bc5d8946-4191-4214-98b4-\
6a405cbdf002"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pcbpd1", "-", "pcbpd0"}], ")"}], "100"}], "pcbpd0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.801781615105376*^9, 3.801781619652999*^9}},
 CellLabel->
  "In[768]:=",ExpressionUUID->"8737bbfb-232a-48e2-ac21-339fb9157f4a"],

Cell[BoxData["0.16690166725822572`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.8017816870341215`*^9, {3.801781996651119*^9, 3.8017820346778655`*^9}, 
   3.8017820876061444`*^9, {3.8017822293285017`*^9, 3.8017822472064533`*^9}, 
   3.8030750862199335`*^9, 3.803075153280796*^9, 3.803075259137355*^9, 
   3.803075403358692*^9, 3.8030755053853264`*^9, 3.803113963932863*^9, 
   3.8031140838335085`*^9, 3.80311414636442*^9, 3.803114191030273*^9, 
   3.803114297585422*^9, 3.80311439355431*^9, 3.8031185694996276`*^9, 
   3.8031186381111774`*^9, 3.8031187019880333`*^9, {3.803118747285389*^9, 
   3.803118768983326*^9}, 3.8031188083890824`*^9, 3.8031205933831987`*^9, 
   3.8031206307143497`*^9, 3.803124416593878*^9, 3.8031245168491087`*^9, 
   3.8031249102200704`*^9, 3.803124991453437*^9, 3.8031257589925904`*^9, 
   3.8031262532869153`*^9, 3.8031284830077505`*^9, 3.8031286690409384`*^9, 
   3.8032924987232356`*^9, 3.803303079529468*^9, 3.8033032715348845`*^9, 
   3.8033104073952737`*^9, 3.8033128976451597`*^9, 3.803313223992544*^9, 
   3.803391645005665*^9, 3.8033920604391584`*^9, 3.8033921245580425`*^9, 
   3.8033925167207117`*^9, 3.803392627231586*^9, 3.803394454803897*^9, 
   3.8033947954597845`*^9, 3.803394908056872*^9, 3.8033973227005763`*^9, 
   3.8033974386422787`*^9, 3.8033980647088223`*^9, 3.8033984287685747`*^9, 
   3.8033985876799994`*^9, 3.8035096204253693`*^9, 3.8035103292663097`*^9, 
   3.803511720796006*^9, 3.8035121803418045`*^9, 3.8046038217327695`*^9, 
   3.804603865179229*^9, 3.80460440183771*^9, 3.8046052300095005`*^9, 
   3.8046057853880725`*^9, 3.8046060139916673`*^9, 3.804866392697974*^9, 
   3.805710251186075*^9, 3.8057109494369583`*^9, 3.805711260561042*^9, 
   3.8057121107894726`*^9, 3.8057121534067516`*^9, 3.8057123643643007`*^9, 
   3.80571297808421*^9, 3.806668202974431*^9, 3.8066685317023277`*^9, 
   3.8066686108063316`*^9, 3.8078698727274528`*^9, 3.807871459540862*^9, 
   3.8078721636414423`*^9, 3.807872778235114*^9, 3.810032030660478*^9, 
   3.8100321136845217`*^9, 3.8100328489947553`*^9, 3.810032885778764*^9, 
   3.8124653837597256`*^9, 3.812466230319853*^9, 3.8124665308270903`*^9, 
   3.8124929592430143`*^9, 3.81282088711458*^9, 3.8129260082754574`*^9, 
   3.8129263321385193`*^9, 3.8129265658139486`*^9, 3.812974835183259*^9, 
   3.812975035954464*^9, 3.812975288380081*^9, 3.814173853351163*^9, 
   3.8154736797984753`*^9, 3.8154765246871147`*^9, 3.8157738614106617`*^9, 
   3.8169824035636897`*^9, 3.818802496057517*^9, 3.8199005826249948`*^9, 
   3.8199006642726803`*^9, 3.819900743315327*^9, 3.819900822170842*^9, 
   3.8199009037274437`*^9, 3.819901800552578*^9, 3.81990216353115*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[768]=",ExpressionUUID->"912404ae-fe13-4ef1-86dc-bc25fb52c7fa"]
}, Open  ]],

Cell["Percent change in quantity of processed pacific cod", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
   3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
   3.803393677315529*^9, 3.803393682613264*^9}, 
   3.803394622455228*^9},ExpressionUUID->"2113cf87-bc00-4d45-aef0-\
6517f28616da"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qcbpd1", "-", "qcbpd0"}], ")"}], "100"}], "qcbpd0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.801781615105376*^9, 3.801781619652999*^9}, {3.80339391505116*^9, 
  3.803393919604658*^9}},
 CellLabel->
  "In[769]:=",ExpressionUUID->"76079d01-f19a-4ef7-b160-ba27f20aceb0"],

Cell[BoxData["4.6509334768879915`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.8017816870341215`*^9, {3.801781996651119*^9, 3.8017820346778655`*^9}, 
   3.8017820876061444`*^9, {3.8017822293285017`*^9, 3.8017822472064533`*^9}, 
   3.8030750862199335`*^9, 3.803075153280796*^9, 3.803075259137355*^9, 
   3.803075403358692*^9, 3.8030755053853264`*^9, 3.803113963932863*^9, 
   3.8031140838335085`*^9, 3.80311414636442*^9, 3.803114191030273*^9, 
   3.803114297585422*^9, 3.80311439355431*^9, 3.8031185694996276`*^9, 
   3.8031186381111774`*^9, 3.8031187019880333`*^9, {3.803118747285389*^9, 
   3.803118768983326*^9}, 3.8031188083890824`*^9, 3.8031205933831987`*^9, 
   3.8031206307143497`*^9, 3.803124416593878*^9, 3.8031245168491087`*^9, 
   3.8031249102200704`*^9, 3.803124991453437*^9, 3.8031257589925904`*^9, 
   3.8031262532869153`*^9, 3.8031284830077505`*^9, 3.8031286690409384`*^9, 
   3.8032924987232356`*^9, 3.803303079529468*^9, 3.8033032715348845`*^9, 
   3.8033104073952737`*^9, 3.8033128976451597`*^9, 3.803313223992544*^9, 
   3.803391645005665*^9, 3.8033920604391584`*^9, 3.8033921245580425`*^9, 
   3.8033925167207117`*^9, 3.803392627231586*^9, 3.803394464677779*^9, 
   3.8033948063057337`*^9, 3.803394920342759*^9, 3.803397332962387*^9, 
   3.803397452066039*^9, 3.803398077589888*^9, 3.8033984442828493`*^9, 
   3.8033985986099977`*^9, 3.803509621503684*^9, 3.8035103303289824`*^9, 
   3.803511721874321*^9, 3.803512181420107*^9, 3.804603822842342*^9, 
   3.804603866335686*^9, 3.804604403101316*^9, 3.8046052301032643`*^9, 
   3.8046057854662113`*^9, 3.804606014085433*^9, 3.8048663927761188`*^9, 
   3.8057102512642136`*^9, 3.805710949530723*^9, 3.805711260654807*^9, 
   3.80571211086761*^9, 3.805712153500476*^9, 3.805712364442438*^9, 
   3.805712978177975*^9, 3.806668203052569*^9, 3.806668531796093*^9, 
   3.8066686109001303`*^9, 3.8078698728212185`*^9, 3.807871459634627*^9, 
   3.8078721637352076`*^9, 3.8078727783132524`*^9, 3.8100320307415404`*^9, 
   3.810032113775593*^9, 3.810032849085828*^9, 3.8100328858688345`*^9, 
   3.812465383846794*^9, 3.8124662304129252`*^9, 3.812466530919155*^9, 
   3.812492959330082*^9, 3.8128208872026544`*^9, 3.812926008396551*^9, 
   3.812926332247622*^9, 3.8129265659270363`*^9, 3.8129748354020433`*^9, 
   3.812975036095092*^9, 3.8129752884894996`*^9, 3.814173853460554*^9, 
   3.8154736798922405`*^9, 3.815476524796507*^9, 3.815773861509735*^9, 
   3.8169824035792665`*^9, 3.818802496076557*^9, 3.819900582701054*^9, 
   3.8199006643617496`*^9, 3.819900743404397*^9, 3.819900822259902*^9, 
   3.8199009038205175`*^9, 3.819901800627636*^9, 3.8199021636122036`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[769]=",ExpressionUUID->"af0cd144-f685-4e73-b133-d3368172aad9"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.805710969379385*^9, 3.8057109987355022`*^9}, {
  3.812926139301429*^9, 
  3.8129261414671173`*^9}},ExpressionUUID->"8dc904b7-b05a-41db-b81d-\
dac9bbea75d9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "sigmacu"}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pcbd1", " ", 
      RowBox[{"(", 
       RowBox[{"qcbd1", "-", "qcbe0", "-", 
        RowBox[{"cr", " ", "qcbpd1"}]}], ")"}]}], " ", "-", " ", 
     RowBox[{"pcbd0", " ", 
      RowBox[{"(", 
       RowBox[{"qcbd0", "-", "qcbe0", "-", 
        RowBox[{"cr", " ", "qcbpd0"}]}], ")"}]}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8057110160869064`*^9, 3.805711037809208*^9}, {
  3.8057111072370305`*^9, 3.8057111129098363`*^9}, {3.8066682781773415`*^9, 
  3.806668297785571*^9}, {3.8199005631738234`*^9, 3.8199005661011076`*^9}},
 CellLabel->
  "In[770]:=",ExpressionUUID->"36a56612-5279-4fe2-bc5c-87e4f2ab0d7a"],

Cell[BoxData["33582.553068213114`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAuILPAURF6PeOHqVTC8G0XOc798F0eItRo9B9CeNiX9B
tIiRh9clIH1QL2Xrkpg3jl/3VB4E0Tsqa+6B6F1n41+A6MnHZcvex71x/OdX
bvMBSL9hq5oCor3YfB+C6Alet4z5k984Sp+xtgPR3xaozgLR0ev3zQPRIrf+
xmxOf+MYJnDhGIg+FpzwBkRfS3x7+QCQ1rB9+Skh443joXwB9ykgOrE7H0S/
+HegB0Rvi+uSWwOkNbjbzUE0xyrhcDC9d9Pkr1lvHGN6/zsW5L5xVPk7Z2kh
kE6p3nyFKe+N47vPRR8CCt44XudjXnGy+I1jwLMbVx6WvnGUzeW7D6KrT71/
AaInK53+BKJDXP7+AdEPksVyHwHpAvOyWSAaAFtKuLk=
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[770]=",ExpressionUUID->"85b55903-7f84-401e-a56c-002c826a332a"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.8057110007983437`*^9, 3.805711013680259*^9}, {
  3.8129261440181*^9, 
  3.8129261460656953`*^9}},ExpressionUUID->"bd5362a0-e861-4727-858e-\
f2475fd4f8ef"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "sigmacp"}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pcbpd1", " ", 
      RowBox[{"(", 
       RowBox[{"qcbpd1", "-", "qcbpe0"}], ")"}]}], " ", "-", " ", 
     RowBox[{"pcbpd0", " ", 
      RowBox[{"(", 
       RowBox[{"qcbpd0", "-", "qcbpe0"}], ")"}]}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.805711055988307*^9, 3.8057110748240037`*^9}, {
   3.8057111162547474`*^9, 3.805711123005851*^9}, {3.8057116820625257`*^9, 
   3.8057116958772807`*^9}, {3.805711891698347*^9, 3.8057118919640155`*^9}, {
   3.8057127052813168`*^9, 3.8057127071878824`*^9}, {3.812820931314987*^9, 
   3.812820946456775*^9}, {3.812926104543377*^9, 3.812926120380705*^9}, 
   3.8199005581228848`*^9},
 CellLabel->
  "In[771]:=",ExpressionUUID->"3f11ab21-b8af-47e2-9c88-649f4c8f645d"],

Cell[BoxData["708906.19960227`"], "Output",
 CellChangeTimes->{
  3.8057110769337215`*^9, 3.805711260811083*^9, 3.8057117013156705`*^9, 
   3.8057118938080645`*^9, 3.8057121110551405`*^9, 3.8057121536723795`*^9, 
   3.8057123646299686`*^9, 3.805712707656709*^9, 3.8057129783498783`*^9, 
   3.806668203208845*^9, 3.8066685319679956`*^9, 3.8066686110876284`*^9, 
   3.80786987300875*^9, 3.8078714598065295`*^9, 3.8078721639071097`*^9, 
   3.807872778500784*^9, 3.810032030912672*^9, 3.810032113960737*^9, 
   3.810032849268011*^9, 3.8100328860489764`*^9, 3.812465384017928*^9, 
   3.8124662305940943`*^9, 3.8124665311042995`*^9, 3.8124929595052185`*^9, 
   3.8128208873767834`*^9, 3.81282094755663*^9, 3.812926008649748*^9, {
   3.81292611033689*^9, 3.8129261230767994`*^9}, 3.8129263324697723`*^9, 
   3.8129265661351976`*^9, 3.812974836886649*^9, 3.8129750363763895`*^9, 
   3.8129752887238865`*^9, 3.814173853694968*^9, 3.8154736800797715`*^9, 
   3.8154765250152936`*^9, 3.815773861809969*^9, 3.8169824036182966`*^9, 
   3.8188024961335783`*^9, 3.819900582855174*^9, 3.8199006645408897`*^9, 
   3.8199007435835376`*^9, 3.819900822435038*^9, 3.8199009040076637`*^9, 
   3.819901800773749*^9, 3.8199021637773323`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[771]=",ExpressionUUID->"a5197d5c-a716-40c9-9e5f-f268e0c5b509"]
}, Open  ]],

Cell["Change in landings (in kg)", "Text",
 CellChangeTimes->{{3.819900979641653*^9, 
  3.8199009832924995`*^9}},ExpressionUUID->"61d6de74-27e0-4fd4-bb2a-\
df5d0c6aae52"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qcbd1", "-", "qcbd0"}], "]"}]], "Input",
 CellChangeTimes->{{3.8154765570830936`*^9, 3.815476562552746*^9}, 
   3.819900870603607*^9},
 CellLabel->
  "In[772]:=",ExpressionUUID->"84b27001-2a34-490c-9bd9-1d2965576040"],

Cell[BoxData["1.7651495441854`*^6"], "Output",
 CellChangeTimes->{3.8154765275782194`*^9, 3.8154765639748573`*^9, 
  3.815773864257882*^9, 3.816982403990328*^9, 3.818802496621956*^9, 
  3.8199005849978485`*^9, 3.819900666664542*^9, 3.8199007455750914`*^9, 
  3.8199008244626226`*^9, 3.819900906116307*^9, 3.8199018008468056`*^9, 
  3.819902163860401*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[772]=",ExpressionUUID->"1cd7195b-2a74-4c31-b120-4f1467a7f3b3"]
}, Open  ]],

Cell[TextData[StyleBox["Atlantic Pollock",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8046046370991073`*^9, 3.8046046475539503`*^9}, {
  3.8046047842187676`*^9, 
  3.8046047862970924`*^9}},ExpressionUUID->"326588d6-03cd-4f3a-bcb3-\
1608f212dfc6"],

Cell["\<\
Percent change in domestic price of unprocessed Atlantic pollock\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804604802382391*^9, 3.804604805899053*^9}, {
  3.8199005991678977`*^9, 
  3.8199006029218254`*^9}},ExpressionUUID->"e23a3c21-0a78-47af-802c-\
c364f4f91f5f"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"ppad1", "-", "ppad0"}], ")"}], "100"}], "ppad0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}},
 CellLabel->
  "In[773]:=",ExpressionUUID->"ec6af1d0-396f-4dba-8cea-a3941b570226"],

Cell[BoxData["0.22285929439936808`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.804603821404587*^9, 3.8046038648354206`*^9, 
   3.8046044014626493`*^9, 3.8046052302282825`*^9, 3.8046057855599794`*^9, 
   3.804606014173745*^9, 3.804866392854249*^9, 3.8057102513423514`*^9, 
   3.8057109496244884`*^9, 3.8057112609204755`*^9, 3.8057121111489058`*^9, 
   3.805712153750516*^9, 3.805712364708106*^9, 3.805712978443643*^9, 
   3.8066682033026114`*^9, 3.806668532061761*^9, 3.8066686111657667`*^9, 
   3.807869873086889*^9, 3.807871459900305*^9, 3.8078721640008745`*^9, 
   3.80787277859455*^9, 3.8100320309917326`*^9, 3.8100321140528097`*^9, 
   3.810032849359043*^9, 3.810032886137046*^9, 3.8124653841039953`*^9, 
   3.812466230691141*^9, 3.812466531196372*^9, 3.812492959592286*^9, 
   3.8128208874718585`*^9, 3.8129260087708416`*^9, 3.81292633258286*^9, 
   3.8129265662392783`*^9, 3.8129748385587845`*^9, 3.8129750365025864`*^9, 
   3.812975288848907*^9, 3.81417385380436*^9, 3.815473680173537*^9, 
   3.815476525124687*^9, 3.815773861910048*^9, 3.816982403633309*^9, 
   3.818802496153629*^9, 3.8199005829312325`*^9, 3.8199006646459713`*^9, 
   3.8199007436595974`*^9, 3.8199008225221057`*^9, 3.8199009041107445`*^9, 
   3.819901800945882*^9, 3.819902163942461*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[773]=",ExpressionUUID->"99d8ac5d-e7c5-4519-8a15-d4a5e3fa94c7"]
}, Open  ]],

Cell["\<\
Percent change in quantity of domestic Atlantic pollock landings \
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
  3.804604819980525*^9, 3.8046048234347324`*^9}, {3.806668723288205*^9, 
  3.806668727305784*^9}, {3.8199006050324745`*^9, 
  3.819900615920968*^9}},ExpressionUUID->"f799dbdf-4080-49d8-a20e-\
90387fa96e77"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qpad1", "-", "qpad0"}], ")"}], "100"}], "qpad0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}},
 CellLabel->
  "In[774]:=",ExpressionUUID->"efe2e1f7-5f4b-4f80-a068-3179b4d26ead"],

Cell[BoxData["1.1125147943318898`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.804603822467274*^9, 3.8046038659606147`*^9, 
   3.8046044027262554`*^9, 3.8046052303220468`*^9, 3.8046057856381187`*^9, 
   3.80460601425681*^9, 3.8048663929323864`*^9, 3.8057102514204893`*^9, 
   3.805710949702626*^9, 3.8057112610142407`*^9, 3.8057121112270436`*^9, 
   3.805712153844282*^9, 3.8057123648018713`*^9, 3.805712978521781*^9, 
   3.806668203380749*^9, 3.8066685321398983`*^9, 3.8066686112595325`*^9, 
   3.8078698731650267`*^9, 3.8078714599940596`*^9, 3.807872164079013*^9, 
   3.8078727786883636`*^9, 3.8100320310737953`*^9, 3.810032114141878*^9, 
   3.810032849447122*^9, 3.810032886228118*^9, 3.8124653841900625`*^9, 
   3.8124662307832127`*^9, 3.812466531289445*^9, 3.8124929596813555`*^9, 
   3.8128208875609264`*^9, 3.8129260088859315`*^9, 3.8129263326979494`*^9, 
   3.8129265663393564`*^9, 3.8129748402621756`*^9, 3.812975036617097*^9, 
   3.8129752889583*^9, 3.814173853929381*^9, 3.815473680282961*^9, 
   3.8154765252341022`*^9, 3.8157738620041213`*^9, 3.81698240364732*^9, 
   3.8188024961736155`*^9, 3.8199005829922805`*^9, 3.8199006647340393`*^9, 
   3.819900743763679*^9, 3.819900822628188*^9, 3.8199009042048187`*^9, 
   3.81990180102194*^9, 3.8199021640255256`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[774]=",ExpressionUUID->"c63576ad-70ca-47a3-8aae-32f1f9a693f1"]
}, Open  ]],

Cell["Percent change in price of processed Atlantic pollock", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.8033937087485523`*^9, 3.803393712030335*^9}, {
  3.819900607561446*^9, 
  3.819900607717569*^9}},ExpressionUUID->"4c57f812-1225-494a-b471-\
d9ab225bc3b0"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"ppapd1", "-", "ppapd0"}], ")"}], "100"}], "ppapd0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.801781628294948*^9, 3.8017816321862173`*^9}},
 CellLabel->
  "In[775]:=",ExpressionUUID->"80d37ed8-cd78-4859-a2af-abe1eefeba35"],

Cell[BoxData["0.22285929439935714`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.8017816872997904`*^9, {
   3.801781996948044*^9, 3.801782034927908*^9}, 3.801782088215561*^9, {
   3.8017822304224353`*^9, 3.8017822487692146`*^9}, 3.803075086500412*^9, 
   3.803075153550009*^9, 3.8030752591613746`*^9, 3.8030754033827114`*^9, 
   3.8030755054093447`*^9, 3.8031139640839825`*^9, 3.803114083979624*^9, 
   3.8031141465105333`*^9, 3.803114191055293*^9, 3.803114297607439*^9, 
   3.803114393575326*^9, 3.8031185695756874`*^9, 3.803118638133195*^9, 
   3.803118702011051*^9, {3.803118747309407*^9, 3.8031187690053434`*^9}, 
   3.8031188084121003`*^9, 3.803120593432237*^9, 3.8031206307373676`*^9, 
   3.803124417006201*^9, 3.803124516873128*^9, 3.803124910244089*^9, 
   3.8031249914754252`*^9, 3.803125759026617*^9, 3.803126253309945*^9, 
   3.8031284830617933`*^9, 3.8031286690639563`*^9, 3.8032924987522593`*^9, 
   3.803303081248493*^9, 3.8033032727069497`*^9, 3.8033104089423995`*^9, 
   3.8033128993798265`*^9, 3.803313228938822*^9, 3.803391646005829*^9, 
   3.8033920611524763`*^9, 3.8033921264465265`*^9, 3.8033925178618298`*^9, 
   3.8033926287005777`*^9, 3.8033944573065386`*^9, 3.8033947975069914`*^9, 
   3.8033949099949303`*^9, 3.8033973253588276`*^9, 3.8033974413677063`*^9, 
   3.8033980657714953`*^9, 3.8033984340200186`*^9, 3.8033985885551414`*^9, 
   3.803509620597272*^9, 3.8035103294382124`*^9, 3.803511720967909*^9, 
   3.803512180513708*^9, 3.8046038218890476`*^9, 3.8046038653511343`*^9, 
   3.8046044020474305`*^9, 3.8046052304158106`*^9, 3.804605785716258*^9, 
   3.8046060143428783`*^9, 3.8048663930261517`*^9, 3.8057102514986277`*^9, 
   3.805710949796519*^9, 3.8057112610923786`*^9, 3.805712111320809*^9, 
   3.8057121539224186`*^9, 3.8057123648956366`*^9, 3.805712978631174*^9, 
   3.806668203474515*^9, 3.806668532233664*^9, 3.806668611384553*^9, 
   3.807869873243164*^9, 3.80787146007222*^9, 3.807872164172777*^9, 
   3.8078727787820807`*^9, 3.8100320311578608`*^9, 3.81003211423195*^9, 
   3.8100328495361834`*^9, 3.8100328863192186`*^9, 3.8124653842781315`*^9, 
   3.81246623087632*^9, 3.8124665313925257`*^9, 3.8124929597664213`*^9, 
   3.812820887647994*^9, 3.812926009010028*^9, 3.812926332807056*^9, 
   3.812926566454446*^9, 3.812974841965808*^9, 3.812975036742117*^9, 
   3.8129752890676928`*^9, 3.8141738540387735`*^9, 3.8154736803923235`*^9, 
   3.8154765253435087`*^9, 3.8157738621052003`*^9, 3.816982403661338*^9, 
   3.8188024961936293`*^9, 3.8199005830683403`*^9, 3.819900664823125*^9, 
   3.819900743852749*^9, 3.8199008227162733`*^9, 3.8199009042978916`*^9, 
   3.8199018011000004`*^9, 3.81990216410859*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[775]=",ExpressionUUID->"e67fdc29-245d-42db-b808-d7e153e5774e"]
}, Open  ]],

Cell["Percent change in quantity of processed Atlantic pollock", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.8033937087485523`*^9, 3.803393712030335*^9}, 
   3.803394622470855*^9, {3.8199006097031164`*^9, 
   3.8199006098562355`*^9}},ExpressionUUID->"2dc081a6-1670-4c41-9346-\
6a020d829e77"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qpapd1", "-", "qpapd0"}], ")"}], "100"}], "qpapd0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.801781628294948*^9, 3.8017816321862173`*^9}, {3.8033939294451303`*^9, 
  3.8033939335537944`*^9}},
 CellLabel->
  "In[776]:=",ExpressionUUID->"f80494bc-0aea-4ebc-8598-5c7930afd620"],

Cell[BoxData["9.840084710458065`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.8017816872997904`*^9, {
   3.801781996948044*^9, 3.801782034927908*^9}, 3.801782088215561*^9, {
   3.8017822304224353`*^9, 3.8017822487692146`*^9}, 3.803075086500412*^9, 
   3.803075153550009*^9, 3.8030752591613746`*^9, 3.8030754033827114`*^9, 
   3.8030755054093447`*^9, 3.8031139640839825`*^9, 3.803114083979624*^9, 
   3.8031141465105333`*^9, 3.803114191055293*^9, 3.803114297607439*^9, 
   3.803114393575326*^9, 3.8031185695756874`*^9, 3.803118638133195*^9, 
   3.803118702011051*^9, {3.803118747309407*^9, 3.8031187690053434`*^9}, 
   3.8031188084121003`*^9, 3.803120593432237*^9, 3.8031206307373676`*^9, 
   3.803124417006201*^9, 3.803124516873128*^9, 3.803124910244089*^9, 
   3.8031249914754252`*^9, 3.803125759026617*^9, 3.803126253309945*^9, 
   3.8031284830617933`*^9, 3.8031286690639563`*^9, 3.8032924987522593`*^9, 
   3.803303081248493*^9, 3.8033032727069497`*^9, 3.8033104089423995`*^9, 
   3.8033128993798265`*^9, 3.803313228938822*^9, 3.803391646005829*^9, 
   3.8033920611524763`*^9, 3.8033921264465265`*^9, 3.8033925178618298`*^9, 
   3.8033926287005777`*^9, 3.8033944658029623`*^9, 3.803394807805978*^9, 
   3.8033949228085628`*^9, 3.8033973339000397`*^9, 3.803397452988065*^9, 
   3.803398080211611*^9, 3.8033984460018787`*^9, 3.8033986004227915`*^9, 
   3.803509621675572*^9, 3.8035103304852576`*^9, 3.803511722030593*^9, 
   3.8035121815763836`*^9, 3.804603823014247*^9, 3.804603866523409*^9, 
   3.8046044033044715`*^9, 3.804605230509576*^9, 3.8046057857943974`*^9, 
   3.804606014424944*^9, 3.8048663931042895`*^9, 3.805710251576766*^9, 
   3.80571094987453*^9, 3.805711261186144*^9, 3.8057121113989463`*^9, 
   3.8057121540161843`*^9, 3.805712364973774*^9, 3.805712978724939*^9, 
   3.8066682035682807`*^9, 3.806668532311802*^9, 3.806668611509574*^9, 
   3.8078698733213024`*^9, 3.8078714601659617`*^9, 3.8078721642509155`*^9, 
   3.807872778860219*^9, 3.8100320312389245`*^9, 3.8100321143200445`*^9, 
   3.8100328496252527`*^9, 3.8100328864112625`*^9, 3.812465384364199*^9, 
   3.8124662309783716`*^9, 3.8124665314855986`*^9, 3.8124929598554907`*^9, 
   3.8128208877350626`*^9, 3.812926009119117*^9, 3.8129263329151416`*^9, 
   3.8129265665545235`*^9, 3.8129748422158475`*^9, 3.8129750368671384`*^9, 
   3.8129752891927133`*^9, 3.8141738541637945`*^9, 3.8154736805017166`*^9, 
   3.8154765254684935`*^9, 3.8157738622032766`*^9, 3.8169824036754208`*^9, 
   3.8188024962126627`*^9, 3.819900583161413*^9, 3.8199006649121785`*^9, 
   3.8199007439398174`*^9, 3.819900822805328*^9, 3.819900904389963*^9, 
   3.81990180117706*^9, 3.8199021642036643`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[776]=",ExpressionUUID->"287a1c99-13a8-44ce-aa71-a663d291f6da"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.805710969379385*^9, 3.8057109987355022`*^9}, {
  3.806668390314887*^9, 
  3.8066683925340033`*^9}},ExpressionUUID->"67598b15-2514-4292-9b95-\
8022ce584210"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "sigmapu"}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"ppad1", " ", 
      RowBox[{"(", 
       RowBox[{"qpad1", "-", "qpae0", "-", 
        RowBox[{"cr", " ", "qpapd1"}]}], ")"}]}], " ", "-", " ", 
     RowBox[{"ppad0", " ", 
      RowBox[{"(", 
       RowBox[{"qpad0", "-", "qpae0", "-", 
        RowBox[{"cr", " ", "qpapd0"}]}], ")"}]}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8057110160869064`*^9, 3.805711037809208*^9}, {
  3.805711131772911*^9, 3.8057111432122803`*^9}, {3.8066683218903885`*^9, 
  3.8066683473495026`*^9}, {3.807870168920203*^9, 3.8078701724363937`*^9}, {
  3.819900642145419*^9, 3.819900645005653*^9}},
 CellLabel->
  "In[777]:=",ExpressionUUID->"76bb7cb9-92d3-4751-9bf5-0e6368529753"],

Cell[BoxData[
 RowBox[{"-", "1500.8200565417583`"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAuILPAURF6PeOP4rWVEMor2PvL8LojewOD8G0V6ai/6C
6K+bIr0uAelq/dKtS2LeOH4xXHwcRP9i6bsHoif4Fb8A0eYndMrexwH1+3fY
fADS89m7p4BoAfb4hyC6xfWVMX/yG0eORF87EP3+sdksEL0t5MI8EL0ygy92
c/obxwsWj46BaLeaojcg+qrlv8sHgPSG/F+fEjLeOMrbqrtPAdIf1i7IB9ER
wld7QHRBZqr8GiDNcX2+OYi+tUozHER/2nti8tesN44GfMJOBblvHPnqNi0t
BNLuz05eYcp745jDXvYhoOCN4+ZM9hUni984/tj4/MrD0jeOakwK90H0kjcM
L0F0Xd+dTyD6Wg7/XxDdI6mR+whIC8d1zgLRAMb4tbo=
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[777]=",ExpressionUUID->"a8d9bdb1-3088-4f8d-af95-0c3e293850a1"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.8057110007983437`*^9, 3.805711013680259*^9}, {
  3.806668395840061*^9, 
  3.8066683978091354`*^9}},ExpressionUUID->"f0b63684-b9c3-4fdb-856a-\
a6edd924c1ea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "sigmapp"}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"ppapd1", " ", 
      RowBox[{"(", 
       RowBox[{"qpapd1", "-", "qpape0"}], ")"}]}], " ", "-", " ", 
     RowBox[{"ppapd0", " ", 
      RowBox[{"(", 
       RowBox[{"qpapd0", "-", "qpape0"}], ")"}]}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.805711055988307*^9, 3.8057110748240037`*^9}, {
  3.8057111464784417`*^9, 3.805711156512991*^9}, {3.8057117948467445`*^9, 
  3.805711799335431*^9}, {3.805711884509862*^9, 3.8057118850724554`*^9}, {
  3.805712685809387*^9, 3.8057126875596776`*^9}, {3.81282095829399*^9, 
  3.8128209723819575`*^9}, {3.819900647233387*^9, 3.8199006501216416`*^9}},
 CellLabel->
  "In[778]:=",ExpressionUUID->"d9537264-93e7-4b15-9914-3300b10cdafd"],

Cell[BoxData["23899.82712483198`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBWKeh3NjLka9cZQrXV0MoiNsvm8D0S2X7h0E0Wkun+6C
6Assbo9BdNPKJX9B9JU3AWqXgPS7TTFeIHrWmvKtS2LeOOq2TrwHojf4lb0A
0ZEn9Mvex71xPH2+y+YDkN7P3jcFRLewJz0E0ceevjHmT37j6BUcYAeiU7da
zgLRemqX54HoZZqCsZvT3zgKaD89BqLf1ZW+AdGbPjFcOQCkDxj8/ZSQ8cZx
WtySvyD6jIi2+xQgva53ST6I3nTrRg+IdsmqkF8DUnd0iTmIZlmtGw6iZfed
mfw1641jEJ+YU0Eu0P//ti4tBNI/VC5cYcp745jwt+xDQMEbR4+FHCtOFr9x
3HXxzZWHpUDzbyvdB9HNS5lfguhP8fc/gehHYUJ/QfSlCVq5j4B02L/uWSAa
APbsyPU=
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[778]=",ExpressionUUID->"a0522879-1deb-40f7-9937-c00f9de829a0"]
}, Open  ]],

Cell["Change in landings (in kg)", "Text",
 CellChangeTimes->{{3.8199009983262267`*^9, 
  3.819901002436433*^9}},ExpressionUUID->"f1532e8f-1ff0-4696-80ab-\
886ff83a5282"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qpad1", "-", "qpad0"}], "]"}]], "Input",
 CellChangeTimes->{{3.819900878136484*^9, 3.819900880479314*^9}},
 CellLabel->
  "In[779]:=",ExpressionUUID->"401d86c5-f709-4ded-a020-e4f984fcca9b"],

Cell[BoxData["34198.704777762294`"], "Output",
 CellChangeTimes->{3.8154765276876125`*^9, 3.8157738643569593`*^9, 
  3.816982404002337*^9, 3.818802496640026*^9, 3.8199005850879183`*^9, 
  3.8199006667656207`*^9, 3.8199007456661654`*^9, 3.819900824546688*^9, 
  3.8199009062183867`*^9, 3.8199018014162445`*^9, 3.8199021644558606`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[779]=",ExpressionUUID->"e0d64307-df9a-42e2-8dbb-3aeb63317f5c"]
}, Open  ]],

Cell[TextData[StyleBox["Alaskan/Pacific Pollock",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8046046370991073`*^9, 3.8046046475539503`*^9}, {
  3.8046047842187676`*^9, 3.8046047862970924`*^9}, {3.804604851781675*^9, 
  3.8046048540735693`*^9}, {3.805711814540925*^9, 
  3.805711815619218*^9}},ExpressionUUID->"834e2ea9-9628-4ebc-a5cd-\
780325b8a182"],

Cell["\<\
Percent change in domestic price of unprocessed Alaskan pollock\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8046048586422396`*^9, 3.804604863002186*^9}, {3.8199006967059765`*^9, 
  3.819900700282767*^9}},ExpressionUUID->"5ed542e3-d498-4e4c-a4dd-\
1b360d55e7d3"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"ppwd1", "-", "ppwd0"}], ")"}], "100"}], "ppwd0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}},
 CellLabel->
  "In[780]:=",ExpressionUUID->"a7a9764c-bf66-49ef-939e-40c84233ba43"],

Cell[BoxData["0.15136454059020896`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.8046038213108177`*^9, 
   3.8046038647572813`*^9, 3.8046044013688874`*^9, 3.804605230618967*^9, 
   3.804605785872537*^9, 3.804606014506007*^9, 3.8048663931824274`*^9, 
   3.8057102516705313`*^9, 3.805710949952668*^9, 3.8057112614518185`*^9, 
   3.8057121116802425`*^9, 3.805712154266225*^9, 3.805712365239444*^9, 
   3.8057129790218625`*^9, 3.806668203817957*^9, 3.806668532625611*^9, 
   3.806668611790871*^9, 3.8078698735713444`*^9, 3.80787146043163*^9, 
   3.807872164516583*^9, 3.8078727791415157`*^9, 3.810032031485112*^9, 
   3.810032114598237*^9, 3.810032849900473*^9, 3.8100328866864796`*^9, 
   3.8124653846254034`*^9, 3.8124662312555876`*^9, 3.8124665317608137`*^9, 
   3.8124929601166935`*^9, 3.8128208879992876`*^9, 3.81292600947639*^9, 
   3.812926333261404*^9, 3.8129265668917856`*^9, 3.8129748454594536`*^9, 
   3.8129750372652097`*^9, 3.8129752895365186`*^9, 3.814173854507601*^9, 
   3.8154736807830133`*^9, 3.815476525796674*^9, 3.8157738626035895`*^9, 
   3.8169824037324443`*^9, 3.8188024962897205`*^9, 3.819900583495675*^9, 
   3.8199006651803875`*^9, 3.8199007441980257`*^9, 3.81990082306753*^9, 
   3.8199009046641765`*^9, 3.819901801494306*^9, 3.819902164537936*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[780]=",ExpressionUUID->"65b5dc05-8e4e-4b49-a4cb-28387a9fe605"]
}, Open  ]],

Cell["\<\
Percent change in quantity of domestic Alaskan pollock landings\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.803394622408345*^9, 3.803394622408345*^9}, {3.804604884580967*^9, 
  3.804604888299903*^9}, {3.806668693400067*^9, 3.8066686967443695`*^9}, {
  3.81990070270265*^9, 
  3.819900717468169*^9}},ExpressionUUID->"82273b4d-e264-45a3-9a5a-\
0b30019357d7"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qpwd1", "-", "qpwd0"}], ")"}], "100"}], "qpwd0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}},
 CellLabel->
  "In[781]:=",ExpressionUUID->"0d15ba49-a590-43d3-aca9-29acdb783728"],

Cell[BoxData["0.7527324490554977`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.8046038223891354`*^9, 
   3.804603865882475*^9, 3.8046044026168637`*^9, 3.8046052306971035`*^9, 
   3.8046057859506793`*^9, 3.8046060145866413`*^9, 3.8048663932605658`*^9, 
   3.805710251733042*^9, 3.8057109500620613`*^9, 3.8057112615612044`*^9, 
   3.805712111758381*^9, 3.805712154375618*^9, 3.8057123653332095`*^9, 
   3.8057129791156273`*^9, 3.806668203911723*^9, 3.806668532719377*^9, 
   3.806668611869009*^9, 3.80786987366511*^9, 3.8078714605097675`*^9, 
   3.8078721646103477`*^9, 3.8078727792352805`*^9, 3.810032031567175*^9, 
   3.8100321146853046`*^9, 3.8100328499885387`*^9, 3.810032886777551*^9, 
   3.8124653847134733`*^9, 3.8124662313456497`*^9, 3.8124665318518853`*^9, 
   3.812492960211767*^9, 3.812820888093343*^9, 3.8129260095984845`*^9, 
   3.8129263333854837`*^9, 3.812926567001871*^9, 3.8129748472847695`*^9, 
   3.812975037378298*^9, 3.812975289661539*^9, 3.81417385463262*^9, 
   3.8154736808924055`*^9, 3.815476525906067*^9, 3.815773862702686*^9, 
   3.8169824037474523`*^9, 3.818802496309735*^9, 3.8199005835817432`*^9, 
   3.8199006652704573`*^9, 3.8199007442850876`*^9, 3.8199008231546197`*^9, 
   3.8199009047562485`*^9, 3.8199018015763683`*^9, 3.8199021646219893`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[781]=",ExpressionUUID->"64ecbc1f-8a7f-42a4-a399-c1e6ffe82c4f"]
}, Open  ]],

Cell["Percent change in price of processed Alaskan pollock", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8033936910231113`*^9, 3.803393702776311*^9}, {3.819900707117093*^9, 
  3.8199007096220493`*^9}},ExpressionUUID->"3352666c-80d2-40ce-810f-\
a8825199cd77"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"ppwpd1", "-", "ppwpd0"}], ")"}], "100"}], "ppwpd0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.8017816232160883`*^9, 3.8017816264508963`*^9}},
 CellLabel->
  "In[782]:=",ExpressionUUID->"e28daa26-f731-472c-a5f4-43da2a375ffe"],

Cell[BoxData["0.15136454059021168`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.8017816871591425`*^9, {3.801781996807395*^9, 3.8017820348028865`*^9}, 
   3.801782088059287*^9, {3.8017822302349033`*^9, 3.801782247347102*^9}, 
   3.803075086364133*^9, 3.803075153415903*^9, 3.8030752591493645`*^9, 
   3.803075403369701*^9, 3.8030755053973355`*^9, 3.8031139640709724`*^9, 
   3.803114083968629*^9, 3.803114146499525*^9, 3.803114191042283*^9, 
   3.803114297596467*^9, 3.803114393565318*^9, 3.8031185695486665`*^9, 
   3.8031186381221867`*^9, 3.8031187019990416`*^9, {3.8031187472973976`*^9, 
   3.8031187689943347`*^9}, 3.8031188084010916`*^9, 3.8031205934092197`*^9, 
   3.8031206307263594`*^9, 3.8031244169751763`*^9, 3.8031245168611298`*^9, 
   3.8031249102320795`*^9, 3.8031249914644413`*^9, 3.8031257590096035`*^9, 
   3.8031262532989244`*^9, 3.8031284830367737`*^9, 3.8031286690529904`*^9, 
   3.8032924987382483`*^9, 3.803303080529626*^9, 3.803303272410026*^9, 
   3.8033104076140594`*^9, 3.8033128982077513`*^9, 3.803313225836578*^9, 
   3.8033916455213737`*^9, 3.8033920606379957`*^9, 3.803392125683226*^9, 
   3.803392516970752*^9, 3.803392628137986*^9, 3.8033944564603844`*^9, 
   3.803394797006911*^9, 3.803394908635091*^9, 3.803397323547353*^9, 
   3.8033974396580696`*^9, 3.803398065490239*^9, 3.803398432644209*^9, 
   3.803398588226963*^9, 3.8035096205035057`*^9, 3.803510329360075*^9, 
   3.8035117208897715`*^9, 3.8035121804355707`*^9, 3.8046038218109074`*^9, 
   3.8046038652573695`*^9, 3.8046044019314766`*^9, 3.804605230790869*^9, 
   3.8046057860288153`*^9, 3.8046060146960354`*^9, 3.8048663933387036`*^9, 
   3.80571025181118*^9, 3.8057109501401997`*^9, 3.8057112616393414`*^9, 
   3.8057121118521757`*^9, 3.8057121544537554`*^9, 3.8057123654269753`*^9, 
   3.8057129792093925`*^9, 3.8066682039898615`*^9, 3.8066685328131847`*^9, 
   3.8066686119627748`*^9, 3.8078698737432685`*^9, 3.807871460603588*^9, 
   3.8078721646884856`*^9, 3.807872779313418*^9, 3.810032031650239*^9, 
   3.8100321147723722`*^9, 3.8100328500766087`*^9, 3.81003288686462*^9, 
   3.812465384805545*^9, 3.812466231435758*^9, 3.8124665319489613`*^9, 
   3.8124929603128457`*^9, 3.8128208881834135`*^9, 3.812926009730587*^9, 
   3.8129263335015736`*^9, 3.812926567106001*^9, 3.812974849076081*^9, 
   3.812975037492386*^9, 3.812975289770939*^9, 3.814173854742014*^9, 
   3.8154736809861712`*^9, 3.81547652601546*^9, 3.815773862797744*^9, 
   3.8169824037760563`*^9, 3.818802496327731*^9, 3.8199005836668096`*^9, 
   3.8199006653595266`*^9, 3.819900744372155*^9, 3.8199008232436676`*^9, 
   3.8199009048483195`*^9, 3.8199018016604333`*^9, 3.819902164704054*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[782]=",ExpressionUUID->"b919e60d-95da-4208-9aff-c73ad14e0407"]
}, Open  ]],

Cell["Percent change in quantity of processed Alaskan pollock", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
   3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
   3.8033936910231113`*^9, 3.803393702776311*^9}, 3.803394622470855*^9, {
   3.8199007129806695`*^9, 
   3.8199007137212467`*^9}},ExpressionUUID->"8bbd25bf-f186-47b7-bdea-\
a067bbd138c8"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qpwpd1", "-", "qpwpd0"}], ")"}], "100"}], "qpwpd0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.8017816232160883`*^9, 3.8017816264508963`*^9}, {3.8033939227091618`*^9, 
  3.8033939264599752`*^9}},
 CellLabel->
  "In[783]:=",ExpressionUUID->"35c7e8ed-6e90-4876-8ad4-951cb59bb75d"],

Cell[BoxData["3.555145803353288`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.8017816871591425`*^9, {3.801781996807395*^9, 3.8017820348028865`*^9}, 
   3.801782088059287*^9, {3.8017822302349033`*^9, 3.801782247347102*^9}, 
   3.803075086364133*^9, 3.803075153415903*^9, 3.8030752591493645`*^9, 
   3.803075403369701*^9, 3.8030755053973355`*^9, 3.8031139640709724`*^9, 
   3.803114083968629*^9, 3.803114146499525*^9, 3.803114191042283*^9, 
   3.803114297596467*^9, 3.803114393565318*^9, 3.8031185695486665`*^9, 
   3.8031186381221867`*^9, 3.8031187019990416`*^9, {3.8031187472973976`*^9, 
   3.8031187689943347`*^9}, 3.8031188084010916`*^9, 3.8031205934092197`*^9, 
   3.8031206307263594`*^9, 3.8031244169751763`*^9, 3.8031245168611298`*^9, 
   3.8031249102320795`*^9, 3.8031249914644413`*^9, 3.8031257590096035`*^9, 
   3.8031262532989244`*^9, 3.8031284830367737`*^9, 3.8031286690529904`*^9, 
   3.8032924987382483`*^9, 3.803303080529626*^9, 3.803303272410026*^9, 
   3.8033104076140594`*^9, 3.8033128982077513`*^9, 3.803313225836578*^9, 
   3.8033916455213737`*^9, 3.8033920606379957`*^9, 3.803392125683226*^9, 
   3.803392516970752*^9, 3.803392628137986*^9, 3.803394465193488*^9, 
   3.8033948069620905`*^9, 3.8033949209020023`*^9, 3.803397333321822*^9, 
   3.803397452706768*^9, 3.8033980790867853`*^9, 3.8033984448610687`*^9, 
   3.803398599469513*^9, 3.803509621581807*^9, 3.80351033040712*^9, 
   3.8035117219524527`*^9, 3.8035121814982457`*^9, 3.8046038229204807`*^9, 
   3.8046038664450727`*^9, 3.80460440319508*^9, 3.8046052309002666`*^9, 
   3.8046057861069555`*^9, 3.804606014790185*^9, 3.8048663934168415`*^9, 
   3.8057102518893185`*^9, 3.8057109502183375`*^9, 3.8057112617331076`*^9, 
   3.8057121119459105`*^9, 3.8057121545475206`*^9, 3.8057123655051136`*^9, 
   3.805712979303158*^9, 3.806668204083627*^9, 3.8066685328912807`*^9, 
   3.8066686120409126`*^9, 3.8078698738213854`*^9, 3.8078714606973143`*^9, 
   3.8078721647822504`*^9, 3.8078727794072065`*^9, 3.810032031733303*^9, 
   3.8100321148604407`*^9, 3.810032850165679*^9, 3.8100328869526896`*^9, 
   3.8124653848936324`*^9, 3.812466231532795*^9, 3.812466532040033*^9, 
   3.8124929604019146`*^9, 3.8128208882794886`*^9, 3.8129260098316674`*^9, 
   3.812926333633716*^9, 3.812926567211034*^9, 3.8129748493261213`*^9, 
   3.8129750375994697`*^9, 3.812975289895952*^9, 3.8141738548514175`*^9, 
   3.815473681079936*^9, 3.815476526124853*^9, 3.8157738628958178`*^9, 
   3.8169824037894573`*^9, 3.8188024963487434`*^9, 3.8199005837508755`*^9, 
   3.819900665447595*^9, 3.819900744459223*^9, 3.8199008233297634`*^9, 
   3.819900904939391*^9, 3.819901801740495*^9, 3.8199021647881193`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[783]=",ExpressionUUID->"4ffe9dea-9b36-4225-8711-6fd0939951f1"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.805710969379385*^9, 3.8057109987355022`*^9}, {
  3.8066687070114403`*^9, 
  3.8066687092482824`*^9}},ExpressionUUID->"254ffe1a-db28-4d32-b3eb-\
d205bcdfa509"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "sigmapu"}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"ppwd1", " ", 
      RowBox[{"(", 
       RowBox[{"qpwd1", "-", "qpwe0", "-", 
        RowBox[{"cr", " ", "qpwpd1"}]}], ")"}]}], " ", "-", " ", 
     RowBox[{"ppwd0", " ", 
      RowBox[{"(", 
       RowBox[{"qpwd0", "-", "qpwe0", "-", 
        RowBox[{"cr", " ", "qpwpd0"}]}], ")"}]}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8057110160869064`*^9, 3.805711037809208*^9}, {
  3.805711163592272*^9, 3.8057111856579466`*^9}, {3.8066684611842327`*^9, 
  3.80666849187914*^9}, {3.8199007375088005`*^9, 3.8199007404530983`*^9}},
 CellLabel->
  "In[784]:=",ExpressionUUID->"c7fe4204-c93d-4e6b-9d7b-8118c7f7d498"],

Cell[BoxData["86388.93677486821`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAuILPAURF6PeOO4t3VUMopmOMtwD0amsIY9BNIvW5r8g
erJxjtclIK2n27p1Scwbx89xa26C6IbW+fdAtJd/ywsQ/emEbdn7uDeOCRdm
2HwA0j4ds6eA6APt+Q9B9Hr5X8b8yW8cp2XF2YHobXIes0C0RNjDeSB6T5d8
7Ob0N45N7z4fA9FpTi1vQHTXMf4rB4D0lcfcnxMy3jgu+WjrPgVIi6jvyAfR
ZmavekB0u7i3whogXXF1mzmIPqntEA6iH9ndn/w1643jnz5Vp4JcoDvrji8t
BNInj96/wpQH9Oe2yg8BBW8cd+3hXnGy+I1j3MdfVx6WvnH8JWx4H0TPSxJ8
CaKd/N5+AtERHxX+guhZhla5j4D0jRuzZ4FoADi3uMQ=
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[784]=",ExpressionUUID->"99c67e53-9fa3-4c51-907b-ea6aaad0408e"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.8057110007983437`*^9, 3.805711013680259*^9}, {
  3.8066687122308364`*^9, 
  3.8066687154744096`*^9}},ExpressionUUID->"baad49c3-052c-4a87-8f8f-\
cc22691c1658"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "sigmapp"}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"ppwpd1", " ", 
      RowBox[{"(", 
       RowBox[{"qpwpd1", "-", "qpwpe0"}], ")"}]}], " ", "-", " ", 
     RowBox[{"ppwpd0", " ", 
      RowBox[{"(", 
       RowBox[{"qpwpd0", "-", "qpwpe0"}], ")"}]}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.805711055988307*^9, 3.8057110748240037`*^9}, {
   3.8057111889084806`*^9, 3.8057112024219413`*^9}, {3.8057118535803404`*^9, 
   3.8057118673168564`*^9}, {3.805711982284641*^9, 3.805711996923309*^9}, {
   3.805712772634124*^9, 3.8057127869645877`*^9}, {3.812820986396867*^9, 
   3.8128210032599916`*^9}, 3.8199007355232506`*^9},
 CellLabel->
  "In[785]:=",ExpressionUUID->"76bb3f98-5ade-4de4-a31a-ec154bd96781"],

Cell[BoxData["1.888935181283525`*^6"], "Output",
 CellChangeTimes->{{3.8057119696844306`*^9, 3.805711998595461*^9}, 
   3.8057121121178145`*^9, 3.8057121547194233`*^9, 3.805712365677018*^9, {
   3.805712774587569*^9, 3.8057127886523685`*^9}, 3.8057129794750605`*^9, 
   3.8066682042399087`*^9, 3.8066685330631847`*^9, 3.806668612212816*^9, 
   3.8078698740245447`*^9, 3.807871460869201*^9, 3.807872164954153*^9, 
   3.8078727795790863`*^9, 3.8100320319024334`*^9, 3.8100321150395803`*^9, 
   3.8100328503428187`*^9, 3.81003288713083*^9, 3.812465385075755*^9, 
   3.8124662317149363`*^9, 3.812466532226178*^9, 3.8124929605840564`*^9, 
   3.812820888464634*^9, 3.8128210045640106`*^9, 3.812926010030821*^9, 
   3.812926333877866*^9, 3.812926567422217*^9, 3.8129748509747405`*^9, 
   3.8129750378496637`*^9, 3.8129752901459928`*^9, 3.81417385508582*^9, 
   3.8154736812674656`*^9, 3.8154765263436394`*^9, 3.8157738631870456`*^9, 
   3.816982403832491*^9, 3.818802496404798*^9, 3.8199005840110903`*^9, 
   3.819900665719807*^9, 3.819900744628354*^9, 3.8199008235008698`*^9, 
   3.8199009051355696`*^9, 3.8199018019056225`*^9, 3.8199021649542484`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[785]=",ExpressionUUID->"9a16b8fe-d3cf-4653-9c06-876292419573"]
}, Open  ]],

Cell["Change in landings (in kg)", "Text",
 CellChangeTimes->{{3.819901014842124*^9, 
  3.819901018390876*^9}},ExpressionUUID->"dab3ed8c-1d4f-47fa-b5b3-\
1144b77ef863"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qpwd1", "-", "qpwd0"}], "]"}]], "Input",
 CellChangeTimes->{{3.8154765961833057`*^9, 3.815476600934089*^9}, 
   3.8199008828271413`*^9},
 CellLabel->
  "In[786]:=",ExpressionUUID->"6acfb596-6902-4032-a982-8171915347fd"],

Cell[BoxData["1.1485605710535765`*^7"], "Output",
 CellChangeTimes->{3.8154765277970057`*^9, 3.815476601277896*^9, 
  3.815773864467046*^9, 3.816982404015347*^9, 3.818802496674035*^9, 
  3.8199005851789894`*^9, 3.819900666851688*^9, 3.8199007457522297`*^9, 
  3.8199008246307535`*^9, 3.819900906306455*^9, 3.8199018019836826`*^9, 
  3.819902165036312*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[786]=",ExpressionUUID->"028d9f5d-a0ea-4768-a14f-a7d946b9ae18"]
}, Open  ]],

Cell[TextData[StyleBox["Cod Imports",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8046046370991073`*^9, 3.8046046475539503`*^9}, {
  3.8046047842187676`*^9, 3.8046047862970924`*^9}, {3.804604851781675*^9, 
  3.8046048540735693`*^9}, {3.8046049097756357`*^9, 
  3.8046049149170465`*^9}},ExpressionUUID->"1142afe0-5471-471d-be27-\
11707bbb354f"],

Cell["Percent change in price of unprocessed cod imports ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, 
   3.8046049194650755`*^9},ExpressionUUID->"48a40800-f00a-4dc9-88f5-\
1bbc6a044c8c"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pcut1", "-", "pcut0"}], ")"}], "100"}], "pcut0"]], "Input",
 CellChangeTimes->{{3.799849043170704*^9, 3.7998490564853735`*^9}},
 CellLabel->
  "In[787]:=",ExpressionUUID->"d6dab62b-3e22-47ae-9eff-2ea7f40fb6ec"],

Cell[BoxData["1.089109897304112`"], "Output",
 CellChangeTimes->{
  3.7998490576574435`*^9, 3.7998495912398295`*^9, 3.799850874360155*^9, 
   3.799851092303023*^9, 3.799855221038303*^9, 3.7998552589374557`*^9, 
   3.7998567327785015`*^9, 3.7998567780902324`*^9, 3.7998571944022226`*^9, {
   3.7998574104875593`*^9, 3.7998574810320826`*^9}, 3.799857521432539*^9, {
   3.799857623111682*^9, 3.7998576649789386`*^9}, 3.7998577597749724`*^9, {
   3.801660849527525*^9, 3.801660862624814*^9}, 3.801662763533171*^9, 
   3.8016634657466803`*^9, 3.8016642626056643`*^9, {3.8016643122917223`*^9, 
   3.8016643345421658`*^9}, 3.8016644601040287`*^9, 3.8016653509488783`*^9, 
   3.80166539686592*^9, 3.801665428450221*^9, {3.8016667225993204`*^9, 
   3.80166675058422*^9}, 3.8016667854451113`*^9, {3.8016669593253546`*^9, 
   3.8016669838779354`*^9}, 3.8016671132660503`*^9, 3.8016672266062574`*^9, 
   3.8016673968816633`*^9, 3.8016675836556864`*^9, {3.801667847037982*^9, 
   3.801667862915349*^9}, 3.8016679340591187`*^9, {3.801668183333703*^9, 
   3.8016682038623843`*^9}, {3.8016682687882276`*^9, 
   3.8016682952171636`*^9}, {3.8016683448377433`*^9, 3.801668369562169*^9}, 
   3.8016684206168647`*^9, 3.8016684522650824`*^9, 3.8016684868003263`*^9, 
   3.801668540850268*^9, 3.8016925867965164`*^9, 3.8016926406071444`*^9, 
   3.801692745909522*^9, 3.8016929516374054`*^9, 3.8016932296256547`*^9, 
   3.801693285958311*^9, 3.8016933962558312`*^9, 3.8016934884622154`*^9, 
   3.8017769832041283`*^9, 3.8017772008385425`*^9, 3.801777273540599*^9, 
   3.8017776507078424`*^9, 3.801778004978783*^9, 3.801778073702798*^9, 
   3.8017783128658295`*^9, 3.801778343719041*^9, 3.801778654371894*^9, 
   3.8017791374425287`*^9, 3.8017792482388325`*^9, 3.8017795060137396`*^9, 
   3.8017795487417655`*^9, 3.8017796215543394`*^9, 3.801779709090421*^9, 
   3.8017798164603386`*^9, 3.8017798531259794`*^9, 3.8017798988439903`*^9, {
   3.8017799398984423`*^9, 3.801779966840557*^9}, 3.8017802548137856`*^9, 
   3.8017803064444437`*^9, 3.8017803435706825`*^9, {3.8017804436733294`*^9, 
   3.8017804718575134`*^9}, 3.801780539903387*^9, 3.8017805795752363`*^9, 
   3.8017806649253283`*^9, 3.801781175850298*^9, 3.801781215727419*^9, 
   3.8017816854232187`*^9, {3.801781995604074*^9, 3.801782033990254*^9}, 
   3.801782087168516*^9, {3.8017822281251793`*^9, 3.801782246096896*^9}, 
   3.803075085767171*^9, 3.8030751528754764`*^9, 3.803075259099325*^9, 
   3.8030754033216634`*^9, 3.803075505348297*^9, 3.803113963644636*^9, 
   3.8031140835492845`*^9, 3.8031141460731936`*^9, 3.803114190993244*^9, 
   3.803114297552397*^9, 3.803114393521284*^9, 3.8031185690843043`*^9, 
   3.8031186380791526`*^9, 3.803118701954007*^9, {3.8031187472493606`*^9, 
   3.8031187689482985`*^9}, 3.803118808353054*^9, 3.8031205929128313`*^9, 
   3.8031206306793222`*^9, 3.8031244165218215`*^9, 3.8031245168100786`*^9, 
   3.803124910188046*^9, 3.8031249914193816`*^9, 3.803125758944553*^9, 
   3.803126253253889*^9, 3.803128482570405*^9, 3.8031286690039167`*^9, 
   3.8032924986802015`*^9, 3.803303077997965*^9, 3.803303270565977*^9, 
   3.80331040398847*^9, 3.803312894779056*^9, 3.8033132225860453`*^9, 
   3.8033916427768393`*^9, 3.8033920582322526`*^9, 3.8033921229932127`*^9, 
   3.8033925143710403`*^9, 3.8033926258874025`*^9, 3.8033944518992615`*^9, 
   3.8033947933188124`*^9, 3.803394903821847*^9, 3.8033973202577605`*^9, 
   3.8033974359807696`*^9, 3.803398060332938*^9, 3.8033984259868727`*^9, 
   3.8033985854140067`*^9, 3.8035096201753283`*^9, 3.803510329016269*^9, 
   3.803511720545965*^9, 3.8035121800761366`*^9, 3.804603821498352*^9, 
   3.8046038649135585`*^9, 3.8046044015720406`*^9, 3.804605230994026*^9, 
   3.804605786185095*^9, 3.804606014876253*^9, 3.8048663934949803`*^9, 
   3.8057102519674563`*^9, 3.8057109503121033`*^9, 3.8057112620144024`*^9, 
   3.805712112195953*^9, 3.8057121547975607`*^9, 3.8057123657707834`*^9, 
   3.805712979553198*^9, 3.8066682043336687`*^9, 3.8066685331569567`*^9, 
   3.8066686123065825`*^9, 3.8078698741027184`*^9, 3.807871460947338*^9, 
   3.8078721650322905`*^9, 3.807872779657223*^9, 3.8100320319965057`*^9, 
   3.8100321151286488`*^9, 3.8100328504318895`*^9, 3.8100328872178984`*^9, 
   3.8124653851668262`*^9, 3.812466231809034*^9, 3.812466532319251*^9, 
   3.8124929606731253`*^9, 3.812820888566746*^9, 3.8129260101288967`*^9, 
   3.812926333999981*^9, 3.812926567527279*^9, 3.812974852854632*^9, 
   3.812975037950123*^9, 3.812975290271013*^9, 3.8141738552108393`*^9, 
   3.8154736813612304`*^9, 3.8154765264686604`*^9, 3.815773863285122*^9, 
   3.8169824038465023`*^9, 3.818802496422823*^9, 3.819900584097147*^9, 
   3.8199006658038726`*^9, 3.8199007447044134`*^9, 3.819900823585936*^9, 
   3.8199009052256308`*^9, 3.819901802062744*^9, 3.819902165118376*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[787]=",ExpressionUUID->"e53401c3-675f-4973-a495-2535466cf892"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed cod imports ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, 
   3.8033946224396005`*^9, 
   3.8046049447689314`*^9},ExpressionUUID->"7c7f2397-6ea3-466d-89ec-\
1abe3b2211b3"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qcut1", "-", "qcut0"}], ")"}], "100"}], "qcut0"]], "Input",
 CellChangeTimes->{{3.799849043170704*^9, 3.7998490564853735`*^9}, {
  3.8033938948662386`*^9, 3.803393898476201*^9}, {3.8033945738959627`*^9, 
  3.8033945775217643`*^9}, {3.8199007783536563`*^9, 3.8199007807865562`*^9}},
 CellLabel->
  "In[788]:=",ExpressionUUID->"0c916522-7a07-4ec0-b186-2d0db90da26d"],

Cell[BoxData[
 RowBox[{"-", "4.263822962496833`"}]], "Output",
 CellChangeTimes->{
  3.7998490576574435`*^9, 3.7998495912398295`*^9, 3.799850874360155*^9, 
   3.799851092303023*^9, 3.799855221038303*^9, 3.7998552589374557`*^9, 
   3.7998567327785015`*^9, 3.7998567780902324`*^9, 3.7998571944022226`*^9, {
   3.7998574104875593`*^9, 3.7998574810320826`*^9}, 3.799857521432539*^9, {
   3.799857623111682*^9, 3.7998576649789386`*^9}, 3.7998577597749724`*^9, {
   3.801660849527525*^9, 3.801660862624814*^9}, 3.801662763533171*^9, 
   3.8016634657466803`*^9, 3.8016642626056643`*^9, {3.8016643122917223`*^9, 
   3.8016643345421658`*^9}, 3.8016644601040287`*^9, 3.8016653509488783`*^9, 
   3.80166539686592*^9, 3.801665428450221*^9, {3.8016667225993204`*^9, 
   3.80166675058422*^9}, 3.8016667854451113`*^9, {3.8016669593253546`*^9, 
   3.8016669838779354`*^9}, 3.8016671132660503`*^9, 3.8016672266062574`*^9, 
   3.8016673968816633`*^9, 3.8016675836556864`*^9, {3.801667847037982*^9, 
   3.801667862915349*^9}, 3.8016679340591187`*^9, {3.801668183333703*^9, 
   3.8016682038623843`*^9}, {3.8016682687882276`*^9, 
   3.8016682952171636`*^9}, {3.8016683448377433`*^9, 3.801668369562169*^9}, 
   3.8016684206168647`*^9, 3.8016684522650824`*^9, 3.8016684868003263`*^9, 
   3.801668540850268*^9, 3.8016925867965164`*^9, 3.8016926406071444`*^9, 
   3.801692745909522*^9, 3.8016929516374054`*^9, 3.8016932296256547`*^9, 
   3.801693285958311*^9, 3.8016933962558312`*^9, 3.8016934884622154`*^9, 
   3.8017769832041283`*^9, 3.8017772008385425`*^9, 3.801777273540599*^9, 
   3.8017776507078424`*^9, 3.801778004978783*^9, 3.801778073702798*^9, 
   3.8017783128658295`*^9, 3.801778343719041*^9, 3.801778654371894*^9, 
   3.8017791374425287`*^9, 3.8017792482388325`*^9, 3.8017795060137396`*^9, 
   3.8017795487417655`*^9, 3.8017796215543394`*^9, 3.801779709090421*^9, 
   3.8017798164603386`*^9, 3.8017798531259794`*^9, 3.8017798988439903`*^9, {
   3.8017799398984423`*^9, 3.801779966840557*^9}, 3.8017802548137856`*^9, 
   3.8017803064444437`*^9, 3.8017803435706825`*^9, {3.8017804436733294`*^9, 
   3.8017804718575134`*^9}, 3.801780539903387*^9, 3.8017805795752363`*^9, 
   3.8017806649253283`*^9, 3.801781175850298*^9, 3.801781215727419*^9, 
   3.8017816854232187`*^9, {3.801781995604074*^9, 3.801782033990254*^9}, 
   3.801782087168516*^9, {3.8017822281251793`*^9, 3.801782246096896*^9}, 
   3.803075085767171*^9, 3.8030751528754764`*^9, 3.803075259099325*^9, 
   3.8030754033216634`*^9, 3.803075505348297*^9, 3.803113963644636*^9, 
   3.8031140835492845`*^9, 3.8031141460731936`*^9, 3.803114190993244*^9, 
   3.803114297552397*^9, 3.803114393521284*^9, 3.8031185690843043`*^9, 
   3.8031186380791526`*^9, 3.803118701954007*^9, {3.8031187472493606`*^9, 
   3.8031187689482985`*^9}, 3.803118808353054*^9, 3.8031205929128313`*^9, 
   3.8031206306793222`*^9, 3.8031244165218215`*^9, 3.8031245168100786`*^9, 
   3.803124910188046*^9, 3.8031249914193816`*^9, 3.803125758944553*^9, 
   3.803126253253889*^9, 3.803128482570405*^9, 3.8031286690039167`*^9, 
   3.8032924986802015`*^9, 3.803303077997965*^9, 3.803303270565977*^9, 
   3.80331040398847*^9, 3.803312894779056*^9, 3.8033132225860453`*^9, 
   3.8033916427768393`*^9, 3.8033920582322526`*^9, 3.8033921229932127`*^9, 
   3.8033925143710403`*^9, 3.8033926258874025`*^9, 3.8033944633700285`*^9, 
   3.8033945780218453`*^9, 3.803394803023739*^9, 3.8033949167602015`*^9, 
   3.8033973313304625`*^9, 3.803397448376726*^9, 3.803398074460521*^9, 
   3.8033984413767877`*^9, 3.803398596979187*^9, 3.8035096212536287`*^9, 
   3.803510330094569*^9, 3.8035117216400065`*^9, 3.803512181154437*^9, 
   3.8046038225766697`*^9, 3.8046038660543804`*^9, 3.8046044028200192`*^9, 
   3.8046052310721626`*^9, 3.804605786263234*^9, 3.8046060149603186`*^9, 
   3.8048663935731297`*^9, 3.8057102520455947`*^9, 3.8057109503902707`*^9, 
   3.8057112621081676`*^9, 3.8057121122897186`*^9, 3.805712154891327*^9, 
   3.805712365848922*^9, 3.805712979646964*^9, 3.806668204411807*^9, 
   3.806668533250716*^9, 3.806668612432823*^9, 3.807869874196449*^9, 
   3.8078714610411034`*^9, 3.8078721651260557`*^9, 3.807872779750989*^9, 
   3.81003203207957*^9, 3.810032115217718*^9, 3.8100328505189576`*^9, 
   3.8100328873059673`*^9, 3.812465385257897*^9, 3.812466231900114*^9, 
   3.812466532423333*^9, 3.8124929607651973`*^9, 3.812820888662789*^9, 
   3.8129260102239704`*^9, 3.812926334138068*^9, 3.812926567629359*^9, 
   3.8129748531003633`*^9, 3.812975038075215*^9, 3.812975290396033*^9, 
   3.8141738553358603`*^9, 3.815473681470623*^9, 3.8154765265780535`*^9, 
   3.8157738633922057`*^9, 3.816982403861521*^9, 3.8188024964438496`*^9, 
   3.819900584201228*^9, 3.8199006658909397`*^9, 3.8199007448004885`*^9, 
   3.8199008236890173`*^9, 3.8199009053156843`*^9, 3.819901802147809*^9, 
   3.8199021651994395`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[788]=",ExpressionUUID->"e906fca1-03df-4322-a41f-a8d77364ce18"]
}, Open  ]],

Cell["Percent change in price of processed cod imports ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, 
   3.8033937789885077`*^9},ExpressionUUID->"68c54ca6-21db-4117-b44f-\
50d489d4ad0e"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pcpt1", "-", "pcpt0"}], ")"}], "100"}], "pcpt0"]], "Input",
 CellChangeTimes->{{3.799849043170704*^9, 3.7998490564853735`*^9}, {
  3.801781635639913*^9, 3.801781641532714*^9}},
 CellLabel->
  "In[789]:=",ExpressionUUID->"84faf935-ac0e-4357-b313-8b675ca8bd95"],

Cell[BoxData["2.45513261998667`"], "Output",
 CellChangeTimes->{
  3.7998490576574435`*^9, 3.7998495912398295`*^9, 3.799850874360155*^9, 
   3.799851092303023*^9, 3.799855221038303*^9, 3.7998552589374557`*^9, 
   3.7998567327785015`*^9, 3.7998567780902324`*^9, 3.7998571944022226`*^9, {
   3.7998574104875593`*^9, 3.7998574810320826`*^9}, 3.799857521432539*^9, {
   3.799857623111682*^9, 3.7998576649789386`*^9}, 3.7998577597749724`*^9, {
   3.801660849527525*^9, 3.801660862624814*^9}, 3.801662763533171*^9, 
   3.8016634657466803`*^9, 3.8016642626056643`*^9, {3.8016643122917223`*^9, 
   3.8016643345421658`*^9}, 3.8016644601040287`*^9, 3.8016653509488783`*^9, 
   3.80166539686592*^9, 3.801665428450221*^9, {3.8016667225993204`*^9, 
   3.80166675058422*^9}, 3.8016667854451113`*^9, {3.8016669593253546`*^9, 
   3.8016669838779354`*^9}, 3.8016671132660503`*^9, 3.8016672266062574`*^9, 
   3.8016673968816633`*^9, 3.8016675836556864`*^9, {3.801667847037982*^9, 
   3.801667862915349*^9}, 3.8016679340591187`*^9, {3.801668183333703*^9, 
   3.8016682038623843`*^9}, {3.8016682687882276`*^9, 
   3.8016682952171636`*^9}, {3.8016683448377433`*^9, 3.801668369562169*^9}, 
   3.8016684206168647`*^9, 3.8016684522650824`*^9, 3.8016684868003263`*^9, 
   3.801668540850268*^9, 3.8016925867965164`*^9, 3.8016926406071444`*^9, 
   3.801692745909522*^9, 3.8016929516374054`*^9, 3.8016932296256547`*^9, 
   3.801693285958311*^9, 3.8016933962558312`*^9, 3.8016934884622154`*^9, 
   3.8017769832041283`*^9, 3.8017772008385425`*^9, 3.801777273540599*^9, 
   3.8017776507078424`*^9, 3.801778004978783*^9, 3.801778073702798*^9, 
   3.8017783128658295`*^9, 3.801778343719041*^9, 3.801778654371894*^9, 
   3.8017791374425287`*^9, 3.8017792482388325`*^9, 3.8017795060137396`*^9, 
   3.8017795487417655`*^9, 3.8017796215543394`*^9, 3.801779709090421*^9, 
   3.8017798164603386`*^9, 3.8017798531259794`*^9, 3.8017798988439903`*^9, {
   3.8017799398984423`*^9, 3.801779966840557*^9}, 3.8017802548137856`*^9, 
   3.8017803064444437`*^9, 3.8017803435706825`*^9, {3.8017804436733294`*^9, 
   3.8017804718575134`*^9}, 3.801780539903387*^9, 3.8017805795752363`*^9, 
   3.8017806649253283`*^9, 3.801781175850298*^9, 3.801781215727419*^9, 
   3.8017816874560657`*^9, {3.801781997119952*^9, 3.801782035037301*^9}, 
   3.801782088403104*^9, {3.80178223128195*^9, 3.801782248925489*^9}, 
   3.803075086638317*^9, 3.8030751536991262`*^9, 3.8030752591733837`*^9, 
   3.80307540339472*^9, 3.8030755054224205`*^9, 3.803113964255118*^9, 
   3.8031140841157312`*^9, 3.8031141466476393`*^9, 3.803114191067302*^9, 
   3.8031142976184483`*^9, 3.803114393587335*^9, 3.8031185695997057`*^9, 
   3.8031186381452045`*^9, 3.8031187020220594`*^9, {3.803118747321417*^9, 
   3.8031187690183535`*^9}, 3.8031188084241095`*^9, 3.8031205934552555`*^9, 
   3.803120630750378*^9, 3.803124417377491*^9, 3.803124516886138*^9, 
   3.8031249102560987`*^9, 3.8031249914864445`*^9, 3.803125759044631*^9, 
   3.803126253320942*^9, 3.8031284831008244`*^9, 3.803128669073964*^9, 
   3.8032924987662697`*^9, 3.803303083451976*^9, 3.803303273253913*^9, 
   3.80331040983317*^9, 3.803312900249586*^9, 3.803313229188795*^9, 
   3.803391646834087*^9, 3.803392062036019*^9, 3.803392127368552*^9, 
   3.8033925186588345`*^9, 3.8033926292475414`*^9, 3.803394457869129*^9, 
   3.803394798463411*^9, 3.8033949115104084`*^9, 3.80339732557761*^9, 
   3.8033974423678694`*^9, 3.803398066318459*^9, 3.8033984355220613`*^9, 
   3.80339858888332*^9, 3.8035096206754103`*^9, 3.80351032951635*^9, 
   3.8035117210460463`*^9, 3.8035121805918455`*^9, 3.804603821967185*^9, 
   3.8046038654292717`*^9, 3.804604402151506*^9, 3.8046052312284513`*^9, 
   3.8046057863413734`*^9, 3.8046060150453863`*^9, 3.8048663936512556`*^9, 
   3.8057102521237335`*^9, 3.805710950468381*^9, 3.805711262201933*^9, 
   3.805712112367857*^9, 3.8057121549694643`*^9, 3.805712365942687*^9, 
   3.8057129797251005`*^9, 3.806668204568083*^9, 3.8066685333288565`*^9, 
   3.8066686125422153`*^9, 3.8078698742745867`*^9, 3.8078714611192408`*^9, 
   3.807872165219821*^9, 3.8078727798447866`*^9, 3.8100320321636353`*^9, 
   3.810032115308789*^9, 3.8100328506070275`*^9, 3.8100328873950386`*^9, 
   3.8124653853489676`*^9, 3.8124662319981775`*^9, 3.812466532516406*^9, 
   3.812492960854266*^9, 3.8128208887598643`*^9, 3.8129260103210464`*^9, 
   3.812926334262164*^9, 3.8129265677264347`*^9, 3.8129748549905024`*^9, 
   3.8129750381845355`*^9, 3.812975290536681*^9, 3.8141738554452906`*^9, 
   3.8154736815800157`*^9, 3.8154765266874466`*^9, 3.8157738634892817`*^9, 
   3.8169824038761067`*^9, 3.8188024964628425`*^9, 3.8199005842963023`*^9, 
   3.819900665977008*^9, 3.819900744887556*^9, 3.8199008237750845`*^9, 
   3.8199009054047527`*^9, 3.819901802232875*^9, 3.819902165297516*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[789]=",ExpressionUUID->"80d555f6-b92c-4c72-891e-1a50cec9f0d3"]
}, Open  ]],

Cell["Percent change in quantity of processed cod imports ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, 
   3.8033937789885077`*^9, 
   3.8033946224864826`*^9},ExpressionUUID->"8cb7caba-4423-4e83-a429-\
2d1d345028b2"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qcpt1", "-", "qcpt0"}], ")"}], "100"}], "qcpt0"]], "Input",
 CellChangeTimes->{{3.799849043170704*^9, 3.7998490564853735`*^9}, {
  3.801781635639913*^9, 3.801781641532714*^9}, {3.8033939369618406`*^9, 
  3.803393940493889*^9}, {3.8033946820028114`*^9, 3.8033946857689657`*^9}, {
  3.819900784888756*^9, 3.8199007871535187`*^9}},
 CellLabel->
  "In[790]:=",ExpressionUUID->"2c83cec5-273c-4ae8-b5b7-2c58e3c45034"],

Cell[BoxData[
 RowBox[{"-", "4.951567827219799`"}]], "Output",
 CellChangeTimes->{
  3.7998490576574435`*^9, 3.7998495912398295`*^9, 3.799850874360155*^9, 
   3.799851092303023*^9, 3.799855221038303*^9, 3.7998552589374557`*^9, 
   3.7998567327785015`*^9, 3.7998567780902324`*^9, 3.7998571944022226`*^9, {
   3.7998574104875593`*^9, 3.7998574810320826`*^9}, 3.799857521432539*^9, {
   3.799857623111682*^9, 3.7998576649789386`*^9}, 3.7998577597749724`*^9, {
   3.801660849527525*^9, 3.801660862624814*^9}, 3.801662763533171*^9, 
   3.8016634657466803`*^9, 3.8016642626056643`*^9, {3.8016643122917223`*^9, 
   3.8016643345421658`*^9}, 3.8016644601040287`*^9, 3.8016653509488783`*^9, 
   3.80166539686592*^9, 3.801665428450221*^9, {3.8016667225993204`*^9, 
   3.80166675058422*^9}, 3.8016667854451113`*^9, {3.8016669593253546`*^9, 
   3.8016669838779354`*^9}, 3.8016671132660503`*^9, 3.8016672266062574`*^9, 
   3.8016673968816633`*^9, 3.8016675836556864`*^9, {3.801667847037982*^9, 
   3.801667862915349*^9}, 3.8016679340591187`*^9, {3.801668183333703*^9, 
   3.8016682038623843`*^9}, {3.8016682687882276`*^9, 
   3.8016682952171636`*^9}, {3.8016683448377433`*^9, 3.801668369562169*^9}, 
   3.8016684206168647`*^9, 3.8016684522650824`*^9, 3.8016684868003263`*^9, 
   3.801668540850268*^9, 3.8016925867965164`*^9, 3.8016926406071444`*^9, 
   3.801692745909522*^9, 3.8016929516374054`*^9, 3.8016932296256547`*^9, 
   3.801693285958311*^9, 3.8016933962558312`*^9, 3.8016934884622154`*^9, 
   3.8017769832041283`*^9, 3.8017772008385425`*^9, 3.801777273540599*^9, 
   3.8017776507078424`*^9, 3.801778004978783*^9, 3.801778073702798*^9, 
   3.8017783128658295`*^9, 3.801778343719041*^9, 3.801778654371894*^9, 
   3.8017791374425287`*^9, 3.8017792482388325`*^9, 3.8017795060137396`*^9, 
   3.8017795487417655`*^9, 3.8017796215543394`*^9, 3.801779709090421*^9, 
   3.8017798164603386`*^9, 3.8017798531259794`*^9, 3.8017798988439903`*^9, {
   3.8017799398984423`*^9, 3.801779966840557*^9}, 3.8017802548137856`*^9, 
   3.8017803064444437`*^9, 3.8017803435706825`*^9, {3.8017804436733294`*^9, 
   3.8017804718575134`*^9}, 3.801780539903387*^9, 3.8017805795752363`*^9, 
   3.8017806649253283`*^9, 3.801781175850298*^9, 3.801781215727419*^9, 
   3.8017816874560657`*^9, {3.801781997119952*^9, 3.801782035037301*^9}, 
   3.801782088403104*^9, {3.80178223128195*^9, 3.801782248925489*^9}, 
   3.803075086638317*^9, 3.8030751536991262`*^9, 3.8030752591733837`*^9, 
   3.80307540339472*^9, 3.8030755054224205`*^9, 3.803113964255118*^9, 
   3.8031140841157312`*^9, 3.8031141466476393`*^9, 3.803114191067302*^9, 
   3.8031142976184483`*^9, 3.803114393587335*^9, 3.8031185695997057`*^9, 
   3.8031186381452045`*^9, 3.8031187020220594`*^9, {3.803118747321417*^9, 
   3.8031187690183535`*^9}, 3.8031188084241095`*^9, 3.8031205934552555`*^9, 
   3.803120630750378*^9, 3.803124417377491*^9, 3.803124516886138*^9, 
   3.8031249102560987`*^9, 3.8031249914864445`*^9, 3.803125759044631*^9, 
   3.803126253320942*^9, 3.8031284831008244`*^9, 3.803128669073964*^9, 
   3.8032924987662697`*^9, 3.803303083451976*^9, 3.803303273253913*^9, 
   3.80331040983317*^9, 3.803312900249586*^9, 3.803313229188795*^9, 
   3.803391646834087*^9, 3.803392062036019*^9, 3.803392127368552*^9, 
   3.8033925186588345`*^9, 3.8033926292475414`*^9, {3.803394465990492*^9, 
   3.8033944959181633`*^9}, 3.803394686425327*^9, 3.8033948090874414`*^9, 
   3.8033949233238854`*^9, 3.8033973352779136`*^9, 3.8033974544726863`*^9, 
   3.803398080664833*^9, 3.8033984465644703`*^9, 3.8033986017355056`*^9, 
   3.803509621769337*^9, 3.8035103305633955`*^9, 3.803511722108733*^9, 
   3.8035121816545453`*^9, 3.804603823092388*^9, 3.804603866617177*^9, 
   3.804604403382613*^9, 3.8046052313378277`*^9, 3.8046057864507694`*^9, 
   3.804606015139187*^9, 3.804866393745021*^9, 3.805710252201872*^9, 
   3.805710950577773*^9, 3.8057112622800713`*^9, 3.8057121124616337`*^9, 
   3.80571215506323*^9, 3.805712366020932*^9, 3.8057129798188667`*^9, 
   3.806668204677476*^9, 3.806668533453875*^9, 3.8066686126375914`*^9, 
   3.807869874368353*^9, 3.8078714612130055`*^9, 3.807872165297959*^9, 
   3.8078727799385185`*^9, 3.8100320322487*^9, 3.810032115395856*^9, 
   3.8100328506950965`*^9, 3.810032887483107*^9, 3.81246538544204*^9, 
   3.8124662320882416`*^9, 3.812466532609481*^9, 3.81249296094436*^9, 
   3.8128208888539376`*^9, 3.8129260104311314`*^9, 3.812926334375264*^9, 
   3.8129265678245115`*^9, 3.8129748552092876`*^9, 3.8129750383095565`*^9, 
   3.8129752906460743`*^9, 3.814173855570275*^9, 3.815473681673781*^9, 
   3.8154765267968397`*^9, 3.815773863587358*^9, 3.816982403889621*^9, 
   3.81880249648186*^9, 3.8199005843803673`*^9, 3.819900666065076*^9, 
   3.8199007449736233`*^9, 3.8199008238611526`*^9, 3.819900905493822*^9, 
   3.819901802315939*^9, 3.8199021653765774`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[790]=",ExpressionUUID->"a68aee0a-983f-4c21-8857-fc110e300e6a"]
}, Open  ]],

Cell[TextData[StyleBox["Pollock Imports",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8046046370991073`*^9, 3.8046046475539503`*^9}, {
  3.8046047842187676`*^9, 3.8046047862970924`*^9}, {3.804604851781675*^9, 
  3.8046048540735693`*^9}, {3.8046049097756357`*^9, 3.8046049149170465`*^9}, {
  3.8046049649980907`*^9, 
  3.8046049666702237`*^9}},ExpressionUUID->"83d06b74-3095-4edc-953e-\
85645ac377d9"],

Cell["Percent change in price of unprocessed pollock imports ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489469994965`*^9}, 
   3.804604930404688*^9},ExpressionUUID->"9604737d-82e3-49c1-ba3c-\
b4893b6fedca"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pput1", "-", "pput0"}], ")"}], "100"}], "pput0"]], "Input",
 CellChangeTimes->{{3.799849065893024*^9, 3.7998490705260077`*^9}},
 CellLabel->
  "In[791]:=",ExpressionUUID->"f722eaec-b4d7-4482-ab02-c9a7ec54c530"],

Cell[BoxData["0.7131689529825175`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB2JDpuqYrRFvHE/4v00F0ZfeBKwG0aFfnh0H0UHhVq9N
It84Xvva8fVC1BtHq79XfC4C6cKy08Ugeqer4D0QLdKW8hhE71p1+C+Idjep
9boEpP/pzti6JOaNoxfbpnsg2i19+gsQnevmV/Y+7o2jQOBKmw9A+hfHmikg
uq6j8SGIZlrGZcKfDORfy7cD0Zv4I2eBaJGCT/NA9L9/BrGb09847jjLehxE
v8ia9gZE8ykpXjkApKXC5D4nZLxxXHctwH0KkPaccT4fRFvv/9sDolOUVBTX
AGmOjLPmIPrdmohwEH1r/9fJX7OA/p5g4VSQ+8aRh+Hu0kIgLXHs6xWmvDeO
fa9qPgQUvHE0YBdYcbL4jSPzU76rD0vfOGpdc7kPopN+Kr4E0SwJ/z6BaPv1
Rn9BNNcan9xHQNpo7bpZIBoA+x7KUw==
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[791]=",ExpressionUUID->"8b519f77-fde5-44fa-b40b-d41333e7aaa1"]
}, Open  ]],

Cell["\<\
Percent change in quantity of whole unprocessed pollock imports \
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489469994965`*^9}, 
   3.8033946224396005`*^9},ExpressionUUID->"0cfb771c-9b76-45c8-b92f-\
562d4e73ee29"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qput1", "-", "qput0"}], ")"}], "100"}], "qput0"]], "Input",
 CellChangeTimes->{{3.799849065893024*^9, 3.7998490705260077`*^9}, {
  3.8033939018209624`*^9, 3.8033939051336765`*^9}, {3.8033945928081512`*^9, 
  3.8033945974171205`*^9}, {3.8199007919542665`*^9, 3.8199007939318075`*^9}},
 CellLabel->
  "In[792]:=",ExpressionUUID->"7bb4680b-39e9-4b9e-85ba-9765d54b1207"],

Cell[BoxData[
 RowBox[{"-", "6.165887089761557`"}]], "Output",
 CellChangeTimes->{
  3.799849072198154*^9, 3.7998495916774035`*^9, 3.7998508744539204`*^9, 
   3.7998510924280457`*^9, 3.7998552211164412`*^9, 3.7998552590468483`*^9, 
   3.799856732870942*^9, 3.799856778183997*^9, 3.799857194558479*^9, {
   3.7998574106282053`*^9, 3.799857481094624*^9}, 3.7998575224652433`*^9, {
   3.799857623502369*^9, 3.7998576650883036`*^9}, 3.799857759868785*^9, {
   3.801660849636916*^9, 3.8016608627654595`*^9}, 3.801662763986375*^9, 
   3.8016634673719516`*^9, 3.8016642627306843`*^9, {3.8016643124011154`*^9, 
   3.8016643346358976`*^9}, 3.8016644602290487`*^9, 3.8016653535359726`*^9, 
   3.8016653969440584`*^9, 3.801665428559614*^9, {3.801666722972541*^9, 
   3.801666750693612*^9}, 3.801666785960819*^9, {3.8016669601536183`*^9, 
   3.8016669840029554`*^9}, 3.8016671134066973`*^9, 3.8016672274188547`*^9, 
   3.8016673977568097`*^9, 3.8016675837807074`*^9, {3.8016678475224285`*^9, 
   3.801667863055975*^9}, 3.8016679341841373`*^9, {3.8016681834430943`*^9, 
   3.801668203956149*^9}, {3.801668268928874*^9, 3.801668295342183*^9}, {
   3.8016683449627857`*^9, 3.801668369671562*^9}, 3.8016684207418857`*^9, 
   3.8016684523901043`*^9, 3.8016684869097185`*^9, 3.8016685409596605`*^9, 
   3.8016925870309296`*^9, 3.8016926408103027`*^9, 3.8016927460769453`*^9, 
   3.801692951793749*^9, 3.8016932297350473`*^9, 3.8016932864583883`*^9, 
   3.8016933964121065`*^9, 3.8016934886028624`*^9, 3.8017769833916583`*^9, 
   3.801777201338623*^9, 3.8017772736968746`*^9, 3.8017776512391815`*^9, 
   3.801778005557005*^9, 3.8017780738747015`*^9, 3.8017783130221047`*^9, 
   3.801778343828433*^9, 3.8017786552001514`*^9, 3.8017791379894953`*^9, 
   3.8017792487389135`*^9, 3.8017795061543865`*^9, 3.801779549148078*^9, 
   3.8017796216949863`*^9, 3.8017797092310677`*^9, 3.801779816960457*^9, 
   3.8017798532511*^9, 3.8017798989221287`*^9, {3.8017799403828955`*^9, 
   3.801779966965578*^9}, 3.801780255627626*^9, 3.801780306600722*^9, 
   3.8017803437113323`*^9, {3.801780443813979*^9, 3.80178047201379*^9}, 
   3.801780540403473*^9, 3.801780580075383*^9, 3.801780665081603*^9, 
   3.8017811760065727`*^9, 3.8017812224785295`*^9, 3.8017816859558167`*^9, {
   3.8017819957447224`*^9, 3.801782034115322*^9}, 3.801782087324792*^9, {
   3.80178222862526*^9, 3.801782246237544*^9}, 3.803075085942481*^9, 
   3.803075153010583*^9, 3.8030752591123357`*^9, 3.8030754033336725`*^9, 
   3.8030755053613076`*^9, 3.8031139637817445`*^9, 3.803114083684391*^9, 
   3.803114146212301*^9, 3.803114191005254*^9, 3.8031142975634055`*^9, 
   3.803114393532293*^9, 3.8031185691113253`*^9, 3.8031186380891604`*^9, 
   3.8031187019650154`*^9, {3.8031187472613697`*^9, 3.803118768960308*^9}, 
   3.803118808366064*^9, 3.8031205929878902`*^9, 3.8031206306923327`*^9, 
   3.8031244165458403`*^9, 3.8031245168230886`*^9, 3.8031249101990547`*^9, 
   3.8031249914303904`*^9, 3.8031257589605656`*^9, 3.803126253264904*^9, 
   3.803128482598428*^9, 3.8031286690159273`*^9, 3.803292498694213*^9, 
   3.8033030784355364`*^9, 3.8033032707847624`*^9, 3.803310405629362*^9, 
   3.803312895376504*^9, 3.803313223133088*^9, 3.8033916431877*^9, 
   3.8033920584510384`*^9, 3.803392123544437*^9, 3.8033925152494493`*^9, 
   3.803392626106188*^9, 3.8033944636356974`*^9, 3.8033945979027915`*^9, 
   3.8033948041176667`*^9, 3.8033949177134805`*^9, 3.8033973320403633`*^9, 
   3.803397449192026*^9, 3.803398075320036*^9, 3.8033984419862785`*^9, 
   3.8033985973232765`*^9, 3.803509621331766*^9, 3.8035103301727066`*^9, 
   3.8035117217180324`*^9, 3.8035121812325754`*^9, 3.804603822670437*^9, 
   3.8046038661481476`*^9, 3.804604402913786*^9, 3.8046052315097294`*^9, 
   3.804605786607048*^9, 3.804606015295464*^9, 3.804866393901297*^9, 
   3.805710252358147*^9, 3.80571095073405*^9, 3.805711262451974*^9, 
   3.805712112617899*^9, 3.805712155235132*^9, 3.805712366192728*^9, 
   3.8057129799907694`*^9, 3.80666820484938*^9, 3.8066685336726894`*^9, 
   3.806668612825121*^9, 3.8078698745398626`*^9, 3.8078714613692803`*^9, 
   3.807872165485489*^9, 3.807872780126049*^9, 3.8100320324178295`*^9, 
   3.810032115585004*^9, 3.810032850871236*^9, 3.8100328876642504`*^9, 
   3.8124653856231804`*^9, 3.8124662322753716`*^9, 3.812466532793623*^9, 
   3.8124929611805196`*^9, 3.812820889041083*^9, 3.8129260106262827`*^9, 
   3.812926334592421*^9, 3.812926568037678*^9, 3.812974857381394*^9, 
   3.8129750385283413`*^9, 3.8129752908961153`*^9, 3.8141738557891006`*^9, 
   3.815473681861311*^9, 3.815476527015626*^9, 3.815773863775505*^9, 
   3.816982403918694*^9, 3.8188024965198784`*^9, 3.8199005845545034`*^9, 
   3.8199006662372093`*^9, 3.819900745147803*^9, 3.819900824034288*^9, 
   3.8199009056769648`*^9, 3.8199018024940825`*^9, 3.819902165538704*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[792]=",ExpressionUUID->"e6459d7d-2d88-4022-8b76-8d434fc41427"]
}, Open  ]],

Cell["Percent change in price of processed pollock imports ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489469994965`*^9}, 
   3.8033937835956526`*^9},ExpressionUUID->"5b70bcc3-b895-46db-ab44-\
1d2cdf6cc817"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pppt1", "-", "pppt0"}], ")"}], "100"}], "pppt0"]], "Input",
 CellChangeTimes->{{3.799849065893024*^9, 3.7998490705260077`*^9}, {
  3.8017816460021996`*^9, 3.8017816516125026`*^9}},
 CellLabel->
  "In[793]:=",ExpressionUUID->"36d8a810-a5a4-4f76-b1d6-a2ce4fbad651"],

Cell[BoxData["2.0410007214744734`"], "Output",
 CellChangeTimes->{
  3.799849072198154*^9, 3.7998495916774035`*^9, 3.7998508744539204`*^9, 
   3.7998510924280457`*^9, 3.7998552211164412`*^9, 3.7998552590468483`*^9, 
   3.799856732870942*^9, 3.799856778183997*^9, 3.799857194558479*^9, {
   3.7998574106282053`*^9, 3.799857481094624*^9}, 3.7998575224652433`*^9, {
   3.799857623502369*^9, 3.7998576650883036`*^9}, 3.799857759868785*^9, {
   3.801660849636916*^9, 3.8016608627654595`*^9}, 3.801662763986375*^9, 
   3.8016634673719516`*^9, 3.8016642627306843`*^9, {3.8016643124011154`*^9, 
   3.8016643346358976`*^9}, 3.8016644602290487`*^9, 3.8016653535359726`*^9, 
   3.8016653969440584`*^9, 3.801665428559614*^9, {3.801666722972541*^9, 
   3.801666750693612*^9}, 3.801666785960819*^9, {3.8016669601536183`*^9, 
   3.8016669840029554`*^9}, 3.8016671134066973`*^9, 3.8016672274188547`*^9, 
   3.8016673977568097`*^9, 3.8016675837807074`*^9, {3.8016678475224285`*^9, 
   3.801667863055975*^9}, 3.8016679341841373`*^9, {3.8016681834430943`*^9, 
   3.801668203956149*^9}, {3.801668268928874*^9, 3.801668295342183*^9}, {
   3.8016683449627857`*^9, 3.801668369671562*^9}, 3.8016684207418857`*^9, 
   3.8016684523901043`*^9, 3.8016684869097185`*^9, 3.8016685409596605`*^9, 
   3.8016925870309296`*^9, 3.8016926408103027`*^9, 3.8016927460769453`*^9, 
   3.801692951793749*^9, 3.8016932297350473`*^9, 3.8016932864583883`*^9, 
   3.8016933964121065`*^9, 3.8016934886028624`*^9, 3.8017769833916583`*^9, 
   3.801777201338623*^9, 3.8017772736968746`*^9, 3.8017776512391815`*^9, 
   3.801778005557005*^9, 3.8017780738747015`*^9, 3.8017783130221047`*^9, 
   3.801778343828433*^9, 3.8017786552001514`*^9, 3.8017791379894953`*^9, 
   3.8017792487389135`*^9, 3.8017795061543865`*^9, 3.801779549148078*^9, 
   3.8017796216949863`*^9, 3.8017797092310677`*^9, 3.801779816960457*^9, 
   3.8017798532511*^9, 3.8017798989221287`*^9, {3.8017799403828955`*^9, 
   3.801779966965578*^9}, 3.801780255627626*^9, 3.801780306600722*^9, 
   3.8017803437113323`*^9, {3.801780443813979*^9, 3.80178047201379*^9}, 
   3.801780540403473*^9, 3.801780580075383*^9, 3.801780665081603*^9, 
   3.8017811760065727`*^9, 3.8017812224785295`*^9, 3.8017816879092636`*^9, {
   3.8017819976669135`*^9, 3.8017820351466937`*^9}, 3.8017820885437393`*^9, {
   3.801782231422597*^9, 3.8017822490505095`*^9}, 3.803075086782975*^9, 
   3.8030751538322315`*^9, 3.803075259186394*^9, 3.80307540340773*^9, 
   3.8030755054343767`*^9, 3.803113964391225*^9, 3.8031140843078833`*^9, 
   3.8031141467827444`*^9, 3.8031141910803127`*^9, 3.803114297630457*^9, 
   3.803114393598344*^9, 3.8031185696147175`*^9, 3.8031186381572137`*^9, 
   3.8031187020330677`*^9, {3.8031187473344274`*^9, 3.803118769029362*^9}, 
   3.803118808436119*^9, 3.8031205934782734`*^9, 3.803120630761387*^9, 
   3.803124417403511*^9, 3.8031245168981476`*^9, 3.803124910269109*^9, 
   3.8031249914974422`*^9, 3.803125759058642*^9, 3.8031262533329515`*^9, 
   3.8031284831148353`*^9, 3.8031286690859737`*^9, 3.803292498780281*^9, 
   3.8033030843271217`*^9, 3.803303273816504*^9, 3.8033104106770563`*^9, 
   3.803312900515255*^9, 3.803313230228526*^9, 3.803391647318711*^9, 
   3.8033920622079215`*^9, 3.8033921276185927`*^9, 3.803392519518593*^9, 
   3.8033926301539383`*^9, 3.803394458462976*^9, 3.8033947986978235`*^9, 
   3.8033949131826243`*^9, 3.8033973257985864`*^9, 3.8033974437826385`*^9, 
   3.803398067115489*^9, 3.803398436459714*^9, 3.8033985897430506`*^9, 
   3.8035096207535477`*^9, 3.803510329594488*^9, 3.8035117211241837`*^9, 
   3.803512180669983*^9, 3.8046038220453234`*^9, 3.804603865523037*^9, 
   3.804604402241802*^9, 3.804605231603493*^9, 3.804605786685188*^9, 
   3.804606015373603*^9, 3.804866393979435*^9, 3.8057102524362855`*^9, 
   3.8057109508121877`*^9, 3.805711262545739*^9, 3.8057121127272925`*^9, 
   3.80571215532894*^9, 3.8057123662864933`*^9, 3.8057129800845346`*^9, 
   3.806668204927518*^9, 3.806668533782055*^9, 3.806668612903259*^9, 
   3.807869874618001*^9, 3.807871461463046*^9, 3.8078721655636263`*^9, 
   3.8078727802198153`*^9, 3.8100320325038967`*^9, 3.810032115676074*^9, 
   3.8100328509693127`*^9, 3.8100328877553225`*^9, 3.812465385716253*^9, 
   3.812466232367443*^9, 3.8124665328856955`*^9, 3.8124929612775955`*^9, 
   3.812820889135156*^9, 3.8129260107273617`*^9, 3.8129263347165174`*^9, 
   3.8129265681417694`*^9, 3.812974859350686*^9, 3.8129750386377344`*^9, 
   3.812975291021135*^9, 3.8141738559140835`*^9, 3.815473681970704*^9, 
   3.815476527125019*^9, 3.8157738638615727`*^9, 3.816982403932655*^9, 
   3.81880249653892*^9, 3.8199005846425714`*^9, 3.819900666322276*^9, 
   3.81990074523387*^9, 3.8199008241223574`*^9, 3.819900905766034*^9, 
   3.8199018025731378`*^9, 3.8199021656217685`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[793]=",ExpressionUUID->"0ec72b82-25cd-4430-be3a-d801cbcf07fd"]
}, Open  ]],

Cell["Percent change in quantity of processed pollock imports ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489469994965`*^9}, 
   3.8033937835956526`*^9, 
   3.8033946224864826`*^9},ExpressionUUID->"0a979a1a-289e-446a-be54-\
7d8ce26971c9"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qppt1", "-", "qppt0"}], ")"}], "100"}], "qppt0"]], "Input",
 CellChangeTimes->{{3.799849065893024*^9, 3.7998490705260077`*^9}, {
  3.8017816460021996`*^9, 3.8017816516125026`*^9}, {3.803393943978521*^9, 
  3.8033939470730877`*^9}, {3.8033947011069136`*^9, 3.8033947061860533`*^9}, {
  3.8199007984393225`*^9, 3.8199008001546636`*^9}},
 CellLabel->
  "In[794]:=",ExpressionUUID->"3eefc79e-b743-4617-abad-11d9932992dc"],

Cell[BoxData[
 RowBox[{"-", "9.924240843353031`"}]], "Output",
 CellChangeTimes->{
  3.799849072198154*^9, 3.7998495916774035`*^9, 3.7998508744539204`*^9, 
   3.7998510924280457`*^9, 3.7998552211164412`*^9, 3.7998552590468483`*^9, 
   3.799856732870942*^9, 3.799856778183997*^9, 3.799857194558479*^9, {
   3.7998574106282053`*^9, 3.799857481094624*^9}, 3.7998575224652433`*^9, {
   3.799857623502369*^9, 3.7998576650883036`*^9}, 3.799857759868785*^9, {
   3.801660849636916*^9, 3.8016608627654595`*^9}, 3.801662763986375*^9, 
   3.8016634673719516`*^9, 3.8016642627306843`*^9, {3.8016643124011154`*^9, 
   3.8016643346358976`*^9}, 3.8016644602290487`*^9, 3.8016653535359726`*^9, 
   3.8016653969440584`*^9, 3.801665428559614*^9, {3.801666722972541*^9, 
   3.801666750693612*^9}, 3.801666785960819*^9, {3.8016669601536183`*^9, 
   3.8016669840029554`*^9}, 3.8016671134066973`*^9, 3.8016672274188547`*^9, 
   3.8016673977568097`*^9, 3.8016675837807074`*^9, {3.8016678475224285`*^9, 
   3.801667863055975*^9}, 3.8016679341841373`*^9, {3.8016681834430943`*^9, 
   3.801668203956149*^9}, {3.801668268928874*^9, 3.801668295342183*^9}, {
   3.8016683449627857`*^9, 3.801668369671562*^9}, 3.8016684207418857`*^9, 
   3.8016684523901043`*^9, 3.8016684869097185`*^9, 3.8016685409596605`*^9, 
   3.8016925870309296`*^9, 3.8016926408103027`*^9, 3.8016927460769453`*^9, 
   3.801692951793749*^9, 3.8016932297350473`*^9, 3.8016932864583883`*^9, 
   3.8016933964121065`*^9, 3.8016934886028624`*^9, 3.8017769833916583`*^9, 
   3.801777201338623*^9, 3.8017772736968746`*^9, 3.8017776512391815`*^9, 
   3.801778005557005*^9, 3.8017780738747015`*^9, 3.8017783130221047`*^9, 
   3.801778343828433*^9, 3.8017786552001514`*^9, 3.8017791379894953`*^9, 
   3.8017792487389135`*^9, 3.8017795061543865`*^9, 3.801779549148078*^9, 
   3.8017796216949863`*^9, 3.8017797092310677`*^9, 3.801779816960457*^9, 
   3.8017798532511*^9, 3.8017798989221287`*^9, {3.8017799403828955`*^9, 
   3.801779966965578*^9}, 3.801780255627626*^9, 3.801780306600722*^9, 
   3.8017803437113323`*^9, {3.801780443813979*^9, 3.80178047201379*^9}, 
   3.801780540403473*^9, 3.801780580075383*^9, 3.801780665081603*^9, 
   3.8017811760065727`*^9, 3.8017812224785295`*^9, 3.8017816879092636`*^9, {
   3.8017819976669135`*^9, 3.8017820351466937`*^9}, 3.8017820885437393`*^9, {
   3.801782231422597*^9, 3.8017822490505095`*^9}, 3.803075086782975*^9, 
   3.8030751538322315`*^9, 3.803075259186394*^9, 3.80307540340773*^9, 
   3.8030755054343767`*^9, 3.803113964391225*^9, 3.8031140843078833`*^9, 
   3.8031141467827444`*^9, 3.8031141910803127`*^9, 3.803114297630457*^9, 
   3.803114393598344*^9, 3.8031185696147175`*^9, 3.8031186381572137`*^9, 
   3.8031187020330677`*^9, {3.8031187473344274`*^9, 3.803118769029362*^9}, 
   3.803118808436119*^9, 3.8031205934782734`*^9, 3.803120630761387*^9, 
   3.803124417403511*^9, 3.8031245168981476`*^9, 3.803124910269109*^9, 
   3.8031249914974422`*^9, 3.803125759058642*^9, 3.8031262533329515`*^9, 
   3.8031284831148353`*^9, 3.8031286690859737`*^9, 3.803292498780281*^9, 
   3.8033030843271217`*^9, 3.803303273816504*^9, 3.8033104106770563`*^9, 
   3.803312900515255*^9, 3.803313230228526*^9, 3.803391647318711*^9, 
   3.8033920622079215`*^9, 3.8033921276185927`*^9, 3.803392519518593*^9, 
   3.8033926301539383`*^9, {3.803394466521867*^9, 3.8033944938709555`*^9}, 
   3.80339470665488*^9, 3.8033948103376446`*^9, 3.8033949235114155`*^9, 
   3.803397336293705*^9, 3.8033974559954433`*^9, 3.8033980812586555`*^9, 
   3.8033984480033407`*^9, 3.8033986031263623`*^9, 3.803509621847488*^9, 
   3.803510330641533*^9, 3.8035117221868734`*^9, 3.8035121817326603`*^9, 
   3.8046038231861534`*^9, 3.8046038667109413`*^9, 3.804604403476405*^9, 
   3.804605231697258*^9, 3.804605786763327*^9, 3.80460601545893*^9, 
   3.804866394073201*^9, 3.8057102525144243`*^9, 3.8057109508903255`*^9, 
   3.8057112626395044`*^9, 3.8057121128054304`*^9, 3.805712155422663*^9, 
   3.8057123663802595`*^9, 3.8057129801783*^9, 3.806668205021284*^9, 
   3.8066685338601933`*^9, 3.8066686129970236`*^9, 3.8078698747117662`*^9, 
   3.8078714615411854`*^9, 3.8078721656417637`*^9, 3.8078727803135805`*^9, 
   3.8100320325909634`*^9, 3.810032115766143*^9, 3.810032851055381*^9, 
   3.810032887844393*^9, 3.812465385819333*^9, 3.8124662324555116`*^9, 
   3.8124665329757657`*^9, 3.8124929613816757`*^9, 3.812820889225239*^9, 
   3.812926010838448*^9, 3.812926334825602*^9, 3.812926568242839*^9, 
   3.8129748596007285`*^9, 3.8129750387483673`*^9, 3.8129752911461554`*^9, 
   3.8141738560234776`*^9, 3.8154736820644693`*^9, 3.815476527234412*^9, 
   3.815773863961651*^9, 3.816982403946666*^9, 3.8188024965589085`*^9, 
   3.8199005847296395`*^9, 3.8199006664083433`*^9, 3.819900745319893*^9, 
   3.819900824207424*^9, 3.8199009058531017`*^9, 3.819901802652199*^9, 
   3.8199021657028313`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[794]=",ExpressionUUID->"bf8b8e9a-ec6f-41b2-a43c-d397c5ffbd11"]
}, Open  ]],

Cell[TextData[StyleBox["Percent change in price indexes ",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
  3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
  3.7998489833914266`*^9, 3.79984901086983*^9}, {3.7998491773192368`*^9, 
  3.79984917888201*^9}, {3.7998492779954705`*^9, 3.799849344403957*^9}, {
  3.799855217193923*^9, 3.7998552176158657`*^9}, {3.819900848371271*^9, 
  3.81990084873055*^9}},ExpressionUUID->"8d6f960c-cea6-4ac7-9d42-\
3184797329a6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pcu1", "-", "Pcu0"}], ")"}], "100"}], "Pcu0"], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Ppu1", "-", "Ppu0"}], ")"}], "100"}], "Ppu0"], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pu1", "-", "Pu0"}], ")"}], "100"}], "Pu0"], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pcp1", "-", "Pcp0"}], ")"}], "100"}], "Pcp0"], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Ppp1", "-", "Ppp0"}], ")"}], "100"}], "Ppp0"], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pp1", "-", "Pp0"}], ")"}], "100"}], "Pp0"]}], "}"}]], "Input",
 CellChangeTimes->{{3.79984918480492*^9, 3.799849273791636*^9}, {
  3.7998552126150475`*^9, 3.7998552128807173`*^9}, {3.8017816587699327`*^9, 
  3.8017816805942984`*^9}},
 CellLabel->
  "In[795]:=",ExpressionUUID->"4be7ba51-cceb-4e00-9209-e3ee85fa7c30"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.32103416808853247`", ",", "0.1596747828785154`", ",", 
   "0.2088381008723648`", ",", "2.226202570131759`", ",", 
   "0.9160932072821193`", ",", "1.7611449023704515`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7998492746667833`*^9, 3.7998495923806477`*^9, 3.7998508747820983`*^9, 
   3.7998510932094183`*^9, 3.7998552215383844`*^9, 3.7998552591406136`*^9, 
   3.799856732964707*^9, 3.7998567782777624`*^9, 3.799857195292985*^9, {
   3.79985741126893*^9, 3.799857481157101*^9}, 3.7998575225746374`*^9, {
   3.799857623596133*^9, 3.799857665541498*^9}, 3.7998577599781284`*^9, {
   3.8016608497619348`*^9, 3.801660862874851*^9}, 3.801662764470834*^9, 
   3.8016634678095245`*^9, 3.8016642628400764`*^9, {3.801664312666783*^9, 
   3.8016643351216216`*^9}, 3.801664460338441*^9, {3.8016653833153267`*^9, 
   3.8016653970378222`*^9}, 3.8016654290440674`*^9, {3.801666723097561*^9, 
   3.8016667511780653`*^9}, 3.8016667864140167`*^9, {3.801666960325522*^9, 
   3.8016669841279755`*^9}, 3.801667113594228*^9, 3.8016672275438757`*^9, 
   3.8016673978818293`*^9, 3.8016675839057274`*^9, {3.8016678479599924`*^9, 
   3.8016678631653695`*^9}, 3.8016679342935286`*^9, {3.801668183552487*^9, 
   3.8016682040499134`*^9}, {3.801668269038266*^9, 3.8016682954359474`*^9}, {
   3.801668345072152*^9, 3.801668369796582*^9}, 3.801668420866907*^9, 
   3.8016684524994974`*^9, 3.801668487394171*^9, 3.801668541287839*^9, 
   3.801692587562277*^9, 3.80169264102909*^9, 3.8016927462307262`*^9, 
   3.8016929523093896`*^9, 3.8016932298288126`*^9, 3.801693287020975*^9, 
   3.8016933968966064`*^9, 3.801693489102943*^9, 3.801776983907366*^9, 
   3.8017772015105257`*^9, 3.801777273900032*^9, 3.8017776517080097`*^9, 
   3.8017780057445364`*^9, 3.801778074046605*^9, 3.8017783131783795`*^9, 
   3.8017783439221983`*^9, 3.8017786553876815`*^9, 3.801779138145771*^9, 
   3.8017792488796043`*^9, 3.801779506310661*^9, 3.8017795492418423`*^9, 
   3.8017796217887506`*^9, 3.801779709371714*^9, 3.801779817116694*^9, 
   3.8017798533916473`*^9, 3.801779899000266*^9, {3.8017799405079165`*^9, 
   3.801779967450033*^9}, 3.8017802560183163`*^9, 3.801780306746418*^9, 
   3.801780344211422*^9, {3.8017804439702563`*^9, 3.8017804721700673`*^9}, 
   3.8017805409035826`*^9, 3.8017805802003374`*^9, 3.8017806656129417`*^9, 
   3.8017811762878675`*^9, 3.801781222587922*^9, 3.801781688096794*^9, {
   3.8017819978231897`*^9, 3.801782035287342*^9}, 3.8017820890438232`*^9, {
   3.8017822319383073`*^9, 3.8017822491911564`*^9}, 3.8030750870008593`*^9, 
   3.8030751540073695`*^9, 3.803075259202407*^9, 3.8030754034217415`*^9, 
   3.8030755054493756`*^9, 3.8031139645613594`*^9, 3.803114084480019*^9, 
   3.8031141469538784`*^9, 3.803114191096325*^9, 3.803114297645469*^9, 
   3.803114393611354*^9, 3.8031185696297293`*^9, 3.803118638170224*^9, 
   3.803118702047079*^9, {3.8031187473594465`*^9, 3.803118769043373*^9}, 
   3.80311880845013*^9, 3.8031205934932847`*^9, 3.803120630774397*^9, 
   3.8031244174185233`*^9, 3.8031245169131594`*^9, 3.8031249102831197`*^9, 
   3.803124991509452*^9, 3.803125759075655*^9, 3.803126253346963*^9, 
   3.803128483130848*^9, 3.8031286690979834`*^9, 3.8032924987962933`*^9, 
   3.803303084561537*^9, 3.8033032747697845`*^9, 3.8033104115209475`*^9, 
   3.803312901030964*^9, 3.803313231275567*^9, 3.803391647600006*^9, 
   3.803392062973687*^9, 3.8033921283218317`*^9, 3.803392520065557*^9, 
   3.8033926306852746`*^9, 3.8033944589630575`*^9, 3.8033947991320267`*^9, 
   3.803394914026799*^9, 3.803397326004096*^9, 3.8033974445483875`*^9, 
   3.8033980677407513`*^9, 3.8033984374911313`*^9, 3.803398591318152*^9, 
   3.8035096208316846`*^9, 3.8035103296726255`*^9, 3.803511721217949*^9, 
   3.803512180748121*^9, 3.8046038221390915`*^9, 3.8046038656011777`*^9, 
   3.8046044023511963`*^9, 3.8046052317753954`*^9, 3.804605786841467*^9, 
   3.804606015542996*^9, 3.8048663941669664`*^9, 3.8057102525925646`*^9, 
   3.805710950968463*^9, 3.8057112627645245`*^9, 3.8057121128991966`*^9, 
   3.805712155516428*^9, 3.8057123664584208`*^9, 3.8057129802564373`*^9, 
   3.8066682050994215`*^9, 3.8066685339695864`*^9, 3.806668613090789*^9, 
   3.8078698747899075`*^9, 3.807871461650576*^9, 3.8078721657355294`*^9, 
   3.807872780391719*^9, 3.8100320326790314`*^9, 3.810032115857214*^9, 
   3.810032851140448*^9, 3.8100328879314613`*^9, 3.812465385912405*^9, 
   3.812466232547583*^9, 3.812466533067837*^9, 3.8124929614737473`*^9, 
   3.8128208893182983`*^9, 3.812926010948579*^9, 3.812926334935688*^9, 
   3.812926568343918*^9, 3.8129748616738195`*^9, 3.8129750388733873`*^9, 
   3.8129752912555475`*^9, 3.8141738561484976`*^9, 3.8154736821582355`*^9, 
   3.815476527343832*^9, 3.8157738640597277`*^9, 3.816982403962187*^9, 
   3.8188024965799227`*^9, 3.81990058482071*^9, 3.8199006664924088`*^9, 
   3.819900745403966*^9, 3.8199008242924905`*^9, 3.81990090594118*^9, 
   3.819901802735263*^9, 3.819902165784896*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[795]=",ExpressionUUID->"4063bd05-dfa5-4d0b-8823-e917fe4c6af6"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{732, 669},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 1417, 28, 196, "Title",ExpressionUUID->"a4eccb85-2d0b-4e19-9d2b-957174bcb5a9"],
Cell[2000, 52, 5323, 77, 568, "Text",ExpressionUUID->"989c9ad2-a2af-449a-afa1-29cf4dade7a1"],
Cell[7326, 131, 270, 7, 48, "Input",ExpressionUUID->"0c777ea8-191a-4659-be18-f91ea0d0ffda"],
Cell[CellGroupData[{
Cell[7621, 142, 404, 7, 62, "Section",ExpressionUUID->"e96e59ff-4f99-46b0-8141-97bb85c5e783"],
Cell[CellGroupData[{
Cell[8050, 153, 381, 7, 43, "Subsubsection",ExpressionUUID->"c256c105-36d6-45fc-b20a-98c412f36db1",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[8434, 162, 555, 8, 48, "Text",ExpressionUUID->"c8dbdd23-6753-4a73-a058-2ad0c1c2ca24",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[8992, 172, 1091, 20, 33, "Text",ExpressionUUID->"076a7c86-bfad-4b97-9f02-1dd5b6e20e72",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[10086, 194, 1571, 24, 44, "Input",ExpressionUUID->"0d44e1c6-e9d4-484e-888a-97e11d7e3438",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[11660, 220, 1129, 20, 33, "Text",ExpressionUUID->"f80f2a91-0269-4b6d-b654-41d20c061408",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[12792, 242, 1628, 25, 44, "Input",ExpressionUUID->"96eac114-d508-47c3-a547-88d986993fd6",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[14423, 269, 1175, 22, 33, "Text",ExpressionUUID->"115496dd-3e15-4302-b34d-38dbfa1c913f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[15601, 293, 1650, 25, 44, "Input",ExpressionUUID->"4be3573e-d8f2-4658-b33e-9898019bab51",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[17254, 320, 1189, 21, 33, "Text",ExpressionUUID->"4417c30d-6b58-4c3d-875e-1a5431be8326",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[18446, 343, 1685, 26, 44, "Input",ExpressionUUID->"503f6090-0640-4711-a500-4cdc6ff03744",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[20168, 374, 433, 8, 43, "Subsubsection",ExpressionUUID->"8cc2fe1d-8e5a-4354-94e7-906d2436cbeb",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[20604, 384, 585, 9, 30, "Text",ExpressionUUID->"cdcb8fff-7373-4897-9aef-c2ad1a3fe6f9",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[21192, 395, 1160, 21, 33, "Text",ExpressionUUID->"c6e279f6-9736-4fcc-8934-b5137f5d9e74",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[22355, 418, 1619, 25, 44, "Input",ExpressionUUID->"5e3a3f8d-ab24-4fc7-84cf-fa63d9a5a902",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[23977, 445, 1207, 21, 33, "Text",ExpressionUUID->"361d8506-8032-4acc-a1e9-75993f05cd7a",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[25187, 468, 1624, 25, 44, "Input",ExpressionUUID->"0fa79466-5a43-4fd1-8cdc-aaf9f2f03649",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[26848, 498, 525, 8, 43, "Subsubsection",ExpressionUUID->"5a591766-6aa5-4ae8-916e-39c5cc13291f",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[27376, 508, 541, 8, 30, "Text",ExpressionUUID->"a4ee10a5-85bd-414a-8f53-f222a94c0077",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[27920, 518, 976, 15, 34, "Text",ExpressionUUID->"684e65e8-9bca-49aa-b764-11c8a8b5a33f",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[28899, 535, 1118, 19, 44, "Input",ExpressionUUID->"ef4b557b-29d1-4476-9b9e-94d8b8493206",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[30020, 556, 846, 14, 34, "Text",ExpressionUUID->"3076b012-20e5-472e-bde1-5dd2b3b3d83e",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[30869, 572, 1117, 19, 44, "Input",ExpressionUUID->"fa127d8a-314c-4b5d-8a5a-0f0e64bdc4f5",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[32023, 596, 572, 9, 43, "Subsubsection",ExpressionUUID->"91661e8c-c0ed-4882-bca2-19a13bc2ecdc",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[32598, 607, 854, 12, 48, "Text",ExpressionUUID->"60a7fe40-f7b5-4a10-9768-1065cca22926",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[33455, 621, 1089, 19, 34, "Text",ExpressionUUID->"6a97488f-358d-4c62-9acd-ba969ebf779f",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[34547, 642, 2363, 35, 44, "Input",ExpressionUUID->"e71883ba-93a1-4219-bd68-67879f88fe63",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[36913, 679, 1045, 18, 56, "Text",ExpressionUUID->"59afd0a7-9f2f-4726-ba40-c1fa575b6f1b",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[37961, 699, 2273, 33, 44, "Input",ExpressionUUID->"8416828b-6e0d-4043-b421-691ce31c4cb1",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[40237, 734, 1026, 18, 34, "Text",ExpressionUUID->"4d8eece9-6cfb-428f-9fbc-50d134b9d515",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[41266, 754, 2332, 35, 44, "Input",ExpressionUUID->"8ff6efc0-70fd-4c16-8f32-5cdad2a49b1b",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[43601, 791, 991, 17, 34, "Text",ExpressionUUID->"120fd5b4-8c0c-44d8-a469-6a2922165a8f",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[44595, 810, 2295, 34, 44, "Input",ExpressionUUID->"ee491d5d-6374-49c8-9dc2-6c962d060566",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[46927, 849, 615, 9, 43, "Subsubsection",ExpressionUUID->"ce987dca-5020-49fc-bb30-d5047dbabafb",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[47545, 860, 585, 9, 30, "Text",ExpressionUUID->"b39bcd75-3fe8-4aec-ab68-5fc748e511d8",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[48133, 871, 871, 13, 34, "Text",ExpressionUUID->"960b6700-ec19-44ba-a95d-a47902d54cf3",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[49007, 886, 2142, 32, 44, "Input",ExpressionUUID->"0e61cea0-3282-45a7-bd8e-9e8e785d69eb",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[51152, 920, 939, 14, 34, "Text",ExpressionUUID->"93ca01ee-3d72-4044-9963-44f54d0ee87f",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[52094, 936, 1977, 29, 44, "Input",ExpressionUUID->"56e55b30-89a1-4886-a913-0a728e7e84b9",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[54074, 967, 994, 15, 34, "Text",ExpressionUUID->"25e03036-c666-4483-9a60-4b8de3ccf145",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[55071, 984, 1955, 29, 44, "Input",ExpressionUUID->"5903b0ce-f117-49f8-a777-07431c955931",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[57029, 1015, 1014, 15, 34, "Text",ExpressionUUID->"68204397-1371-435b-af3b-a76ba499f904",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[58046, 1032, 1900, 28, 44, "Input",ExpressionUUID->"187aeac4-0a18-4a09-9eed-f30313a792d3",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[59983, 1065, 707, 11, 43, "Subsubsection",ExpressionUUID->"cb23405b-de33-496e-8c8d-49a4fe2c6b7e",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[60693, 1078, 622, 9, 30, "Text",ExpressionUUID->"d3597c75-e2e2-4f10-86ad-5b9a7071fc9a",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[61318, 1089, 1938, 29, 44, "Input",ExpressionUUID->"58804126-1412-43db-bc71-7a15e6e4ea36",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[63305, 1124, 445, 7, 62, "Section",ExpressionUUID->"3bff5bdf-b9e3-4e90-b493-eafdaf8b8442"],
Cell[CellGroupData[{
Cell[63775, 1135, 395, 6, 43, "Subsubsection",ExpressionUUID->"63910411-53e3-4690-898a-c7f3d58e4156",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[64173, 1143, 748, 11, 66, "Text",ExpressionUUID->"25666e5b-dc9d-4eac-a5c5-b2cb1597a376",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[64924, 1156, 482, 8, 34, "Text",ExpressionUUID->"f0b2e34b-bfe7-48ba-a942-d73266fd09be",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[65409, 1166, 856, 16, 44, "Input",ExpressionUUID->"400c8e39-93cb-4fef-a9fb-41930d195d3f",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[66268, 1184, 1563, 27, 47, "Input",ExpressionUUID->"cfe43c25-be78-4227-bac0-674e47880d70",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[67834, 1213, 485, 8, 34, "Text",ExpressionUUID->"bcc913a9-8045-4166-8ce8-85640c3ec833",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[68322, 1223, 805, 15, 44, "Input",ExpressionUUID->"d09dd51b-82ec-49d3-8302-dd49184416cc",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[69130, 1240, 974, 18, 47, "Input",ExpressionUUID->"bbe25b2d-bbf5-45c8-98c1-b268a76c3c79",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[70107, 1260, 533, 9, 34, "Text",ExpressionUUID->"28deb856-a428-42d4-96bb-906498681a27",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[70643, 1271, 905, 17, 44, "Input",ExpressionUUID->"a6284bc6-b3b5-4538-8fac-ffe370475df7",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[71551, 1290, 1074, 20, 47, "Input",ExpressionUUID->"f518a895-fc64-4c1b-8016-df1a33c9f6f1",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[72628, 1312, 487, 8, 34, "Text",ExpressionUUID->"ff8117d2-a6f1-4ee9-8557-c454d0886015",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[73118, 1322, 852, 16, 44, "Input",ExpressionUUID->"08566025-7eee-454b-b072-70e11923a542",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[73973, 1340, 1026, 19, 47, "Input",ExpressionUUID->"780be44e-d362-41c6-bc75-eb26841e8c10",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[75002, 1361, 631, 13, 28, "Input",ExpressionUUID->"4efaff18-5f26-453e-89e9-fb6591dd7d2f",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[75670, 1379, 464, 8, 43, "Subsubsection",ExpressionUUID->"0e9f0534-43ec-432b-935c-097a2e6c4178",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[76137, 1389, 823, 12, 66, "Text",ExpressionUUID->"7fa61df1-1cc7-44b8-9339-1e77aab25d94",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[76963, 1403, 776, 12, 34, "Text",ExpressionUUID->"4ce2cc24-0690-4af8-bc7c-58b9e47b8097",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[77742, 1417, 1462, 24, 44, "Input",ExpressionUUID->"fb154a27-7923-4181-bb99-8c4111e6cec7",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[79207, 1443, 711, 14, 47, "Input",ExpressionUUID->"aacd9766-9a85-4a37-a3d8-4308b11c83a1",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[79921, 1459, 804, 12, 34, "Text",ExpressionUUID->"5b73b9ab-13cf-48f7-9d78-99d5d583aeaa",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[80728, 1473, 1538, 25, 44, "Input",ExpressionUUID->"51cf68ff-7d6d-4258-b370-c883d69bded9",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[82269, 1500, 711, 14, 47, "Input",ExpressionUUID->"3f2cd940-518b-4740-abd1-69f0eb20150d",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[82983, 1516, 668, 10, 34, "Text",ExpressionUUID->"4b0869e3-12bf-46f3-97ff-d8b6e056e331",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[83654, 1528, 1507, 25, 44, "Input",ExpressionUUID->"6067bc99-e1a2-406a-b269-01a61d357bb6",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[85164, 1555, 820, 16, 47, "Input",ExpressionUUID->"889c4ac7-296b-4a31-aec4-ecc1be450169",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[85987, 1573, 700, 11, 34, "Text",ExpressionUUID->"b2439711-a2cd-49da-ad65-bf6d0aca1022",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[86690, 1586, 1468, 26, 44, "Input",ExpressionUUID->"b7e85291-6808-40e4-8abd-95af24383ed5",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[88161, 1614, 1268, 22, 47, "Input",ExpressionUUID->"6363b9cc-dee9-4996-aa99-2a636ee3de52",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[89466, 1641, 442, 7, 43, "Subsubsection",ExpressionUUID->"e69dc710-53d9-4a72-a0d8-b568d6d6d7a1",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[89911, 1650, 640, 9, 48, "Text",ExpressionUUID->"ef22ff47-6cc0-48cf-8c4a-99a89ebfb93a",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[90554, 1661, 565, 9, 34, "Text",ExpressionUUID->"abfd6d65-a0da-4d04-93c3-174769637def",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[91122, 1672, 239, 4, 34, "Text",ExpressionUUID->"0d85f90c-ac64-477f-9323-d0a42a6e7ba4",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[91364, 1678, 1082, 20, 44, "Input",ExpressionUUID->"ae10a51e-203c-49fc-b34c-3bab85f2f593",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[92449, 1700, 1225, 21, 47, "Input",ExpressionUUID->"5d0f8d58-2d52-4700-ab9a-726ed981e429",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[93677, 1723, 237, 4, 34, "Text",ExpressionUUID->"6d44007d-99b4-4071-a6b1-aa3ec7cc1229",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[93917, 1729, 1171, 22, 44, "Input",ExpressionUUID->"ef17bc6d-a4c5-40a9-85a0-e1e90d4683ba",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[95091, 1753, 564, 9, 34, "Text",ExpressionUUID->"d9aa3b4d-191b-46e8-b6d9-0c7164d1e004",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[95658, 1764, 239, 4, 34, "Text",ExpressionUUID->"408ab314-0451-41ed-9556-fc7dbbd186b7",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[95900, 1770, 1128, 20, 44, "Input",ExpressionUUID->"9485f714-e9cc-42a5-989a-eec3da2d3d9d",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[97031, 1792, 1253, 21, 47, "Input",ExpressionUUID->"578b9a02-f6f7-480e-8b1c-cd3f8f9ad6f1",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[98287, 1815, 237, 4, 34, "Text",ExpressionUUID->"391bbfc6-c5be-459d-b82b-c63a1a8779ff",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[98527, 1821, 1340, 23, 44, "Input",ExpressionUUID->"5869e936-4b85-417d-9535-9acd134d3627",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[99870, 1846, 506, 8, 34, "Text",ExpressionUUID->"4d9c96b8-8274-40c3-81d2-979c7c1881f1",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[100379, 1856, 237, 4, 34, "Text",ExpressionUUID->"4d62d6cc-3a72-4947-b2c6-fbcbb1fc7529",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[100619, 1862, 1090, 21, 44, "Input",ExpressionUUID->"92f3b465-0c73-4bf9-aeac-06ed8b0e44c5",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[101712, 1885, 1104, 19, 47, "Input",ExpressionUUID->"bc60f9f2-e26c-4d4b-a631-d2c52a006534",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[102819, 1906, 235, 4, 34, "Text",ExpressionUUID->"763c99c5-8380-4785-aa0e-8f9905c3e59d",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[103057, 1912, 1222, 22, 44, "Input",ExpressionUUID->"79e20383-f91e-4c86-8cec-44a95e8a738c",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[104282, 1936, 555, 9, 34, "Text",ExpressionUUID->"7990c4b7-1e23-4d49-9783-a426c382c49c",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[104840, 1947, 239, 4, 34, "Text",ExpressionUUID->"6f0804f9-7bb4-4335-88a0-104570b45a16",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[105082, 1953, 1172, 19, 44, "Input",ExpressionUUID->"56b39f13-016a-4733-8a4d-8ef9518d0c53",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[106257, 1974, 1495, 24, 47, "Input",ExpressionUUID->"48fd1397-4f17-42ba-b7bd-d46d9f217762",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[107755, 2000, 495, 8, 34, "Text",ExpressionUUID->"df318f12-7498-42c0-8dd0-12c54a37ad50",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[108253, 2010, 1332, 24, 44, "Input",ExpressionUUID->"df31cb57-f8ab-4714-a3aa-5b59ffcdf3bf",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[109588, 2036, 474, 7, 34, "Text",ExpressionUUID->"cd6f868f-52a1-4b7d-bdd8-1e0c25075729",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[110065, 2045, 643, 12, 28, "Input",ExpressionUUID->"411685ec-4e7e-4e82-ae79-6c9d904a1b83",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[110711, 2059, 463, 9, 28, "Input",ExpressionUUID->"34e10a13-0897-4126-a042-cb29ac11441b",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[111177, 2070, 467, 9, 28, "Input",ExpressionUUID->"e91a2bc8-f2fb-43cf-90ba-a764f6838fda",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[111647, 2081, 464, 9, 28, "Input",ExpressionUUID->"4f533b92-d636-4a31-8784-e9c28f54a747",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[112148, 2095, 482, 8, 43, "Subsubsection",ExpressionUUID->"bc1a7e40-e010-4455-b1a8-8088fcf682e9",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[112633, 2105, 678, 10, 66, "Text",ExpressionUUID->"67e30bef-4e5d-49ab-97aa-093bdc9c34be",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[113314, 2117, 639, 12, 44, "Input",ExpressionUUID->"d36c758b-7ed8-4713-92ae-51ee7315a7bf",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[113956, 2131, 571, 11, 44, "Input",ExpressionUUID->"f5a00f2e-1382-4412-b39c-d22462e02472",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[114530, 2144, 590, 11, 44, "Input",ExpressionUUID->"fbaebb24-5110-4256-8b52-1343c623e9e1",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[115123, 2157, 464, 10, 44, "Input",ExpressionUUID->"6f5eed8c-63d2-4535-ac6e-c3514f953153",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[115590, 2169, 815, 14, 44, "Input",ExpressionUUID->"f0aeeadb-9112-4d7d-8f18-afea7fe425a9",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[116408, 2185, 705, 13, 44, "Input",ExpressionUUID->"6962a6b9-e0ac-4c9b-9753-e8666aa02ab4",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[117116, 2200, 789, 15, 44, "Input",ExpressionUUID->"63517908-303c-475f-8788-8ff7fb76652c",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[117908, 2217, 836, 17, 44, "Input",ExpressionUUID->"7a2ac05e-8641-442a-a784-960f3adc8917",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[118781, 2239, 476, 8, 43, "Subsubsection",ExpressionUUID->"ef609090-ec87-41c8-918d-9597042e4d9e",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[119260, 2249, 298, 5, 34, "Text",ExpressionUUID->"92736aaf-d483-45eb-82e1-160907cba390",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[119561, 2256, 634, 11, 66, "Text",ExpressionUUID->"cab97767-d8b3-4d1d-b168-70d85c29c904",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[120198, 2269, 1085, 19, 44, "Input",ExpressionUUID->"802c6b9b-1962-431d-b17b-a621193520c7",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[121286, 2290, 258, 5, 34, "Text",ExpressionUUID->"77fb6752-3ecc-4981-970f-f1131d135c0d",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[121547, 2297, 685, 12, 66, "Text",ExpressionUUID->"ddb64eed-93ed-43e7-ae85-696d399a6748",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[122235, 2311, 526, 11, 44, "Input",ExpressionUUID->"514171d9-80b4-4e7a-919e-9bd5f5c7fd21",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[122764, 2324, 253, 5, 34, "Text",ExpressionUUID->"8243c38e-7aa2-4bce-8747-84889a6704f6",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[123020, 2331, 634, 11, 66, "Text",ExpressionUUID->"23ef4638-3216-45cd-855f-05309bf17b5c",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[123657, 2344, 480, 11, 44, "Input",ExpressionUUID->"1e47603f-a95b-446e-b5c4-6a45ff2fc269",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[124140, 2357, 252, 5, 34, "Text",ExpressionUUID->"1b3d8f66-b8e7-4521-86e1-e074a5e020f4",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[124395, 2364, 685, 12, 66, "Text",ExpressionUUID->"c94e0dde-adc4-4f43-a901-94d3cd4cef0f",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[125083, 2378, 521, 11, 44, "Input",ExpressionUUID->"e8a3d92a-44ce-4bb7-9c7f-5ccd52441f93",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[125641, 2394, 344, 6, 43, "Subsubsection",ExpressionUUID->"ecc674be-2e1c-452c-a8cc-30a51a736b3a",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[125988, 2402, 269, 4, 34, "Text",ExpressionUUID->"585e23f8-311d-4da1-8618-19a30ab95a1b",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[126260, 2408, 967, 20, 28, "Input",ExpressionUUID->"867a6866-4e2b-4a27-a4f0-9c73447e4c1e",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[127230, 2430, 627, 10, 32, "Output",ExpressionUUID->"7ed354c5-408f-4fa0-b552-bef70dc46d9c",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[127860, 2442, 265, 4, 34, "Text",ExpressionUUID->"34949613-6719-4ddb-8899-464d23dfd0f7",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[128128, 2448, 1019, 21, 28, "Input",ExpressionUUID->"26a50155-6ae7-4e2c-a4d6-b4a54b066f7a",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[129150, 2471, 661, 10, 32, "Output",ExpressionUUID->"a71f7f39-063b-4637-9307-a41d00bc9482",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[129814, 2483, 319, 5, 34, "Text",ExpressionUUID->"2912fc0f-6769-4b6d-8fb5-510eb8fef073",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[130136, 2490, 935, 19, 28, "Input",ExpressionUUID->"1d1bdaad-6da2-4b5e-8a55-ef38be123e6b",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[131074, 2511, 679, 10, 32, "Output",ExpressionUUID->"b907d402-1b32-4f5b-8c1c-bc2447ae6208",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[131756, 2523, 367, 6, 34, "Text",ExpressionUUID->"bfd0c625-22b9-4f6a-ba27-62de0d411881",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[132126, 2531, 933, 19, 28, "Input",ExpressionUUID->"092486ad-0785-496d-8f30-411c9c10a6b0",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[133062, 2552, 705, 11, 32, "Output",ExpressionUUID->"b55a2f64-a90e-4206-ab8b-52f958adba9a",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[133816, 2569, 446, 7, 62, "Section",ExpressionUUID->"799a58ab-534e-47a3-9fca-de06a3bd41fb"],
Cell[134265, 2578, 532, 9, 34, "Text",ExpressionUUID->"d34b8fec-59f2-4b2d-bfaf-10e9b93c4791",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[134800, 2589, 742, 13, 28, "Input",ExpressionUUID->"9d5a52cf-3316-4cb2-80ab-9c9bede1d617"],
Cell[135545, 2604, 812, 14, 28, "Input",ExpressionUUID->"563be225-6049-49ee-806a-d676b042abd2"],
Cell[136360, 2620, 1145, 21, 28, "Input",ExpressionUUID->"a3ab304f-2aee-4fbd-bfd7-6f5a12f02f88"],
Cell[137508, 2643, 1146, 21, 28, "Input",ExpressionUUID->"3f3f71a9-fce2-4be4-b505-60d2d9a2083c"],
Cell[138657, 2666, 1243, 22, 28, "Input",ExpressionUUID->"8d56dae7-fd14-4978-b7e8-1a8ba1c95d3d"],
Cell[139903, 2690, 1192, 21, 28, "Input",ExpressionUUID->"2dba8ce9-5754-49de-ac08-6a28a3d86633"],
Cell[141098, 2713, 230, 6, 28, "Input",ExpressionUUID->"235d8191-f491-418f-822d-bfa5f085049a"],
Cell[141331, 2721, 228, 6, 28, "Input",ExpressionUUID->"7bb5a92c-72b9-4951-9702-47267eff001b"],
Cell[141562, 2729, 641, 14, 28, "Input",ExpressionUUID->"4be17dd9-1a35-446f-80bc-e5bce12e0aa8"],
Cell[142206, 2745, 496, 12, 28, "Input",ExpressionUUID->"0d488b17-f9ca-4f04-bb1e-e440e9a83cfd"],
Cell[142705, 2759, 518, 12, 28, "Input",ExpressionUUID->"864c3a74-b660-4086-b1a5-7b36cf5edea5"],
Cell[143226, 2773, 518, 12, 28, "Input",ExpressionUUID->"2f875836-a088-442e-bc28-48601d7a2159"],
Cell[143747, 2787, 377, 12, 36, "Input",ExpressionUUID->"2fc5f281-f54b-4ec7-93d8-bec79dce8a7d"],
Cell[144127, 2801, 681, 14, 48, "Input",ExpressionUUID->"251b4ab0-22c0-46e3-b8e5-e9aa3e6836c2"],
Cell[144811, 2817, 683, 14, 48, "Input",ExpressionUUID->"99815906-5027-4fb5-8dce-9c0abc30321c"],
Cell[145497, 2833, 740, 15, 48, "Input",ExpressionUUID->"55c252f7-7837-4dde-9c45-c2035e0188c3"],
Cell[146240, 2850, 678, 14, 48, "Input",ExpressionUUID->"53354d98-ccf5-449d-86e2-ae59f439ea18"],
Cell[CellGroupData[{
Cell[146943, 2868, 1567, 26, 28, "Input",ExpressionUUID->"84a21240-2395-4207-a627-0bd1de0b1bd2",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[148513, 2896, 1573, 26, 28, "Input",ExpressionUUID->"b66c027d-500d-44bd-8465-5da959225730",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[150089, 2924, 1617, 26, 28, "Input",ExpressionUUID->"8bf8f110-2810-47e4-abd8-a9befc05e97a",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[151709, 2952, 1617, 26, 28, "Input",ExpressionUUID->"f58825e8-1641-460f-89c2-c1bda2d705d5",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}]
}, Open  ]],
Cell[153341, 2981, 269, 7, 36, "Input",ExpressionUUID->"a7690091-e227-4455-a6af-7b439871af2e"],
Cell[153613, 2990, 2269, 36, 49, "Input",ExpressionUUID->"1bd69a31-8d5e-4be7-ac7b-526a6a7dc4b5"],
Cell[155885, 3028, 2296, 37, 49, "Input",ExpressionUUID->"dc072c2e-dd27-47ff-83b5-729f3420970e"],
Cell[158184, 3067, 886, 22, 41, "Input",ExpressionUUID->"bfe09279-c02a-4e14-b37a-2ead85213dd7"],
Cell[159073, 3091, 2266, 36, 49, "Input",ExpressionUUID->"eddc8647-ebe7-40a4-a643-b409f1d084b9"],
Cell[161342, 3129, 2291, 37, 49, "Input",ExpressionUUID->"8aabf531-3737-44f4-9f4a-d8228f49d1bb"],
Cell[163636, 3168, 961, 23, 41, "Input",ExpressionUUID->"35dd4b8a-00c6-48ab-97e6-0783217197b1"],
Cell[164600, 3193, 719, 17, 47, "Input",ExpressionUUID->"118d54ab-c2a3-4606-809f-4033f4bf6a48"],
Cell[165322, 3212, 894, 20, 39, "Input",ExpressionUUID->"50bd11cc-cd2a-48a5-b26d-654657e589b6"],
Cell[166219, 3234, 576, 14, 49, "Input",ExpressionUUID->"56b63af6-500f-447d-ba85-8ed829f874bf"],
Cell[166798, 3250, 551, 13, 49, "Input",ExpressionUUID->"165a5eb4-6be8-421b-bc30-a8601059fa40"],
Cell[167352, 3265, 945, 22, 41, "Input",ExpressionUUID->"1db1b605-38f2-4865-81d9-83fb4ce5459c"],
Cell[168300, 3289, 598, 14, 49, "Input",ExpressionUUID->"6d56b8bf-eb10-44eb-bd20-616bfb3793c8"],
Cell[168901, 3305, 657, 15, 49, "Input",ExpressionUUID->"0c5a1fc9-a17f-4162-b95a-a57947163dce"],
Cell[169561, 3322, 964, 23, 41, "Input",ExpressionUUID->"f8185cd5-d52f-42fa-966e-684c811d7782"],
Cell[170528, 3347, 603, 15, 49, "Input",ExpressionUUID->"8015aced-4496-4f5f-ad9f-c35b0f5b0126"],
Cell[171134, 3364, 836, 20, 41, "Input",ExpressionUUID->"d7ddb0c5-7c39-4b8b-9840-c5616c2a57a2"],
Cell[171973, 3386, 1492, 27, 47, "Input",ExpressionUUID->"0f3e7553-f6e2-4c16-ad42-a622b32f2bcb"],
Cell[173468, 3415, 661, 16, 50, "Input",ExpressionUUID->"3ef16ad7-9288-471b-b407-adece8171bc8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[174166, 3436, 509, 8, 62, "Section",ExpressionUUID->"6efe3518-2c63-42f3-8971-bde633ae5275"],
Cell[174678, 3446, 827, 21, 41, "Input",ExpressionUUID->"aa8d578c-5b5a-45ae-83be-ba8751860eb4"],
Cell[175508, 3469, 903, 22, 41, "Input",ExpressionUUID->"0fd66d5b-dd6a-4f0a-b82d-c0927a6d29fb"],
Cell[176414, 3493, 311, 8, 48, "Input",ExpressionUUID->"4d3a58b9-84d8-4177-9dd1-24446efe7c35"],
Cell[176728, 3503, 307, 8, 48, "Input",ExpressionUUID->"802af631-5e9c-4f44-8dae-f13bf930810d"],
Cell[177038, 3513, 332, 8, 48, "Input",ExpressionUUID->"d6f6c8e7-6f57-4e9b-9f70-fc156e1ed5c0"],
Cell[177373, 3523, 309, 8, 48, "Input",ExpressionUUID->"af8364b8-7c21-4147-80b1-1df6901268b2"],
Cell[177685, 3533, 706, 18, 39, "Input",ExpressionUUID->"2df0c153-d783-43ec-bb5f-1245fe3caf68"],
Cell[178394, 3553, 979, 23, 41, "Input",ExpressionUUID->"5914bcc6-5e47-452d-ae70-a78ec9af93a0"],
Cell[179376, 3578, 984, 23, 41, "Input",ExpressionUUID->"7e387e4e-35a0-4e83-b5c5-ced9406f2ab4"],
Cell[180363, 3603, 708, 18, 41, "Input",ExpressionUUID->"f10a4f32-6691-49e0-827e-d253aea0766f"],
Cell[181074, 3623, 206, 4, 34, "Text",ExpressionUUID->"75f96c3d-f0f4-4f9c-9665-d923a4e53876"],
Cell[181283, 3629, 600, 10, 34, "Text",ExpressionUUID->"a73e3fe0-db97-486d-b715-1d3b31d8449a"],
Cell[181886, 3641, 1216, 30, 28, "Input",ExpressionUUID->"7054bfa1-6724-4536-94f8-428722fa9818"],
Cell[183105, 3673, 552, 10, 34, "Text",ExpressionUUID->"96ffae92-0cfd-45d5-9cfd-a3dd0c38ff9b"],
Cell[183660, 3685, 1216, 30, 28, "Input",ExpressionUUID->"ca132e8b-97e1-4b30-963a-ef271fc37fca"],
Cell[184879, 3717, 562, 10, 34, "Text",ExpressionUUID->"36be4f30-6b3d-4bb6-ba05-5f631c9e769d"],
Cell[185444, 3729, 1141, 29, 28, "Input",ExpressionUUID->"d0db1933-af5c-479a-bd96-4f2a868289a9"],
Cell[186588, 3760, 556, 10, 34, "Text",ExpressionUUID->"5bce048f-2e4b-44f4-b547-0f9537bd8e95"],
Cell[187147, 3772, 1212, 29, 28, "Input",ExpressionUUID->"f35fcdc3-ebb1-4d2b-a054-a2ede2c86ca9"],
Cell[188362, 3803, 437, 9, 34, "Text",ExpressionUUID->"f2222292-c02a-4dff-bfb0-5253e658f6aa"],
Cell[188802, 3814, 611, 16, 28, "Input",ExpressionUUID->"791f993f-332f-45c9-b74d-5610bfc47b08"],
Cell[189416, 3832, 573, 15, 28, "Input",ExpressionUUID->"62f1499c-24cc-425f-9324-f3be4945ab76"],
Cell[189992, 3849, 477, 8, 34, "Text",ExpressionUUID->"aee4aa60-9cad-4f3f-8312-69ed87061370"],
Cell[190472, 3859, 561, 15, 28, "Input",ExpressionUUID->"dc442f99-2bf6-4cb3-b474-ca34a001692e"],
Cell[191036, 3876, 568, 15, 28, "Input",ExpressionUUID->"3fc77d92-ac80-4744-8d45-862d3d502330"],
Cell[CellGroupData[{
Cell[191629, 3895, 1206, 30, 28, "Input",ExpressionUUID->"6340c5ef-1fdf-4a1b-8913-8de97b421861"],
Cell[192838, 3927, 5597, 81, 32, "Output",ExpressionUUID->"4998d516-9158-4ff2-9055-0f4b9d004cea"]
}, Open  ]],
Cell[198450, 4011, 262, 6, 28, "Input",ExpressionUUID->"946f9cfe-6f47-48dd-8266-de1998056519"],
Cell[198715, 4019, 263, 6, 28, "Input",ExpressionUUID->"43559586-6a2c-42e9-a31e-8d54a991c323"],
Cell[198981, 4027, 264, 6, 28, "Input",ExpressionUUID->"fe6319c4-183f-4cb1-8921-13252519ec27"],
Cell[199248, 4035, 261, 6, 28, "Input",ExpressionUUID->"bc2bf2dc-1d05-4fe9-9efe-2172e9675c5a"],
Cell[199512, 4043, 264, 6, 28, "Input",ExpressionUUID->"e6a552d1-cf06-4d90-935d-feefd60c255d"],
Cell[199779, 4051, 265, 6, 28, "Input",ExpressionUUID->"a6404b66-6b0d-45b1-9391-804c29018842"],
Cell[200047, 4059, 268, 6, 28, "Input",ExpressionUUID->"a134f14b-cc5d-4e74-b79f-e0f1ea953b32"],
Cell[200318, 4067, 267, 6, 28, "Input",ExpressionUUID->"a3935f56-7f28-4cc4-b0c6-cecdf51079f9"],
Cell[200588, 4075, 332, 8, 48, "Input",ExpressionUUID->"91bd7d00-1d82-44fa-9b43-aa2c00886121"],
Cell[200923, 4085, 285, 7, 48, "Input",ExpressionUUID->"c6382e9b-f16f-45a4-8818-5c66c4a53a51"],
Cell[201211, 4094, 335, 8, 48, "Input",ExpressionUUID->"2eef2dd1-4242-4d28-9088-8ba13709e6c3"],
Cell[201549, 4104, 283, 7, 48, "Input",ExpressionUUID->"70209f65-ab01-40c7-a573-6d42b6ba8db8"],
Cell[201835, 4113, 890, 22, 41, "Input",ExpressionUUID->"fc95c1e6-633a-4511-a3f9-d176ef1fdd31"],
Cell[202728, 4137, 990, 23, 41, "Input",ExpressionUUID->"c0e293fb-b689-4d8a-8e4b-1a11368dcbba"],
Cell[203721, 4162, 910, 21, 39, "Input",ExpressionUUID->"0246d465-db44-4b41-93d2-8a4ab521c5d2"],
Cell[204634, 4185, 1051, 24, 41, "Input",ExpressionUUID->"9d35a1f8-79b4-4ca5-a2ba-98cd853fc1a6"],
Cell[205688, 4211, 1112, 25, 41, "Input",ExpressionUUID->"10aff98a-4857-41ac-bede-105e8cb621c5"],
Cell[206803, 4238, 807, 19, 41, "Input",ExpressionUUID->"7eb3f504-88f5-427e-a252-e664984961bf"],
Cell[207613, 4259, 335, 9, 28, "Input",ExpressionUUID->"da2c9595-e3fc-4efc-8340-7fcfa41ee32f"],
Cell[207951, 4270, 345, 9, 28, "Input",ExpressionUUID->"c290c976-f5e3-49dc-963f-e8722bd80e20"],
Cell[208299, 4281, 345, 9, 28, "Input",ExpressionUUID->"32873a83-47cb-406a-a308-fda2fe93d096"],
Cell[208647, 4292, 345, 9, 28, "Input",ExpressionUUID->"392881df-afab-4cc6-9d89-7dcceec768ae"],
Cell[208995, 4303, 292, 7, 28, "Input",ExpressionUUID->"968cd914-3f2c-4fc0-8be1-87db76fa5032"],
Cell[209290, 4312, 286, 7, 28, "Input",ExpressionUUID->"5d201a59-15f3-4a9f-b1d9-6ab7b8e60249"],
Cell[209579, 4321, 335, 8, 28, "Input",ExpressionUUID->"f24cfdc7-08f2-44bc-bea0-c6332a30c99f"],
Cell[209917, 4331, 347, 8, 28, "Input",ExpressionUUID->"feffc2a7-9dec-48a2-9dc1-d09d88885cf1"],
Cell[210267, 4341, 500, 13, 28, "Input",ExpressionUUID->"c5d80009-058b-43b9-95a0-97be06ff345a"],
Cell[210770, 4356, 563, 14, 28, "Input",ExpressionUUID->"05682ff6-110c-4854-9b88-b875f516b0b2"],
Cell[211336, 4372, 563, 14, 28, "Input",ExpressionUUID->"c09042e5-a5a6-4a4c-ad37-d566df5a5ae3"],
Cell[211902, 4388, 524, 13, 28, "Input",ExpressionUUID->"af293642-5d60-446c-b59f-4f464d139757"]
}, Open  ]],
Cell[CellGroupData[{
Cell[212463, 4406, 544, 9, 62, "Section",ExpressionUUID->"d008b414-03c7-4600-8da5-347b8bf4e0ea"],
Cell[213010, 4417, 197, 4, 34, "Text",ExpressionUUID->"2391fa81-ec42-46b0-85cb-d4028e06387d"],
Cell[213210, 4423, 762, 12, 34, "Text",ExpressionUUID->"37b6f62e-ab42-474a-883b-a789278bd2e7"],
Cell[CellGroupData[{
Cell[213997, 4439, 276, 7, 48, "Input",ExpressionUUID->"7851d6b9-66dd-4b24-bb64-9b1361450660"],
Cell[214276, 4448, 4894, 68, 48, "Output",ExpressionUUID->"cf25cff5-9b3b-4f68-90ba-fd2363d52d7f"]
}, Open  ]],
Cell[219185, 4519, 834, 13, 34, "Text",ExpressionUUID->"ff34ab77-1d9f-4ec0-ba1d-cae076d2ebb1"],
Cell[CellGroupData[{
Cell[220044, 4536, 327, 8, 48, "Input",ExpressionUUID->"12284875-4e6e-4aaf-8a4e-b74c3485c4eb"],
Cell[220374, 4546, 4908, 68, 48, "Output",ExpressionUUID->"6f9ae369-6a3d-4cc4-8aed-f8b0392a77a6"]
}, Open  ]],
Cell[225297, 4617, 692, 10, 34, "Text",ExpressionUUID->"5b25d0db-0b8a-4f08-8076-8a19a2fd0c65"],
Cell[CellGroupData[{
Cell[226014, 4631, 330, 8, 48, "Input",ExpressionUUID->"fd15cdf5-0467-4432-8576-ed1b9313284c"],
Cell[226347, 4641, 4894, 68, 48, "Output",ExpressionUUID->"30f1172e-0484-4074-8fc8-09085f91e2e1"]
}, Open  ]],
Cell[231256, 4712, 723, 10, 34, "Text",ExpressionUUID->"c8d7b42c-adef-4dde-b31f-3325d779b26d"],
Cell[CellGroupData[{
Cell[232004, 4726, 379, 9, 48, "Input",ExpressionUUID->"09104b58-19e4-45a6-ae58-5e9b94d8a8d3"],
Cell[232386, 4737, 4881, 68, 48, "Output",ExpressionUUID->"19f0fbd2-ebf5-432e-a372-04164aadf0a4"]
}, Open  ]],
Cell[237282, 4808, 248, 4, 34, "Text",ExpressionUUID->"0f1ee070-f371-4b9c-a9d8-df760d997372"],
Cell[CellGroupData[{
Cell[237555, 4816, 762, 19, 28, "Input",ExpressionUUID->"ed2ff5df-b3e3-4f0f-9c11-eedff7bc11c7"],
Cell[238320, 4837, 620, 12, 48, "Output",ExpressionUUID->"4a1bed63-2cd5-4b93-a1ef-2027aeb2fb32"]
}, Open  ]],
Cell[238955, 4852, 246, 4, 34, "Text",ExpressionUUID->"e1d25baf-bfd9-4939-8f65-b660f344b49a"],
Cell[CellGroupData[{
Cell[239226, 4860, 681, 17, 28, "Input",ExpressionUUID->"84671d5d-f841-4fec-93a6-edc2ed8d29a5"],
Cell[239910, 4879, 1235, 19, 48, "Output",ExpressionUUID->"15336d4c-3826-45c9-bcb6-6cb976473127"]
}, Open  ]],
Cell[241160, 4901, 168, 3, 34, "Text",ExpressionUUID->"7ec1e3b2-57ae-44a5-98a3-a8cf6e08a231"],
Cell[CellGroupData[{
Cell[241353, 4908, 287, 6, 28, "Input",ExpressionUUID->"cba0527c-b7a4-4a87-97f4-76bc6e0dcbd9"],
Cell[241643, 4916, 474, 8, 48, "Output",ExpressionUUID->"53056330-d7a6-44f9-9c08-a46cbc7f2de9"]
}, Open  ]],
Cell[242132, 4927, 198, 4, 34, "Text",ExpressionUUID->"19487b4b-48d9-4364-8515-371dbb67b929"],
Cell[242333, 4933, 749, 10, 34, "Text",ExpressionUUID->"fc388840-19e8-4dd3-9747-f8ff5f18cc62"],
Cell[CellGroupData[{
Cell[243107, 4947, 279, 7, 48, "Input",ExpressionUUID->"c01ee3c4-d5c4-4b0f-ad48-10861ea850e0"],
Cell[243389, 4956, 4917, 68, 48, "Output",ExpressionUUID->"64cdbd3a-b197-44c7-9ed9-0cb6e1b12e5c"]
}, Open  ]],
Cell[248321, 5027, 851, 12, 34, "Text",ExpressionUUID->"7abf6cfa-d615-4f2a-b170-479ece4c4f53"],
Cell[CellGroupData[{
Cell[249197, 5043, 330, 8, 48, "Input",ExpressionUUID->"3b33f5e5-576c-4782-ba04-8feac09ec40f"],
Cell[249530, 5053, 4916, 68, 48, "Output",ExpressionUUID->"67ddc40c-6cb6-47ee-ad48-9a53fe751954"]
}, Open  ]],
Cell[254461, 5124, 688, 10, 34, "Text",ExpressionUUID->"bc5d8946-4191-4214-98b4-6a405cbdf002"],
Cell[CellGroupData[{
Cell[255174, 5138, 331, 8, 48, "Input",ExpressionUUID->"8737bbfb-232a-48e2-ac21-339fb9157f4a"],
Cell[255508, 5148, 4917, 68, 48, "Output",ExpressionUUID->"912404ae-fe13-4ef1-86dc-bc25fb52c7fa"]
}, Open  ]],
Cell[260440, 5219, 721, 10, 34, "Text",ExpressionUUID->"2113cf87-bc00-4d45-aef0-6517f28616da"],
Cell[CellGroupData[{
Cell[261186, 5233, 379, 9, 48, "Input",ExpressionUUID->"76079d01-f19a-4ef7-b160-ba27f20aceb0"],
Cell[261568, 5244, 4895, 68, 48, "Output",ExpressionUUID->"af0cd144-f685-4e73-b133-d3368172aad9"]
}, Open  ]],
Cell[266478, 5315, 246, 4, 34, "Text",ExpressionUUID->"8dc904b7-b05a-41db-b81d-dac9bbea75d9"],
Cell[CellGroupData[{
Cell[266749, 5323, 767, 19, 28, "Input",ExpressionUUID->"36a56612-5279-4fe2-bc5c-87e4f2ab0d7a"],
Cell[267519, 5344, 621, 12, 48, "Output",ExpressionUUID->"85b55903-7f84-401e-a56c-002c826a332a"]
}, Open  ]],
Cell[268155, 5359, 242, 4, 34, "Text",ExpressionUUID->"bd5362a0-e861-4727-858e-f2475fd4f8ef"],
Cell[CellGroupData[{
Cell[268422, 5367, 861, 20, 28, "Input",ExpressionUUID->"3f11ab21-b8af-47e2-9c88-649f4c8f645d"],
Cell[269286, 5389, 1338, 20, 48, "Output",ExpressionUUID->"a5197d5c-a716-40c9-9e5f-f268e0c5b509"]
}, Open  ]],
Cell[270639, 5412, 170, 3, 34, "Text",ExpressionUUID->"61d6de74-27e0-4fd4-bb2a-df5d0c6aae52"],
Cell[CellGroupData[{
Cell[270834, 5419, 262, 6, 28, "Input",ExpressionUUID->"84b27001-2a34-490c-9bd9-1d2965576040"],
Cell[271099, 5427, 475, 8, 48, "Output",ExpressionUUID->"1cd7195b-2a74-4c31-b120-4f1467a7f3b3"]
}, Open  ]],
Cell[271589, 5438, 256, 5, 34, "Text",ExpressionUUID->"326588d6-03cd-4f3a-bcb3-1608f212dfc6"],
Cell[271848, 5445, 711, 12, 34, "Text",ExpressionUUID->"e23a3c21-0a78-47af-802c-c364f4f91f5f"],
Cell[CellGroupData[{
Cell[272584, 5461, 279, 7, 48, "Input",ExpressionUUID->"ec6af1d0-396f-4dba-8cea-a3941b570226"],
Cell[272866, 5470, 4841, 68, 48, "Output",ExpressionUUID->"99d8ac5d-e7c5-4519-8a15-d4a5e3fa94c7"]
}, Open  ]],
Cell[277722, 5541, 807, 13, 34, "Text",ExpressionUUID->"f799dbdf-4080-49d8-a20e-90387fa96e77"],
Cell[CellGroupData[{
Cell[278554, 5558, 330, 8, 48, "Input",ExpressionUUID->"efe2e1f7-5f4b-4f80-a068-3179b4d26ead"],
Cell[278887, 5568, 4850, 68, 48, "Output",ExpressionUUID->"c63576ad-70ca-47a3-8aae-32f1f9a693f1"]
}, Open  ]],
Cell[283752, 5639, 690, 10, 34, "Text",ExpressionUUID->"4c57f812-1225-494a-b471-d9ab225bc3b0"],
Cell[CellGroupData[{
Cell[284467, 5653, 333, 8, 48, "Input",ExpressionUUID->"80d37ed8-cd78-4859-a2af-abe1eefeba35"],
Cell[284803, 5663, 4858, 68, 48, "Output",ExpressionUUID->"e67fdc29-245d-42db-b808-d7e153e5774e"]
}, Open  ]],
Cell[289676, 5734, 727, 10, 34, "Text",ExpressionUUID->"2dc081a6-1670-4c41-9346-6a020d829e77"],
Cell[CellGroupData[{
Cell[290428, 5748, 386, 9, 48, "Input",ExpressionUUID->"f80494bc-0aea-4ebc-8598-5c7930afd620"],
Cell[290817, 5759, 4862, 68, 48, "Output",ExpressionUUID->"287a1c99-13a8-44ce-aa71-a663d291f6da"]
}, Open  ]],
Cell[295694, 5830, 246, 4, 34, "Text",ExpressionUUID->"67598b15-2514-4292-9b95-8022ce584210"],
Cell[CellGroupData[{
Cell[295965, 5838, 814, 20, 28, "Input",ExpressionUUID->"76bb7cb9-92d3-4751-9bf5-0e6368529753"],
Cell[296782, 5860, 638, 13, 48, "Output",ExpressionUUID->"a8d9bdb1-3088-4f8d-af95-0c3e293850a1"]
}, Open  ]],
Cell[297435, 5876, 244, 4, 34, "Text",ExpressionUUID->"f0b63684-b9c3-4fdb-856a-a6edd924c1ea"],
Cell[CellGroupData[{
Cell[297704, 5884, 828, 19, 28, "Input",ExpressionUUID->"d9537264-93e7-4b15-9914-3300b10cdafd"],
Cell[298535, 5905, 645, 13, 48, "Output",ExpressionUUID->"a0522879-1deb-40f7-9937-c00f9de829a0"]
}, Open  ]],
Cell[299195, 5921, 170, 3, 34, "Text",ExpressionUUID->"f1532e8f-1ff0-4696-80ab-886ff83a5282"],
Cell[CellGroupData[{
Cell[299390, 5928, 234, 5, 28, "Input",ExpressionUUID->"401d86c5-f709-4ded-a020-e4f984fcca9b"],
Cell[299627, 5935, 454, 7, 48, "Output",ExpressionUUID->"e0d64307-df9a-42e2-8dbb-3aeb63317f5c"]
}, Open  ]],
Cell[300096, 5945, 360, 6, 34, "Text",ExpressionUUID->"834e2ea9-9628-4ebc-a5cd-780325b8a182"],
Cell[300459, 5953, 757, 12, 34, "Text",ExpressionUUID->"5ed542e3-d498-4e4c-a4dd-1b360d55e7d3"],
Cell[CellGroupData[{
Cell[301241, 5969, 281, 7, 48, "Input",ExpressionUUID->"a7a9764c-bf66-49ef-939e-40c84233ba43"],
Cell[301525, 5978, 4897, 68, 48, "Output",ExpressionUUID->"65b5dc05-8e4e-4b49-a4cb-28387a9fe605"]
}, Open  ]],
Cell[306437, 6049, 852, 14, 34, "Text",ExpressionUUID->"82273b4d-e264-45a3-9a5a-0b30019357d7"],
Cell[CellGroupData[{
Cell[307314, 6067, 332, 8, 48, "Input",ExpressionUUID->"0d15ba49-a590-43d3-aca9-29acdb783728"],
Cell[307649, 6077, 4906, 68, 48, "Output",ExpressionUUID->"64ecbc1f-8a7f-42a4-a399-c1e6ffe82c4f"]
}, Open  ]],
Cell[312570, 6148, 738, 10, 34, "Text",ExpressionUUID->"3352666c-80d2-40ce-810f-a8825199cd77"],
Cell[CellGroupData[{
Cell[313333, 6162, 337, 8, 48, "Input",ExpressionUUID->"e28daa26-f731-472c-a5f4-43da2a375ffe"],
Cell[313673, 6172, 4913, 68, 48, "Output",ExpressionUUID->"b919e60d-95da-4208-9aff-c73ad14e0407"]
}, Open  ]],
Cell[318601, 6243, 777, 11, 34, "Text",ExpressionUUID->"8bbd25bf-f186-47b7-bdea-a067bbd138c8"],
Cell[CellGroupData[{
Cell[319403, 6258, 390, 9, 48, "Input",ExpressionUUID->"35c7e8ed-6e90-4876-8ad4-951cb59bb75d"],
Cell[319796, 6269, 4918, 68, 48, "Output",ExpressionUUID->"4ffe9dea-9b36-4225-8711-6fd0939951f1"]
}, Open  ]],
Cell[324729, 6340, 248, 4, 34, "Text",ExpressionUUID->"254ffe1a-db28-4d32-b3eb-d205bcdfa509"],
Cell[CellGroupData[{
Cell[325002, 6348, 764, 19, 28, "Input",ExpressionUUID->"c7fe4204-c93d-4e6b-9d7b-8118c7f7d498"],
Cell[325769, 6369, 620, 12, 48, "Output",ExpressionUUID->"99c67e53-9fa3-4c51-907b-ea6aaad0408e"]
}, Open  ]],
Cell[326404, 6384, 246, 4, 34, "Text",ExpressionUUID->"baad49c3-052c-4a87-8f8f-cc22691c1658"],
Cell[CellGroupData[{
Cell[326675, 6392, 811, 19, 28, "Input",ExpressionUUID->"76bb3f98-5ade-4de4-a31a-ec154bd96781"],
Cell[327489, 6413, 1267, 18, 48, "Output",ExpressionUUID->"9a16b8fe-d3cf-4653-9c06-876292419573"]
}, Open  ]],
Cell[328771, 6434, 168, 3, 34, "Text",ExpressionUUID->"dab3ed8c-1d4f-47fa-b5b3-1144b77ef863"],
Cell[CellGroupData[{
Cell[328964, 6441, 264, 6, 28, "Input",ExpressionUUID->"6acfb596-6902-4032-a982-8171915347fd"],
Cell[329231, 6449, 476, 8, 48, "Output",ExpressionUUID->"028d9f5d-a0ea-4768-a14f-a7d946b9ae18"]
}, Open  ]],
Cell[329722, 6460, 352, 6, 34, "Text",ExpressionUUID->"1142afe0-5471-471d-be27-11707bbb354f"],
Cell[330077, 6468, 673, 9, 34, "Text",ExpressionUUID->"48a40800-f00a-4dc9-88f5-1bbc6a044c8c"],
Cell[CellGroupData[{
Cell[330775, 6481, 279, 7, 47, "Input",ExpressionUUID->"d6dab62b-3e22-47ae-9eff-2ea7f40fb6ec"],
Cell[331057, 6490, 4902, 68, 48, "Output",ExpressionUUID->"e53401c3-675f-4973-a495-2535466cf892"]
}, Open  ]],
Cell[335974, 6561, 704, 10, 34, "Text",ExpressionUUID->"7c7f2397-6ea3-466d-89ec-1abe3b2211b3"],
Cell[CellGroupData[{
Cell[336703, 6575, 433, 9, 47, "Input",ExpressionUUID->"0c916522-7a07-4ec0-b186-2d0db90da26d"],
Cell[337139, 6586, 4940, 70, 48, "Output",ExpressionUUID->"e906fca1-03df-4322-a41f-a8d77364ce18"]
}, Open  ]],
Cell[342094, 6659, 671, 9, 34, "Text",ExpressionUUID->"68c54ca6-21db-4117-b44f-50d489d4ad0e"],
Cell[CellGroupData[{
Cell[342790, 6672, 328, 8, 47, "Input",ExpressionUUID->"84faf935-ac0e-4357-b313-8b675ca8bd95"],
Cell[343121, 6682, 4894, 68, 48, "Output",ExpressionUUID->"80d555f6-b92c-4c72-891e-1a50cec9f0d3"]
}, Open  ]],
Cell[348030, 6753, 702, 10, 34, "Text",ExpressionUUID->"8cb7caba-4423-4e83-a429-2d1d345028b2"],
Cell[CellGroupData[{
Cell[348757, 6767, 480, 10, 47, "Input",ExpressionUUID->"2c83cec5-273c-4ae8-b5b7-2c58e3c45034"],
Cell[349240, 6779, 4943, 70, 48, "Output",ExpressionUUID->"a68aee0a-983f-4c21-8857-fc110e300e6a"]
}, Open  ]],
Cell[354198, 6852, 409, 7, 34, "Text",ExpressionUUID->"83d06b74-3095-4edc-953e-85645ac377d9"],
Cell[354610, 6861, 675, 9, 34, "Text",ExpressionUUID->"9604737d-82e3-49c1-ba3c-b4893b6fedca"],
Cell[CellGroupData[{
Cell[355310, 6874, 279, 7, 47, "Input",ExpressionUUID->"f722eaec-b4d7-4482-ab02-c9a7ec54c530"],
Cell[355592, 6883, 670, 13, 48, "Output",ExpressionUUID->"8b519f77-fde5-44fa-b40b-d41333e7aaa1"]
}, Open  ]],
Cell[356277, 6899, 694, 11, 34, "Text",ExpressionUUID->"0cfb771c-9b76-45c8-b92f-562d4e73ee29"],
Cell[CellGroupData[{
Cell[356996, 6914, 435, 9, 47, "Input",ExpressionUUID->"7bb4680b-39e9-4b9e-85ba-9765d54b1207"],
Cell[357434, 6925, 4916, 69, 48, "Output",ExpressionUUID->"e6459d7d-2d88-4022-8b76-8d434fc41427"]
}, Open  ]],
Cell[362365, 6997, 675, 9, 34, "Text",ExpressionUUID->"5b70bcc3-b895-46db-ab44-1d2cdf6cc817"],
Cell[CellGroupData[{
Cell[363065, 7010, 332, 8, 47, "Input",ExpressionUUID->"36d8a810-a5a4-4f76-b1d6-a2ce4fbad651"],
Cell[363400, 7020, 4883, 68, 48, "Output",ExpressionUUID->"0ec72b82-25cd-4430-be3a-d801cbcf07fd"]
}, Open  ]],
Cell[368298, 7091, 706, 10, 34, "Text",ExpressionUUID->"0a979a1a-289e-446a-be54-7d8ce26971c9"],
Cell[CellGroupData[{
Cell[369029, 7105, 486, 10, 47, "Input",ExpressionUUID->"3eefc79e-b743-4617-abad-11d9932992dc"],
Cell[369518, 7117, 4960, 70, 48, "Output",ExpressionUUID->"bf8b8e9a-ec6f-41b2-a43c-d397c5ffbd11"]
}, Open  ]],
Cell[374493, 7190, 908, 13, 34, "Text",ExpressionUUID->"8d6f960c-cea6-4ac7-9d42-3184797329a6"],
Cell[CellGroupData[{
Cell[375426, 7207, 996, 31, 87, "Input",ExpressionUUID->"4be7ba51-cceb-4e00-9209-e3ee85fa7c30"],
Cell[376425, 7240, 5069, 73, 48, "Output",ExpressionUUID->"4063bd05-dfa5-4d0b-8823-e917fe4c6af6"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

