(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    634872,      11212]
NotebookOptionsPosition[    577821,      10424]
NotebookOutlinePosition[    578161,      10439]
CellTagsIndexPosition[    578118,      10436]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["IUU Fishing: Economic Effects of IUU Imports on U.S. Commercial \
Fishers\n",
  FontSize->36],
 StyleBox["Species: Sardine, Herring, Anchovies, Mackerel",
  FontSize->24],
 StyleBox["\n",
  FontSize->18],
 StyleBox["Model Release",
  FontSize->18,
  FontSlant->"Italic"]
}], "Title",
 CellChangeTimes->{{3.7159437701501894`*^9, 3.715943776742571*^9}, {
   3.7160177883406353`*^9, 3.716017799612287*^9}, {3.716044926298222*^9, 
   3.7160449278653135`*^9}, {3.7167127367223215`*^9, 3.716712737322365*^9}, {
   3.716716446852584*^9, 3.716716448548705*^9}, {3.717141741657609*^9, 
   3.717141743761731*^9}, {3.717937945363772*^9, 3.7179379529402757`*^9}, {
   3.7185331704286838`*^9, 3.7185331826684923`*^9}, {3.7185539001319838`*^9, 
   3.7185539082355175`*^9}, {3.7847892842210164`*^9, 
   3.7847892988406277`*^9}, {3.787835927539494*^9, 3.7878359285709715`*^9}, {
   3.7879338873743715`*^9, 3.7879338874784536`*^9}, {3.791201099377099*^9, 
   3.7912011013376207`*^9}, 3.7954520024204845`*^9, {3.798810740721634*^9, 
   3.798810744523918*^9}, {3.799789945142694*^9, 3.7997899492227287`*^9}, {
   3.7998541778687954`*^9, 3.7998541814351215`*^9}, {3.8016687240812187`*^9, 
   3.8016687246281986`*^9}, {3.8017788040189447`*^9, 
   3.8017788092541156`*^9}, {3.819664877798711*^9, 3.819664951849766*^9}, {
   3.8199010796026187`*^9, 3.8199010810067167`*^9}, {3.8249771280972795`*^9, 
   3.824977134543296*^9}},ExpressionUUID->"801921a0-034a-43a0-82ec-\
dcdaf955be7a"],

Cell[TextData[{
 StyleBox["Read Me :",
  FontWeight->"Bold"],
 "\nThis model accompanies the USITC report, ",
 StyleBox["Seafood Obtained via Illegal, Unreported, and Unregulated Fishing: \
U.S. Imports and Economic Impact on U.S. Commercial Fisheries",
  FontSlant->"Italic"],
 ", Inv. 332-575. The report includes a quantitative analysis of the economic \
impact of IUU imports on U.S. commercial fishers and U.S. commercial fishing \
production, trade, and prices. Economic effects are modeled by species, with \
each species-level model customized to fit the unique features of the U.S. \
domestic industry. Consumers of seafood products choose between domestic \
marine-capture sources, imports, and in some models, domestic aquaculture \
products. Imports include both legal and IUU sources that enter the U.S. at \
the same price, so consumers cannot distinguish an IUU from non-IUU product. \
2018 data is used to establish an initial equilibrium with imports of IUU \
products included in the baseline. The model then removes the IUU imports, as \
estimated in chapter 3, and solves for a new equilibrium absent those \
products. \n\nIn the forage fish model, there are domestic and imported  \
varieties of sardine, herring, anchovies, and mackerel species. The model \
includes cross-species substitution, so relative price changes in one species \
affects the other species. Annual catch limits (ACLs) are enforced in the \
model so modeled increases in domestic landings cannot exceed their legal \
limits. Catch limits are modeled as a vertical asymptote directly in the \
supply equation and not as a constraint.\n\nThere are two markets modeled: \
unprocessed and processed products. Landings  flow to three destinations: the \
unprocessed market, the processed market, or are exported outside the \
country. The price of the processed product is a constant markup over the \
price of the unprocessed product, so increases in domestic prices of landed \
fish affect the price of processing. Initial consumption of unprocessed \
products, before the policy change was implemented, was calculated as a \
residual using 2018 conversion factors.\n\nData inputs in the simulation are \
in the BLUE-shaded cells (with sources for the input data listed in the cell \
above). Outputs are in the GREEN-shaded cells. The white cells are \
intermediate calculations. \n\nNote: p_xDU is the price of the unprocessed \
product sold to consumers. q_xDU is the quantity of landings, not the \
unprocessed quantity sold to U.S. consumers. The unprocessed quantity sold to \
U.S. consumers must exclude exports and processed product * conversion rate."
}], "Text",
 CellChangeTimes->{{3.8151793544957237`*^9, 3.8151793654382553`*^9}, {
   3.815180147319877*^9, 3.8151801612046986`*^9}, 3.8193117353392124`*^9, {
   3.819364667233782*^9, 3.819364673128374*^9}, {3.819364986036234*^9, 
   3.81936502379967*^9}, {3.8193652789237294`*^9, 3.819365313721591*^9}, {
   3.819365363147914*^9, 3.819365382037648*^9}, {3.8193654602015305`*^9, 
   3.8193655738330727`*^9}, {3.819365634647441*^9, 3.8193657347144046`*^9}, {
   3.8193659700247307`*^9, 3.819365970554162*^9}, 3.8193660018247957`*^9, {
   3.819366258029726*^9, 3.819366301792824*^9}, {3.819366347287284*^9, 
   3.819366415704628*^9}, {3.8193664545638943`*^9, 3.819366511109967*^9}, {
   3.819366610713606*^9, 3.8193669391806083`*^9}, {3.8193669763456044`*^9, 
   3.8193670889590435`*^9}, {3.819367863082618*^9, 3.8193678631977077`*^9}, {
   3.819400007994233*^9, 3.819400030667904*^9}, {3.819400277598463*^9, 
   3.8194002936449785`*^9}, {3.8194011542913923`*^9, 
   3.8194012480694838`*^9}, {3.8194013222643557`*^9, 
   3.8194013264886327`*^9}, {3.8194013868456955`*^9, 
   3.8194013890784397`*^9}, {3.819401463985852*^9, 3.819401508238408*^9}, {
   3.8194019318657284`*^9, 3.8194019329005365`*^9}, {3.819665080356598*^9, 
   3.8196650954828777`*^9}, {3.8196652430795116`*^9, 3.819665263767852*^9}, {
   3.8196694045310993`*^9, 3.819669946270366*^9}, {3.819669976834861*^9, 
   3.8196705383246193`*^9}, {3.819670606948246*^9, 3.819670798460183*^9}, {
   3.819670860785177*^9, 3.8196709679574733`*^9}, {3.8196710056524982`*^9, 
   3.819671491943797*^9}, 3.819671563400182*^9, {3.819672484886944*^9, 
   3.8196724859338183`*^9}, {3.8199011533041058`*^9, 
   3.8199012321717076`*^9}, {3.8199021437167053`*^9, 3.819902144786538*^9}, {
   3.819904727337638*^9, 3.8199047710337067`*^9}, {3.820012303009897*^9, 
   3.820012307046046*^9}, {3.820012457109111*^9, 3.820012461730715*^9}, {
   3.821228471311254*^9, 3.821228478115568*^9}, {3.821228583604739*^9, 
   3.8212286069008274`*^9}, {3.821254034767659*^9, 3.8212540557230434`*^9}, {
   3.8212540945664053`*^9, 3.8212541288301916`*^9}, {3.821254184887725*^9, 
   3.8212542155085*^9}, {3.8249772744922485`*^9, 3.824977299960084*^9}, {
   3.824977554120001*^9, 3.8249776832165327`*^9}, {3.8249777599192657`*^9, 
   3.824977766653509*^9}, {3.82507490832841*^9, 3.825074908517795*^9}, 
   3.8250749591061897`*^9, {3.8250758189670277`*^9, 3.8250758195591617`*^9}, {
   3.8253519476689377`*^9, 3.825351974993293*^9}, {3.825352024652111*^9, 
   3.825352025379668*^9}, {3.8253524707402463`*^9, 3.8253524713066893`*^9}},
 FontSize->12,
 Background->GrayLevel[
  0.85],ExpressionUUID->"f0b295dd-f91c-483d-b6ca-da78d06e7819"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ClearAll", "[", "f", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.791207469588732*^9, 3.7912074737709374`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"0c777ea8-191a-4659-be18-f91ea0d0ffda"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1. Model Parameters",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
   3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
   3.791628711832301*^9}, {3.795452961580968*^9, 3.795452962713849*^9}, 
   3.82497785724205*^9},ExpressionUUID->"e96e59ff-4f99-46b0-8141-\
97bb85c5e783"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.1 Within-Species Elasticity of Substitution", \
"Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.819814333471882*^9, 
   3.8198143380684657`*^9}},ExpressionUUID->"36f1d069-9e60-47fe-944f-\
3d46d93bc2b7"],

Cell[TextData[StyleBox["Source: USITC\[CloseCurlyQuote]s econometric \
estimation using the trade cost method in Riker (2020). More information can \
be found in the technical appendix (appendix I). ",
 FontSize->12]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, 3.819672507377739*^9},
 FontSlant->"Italic",ExpressionUUID->"3e7f441b-c404-4d77-b05c-440c2c0e20ef"],

Cell[TextData[{
 StyleBox["Unprocessed Sardine:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across varieties of unprocessed \
sardine",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, 3.8196721378915873`*^9, 3.819672507377739*^9, {
   3.8198159346525345`*^9, 3.8198159348206663`*^9}, {3.824980156894936*^9, 
   3.8249801683568616`*^9}},ExpressionUUID->"f78bda85-40b2-4149-bb25-\
a6cc46c630d6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmasu", " ", "=", "6.57295"}], " ", ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, 3.8048512034675865`*^9, {
   3.8048685945427647`*^9, 3.804868597324478*^9}, {3.8129266197409177`*^9, 
   3.8129266412346473`*^9}, 3.8129266934392786`*^9, 3.8129270740308247`*^9, 
   3.8129274849676514`*^9, {3.8249778959401827`*^9, 3.8249779209566684`*^9}, 
   3.8249801786058426`*^9, 3.824980327469076*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[2]:=",ExpressionUUID->"0d44e1c6-e9d4-484e-888a-97e11d7e3438"],

Cell[TextData[{
 StyleBox["Processed Sardine:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across varieties of processed sardine",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, {3.819671893067898*^9, 3.819671897578418*^9}, 
   3.819672140510911*^9, 3.819672507377739*^9, {3.819815937731935*^9, 
   3.8198159380872116`*^9}, {3.82498018535109*^9, 
   3.8249801901958656`*^9}},ExpressionUUID->"b37b650e-a17b-4e87-9952-\
51ad9ceedb32"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmasp", " ", "=", "6.57295"}], " ", ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, 3.8048512034675865`*^9, {
   3.8048685945427647`*^9, 3.804868597324478*^9}, {3.8129266197409177`*^9, 
   3.8129266412346473`*^9}, 3.8129266934392786`*^9, 3.8129270740308247`*^9, 
   3.8129274849676514`*^9, {3.8249778959401827`*^9, 3.8249779209566684`*^9}, {
   3.824978050910866*^9, 3.824978051466297*^9}, 3.8249801765682535`*^9, 
   3.824980327469076*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[3]:=",ExpressionUUID->"2db00afb-2db9-4f8d-b635-efd25d598ba2"],

Cell[TextData[{
 StyleBox["Unprocessed Herring:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across varieties of unprocessed \
herring",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, 3.8196721378915873`*^9, 3.819672507377739*^9, {
   3.8198159346525345`*^9, 3.8198159348206663`*^9}, {3.824980156894936*^9, 
   3.8249801683568616`*^9}, {3.824980207811579*^9, 
   3.8249802132287965`*^9}},ExpressionUUID->"69b49a6e-2825-4d87-b4ad-\
ad9ada03bb4d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sigmahu", " ", "=", "7.794977"}], ";"}], " "}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.804851215720364*^9}, {3.804868607217617*^9, 3.8048686106688566`*^9}, {
   3.812926654004586*^9, 3.8129266978307047`*^9}, 3.8129270784332533`*^9, 
   3.81292749344625*^9, {3.8249779027935195`*^9, 3.8249779290389595`*^9}, 
   3.8249802343168945`*^9, 3.824980327469076*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[4]:=",ExpressionUUID->"68e3b805-5eb8-437a-a7f8-432c5dc38fa6"],

Cell[TextData[{
 StyleBox["Processed Herring:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across varieties of processed herring",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, {3.819671893067898*^9, 3.819671897578418*^9}, 
   3.819672140510911*^9, 3.819672507377739*^9, {3.819815937731935*^9, 
   3.8198159380872116`*^9}, {3.82498018535109*^9, 3.8249801901958656`*^9}, {
   3.824980253230619*^9, 
   3.8249802657313485`*^9}},ExpressionUUID->"4edd4f8f-8cfd-4a1b-b8fe-\
29f75eb7f019"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sigmahp", " ", "=", "7.794977"}], ";"}], " "}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.804851215720364*^9}, {3.804868607217617*^9, 3.8048686106688566`*^9}, {
   3.812926654004586*^9, 3.8129266978307047`*^9}, 3.8129270784332533`*^9, 
   3.81292749344625*^9, {3.8249779027935195`*^9, 3.8249779290389595`*^9}, {
   3.8249780541633987`*^9, 3.8249780546798*^9}, {3.82498025623496*^9, 
   3.8249802564050922`*^9}, 3.824980327469076*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[5]:=",ExpressionUUID->"2d53b917-3bb8-4216-97a2-5728876c05b0"],

Cell[TextData[{
 StyleBox["Unprocessed Anchovy:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across varieties of unprocessed \
anchovy",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, 3.8196721378915873`*^9, 3.819672507377739*^9, {
   3.8198159346525345`*^9, 3.8198159348206663`*^9}, {3.824980156894936*^9, 
   3.8249801683568616`*^9}, {3.8249802162221394`*^9, 
   3.824980221153002*^9}},ExpressionUUID->"c57c3269-221e-4ee9-abd4-\
2bcaf6b11529"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sigmaau", " ", "=", "5.863256"}], ";"}], " "}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.804851225082076*^9}, 3.8048805400169473`*^9, {3.8129267222286816`*^9, 
   3.812926752961002*^9}, 3.812927093612073*^9, 3.8129275052124033`*^9, {
   3.824977906295248*^9, 3.8249779357962217`*^9}, {3.824980236679737*^9, 
   3.824980236881893*^9}, 3.8249803274700775`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[6]:=",ExpressionUUID->"8ce1a048-b83e-4f20-84d6-e5ec15b6f8ef"],

Cell[TextData[{
 StyleBox["Processed Anchovy:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across varieties of processed anchovy",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, {3.819671893067898*^9, 3.819671897578418*^9}, 
   3.819672140510911*^9, 3.819672507377739*^9, {3.819815937731935*^9, 
   3.8198159380872116`*^9}, {3.82498018535109*^9, 3.8249801901958656`*^9}, {
   3.824980253230619*^9, 
   3.824980292163711*^9}},ExpressionUUID->"c6f8303c-c267-4f20-a568-\
2e35ce70f364"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sigmaap", " ", "=", "5.863256"}], ";"}], " "}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.804851225082076*^9}, 3.8048805400169473`*^9, {3.8129267222286816`*^9, 
   3.812926752961002*^9}, 3.812927093612073*^9, 3.8129275052124033`*^9, {
   3.824977906295248*^9, 3.8249779357962217`*^9}, {3.824978057281828*^9, 
   3.824978057742185*^9}, 3.8249802770880976`*^9, 3.8249803274700775`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[7]:=",ExpressionUUID->"d25950bb-8a53-4244-b786-111775e2873b"],

Cell[TextData[{
 StyleBox["Unprocessed Mackerel:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across varieties of unprocessed \
mackerel",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, 3.8196721378915873`*^9, 3.819672507377739*^9, {
   3.8198159346525345`*^9, 3.8198159348206663`*^9}, {3.824980156894936*^9, 
   3.8249801683568616`*^9}, {3.8249802252602186`*^9, 
   3.8249802295602117`*^9}},ExpressionUUID->"831362de-d808-4975-bf49-\
016ef7debc53"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmamu", " ", "=", "7.794977"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.8048512302547855`*^9}, 3.804881140319895*^9, 3.8129267037192774`*^9, 
   3.8129271018334703`*^9, {3.812927496240421*^9, 3.812927496594696*^9}, 
   3.824977910351406*^9, {3.8249779412935047`*^9, 3.824977942994827*^9}, {
   3.824980239480912*^9, 3.82498023967006*^9}, 3.8249803274700775`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[8]:=",ExpressionUUID->"055efbdb-f3e0-4860-881d-c7aa622d1cfb"],

Cell[TextData[{
 StyleBox["Processed Mackerel:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across varieties of processed mackerel",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, {3.819671893067898*^9, 3.819671897578418*^9}, 
   3.819672140510911*^9, 3.819672507377739*^9, {3.819815937731935*^9, 
   3.8198159380872116`*^9}, {3.82498018535109*^9, 3.8249801901958656`*^9}, {
   3.824980253230619*^9, 3.8249802657313485`*^9}, {3.8249802974007454`*^9, 
   3.8249803031201515`*^9}},ExpressionUUID->"1de89b03-9b1a-4638-b139-\
83b9a727d7f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmamp", " ", "=", "7.794977"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.8048512302547855`*^9}, 3.804881140319895*^9, 3.8129267037192774`*^9, 
   3.8129271018334703`*^9, {3.812927496240421*^9, 3.812927496594696*^9}, 
   3.824977910351406*^9, {3.8249779412935047`*^9, 3.824977942994827*^9}, {
   3.8249780604082627`*^9, 3.8249780609446793`*^9}, 3.824980274572159*^9, 
   3.8249803274700775`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[9]:=",ExpressionUUID->"634e6d9f-798a-4eec-aa52-d43e4534b1a9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.2 Cross-Species Elasticity of Substitution", \
"Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, 3.8196725148810096`*^9, {
   3.8198143408736553`*^9, 
   3.819814345001872*^9}},ExpressionUUID->"15f452e6-d489-4c7a-a831-\
1523a9049dbe"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate and Interviews with \
Industry Participants.",
 FontSize->12]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725148810096`*^9, 3.820012465372556*^9, {3.8200125245600863`*^9, 
   3.8200125375572243`*^9}},
 FontSlant->"Italic",ExpressionUUID->"10e61272-e8eb-4a92-9e23-2ceead6b8a8f"],

Cell[TextData[{
 StyleBox["Unprocessed:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across unprocessed products",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, {3.819672030964613*^9, 3.8196720315651684`*^9}, {
   3.819672128429147*^9, 3.819672157389882*^9}, 3.8196725148810096`*^9, {
   3.8198159557829914`*^9, 3.819815955882069*^9}, {3.824978024405224*^9, 
   3.824978028343289*^9}},ExpressionUUID->"ca749f20-babd-4cae-9cdd-\
32c597337e02"],

Cell[BoxData[
 RowBox[{
  RowBox[{"betau", " ", "=", "3.0"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.812465279359131*^9, 
   3.8124653094376397`*^9}, {3.81292590136325*^9, 3.812925939936266*^9}, 
   3.812926311880746*^9, 3.812926544214137*^9, 3.8196717219763446`*^9, {
   3.819671819711873*^9, 3.819671820331375*^9}, {3.81967192002273*^9, 
   3.8196719205252266`*^9}, {3.819672064642597*^9, 3.819672075061104*^9}, 
   3.8196725148810096`*^9, {3.8249803457152834`*^9, 3.8249803461436157`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[10]:=",ExpressionUUID->"032c980e-ebad-4d4e-8127-df2782b438fd"],

Cell[TextData[{
 StyleBox["Processed:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across processed products",
  FontSize->14]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, {3.819671893067898*^9, 3.819671897578418*^9}, {
   3.8196720341255374`*^9, 3.8196720347751384`*^9}, {3.8196721610431147`*^9, 
   3.8196721644200883`*^9}, 3.8196725148810096`*^9, {3.8198159580197334`*^9, 
   3.81981595815784*^9}, {3.8249780325525694`*^9, 
   3.8249780336674385`*^9}},ExpressionUUID->"25c2a9cd-6d54-4cd1-8cb6-\
aa67dd64a560"],

Cell[BoxData[
 RowBox[{
  RowBox[{"betap", " ", "=", "3.0"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.812465279359131*^9, 
   3.8124653094376397`*^9}, {3.81292590136325*^9, 3.812925939936266*^9}, 
   3.812926311880746*^9, 3.812926544214137*^9, 3.8196717219763446`*^9, {
   3.819671819711873*^9, 3.819671820331375*^9}, {3.8196719225732403`*^9, 
   3.8196719232829375`*^9}, {3.819672069645162*^9, 3.8196720784491777`*^9}, 
   3.8196725148810096`*^9, {3.8249803481271567`*^9, 3.8249803485765057`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[11]:=",ExpressionUUID->"fd7a3398-1416-478f-ab09-0f728be2ac6a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.3 Industry Price Elasticity of Demand", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, 3.8196725271002216`*^9, {3.819814291546197*^9, 
   3.819814297331707*^9}, {3.8198143479321556`*^9, 
   3.8198143530561504`*^9}},ExpressionUUID->"96cf782b-13a7-43de-8308-\
f00615cea5ca"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate.",
 FontSize->12]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725271002216`*^9, 3.820012468652115*^9, {3.8200125463901167`*^9, 
   3.8200125607253003`*^9}},
 FontSlant->"Italic",ExpressionUUID->"b7907907-4ad8-4f22-a3b9-1ccff4acff46"],

Cell[TextData[StyleBox["Unprocessed",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.8016643815964966`*^9, 3.80166438203933*^9}, {
   3.8031104952208443`*^9, 3.8031105339530745`*^9}, {3.803118428298416*^9, 
   3.8031184400395803`*^9}, 3.8033028142898912`*^9, {3.80571075980079*^9, 
   3.8057107601133404`*^9}, {3.8196721218802958`*^9, 
   3.8196721245096445`*^9}, {3.8196721773104386`*^9, 3.8196721827752504`*^9}, 
   3.8196725271002216`*^9},ExpressionUUID->"d9010a8d-269c-409d-87bb-\
3a17d8b809bd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"etau", "=", " ", 
   RowBox[{"-", "1.0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, 
   3.8016643791586046`*^9, {3.801780399382991*^9, 3.8017804002581425`*^9}, 
   3.803110491929274*^9, {3.819672112733116*^9, 3.819672113234567*^9}, 
   3.819672527101222*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[12]:=",ExpressionUUID->"27835e5a-02b3-4138-b277-7ab38eb701e7"],

Cell[TextData[StyleBox["Processed",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.8016643815964966`*^9, 
   3.8016643912751904`*^9}, {3.8031105485584755`*^9, 
   3.8031105510724382`*^9}, {3.805710761160388*^9, 3.805710761519824*^9}, {
   3.819672173174797*^9, 3.8196721856998253`*^9}, 
   3.819672527101222*^9},ExpressionUUID->"dfc88d43-fa3a-4b19-9406-\
5673cf2abd78"],

Cell[BoxData[
 RowBox[{
  RowBox[{"etap", "=", " ", 
   RowBox[{"-", "1.0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016643791586046`*^9, 3.801664387008879*^9}, {3.80178040319617*^9, 
   3.801780404211971*^9}, {3.819672116662634*^9, 3.819672117252161*^9}, 
   3.819672527101222*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[13]:=",ExpressionUUID->"2c5e7f74-9a89-4ceb-8daa-2687f3a43f10"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.4 Illegal Imports Replacement Rates", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, {3.81967219811668*^9, 3.819672213143815*^9}, 
   3.819672537084565*^9, {3.819814300125886*^9, 3.8198143058253307`*^9}, {
   3.8198143561535683`*^9, 
   3.8198143611354523`*^9}},ExpressionUUID->"06422778-09b4-480b-889a-\
6b8868a92f5e"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate.  Further discussion on \
qualitative factors and rate determination can be found in appendix I of the \
USITC\[CloseCurlyQuote]s report.",
 FontSize->12]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196723427492237`*^9, 3.8196725370855665`*^9, {3.819815993710532*^9, 
   3.819815996531728*^9}, {3.8198381383987584`*^9, 3.819838144753663*^9}, {
   3.8198382402870555`*^9, 3.8198383754614663`*^9}, 3.8200124721278267`*^9, {
   3.820012579354833*^9, 3.8200125899691114`*^9}},
 FontSlant->"Italic",ExpressionUUID->"fc27f0d3-736e-4342-adf0-887321523fef"],

Cell[TextData[{
 StyleBox["Sardine: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of sardine"
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}},ExpressionUUID->"54df29dd-63b6-4dfe-ae21-\
a854f55d7518"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"repls", " ", "=", " ", 
    StyleBox["0.30",
     FontColor->GrayLevel[0]]}], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], ";"}], " "}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662885297171*^9}, {3.8016683902542915`*^9, 
   3.801668392194314*^9}, {3.801668476343513*^9, 3.8016684764529057`*^9}, {
   3.8016685159337964`*^9, 3.801668531426852*^9}, 3.801692415143248*^9, {
   3.8016926196184893`*^9, 3.801692619774764*^9}, {3.801780289233728*^9, 
   3.8017802906278515`*^9}, 3.8033028464480004`*^9, 3.8033032141861067`*^9, {
   3.80339474346602*^9, 3.803394743762943*^9}, {3.8033948509102745`*^9, 
   3.80339485100404*^9}, 3.803397269400152*^9, 3.804343569032516*^9, {
   3.8043441779843903`*^9, 3.8043441785348186`*^9}, {3.804345528212033*^9, 
   3.8043455283191147`*^9}, {3.8043482483389072`*^9, 3.804348250335457*^9}, {
   3.804348999502578*^9, 3.8043489995996523`*^9}, {3.8043490925820007`*^9, 
   3.8043490927291145`*^9}, {3.80451933962536*^9, 3.804519339859774*^9}, {
   3.8045205567782145`*^9, 3.804520557247041*^9}, {3.804521073038145*^9, 
   3.8045210732569275`*^9}, {3.804521152663441*^9, 3.804521152757205*^9}, {
   3.804521464187267*^9, 3.8045214643279123`*^9}, {3.804545874319066*^9, 
   3.8045458744753385`*^9}, {3.8045460890897703`*^9, 
   3.8045460891835356`*^9}, {3.804546190142262*^9, 3.804546190595456*^9}, {
   3.8045868865938334`*^9, 3.8045868868282475`*^9}, {3.8045916336063304`*^9, 
   3.8045916336844664`*^9}, {3.804591811382941*^9, 3.804591811507962*^9}, 
   3.8048513408389482`*^9, {3.804858869583768*^9, 3.8048588697400417`*^9}, {
   3.8048672372703323`*^9, 3.8048672375047445`*^9}, 3.8048969343130455`*^9, {
   3.8057297547412767`*^9, 3.8057297898903933`*^9}, {3.805730572927047*^9, 
   3.8057305761263294`*^9}, {3.805731232078761*^9, 3.805731232172532*^9}, {
   3.805757761008747*^9, 3.8057577611806498`*^9}, {3.806667838993374*^9, 
   3.806667839102767*^9}, {3.806667948653041*^9, 3.8066679489343357`*^9}, 
   3.812467698895193*^9, {3.8124683053373656`*^9, 3.8124683089501886`*^9}, {
   3.817018299288029*^9, 3.817018324399062*^9}, {3.824980395274864*^9, 
   3.8249803954570065`*^9}, 3.8249804476026*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[14]:=",ExpressionUUID->"e71883ba-93a1-4219-bd68-67879f88fe63"],

Cell[TextData[{
 StyleBox["Herring: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of herring"
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980422642171*^9}},ExpressionUUID->"44c07241-9d58-4849-864f-\
83f0aa6a6962"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"replh", " ", "=", "0.50"}], ";"}], " "}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662885297171*^9}, {3.8016683902542915`*^9, 
   3.801668392194314*^9}, {3.801668476343513*^9, 3.8016684764529057`*^9}, {
   3.8016685159337964`*^9, 3.801668531426852*^9}, 3.801692415143248*^9, {
   3.8016926196184893`*^9, 3.801692619774764*^9}, {3.801780289233728*^9, 
   3.8017802906278515`*^9}, 3.8033028464480004`*^9, 3.8033032141861067`*^9, {
   3.80339474346602*^9, 3.803394743762943*^9}, {3.8033948509102745`*^9, 
   3.80339485100404*^9}, 3.803397269400152*^9, 3.804343569032516*^9, {
   3.8043441779843903`*^9, 3.8043441785348186`*^9}, {3.804345528212033*^9, 
   3.8043455283191147`*^9}, {3.8043482483389072`*^9, 3.804348250335457*^9}, {
   3.804348999502578*^9, 3.8043489995996523`*^9}, {3.8043490925820007`*^9, 
   3.8043490927291145`*^9}, {3.80451933962536*^9, 3.804519339859774*^9}, {
   3.8045205567782145`*^9, 3.804520557247041*^9}, {3.804521073038145*^9, 
   3.8045210732569275`*^9}, {3.804521152663441*^9, 3.804521152757205*^9}, {
   3.804521464187267*^9, 3.8045214643279123`*^9}, {3.804545874319066*^9, 
   3.8045458744753385`*^9}, {3.8045460890897703`*^9, 
   3.8045460891835356`*^9}, {3.804546190142262*^9, 3.804546190595456*^9}, {
   3.8045868865938334`*^9, 3.8045868868282475`*^9}, {3.8045916336063304`*^9, 
   3.8045916336844664`*^9}, {3.804591811382941*^9, 3.804591811507962*^9}, 
   3.8048513408389482`*^9, {3.804858869583768*^9, 3.8048588697400417`*^9}, {
   3.8048672372703323`*^9, 3.8048672375047445`*^9}, 3.8048969343130455`*^9, {
   3.8057297601716413`*^9, 3.80572976031229*^9}, {3.8057298167586813`*^9, 
   3.805729833074809*^9}, {3.8057305794269066`*^9, 3.8057305798644695`*^9}, {
   3.805731235532667*^9, 3.805731235657696*^9}, {3.8057577643686666`*^9, 
   3.8057577646187077`*^9}, {3.806667841993857*^9, 3.8066678421032495`*^9}, {
   3.8066679522681684`*^9, 3.806667952440071*^9}, 3.8124677165099587`*^9, 
   3.8249804059251547`*^9, 3.8249804476026*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[15]:=",ExpressionUUID->"0e18a7d4-8fb2-4ced-909c-3413ff8556fe"],

Cell[TextData[{
 StyleBox["Anchovy: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of anchovy"
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}, {3.8249804266412845`*^9, 
   3.824980431563115*^9}},ExpressionUUID->"ff64f6d0-3cae-46f5-b93b-\
2df56fdb9935"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"repla", " ", "=", " ", "0.50"}], ";"}], " "}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662885297171*^9}, {3.8016683902542915`*^9, 
   3.801668392194314*^9}, {3.801668476343513*^9, 3.8016684764529057`*^9}, {
   3.8016685159337964`*^9, 3.801668531426852*^9}, 3.801692415143248*^9, {
   3.8016926196184893`*^9, 3.801692619774764*^9}, {3.801780289233728*^9, 
   3.8017802906278515`*^9}, 3.8033028464480004`*^9, 3.8033032141861067`*^9, {
   3.80339474346602*^9, 3.803394743762943*^9}, {3.8033948509102745`*^9, 
   3.80339485100404*^9}, 3.803397269400152*^9, 3.804343569032516*^9, {
   3.8043441779843903`*^9, 3.8043441785348186`*^9}, {3.804345528212033*^9, 
   3.8043455283191147`*^9}, {3.8043482483389072`*^9, 3.804348250335457*^9}, {
   3.804348999502578*^9, 3.8043489995996523`*^9}, {3.8043490925820007`*^9, 
   3.8043490927291145`*^9}, {3.80451933962536*^9, 3.804519339859774*^9}, {
   3.8045205567782145`*^9, 3.804520557247041*^9}, {3.804521073038145*^9, 
   3.8045210732569275`*^9}, {3.804521152663441*^9, 3.804521152757205*^9}, {
   3.804521464187267*^9, 3.8045214643279123`*^9}, {3.804545874319066*^9, 
   3.8045458744753385`*^9}, {3.8045460890897703`*^9, 
   3.8045460891835356`*^9}, {3.804546190142262*^9, 3.804546190595456*^9}, {
   3.8045868865938334`*^9, 3.8045868868282475`*^9}, {3.8045916336063304`*^9, 
   3.8045916336844664`*^9}, {3.804591811382941*^9, 3.804591811507962*^9}, 
   3.8048513408389482`*^9, {3.804858869583768*^9, 3.8048588697400417`*^9}, {
   3.8048672372703323`*^9, 3.8048672375047445`*^9}, 3.8048969343130455`*^9, {
   3.805729763626602*^9, 3.8057297639391527`*^9}, 3.805729803756566*^9, {
   3.8057305829542933`*^9, 3.805730583329347*^9}, {3.8057312402993703`*^9, 
   3.8057312409713974`*^9}, {3.8057577703227654`*^9, 
   3.8057577705102954`*^9}, {3.8066678454006543`*^9, 3.806667845510047*^9}, {
   3.806667955122754*^9, 3.806667955263402*^9}, 3.8124677064380884`*^9, {
   3.812468351446398*^9, 3.8124683546358895`*^9}, 3.8249804089124804`*^9, 
   3.8249804476026*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[16]:=",ExpressionUUID->"7465d23f-f8c3-4f77-a89e-814ec6dd6ef5"],

Cell[TextData[{
 StyleBox["Mackerel: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of mackerel"
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}, {3.824980435595253*^9, 
   3.8249804402939095`*^9}},ExpressionUUID->"8f79e8eb-364e-4645-af5e-\
08fa3b56a048"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"replm", " ", "=", " ", "0.30"}], ";"}], " "}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662885297171*^9}, {3.8016683902542915`*^9, 
   3.801668392194314*^9}, {3.801668476343513*^9, 3.8016684764529057`*^9}, {
   3.8016685159337964`*^9, 3.801668531426852*^9}, 3.801692415143248*^9, {
   3.8016926196184893`*^9, 3.801692619774764*^9}, {3.801780289233728*^9, 
   3.8017802906278515`*^9}, 3.8033028464480004`*^9, 3.8033032141861067`*^9, {
   3.80339474346602*^9, 3.803394743762943*^9}, {3.8033948509102745`*^9, 
   3.80339485100404*^9}, 3.803397269400152*^9, 3.804343569032516*^9, {
   3.8043441779843903`*^9, 3.8043441785348186`*^9}, {3.804345528212033*^9, 
   3.8043455283191147`*^9}, {3.8043482483389072`*^9, 3.804348250335457*^9}, {
   3.804348999502578*^9, 3.8043489995996523`*^9}, {3.8043490925820007`*^9, 
   3.8043490927291145`*^9}, {3.80451933962536*^9, 3.804519339859774*^9}, {
   3.8045205567782145`*^9, 3.804520557247041*^9}, {3.804521073038145*^9, 
   3.8045210732569275`*^9}, {3.804521152663441*^9, 3.804521152757205*^9}, {
   3.804521464187267*^9, 3.8045214643279123`*^9}, {3.804545874319066*^9, 
   3.8045458744753385`*^9}, {3.8045460890897703`*^9, 
   3.8045460891835356`*^9}, {3.804546190142262*^9, 3.804546190595456*^9}, {
   3.8045868865938334`*^9, 3.8045868868282475`*^9}, {3.8045916336063304`*^9, 
   3.8045916336844664`*^9}, {3.804591811382941*^9, 3.804591811507962*^9}, 
   3.8048513408389482`*^9, {3.804858869583768*^9, 3.8048588697400417`*^9}, {
   3.8048672372703323`*^9, 3.8048672375047445`*^9}, 3.8048969343130455`*^9, {
   3.805729766314539*^9, 3.8057297666427164`*^9}, {3.8057298198079557`*^9, 
   3.805729842607835*^9}, {3.8057305859703493`*^9, 3.8057305865485573`*^9}, {
   3.805731243699998*^9, 3.805731243778141*^9}, {3.805757775041937*^9, 
   3.8057577752294674`*^9}, {3.8066678481042147`*^9, 
   3.8066678482448616`*^9}, {3.8066679584201593`*^9, 
   3.8066679585295515`*^9}, {3.81246770920525*^9, 3.8124677119994326`*^9}, 
   3.8249804114354467`*^9, 3.8249804476026*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[17]:=",ExpressionUUID->"cc0bc1ac-d58b-488a-b50e-37b05eb85d04"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.5 Price Elasticity of Supply", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, {3.81967219811668*^9, 3.819672213143815*^9}, {
   3.819672363407755*^9, 3.819672372555518*^9}, 3.8196725593450384`*^9, {
   3.8198143101346893`*^9, 3.8198143131120086`*^9}, {3.8198143634432487`*^9, 
   3.8198143660582876`*^9}},ExpressionUUID->"a4c19597-a956-4d47-b33a-\
2e05160e9758"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate and Interviews with \
Industry Participants.",
 FontSize->12]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725593450384`*^9, 3.8200124748939843`*^9, {3.8200126204719076`*^9, 
   3.820012620846199*^9}},
 FontSlant->"Italic",ExpressionUUID->"88a33b7b-b69c-43e4-a11c-8d4ee25cbbce"],

Cell[TextData[StyleBox["U.S. landings of Sardine",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.8249805094257298`*^9, 
   3.8249805103694663`*^9}},ExpressionUUID->"db6987eb-0e05-401c-b00a-\
057ce9de43f5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"esd", " ", "=", "1.0"}], ";"}], " "}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, 3.8048513547315273`*^9, {
   3.8048597028089485`*^9, 3.8048597031058826`*^9}, {3.8091743211490164`*^9, 
   3.809174335484453*^9}, 3.824978129596139*^9, 3.824980538468343*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[18]:=",ExpressionUUID->"0e61cea0-3282-45a7-bd8e-9e8e785d69eb"],

Cell[TextData[StyleBox["U.S. landings of Herring",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.824980514429674*^9, 
   3.824980515080135*^9}},ExpressionUUID->"91eb547e-5ee0-4dcd-b4c1-\
98bc27ce55b7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ehd", " ", "=", "2.0"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8048513547315273`*^9, 
   3.804851365641842*^9}, {3.8048597057626595`*^9, 3.804859706091468*^9}, {
   3.810035701835402*^9, 3.8100357216447754`*^9}, 3.8249781319199495`*^9, 
   3.824980538468343*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[19]:=",ExpressionUUID->"daaf0596-c33a-4587-81b3-e028c2d51607"],

Cell[TextData[StyleBox["U.S. landings of Anchovy",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.824980519091257*^9, 
   3.824980521730307*^9}},ExpressionUUID->"9bfdab0d-22e5-4118-807c-\
6fdecc82ee3e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ead", " ", "=", "5.0"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8048513547315273`*^9, 
   3.8048513680171757`*^9}, {3.804859708529451*^9, 3.8048597088263845`*^9}, 
   3.824980538468343*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[20]:=",ExpressionUUID->"61c0c99e-cd47-4677-a666-19e1cd12c8f5"],

Cell[TextData[StyleBox["U.S. landings of Mackerel",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.8249805261347375`*^9, 
   3.8249805271155033`*^9}},ExpressionUUID->"a235a056-7d5e-4248-9ede-\
429a18bb62f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"emd", " ", "=", "5.0"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8048513547315273`*^9, 
   3.8048513702674923`*^9}, {3.804859712264567*^9, 3.8048597125615005`*^9}, 
   3.824980538468343*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[21]:=",ExpressionUUID->"c77200e6-564e-48a4-9d46-75e553d26040"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.6 Conversion Factors", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, {3.81967219811668*^9, 3.819672213143815*^9}, {
   3.819672363407755*^9, 3.819672372555518*^9}, {3.8196724504932003`*^9, 
   3.8196724570907135`*^9}, 3.8196725668572683`*^9, {3.819814317458398*^9, 
   3.8198143176155205`*^9}, {3.819814368847461*^9, 3.819814369193731*^9}, {
   3.8199024597734833`*^9, 
   3.819902461929121*^9}},ExpressionUUID->"ec2bb41e-29b7-4a5d-b443-\
f21a75702f06"],

Cell[TextData[StyleBox["Source: Conversion factors were obtained from NOAA \
Fisheries",
 FontSize->12]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725593450384`*^9, 3.8198384238111687`*^9, {3.819839089463401*^9, 
   3.8198391080298843`*^9}, {3.8198393115996747`*^9, 3.819839330504422*^9}},
 FontSlant->"Italic",ExpressionUUID->"c125caf2-f3cc-4c41-8397-f7fd0c54b59c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cr", " ", "=", " ", "1.0"}], ";"}], " "}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8045456043635373`*^9, 
   3.804545605751848*^9}, {3.804851384410106*^9, 3.8048514151977367`*^9}, {
   3.804859716468526*^9, 3.8048597167967157`*^9}, {3.804859952266411*^9, 
   3.8048599526102223`*^9}, 3.804881198177019*^9, 3.8249805609558496`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[22]:=",ExpressionUUID->"53379da6-b7f9-4200-b622-21275c340c98"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2. Data Inputs",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.795452962713849*^9}, {
  3.8196715794204283`*^9, 3.8196715805723763`*^9}, {3.819672652231064*^9, 
  3.819672658049889*^9}},ExpressionUUID->"d4695fb3-0a18-49e6-835a-\
b22ed7f295ac"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.1 U.S. Landings Quantities and Prices", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672709332239*^9}, 
   3.819814602882104*^9, 
   3.8249807397550435`*^9},ExpressionUUID->"b6c27210-9183-49b2-be67-\
fc2df293ddda"],

Cell[TextData[StyleBox["Source: National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries).\
\[NonBreakingSpace]Fisheries of the United States 2018. Current Fishery \
Statistics No. 2018. U.S. Department of Commerce. Silver Spring MD:\
\[NonBreakingSpace]NOAA,\[NonBreakingSpace]February 2020. \
https://www.fisheries.noaa.gov/resource/document/fisheries-united-states-2018-\
report.\[NonBreakingSpace]",
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, 
   3.819814602882104*^9, {3.8198155788251867`*^9, 3.8198155811910124`*^9}, 
   3.8249807397550435`*^9},
 FontSize->12,ExpressionUUID->"04d83cbe-5516-46f5-b4b8-b781d5ac2e29"],

Cell[TextData[StyleBox["Sardine",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.7997922037144547`*^9, 
   3.799792207899268*^9}, {3.805710690264936*^9, 3.8057106905149765`*^9}, {
   3.819814387925336*^9, 3.819814398951932*^9}, 3.819814602882104*^9, {
   3.8249806046378546`*^9, 3.824980605591595*^9}, 
   3.8249807397550435`*^9},ExpressionUUID->"2b5f3e83-7e35-4acf-98b4-\
430eeba265e4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdu0", " ", "=", "1005000"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.8048514547791586`*^9, {
   3.804858998862688*^9, 3.8048590002413826`*^9}, 3.8249806838235035`*^9, 
   3.8249807397560444`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[23]:=",ExpressionUUID->"400c8e39-93cb-4fef-a9fb-41930d195d3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"psdu0", " ", "=", "0.44776119"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, 
   3.8048516657287436`*^9, {3.804859289924417*^9, 3.804859293881085*^9}, 
   3.8249806939483824`*^9, 3.8249807397560444`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[24]:=",ExpressionUUID->"cfe43c25-be78-4227-bac0-674e47880d70"],

Cell[TextData[StyleBox["Herring",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.7997922037144547`*^9, 
   3.799792207899268*^9}, {3.805710690264936*^9, 3.8057106905149765`*^9}, {
   3.819814387925336*^9, 3.819814398951932*^9}, 3.819814602882104*^9, {
   3.8249806046378546`*^9, 3.824980625447056*^9}, 
   3.8249807397560444`*^9},ExpressionUUID->"b528d670-b0bf-4367-9dd3-\
5becbbd0b094"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhdu0", " ", "=", "66719000"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.8048514568888445`*^9, {
   3.804859007321229*^9, 3.804859009274654*^9}, 3.824980685227595*^9, 
   3.8249807397560444`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[25]:=",ExpressionUUID->"4ecde827-d0a5-44ad-8f2a-1ab84264d7b8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"phdu0", " ", "=", "0.49371244"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.8048516736382985`*^9}, {3.8048592982724123`*^9, 
   3.80485930216366*^9}, 3.8249806951733356`*^9, 3.8249807397560444`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[26]:=",ExpressionUUID->"fc8eb168-ab40-4abf-a2f7-a6c4a5fe0448"],

Cell[TextData[StyleBox["Anchovy",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.7997922037144547`*^9, 
   3.799792207899268*^9}, {3.805710690264936*^9, 3.8057106905149765`*^9}, {
   3.819814387925336*^9, 3.819814398951932*^9}, 3.819814602882104*^9, {
   3.8249806046378546`*^9, 3.8249806415305767`*^9}, 
   3.8249807397560444`*^9},ExpressionUUID->"23537e42-f22b-4d4a-b814-\
07c78ce53216"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadu0", " ", "=", "17360000"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.8048514589516478`*^9, {
   3.8048590130252295`*^9, 3.804859016210842*^9}, 3.8249806865706387`*^9, 
   3.8249807397560444`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[27]:=",ExpressionUUID->"6682d775-94cf-4a53-8c9a-592c4584bd42"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"padu0", " ", "=", "0.11388249"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.8048516760920506`*^9}, {3.804859306715953*^9, 
   3.804859310810358*^9}, 3.8249806964052973`*^9, 3.824980739757045*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[28]:=",ExpressionUUID->"5c93ef97-317b-45bc-930c-7ed4a5083bcf"],

Cell[TextData[StyleBox["Mackerel",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.7997922037144547`*^9, 
   3.799792207899268*^9}, {3.805710690264936*^9, 3.8057106905149765`*^9}, {
   3.819814387925336*^9, 3.819814398951932*^9}, 3.819814602882104*^9, {
   3.8249806046378546`*^9, 3.824980659845832*^9}, 
   3.824980739757045*^9},ExpressionUUID->"2b07763f-3cfd-4858-b497-\
e8fb0b404ccf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qmdu0", " ", "=", "87333209"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.804851461217606*^9, {
   3.8048590263373966`*^9, 3.8048590278376274`*^9}, 3.8249806879046807`*^9, 
   3.824980739757045*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[29]:=",ExpressionUUID->"aba9680d-c0d7-4bcf-aed7-0787606061b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pmdu0", " ", "=", "0.90390598"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.804851678024618*^9}, {3.804859329331564*^9, 
   3.8048593352231383`*^9}, {3.804859838203453*^9, 3.804859839094244*^9}, 
   3.8249806976963*^9, 3.824980739757045*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[30]:=",ExpressionUUID->"a81323c0-f581-4d29-94ee-cd5c44c14b81"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.2 U.S. Processing Production Quantities and \
Prices", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672733348008*^9}, {
   3.8196727961837325`*^9, 3.8196728038250227`*^9}, 3.819814751753172*^9, 
   3.8249808810930777`*^9},ExpressionUUID->"d26a83b2-cfac-4241-a654-\
e88df3ce54b3"],

Cell[TextData[StyleBox["Sources:\n National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries).\
\[NonBreakingSpace]Fisheries of the United States 2018. Current Fishery \
Statistics No. 2018. U.S. Department of Commerce. Silver Spring MD:\
\[NonBreakingSpace]NOAA,\[NonBreakingSpace]February 2020. \
https://www.fisheries.noaa.gov/resource/document/fisheries-united-states-2018-\
report.\[NonBreakingSpace] \n\nNational Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries). NOAA \
Processed Products database. Accessed September 1, \
2020.https://www.fisheries.noaa.gov/foss/f?p=215:3:5412288074334::NO:::",
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, {
   3.819814602882104*^9, 3.819814670599902*^9}, {3.8198147375350885`*^9, 
   3.819814751753172*^9}, {3.8198155956591797`*^9, 3.8198155972494073`*^9}, 
   3.8249808810930777`*^9, {3.8253518377931767`*^9, 3.8253518957234063`*^9}},
 FontSize->12,ExpressionUUID->"e57cf532-9da8-4855-9e40-46e0c11ef26f"],

Cell[TextData[StyleBox["Processed Sardine",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9, {3.824980768462393*^9, 3.824980769184957*^9}, 
   3.8249808810930777`*^9},ExpressionUUID->"3702204a-2207-4fb1-8ddd-\
7ae37503c070"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdp0", " ", "=", "42925"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.80485147925504*^9, {3.8048590537865825`*^9, 3.8048590560213146`*^9}, 
   3.8249808483125567`*^9, 3.8249808810930777`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[31]:=",ExpressionUUID->"24e0d001-9c3c-4664-b4e5-84955a14c169"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"psdp0", " ", "=", "1.1706711"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.804343942476156*^9, 3.804343949889929*^9}, {
   3.8045210306472683`*^9, 3.8045210368829145`*^9}, {3.804587081702225*^9, 
   3.8045870826558285`*^9}, 3.8048517570505433`*^9, 3.804865877652568*^9, {
   3.824980857437663*^9, 3.8249808810930777`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[32]:=",ExpressionUUID->"f518a895-fc64-4c1b-8016-df1a33c9f6f1"],

Cell[TextData[StyleBox["Processed Herring",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9, {3.824980768462393*^9, 3.824980791846599*^9}, 
   3.8249808810930777`*^9},ExpressionUUID->"5e5a9bf6-4421-4411-a4a8-\
fa63622ab566"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhdp0", " ", "=", "2857406"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.804851484318285*^9, {3.8048590605689173`*^9, 3.8048590667730417`*^9}, 
   3.824980849871773*^9, 3.8249808810930777`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[33]:=",ExpressionUUID->"6561412e-06fd-4c57-ae93-47270a6df98e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"phdp0", " ", "=", "1.1706713"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.804343942476156*^9, 3.804343949889929*^9}, {
   3.8045210306472683`*^9, 3.8045210368829145`*^9}, {3.804587081702225*^9, 
   3.8045870826558285`*^9}, {3.804851759302089*^9, 3.8048517613180237`*^9}, 
   3.804865883950451*^9, {3.8249808585104966`*^9, 3.824980881094079*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[34]:=",ExpressionUUID->"09c8ff30-42fd-4efc-951c-d2cfbedd4dcc"],

Cell[TextData[StyleBox["Processed Anchovy",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9, {3.824980768462393*^9, 3.824980798186533*^9}, 
   3.824980881094079*^9},ExpressionUUID->"74fef3b2-0c62-4723-8c84-\
1fb7b6453b0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadp0", " ", "=", "7229685"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.804851485974779*^9, {3.8048590710549765`*^9, 3.804859073899182*^9}, {
   3.8249808513389125`*^9, 3.824980881094079*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[35]:=",ExpressionUUID->"abd93098-806c-4525-be8c-4d88e9e76f05"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"padp0", " ", "=", "0.4867994"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.804343942476156*^9, 3.804343949889929*^9}, {
   3.8045210306472683`*^9, 3.8045210368829145`*^9}, {3.804587081702225*^9, 
   3.8045870826558285`*^9}, 3.8048517637402706`*^9, 3.804865889483494*^9, {
   3.8249808597524614`*^9, 3.824980881094079*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[36]:=",ExpressionUUID->"c11b0971-44f2-457e-a56f-d2e8e07d9df7"],

Cell[TextData[StyleBox["Processed Mackerel",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9, {3.824980768462393*^9, 3.824980769184957*^9}, {
   3.8249808004923286`*^9, 3.82498080134299*^9}, 
   3.824980881094079*^9},ExpressionUUID->"8358122a-dcdf-4af8-b13c-\
6d4facc289fc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qmdp0", " ", "=", "40331122"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.8048514880219545`*^9, {3.8048590780406504`*^9, 3.8048590807442083`*^9}, {
   3.824980852606901*^9, 3.824980881094079*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[37]:=",ExpressionUUID->"99c6e44e-061a-4ff5-961c-12a04ff14f1d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pmdp0", " ", "=", "3.0128494"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.804343942476156*^9, 3.804343949889929*^9}, {
   3.8045210306472683`*^9, 3.8045210368829145`*^9}, {3.804587081702225*^9, 
   3.8045870826558285`*^9}, 3.804851766084381*^9, 3.804865895093766*^9, {
   3.8249808610314617`*^9, 3.824980881094079*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[38]:=",ExpressionUUID->"b2da8702-0316-46b8-9356-5aa032c6c832"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.3 Import Quantities and Prices", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672733348008*^9}, {
   3.819672809477676*^9, 3.8196728096938534`*^9}, 3.8198152044580364`*^9, 
   3.8249830230169973`*^9},ExpressionUUID->"b021c4ce-bcc6-4034-9232-\
8fda8d1adcb9"],

Cell[TextData[StyleBox["Source: IUU Estimate Database as described in Chapter \
3 of the report. ",
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, 
   3.819814602882104*^9, {3.8198147741606445`*^9, 3.8198147935287457`*^9}, 
   3.8198152044580364`*^9, 3.820012478192554*^9, {3.8208559831037273`*^9, 
   3.8208560402321887`*^9}, 3.824980895304139*^9, 3.8249830230169973`*^9},
 FontSize->12,ExpressionUUID->"8465ec6c-fd6d-4cd2-be59-f3c94e338e2e"],

Cell[TextData[StyleBox["Sardine",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.82498135149479*^9, 3.824981353015973*^9}, 3.8249814426737957`*^9, 
   3.8249830230169973`*^9},ExpressionUUID->"df7d710e-e2ce-4964-912d-\
2d1215c1f9bf"],

Cell["Total unprocessed imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814453368645`*^9, 3.8249814468960824`*^9}, 
   3.8249830230169973`*^9},ExpressionUUID->"21e9dddf-955e-4046-8c7d-\
1f061d77ced8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qstu0", " ", "=", 
    StyleBox["14991943",
     FontColor->GrayLevel[0]]}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.8048514991738663`*^9, {
   3.8048590916512775`*^9, 3.8048590942923245`*^9}, {3.8124677907589808`*^9, 
   3.8124677932499256`*^9}, {3.8170183892731037`*^9, 
   3.8170183986355124`*^9}, {3.817018503244489*^9, 3.817018511310743*^9}, {
   3.8188025813538103`*^9, 3.818802581434873*^9}, 3.824980910176717*^9, {
   3.824980992460779*^9, 3.8249809938858857`*^9}, 3.8249830230169973`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[39]:=",ExpressionUUID->"ae10a51e-203c-49fc-b34c-3bab85f2f593"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pstu0", " ", "=", "0.641524"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851738717746*^9, {3.8048593644040937`*^9, 
   3.804859369373639*^9}, {3.8124679886835213`*^9, 3.8124679888996897`*^9}, {
   3.817019052269328*^9, 3.8170190578355637`*^9}, {3.817019126900281*^9, 
   3.817019159716982*^9}, 3.8171067074132996`*^9, 3.817106753496872*^9, {
   3.8171067913406672`*^9, 3.817106797484902*^9}, {3.8188029981474495`*^9, 
   3.8188030059155245`*^9}, {3.824981081667226*^9, 3.824981111694604*^9}, 
   3.8249830230179977`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[40]:=",ExpressionUUID->"bbe25b2d-bbf5-45c8-98c1-b268a76c3c79"],

Cell["Total processed imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814453368645`*^9, 3.8249814468960824`*^9}, {
   3.8249814992608576`*^9, 3.824981499646157*^9}, 
   3.8249830230179977`*^9},ExpressionUUID->"b8fe53e8-ab34-480d-9453-\
8980ed3108bb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qstp0", " ", "=", 
    StyleBox["35602018",
     FontColor->GrayLevel[0]]}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.8048515168380613`*^9, {3.8048591480713325`*^9, 
   3.804859151134322*^9}, {3.81246782845944*^9, 3.8124678323584876`*^9}, {
   3.817018458811661*^9, 3.81701846338055*^9}, {3.817018655821101*^9, 
   3.817018663469618*^9}, {3.817106317707793*^9, 3.817106319069307*^9}, {
   3.818802712663865*^9, 3.818802713152245*^9}, {3.8249815340439444`*^9, 
   3.8249815484021287`*^9}, 3.8249830230179977`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[41]:=",ExpressionUUID->"9485f714-e9cc-42a5-989a-eec3da2d3d9d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pstp0", " ", "=", "4.17392"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.8048517763987885`*^9, {
   3.8048594197297783`*^9, 3.80485942321471*^9}, {3.804859460017418*^9, 
   3.804859464424373*^9}, {3.804865902826519*^9, 3.80486590501756*^9}, {
   3.8124680466965876`*^9, 3.8124680500732107`*^9}, {3.817019086697604*^9, 
   3.8170190912120934`*^9}, {3.817019358048959*^9, 3.817019376504242*^9}, 
   3.817106698259956*^9, {3.8171068442750673`*^9, 3.8171068496719646`*^9}, {
   3.8188031971559258`*^9, 3.8188031973881054`*^9}, {3.8249815383723183`*^9, 
   3.8249815453187275`*^9}, 3.8249830230179977`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[42]:=",ExpressionUUID->"780be44e-d362-41c6-bc75-eb26841e8c10"],

Cell["Illegal imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249810181827993`*^9, 3.824981019918154*^9}, {
   3.824981450035527*^9, 3.8249814516147547`*^9}, 3.8249815081047473`*^9, 
   3.8249830230179977`*^9},ExpressionUUID->"e618723c-91d6-459c-9306-\
7dcf820ef40d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsiu0", " ", "=", 
    StyleBox["2943611",
     FontColor->GrayLevel[0]]}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.8048515369847345`*^9, {3.804859197487756*^9, 
   3.8048592001756873`*^9}, {3.812467874979795*^9, 3.812467876929315*^9}, {
   3.8170187517866635`*^9, 3.817018756100666*^9}, {3.8170188204891877`*^9, 
   3.81701882744118*^9}, {3.8171063359554963`*^9, 3.8171063371189847`*^9}, {
   3.8188028215504923`*^9, 3.818802824994169*^9}, {3.824981047071293*^9, 
   3.824981063056736*^9}, 3.8249830230179977`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[43]:=",ExpressionUUID->"fcb4851d-56ab-49c4-a7ef-580097bba28d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsip0", " ", "=", 
    StyleBox["7470902",
     FontColor->GrayLevel[0]]}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515541907682`*^9, {3.8048592345130177`*^9, 3.804859239029372*^9}, {
   3.812467909530793*^9, 3.8124679121578445`*^9}, {3.817018781822551*^9, 
   3.8170187864347725`*^9}, {3.8170188343386927`*^9, 
   3.8170188395920696`*^9}, {3.8171063502392654`*^9, 3.817106351331723*^9}, {
   3.818802892792108*^9, 3.818802895979604*^9}, 3.824981584605323*^9, 
   3.824981645250547*^9, 3.8249830230179977`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[44]:=",ExpressionUUID->"5869e936-4b85-417d-9535-9acd134d3627"],

Cell[TextData[StyleBox["Herring",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.8249811305723004`*^9, 3.8249811319103403`*^9}, {3.824981355234703*^9, 
   3.8249813567088475`*^9}, 3.824981468754101*^9, 
   3.824983023018999*^9},ExpressionUUID->"576b77e5-2f40-4970-a883-\
73790c3eea83"],

Cell["Total unprocessed imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.824981455897089*^9, 3.8249814573582287`*^9}, 
   3.824983023018999*^9},ExpressionUUID->"2897e784-5bd0-4cfa-9275-\
23952dc2873f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhtu0", " ", "=", 
    StyleBox["2459463",
     FontColor->GrayLevel[0]]}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.8048515018675895`*^9, {
   3.8048590980585527`*^9, 3.8048591016372504`*^9}, {3.812467798251837*^9, 
   3.8124678009199204`*^9}, {3.8170184014558473`*^9, 3.817018406429657*^9}, {
   3.8170185217955303`*^9, 3.8170185343289633`*^9}, {3.8188026062551637`*^9, 
   3.8188026112900767`*^9}, 3.824980921681673*^9, 3.824980997365596*^9, 
   3.824983023018999*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[45]:=",ExpressionUUID->"4f31d8a3-142a-4e41-9984-1a88a6f968f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"phtu0", " ", "=", "1.50032"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851741390031*^9, {3.8048593749382596`*^9, 
   3.8048593807364388`*^9}, {3.8124679966487093`*^9, 
   3.8124679987163153`*^9}, {3.817019061001256*^9, 3.817019064916585*^9}, {
   3.8170191724110146`*^9, 3.8170191971922684`*^9}, 3.817106709857418*^9, 
   3.817106760363701*^9, {3.8171068014354296`*^9, 3.8171068050886817`*^9}, {
   3.81880304837671*^9, 3.818803059784626*^9}, 3.818803123118126*^9, {
   3.824981282161929*^9, 3.824981288093546*^9}, 3.8249813231827393`*^9, 
   3.824983023018999*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[46]:=",ExpressionUUID->"3ff847f8-e519-4d22-a466-267ec672c9ff"],

Cell["Total processed imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.824981455897089*^9, 3.8249814573582287`*^9}, {
   3.824981662011598*^9, 3.82498166215471*^9}, 
   3.824983023018999*^9},ExpressionUUID->"f66ff504-57ee-4e29-9ef1-\
608946c61119"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhtp0", " ", "=", 
    StyleBox["11509060",
     FontColor->GrayLevel[0]]}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.804851519404023*^9, {3.8048591560917697`*^9, 
   3.8048591592391844`*^9}, {3.812467837794733*^9, 3.812467839819319*^9}, {
   3.8170184666149254`*^9, 3.8170184716348047`*^9}, {3.8170185422896404`*^9, 
   3.817018550486697*^9}, {3.817106322764189*^9, 3.8171063240089836`*^9}, {
   3.8188027326934323`*^9, 3.8188027368936973`*^9}, {3.824981686237464*^9, 
   3.8249817080484505`*^9}, 3.824983023018999*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[47]:=",ExpressionUUID->"29350a81-3a4a-4b4b-a909-8f3dc67795fb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"phtp0", " ", "=", "3.75706"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.8048517788079557`*^9, {
   3.8048594276529274`*^9, 3.8048594301064444`*^9}, {3.8048594705997667`*^9, 
   3.8048594745222692`*^9}, {3.804865909505168*^9, 3.8048659121618433`*^9}, {
   3.81246805426847*^9, 3.8124680585117664`*^9}, {3.81701909447643*^9, 
   3.817019097804056*^9}, {3.8170193888206015`*^9, 3.8170194119198985`*^9}, 
   3.817106700413266*^9, {3.8171068534432077`*^9, 3.8171068565781736`*^9}, {
   3.8188032245322027`*^9, 3.8188032602309475`*^9}, {3.8249816960310903`*^9, 
   3.824981704730867*^9}, 3.824983023018999*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[48]:=",ExpressionUUID->"6af3a0db-6bd1-4bd8-b13c-06058f2aad81"],

Cell["Illegal imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249810181827993`*^9, 3.824981019918154*^9}, {
   3.8249814599542522`*^9, 3.824981461369351*^9}, 3.824981654929083*^9, 
   3.824983023018999*^9},ExpressionUUID->"200ae52d-9f29-437a-ba63-\
690385364d99"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhiu0", " ", "=", 
    StyleBox["176774",
     FontColor->GrayLevel[0]]}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.8048515390631647`*^9, {3.8048592061610203`*^9, 
   3.804859208024148*^9}, {3.8124678806322093`*^9, 3.812467883122154*^9}, {
   3.8170187597112913`*^9, 3.8170187638204145`*^9}, {3.817018847245697*^9, 
   3.8170188534548006`*^9}, 3.8171063400112453`*^9, {3.8188028367292943`*^9, 
   3.8188028397366447`*^9}, {3.8249812949987936`*^9, 3.8249813190235014`*^9}, 
   3.8249830230199995`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[49]:=",ExpressionUUID->"49bbfc31-81e6-46c1-a11b-7bf50613d980"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhip0", " ", "=", 
    StyleBox["799269",
     FontColor->GrayLevel[0]]}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515567692885`*^9, {3.8048592431706595`*^9, 3.8048592455772943`*^9}, {
   3.812467918184553*^9, 3.8124679201240716`*^9}, {3.817018789525627*^9, 
   3.8170187943159466`*^9}, {3.8170188601533155`*^9, 3.817018874489888*^9}, 
   3.8171063540733423`*^9, {3.81880291749842*^9, 3.818802920656887*^9}, {
   3.8249817317499075`*^9, 3.824981746753589*^9}, 3.8249830230199995`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[50]:=",ExpressionUUID->"21327809-8401-4b20-ae5b-310e4df12604"],

Cell[TextData[StyleBox["Anchovy",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.8249811305723004`*^9, 3.824981142293425*^9}, {3.8249813587714567`*^9, 
   3.8249813602456017`*^9}, 3.824981471403165*^9, 
   3.8249830230199995`*^9},ExpressionUUID->"5796d752-9475-4edc-aaae-\
7a3e78b3f9f5"],

Cell["Total unprocessed imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814636221075`*^9, 3.8249814650452137`*^9}, 
   3.8249830230199995`*^9},ExpressionUUID->"bf2b7532-8dcf-4a44-ae68-\
73baf8480531"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qatu0", " ", "=", 
    StyleBox["1761278",
     FontColor->GrayLevel[0]]}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.804851503993678*^9, {
   3.804859106546692*^9, 3.8048591085313845`*^9}, {3.812467805370399*^9, 
   3.812467808471821*^9}, {3.8170184096421137`*^9, 3.8170184138788443`*^9}, {
   3.817018559953476*^9, 3.817018564731906*^9}, 3.824980930688689*^9, 
   3.824981002218373*^9, 3.8249830230199995`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[51]:=",ExpressionUUID->"8ccfd944-c19b-49ca-bd97-ae7982c4c14d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"patu0", " ", "=", "2.39253"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851745095583*^9, {3.8048593855964956`*^9, 
   3.804859389253332*^9}, {3.8124679691983852`*^9, 3.812467975646394*^9}, {
   3.817019068006332*^9, 3.8170190718692484`*^9}, {3.817019204569222*^9, 
   3.8170192183779573`*^9}, 3.817106711684542*^9, 3.8171067646161795`*^9, {
   3.8171068080150604`*^9, 3.8171068115859437`*^9}, {3.818803086612593*^9, 
   3.8188030867917323`*^9}, 3.8188031270682106`*^9, {3.8249812639747715`*^9, 
   3.8249812720850844`*^9}, 3.8249830230199995`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[52]:=",ExpressionUUID->"8b465579-3011-4468-9c89-a2f6795256be"],

Cell["Total processed imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.824981455897089*^9, 3.8249814573582287`*^9}, {
   3.824981662011598*^9, 3.82498166215471*^9}, 
   3.8249830230199995`*^9},ExpressionUUID->"6820d8ff-b589-4ea4-ae6f-\
2b35693ba7fb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qatp0", " ", "=", 
    StyleBox["4890903",
     FontColor->GrayLevel[0]]}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.8048515215605907`*^9, {3.804859164699379*^9, 
   3.804859168700019*^9}, {3.8124678479826956`*^9, 3.8124678517626514`*^9}, {
   3.817018474825408*^9, 3.817018478857918*^9}, {3.817018571620371*^9, 
   3.817018577471934*^9}, {3.8171063269477425`*^9, 3.817106328105254*^9}, {
   3.8188027678517575`*^9, 3.81880276820203*^9}, {3.824981797144831*^9, 
   3.8249818161636443`*^9}, 3.8249830230199995`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[53]:=",ExpressionUUID->"e01165ce-f1d5-466c-bd97-2cfeb5fb52a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"patp0", " ", "=", "8.04725"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.804851781495868*^9, {
   3.8048594347165575`*^9, 3.8048594421552544`*^9}, {3.8048594788678904`*^9, 
   3.804859482930971*^9}, {3.8048659166313086`*^9, 3.8048659239918613`*^9}, {
   3.8124680643312874`*^9, 3.8124680669593287`*^9}, {3.817019100922312*^9, 
   3.8170191042387033`*^9}, {3.8170194184266257`*^9, 3.8170194333229284`*^9}, 
   3.817106702251444*^9, {3.817106860396476*^9, 3.8171068635491915`*^9}, 
   3.818803227831767*^9, {3.8188032860420094`*^9, 3.8188032967333183`*^9}, {
   3.82498180713361*^9, 3.824981820479003*^9}, 3.824983023021001*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[54]:=",ExpressionUUID->"cf846bbd-4358-4ded-a3bd-51431faf16f0"],

Cell["Illegal imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249810181827993`*^9, 3.824981019918154*^9}, {
   3.8249814747797947`*^9, 3.8249814760677977`*^9}, {3.824981765296032*^9, 
   3.8249817662197495`*^9}, 
   3.824983023021001*^9},ExpressionUUID->"9d5d74ed-5fb4-49f2-9b01-\
d522648cd8a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qaiu0", " ", "=", 
    StyleBox["249603",
     FontColor->GrayLevel[0]]}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.804851541954215*^9, {3.804859212477992*^9, 
   3.804859214822117*^9}, {3.8124678896312428`*^9, 3.812467892367381*^9}, {
   3.817018767535432*^9, 3.8170187715970078`*^9}, {3.8170188869943027`*^9, 
   3.817018892090475*^9}, 3.8171063426110067`*^9, {3.8188028538857*^9, 
   3.8188028569911275`*^9}, {3.8249813046352987`*^9, 3.8249813148272357`*^9}, 
   3.824983023021001*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[55]:=",ExpressionUUID->"adf09bb8-ba09-42d4-8fa1-3851ed8f03f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qaip0", " ", "=", 
    StyleBox["797667",
     FontColor->GrayLevel[0]]}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.80485155892587*^9, {3.8048592504999576`*^9, 3.8048592528905926`*^9}, {
   3.8124679242012587`*^9, 3.812467925421208*^9}, {3.817018798278716*^9, 
   3.817018801993883*^9}, {3.8170188992658014`*^9, 3.8170189032839627`*^9}, 
   3.817106357024867*^9, {3.8188029342084785`*^9, 3.8188029368495417`*^9}, {
   3.8249818370839343`*^9, 3.824981845904806*^9}, 3.824983023021001*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[56]:=",ExpressionUUID->"eecac173-9bd3-4c06-b1be-e9c182499ee0"],

Cell[TextData[StyleBox["Mackerel",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.8249811305723004`*^9, 3.824981147166217*^9}, {3.824981363180888*^9, 
   3.8249813648071585`*^9}, 3.824981479497471*^9, 
   3.824983023021001*^9},ExpressionUUID->"70ff68f7-73ff-4517-9eeb-\
5a1051171f3e"],

Cell["Total unprocessed imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.824981481586095*^9, 3.824981483066247*^9}, 
   3.824983023021001*^9},ExpressionUUID->"04f5fbb3-11b5-4ce2-ae21-\
563112d1444e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qmtu0", " ", "=", 
    StyleBox["12751352",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.804851506634692*^9, {
   3.8048591212377567`*^9, 3.8048591249079113`*^9}, {3.8124678137799673`*^9, 
   3.8124678172646904`*^9}, {3.8170184173995*^9, 3.817018422860948*^9}, {
   3.8170185867938905`*^9, 3.817018606582735*^9}, {3.81710631239686*^9, 
   3.817106313623678*^9}, {3.8188026501132503`*^9, 3.818802650507557*^9}, {
   3.824980940032961*^9, 3.8249809404512863`*^9}, {3.8249809719117775`*^9, 
   3.824981003322235*^9}, 3.824983023021001*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[57]:=",ExpressionUUID->"371d9049-7ce7-40f7-b41b-29c4bc91fb4b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pmtu0", " ", "=", "2.76512"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851748049161*^9, {3.8048593936292486`*^9, 
   3.804859397458267*^9}, {3.812468005963946*^9, 3.8124680103343406`*^9}, {
   3.8170190751397657`*^9, 3.817019078898097*^9}, {3.817019224620341*^9, 
   3.817019281913127*^9}, 3.817106714412834*^9, {3.8171068165908794`*^9, 
   3.8171068233977532`*^9}, {3.81880313177389*^9, 3.8188031667572317`*^9}, {
   3.8249812468024006`*^9, 3.82498125895286*^9}, 3.824983023022001*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[58]:=",ExpressionUUID->"aac04036-7655-40bb-aad7-1dc7991d1003"],

Cell["Total processed imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.824981481586095*^9, 3.824981483066247*^9}, {
   3.824982100839331*^9, 3.824982100985444*^9}, 
   3.824983023022001*^9},ExpressionUUID->"d77feda2-b240-4e67-b4fa-\
cff0d2e4c083"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qmtp0", " ", "=", 
    StyleBox["20583069",
     FontColor->GrayLevel[0]]}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.804851523748412*^9, {3.8048591766858854`*^9, 
   3.80485918053025*^9}, {3.812467856371251*^9, 3.812467859619789*^9}, {
   3.8170184824291873`*^9, 3.8170184869126496`*^9}, {3.817018616549312*^9, 
   3.8170186421404085`*^9}, {3.8171063312445707`*^9, 
   3.8171063323127375`*^9}, {3.818802789643695*^9, 3.8188027980402203`*^9}, {
   3.8249821524535236`*^9, 3.8249821635881925`*^9}, 3.824983023022001*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[59]:=",ExpressionUUID->"fc53ee63-8e40-4683-b321-8821e0a01696"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pmtp0", " ", "=", "3.63618"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.804851783996252*^9, {
   3.8048594463590517`*^9, 3.8048594494689245`*^9}, {3.804859487327943*^9, 
   3.8048594931426477`*^9}, {3.8048659293832474`*^9, 
   3.8048659328369255`*^9}, {3.812468071528878*^9, 3.812468074295027*^9}, {
   3.817019107247551*^9, 3.817019110772709*^9}, {3.8170194403759403`*^9, 
   3.8170194868641224`*^9}, {3.817106686484783*^9, 3.8171067043922687`*^9}, {
   3.817106867203182*^9, 3.817106870414147*^9}, 3.818803231925949*^9, {
   3.8188033145051303`*^9, 3.8188033506472197`*^9}, {3.824982140436164*^9, 
   3.8249821679385834`*^9}, 3.824983023022001*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[60]:=",ExpressionUUID->"a19c8c06-1203-453b-97b9-81d7697dca09"],

Cell["Illegal imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249810181827993`*^9, 3.824981019918154*^9}, {
   3.8249814857603445`*^9, 3.8249814872014704`*^9}, {3.8249820939950013`*^9, 
   3.8249820951659107`*^9}, 
   3.824983023022001*^9},ExpressionUUID->"7171352e-8d71-4f6a-b1d6-\
30fb4a0fa74d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qmiu0", " ", "=", 
    StyleBox["1575693",
     FontColor->GrayLevel[0]]}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.804851544345194*^9, {3.804859222792143*^9, 
   3.8048592281838903`*^9}, {3.812467897823643*^9, 3.812467900136449*^9}, {
   3.8170187745068564`*^9, 3.81701877865279*^9}, {3.8170189149451647`*^9, 
   3.8170189337452602`*^9}, {3.8171063459738607`*^9, 
   3.8171063471023893`*^9}, {3.8188028693367767`*^9, 
   3.8188028729506025`*^9}, {3.8249813806474895`*^9, 3.8249814085252028`*^9}, 
   3.824983023022001*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[61]:=",ExpressionUUID->"7d33a6af-ed15-4356-8e81-ee1b51ecb618"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qmip0", " ", "=", 
    StyleBox["3350876",
     FontColor->GrayLevel[0]]}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515613793716`*^9, {3.804859261769577*^9, 3.8048592662859316`*^9}, {
   3.8124679301479034`*^9, 3.812467932588809*^9}, {3.8170188052906637`*^9, 
   3.8170188091020966`*^9}, {3.8170189441401615`*^9, 3.81701897129709*^9}, {
   3.8171063595446568`*^9, 3.8171063605910435`*^9}, {3.818802953501559*^9, 
   3.8188029571394033`*^9}, {3.824982174413622*^9, 3.8249821841982417`*^9}, 
   3.824983023022001*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[62]:=",ExpressionUUID->"35bf12f1-9497-43a8-93f9-a343c7e57c0a"],

Cell["Calculation of legal imports ", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.799061046869288*^9, 3.799061055183115*^9}, {
   3.799791360292451*^9, 3.7997914000229187`*^9}, {3.799791698056525*^9, 
   3.7997916983378224`*^9}, {3.7997917503203683`*^9, 3.799791755353649*^9}, {
   3.800692812549324*^9, 3.800692822846528*^9}, {3.8249829620275087`*^9, 
   3.824982964726609*^9}, 
   3.824983023022001*^9},ExpressionUUID->"cd6f868f-52a1-4b7d-bdd8-\
1e0c25075729"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qslu0", " ", "=", " ", 
   RowBox[{"qstu0", "-", "qsiu0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516193628035`*^9}, 
   3.8249829684975433`*^9, 3.8249830230230017`*^9},
 CellLabel->"In[63]:=",ExpressionUUID->"411685ec-4e7e-4e82-ae79-6c9d904a1b83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qslp0", " ", "=", " ", 
   RowBox[{"qstp0", "-", "qsip0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516228761787`*^9}, 3.8249829707933316`*^9, 3.8249830230230017`*^9},
 CellLabel->"In[64]:=",ExpressionUUID->"34e10a13-0897-4126-a042-cb29ac11441b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qhlu0", " ", "=", " ", 
   RowBox[{"qhtu0", "-", "qhiu0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516271213703`*^9}, 
   3.824982972984039*^9, 3.8249830230230017`*^9},
 CellLabel->"In[65]:=",ExpressionUUID->"6db908f8-9ec3-41b6-8085-74a4b5f16e26"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qhlp0", " ", "=", " ", 
   RowBox[{"qhtp0", "-", "qhip0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516321373944`*^9}, 3.8249829751817474`*^9, 3.8249830230230017`*^9},
 CellLabel->"In[66]:=",ExpressionUUID->"47372b87-46e4-4e84-abb6-b4b18d167dd3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qalu0", " ", "=", " ", 
   RowBox[{"qatu0", "-", "qaiu0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516376071844`*^9}, 
   3.8249829787164993`*^9, 3.8249830230230017`*^9},
 CellLabel->"In[67]:=",ExpressionUUID->"5cef1721-b569-43ee-b7b4-73bb1e65ec8f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qalp0", " ", "=", " ", 
   RowBox[{"qatp0", "-", "qaip0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516080308895`*^9}, {3.804851639935667*^9, 3.8048516418820176`*^9}, 
   3.824982981008286*^9, 3.8249830230230017`*^9},
 CellLabel->"In[68]:=",ExpressionUUID->"72241c77-9f0f-489b-8a81-f6b0d3b357f1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qmlu0", " ", "=", " ", 
   RowBox[{"qmtu0", "-", "qmiu0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516110447454`*^9}, {
   3.804851645028388*^9, 3.8048516486545525`*^9}, 3.824982984749199*^9, 
   3.8249830230230017`*^9},
 CellLabel->"In[69]:=",ExpressionUUID->"7642a00a-7e5c-4224-8711-9ffc11e1be68"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qmlp0", " ", "=", " ", 
   RowBox[{"qmtp0", "-", "qmip0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516144799304`*^9}, {3.8048516517171288`*^9, 3.804851653045458*^9}, 
   3.824982986799796*^9, 3.824983023024003*^9},
 CellLabel->"In[70]:=",ExpressionUUID->"912b37a4-b188-4750-8262-c62c624d05cf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.4 Export Quantities", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672744603273*^9}, {
   3.8196728121258554`*^9, 3.8196728122829847`*^9}, {3.819815211108224*^9, 
   3.8198152128205585`*^9}, 3.81981526037964*^9, 
   3.825007774600871*^9},ExpressionUUID->"aa24486a-5d0a-4f46-8242-\
567c41c34ef1"],

Cell[TextData[StyleBox["Source:National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries). NOAA US \
Trade in Fishery Products database. Accessed September 1, 2020. \
https://foss.nmfs.noaa.gov/apexfoss/f?p=215:2:14884747663545::NO",
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, 
   3.819814602882104*^9, {3.8198147741606445`*^9, 3.8198147935287457`*^9}, {
   3.819815219280593*^9, 3.81981526037964*^9}, {3.819815772355571*^9, 
   3.8198157737996855`*^9}, 3.825007774600871*^9},
 FontSize->12,ExpressionUUID->"e0770484-edb2-46de-b58c-215c4beeab57"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdue0", " ", "=", "0"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.8048518506428456`*^9}, {3.8250077439750223`*^9, 
   3.825007774600871*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[71]:=",ExpressionUUID->"d36c758b-7ed8-4713-92ae-51ee7315a7bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdpe0", " ", "=", "  ", "0"}], ";"}], "  ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.80485185308072*^9}, {
   3.82500774909901*^9, 3.825007774600871*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[72]:=",ExpressionUUID->"f5a00f2e-1382-4412-b39c-d22462e02472"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhdue0", " ", "=", "24393816"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.8048518633108516`*^9}, {3.804859565020601*^9, 
   3.8048595675211444`*^9}, {3.814820672498847*^9, 3.814820676293739*^9}, {
   3.8250077503850145`*^9, 3.825007774600871*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[73]:=",ExpressionUUID->"ebbcdefa-e8b4-418d-bbcc-8a1406b8ea24"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhdpe0", " ", "=", "  ", "70366"}], ";"}], "  ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.804851865652524*^9}, {
   3.8048595759473476`*^9, 3.8048595789792566`*^9}, {3.8148206562115355`*^9, 
   3.8148206605738297`*^9}, {3.825007751548919*^9, 3.825007774600871*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[74]:=",ExpressionUUID->"3302594c-3311-486c-975d-02c4f6420f26"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadue0", " ", "=", "976448"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.804851867681604*^9}, {3.8048595877155313`*^9, 
   3.804859590950609*^9}, {3.8250077525406914`*^9, 3.825007774600871*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[75]:=",ExpressionUUID->"1673fb4d-d680-490d-a146-b94de2c1ce9e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadpe0", " ", "=", "  ", "920018"}], ";"}], "  ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.8048518697629004`*^9}, {
   3.8048595996715755`*^9, 3.804859601859536*^9}, {3.825007753513452*^9, 
   3.8250077746018724`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[76]:=",ExpressionUUID->"6a1cb2bd-9ccd-4c6e-a7ca-0c0cc8e3fd86"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qmdue0", " ", "=", "44884808"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.804851871981992*^9}, {3.804859615581441*^9, 
   3.804859619692989*^9}, {3.8250077544561844`*^9, 3.8250077746018724`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[77]:=",ExpressionUUID->"778b1d34-2b16-4641-afe4-958ffaa66eba"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qmdpe0", " ", "=", "  ", "19330"}], ";"}], "  ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.8048518740604353`*^9}, {
   3.8048596312446957`*^9, 3.8048596325730925`*^9}, {3.82500775591932*^9, 
   3.8250077746018724`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[78]:=",ExpressionUUID->"17bf2afb-74a4-4899-a403-1ee2cb2495d4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.5 Catch Limits", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672709332239*^9}, {
   3.819672747951029*^9, 3.819672752938134*^9}, {3.819672814932173*^9, 
   3.8196728150802965`*^9}, 3.8198153194016666`*^9, 
   3.8250241781979237`*^9},ExpressionUUID->"0ced3238-6152-456e-ae55-\
92955302da4c"],

Cell[TextData[StyleBox["Sardine",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.819815276384116*^9, 3.819815279760747*^9}, 
   3.8198153194026575`*^9, {3.825007835683432*^9, 3.825007836454032*^9}, {
   3.8250241515641828`*^9, 3.825024178198924*^9}},
 FontWeight->"Plain",ExpressionUUID->"a58a66f0-a95b-487b-8515-59a08e11f104"],

Cell[TextData[StyleBox["Source: 82 Fed. Reg. 29776 (June 30, 2018)",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934406567`*^9, 3.8250232599285984`*^9, 3.8250234385889854`*^9, {
   3.8250235568550773`*^9, 3.825023650634104*^9}, {3.8250241515651827`*^9, 
   3.825024178198924*^9}},ExpressionUUID->"919b1cdc-78c3-4722-9e42-\
640189488d70"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdcap", " ", "=", "8000000"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.804851796545054*^9, 
   3.8048952007649207`*^9, {3.804895250483545*^9, 3.8048952544374237`*^9}, {
   3.809174282526044*^9, 3.809174311934317*^9}, {3.8100356823602877`*^9, 
   3.8100356825854626`*^9}, {3.8250078554838524`*^9, 3.82500785857526*^9}, {
   3.8250241515651827`*^9, 3.825024178198924*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[79]:=",ExpressionUUID->"802c6b9b-1962-431d-b17b-a621193520c7"],

Cell[TextData[StyleBox["Herring",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.819815276384116*^9, 3.819815279760747*^9}, 
   3.8198153194026575`*^9, {3.825007835683432*^9, 3.8250078459954624`*^9}, {
   3.8250241515651827`*^9, 3.825024178198924*^9}},
 FontWeight->"Plain",ExpressionUUID->"d009db3a-da57-4c3a-9848-44742eaef7df"],

Cell[TextData[StyleBox["No aggregate ACL available, inserted arbitrarily high \
limit so it doesn\[CloseCurlyQuote]t affect calculation. ",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934406567`*^9, 3.8250232599285984`*^9, 3.8250234385889854`*^9, {
   3.8250235568550773`*^9, 3.825023721715456*^9}, {3.8250241515651827`*^9, 
   3.825024178198924*^9}},ExpressionUUID->"422530ff-18da-4d53-abf8-\
b618ec1dd26c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhdcap", " ", "=", "200000000"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.8048517992485948`*^9, {
   3.8048952270850687`*^9, 3.8048952446230383`*^9}, {3.825007818658174*^9, 
   3.825007819928165*^9}, {3.82502369362158*^9, 3.825023693701642*^9}, {
   3.8250241515651827`*^9, 3.825024178198924*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[80]:=",ExpressionUUID->"cb959750-59dd-405b-8ff0-098877582c11"],

Cell[TextData[StyleBox["Anchovy",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.819815276384116*^9, 3.819815279760747*^9}, 
   3.8198153194026575`*^9, {3.825007835683432*^9, 3.825007849925522*^9}, {
   3.8250241515651827`*^9, 3.825024178198924*^9}},
 FontWeight->"Plain",ExpressionUUID->"077c3aa7-41d8-4cfa-97ed-200128de5ce3"],

Cell[TextData[StyleBox["Source: Pacific Fishery Management Council, \
\[OpenCurlyDoubleQuote]Annual Season Management,\[CloseCurlyDoubleQuote] \
accessed November 19, 2020. \
https://www.pcouncil.org/current-season-management/",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934406567`*^9, 3.8250232599285984`*^9, 3.8250234385889854`*^9, {
   3.8250235568550773`*^9, 3.825023650634104*^9}, 3.825023811443327*^9, {
   3.8250238929357877`*^9, 3.8250238957149534`*^9}, {3.8250241515651827`*^9, 
   3.825024178198924*^9}},ExpressionUUID->"ec69fdba-0c82-41f3-a5d6-\
c7f09f46d0ac"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadcap", " ", "=", "34750000"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.8048518024053288`*^9, 
   3.8048952209520655`*^9, 3.8048952578286753`*^9, {3.8250078619749055`*^9, 
   3.82500786356415*^9}, {3.8250241515651827`*^9, 3.8250241781999254`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[81]:=",ExpressionUUID->"63bde8db-8dca-4231-b99b-9dc06652c0ae"],

Cell[TextData[StyleBox["Mackerel",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.819815276384116*^9, 3.819815279760747*^9}, 
   3.8198153194026575`*^9, {3.825007835683432*^9, 3.8250078532340984`*^9}, {
   3.825024151566184*^9, 3.8250241781999254`*^9}},
 FontWeight->"Plain",ExpressionUUID->"502055fe-4923-4c04-b0e1-a40cb5edfc91"],

Cell[TextData[StyleBox["Source: Aggregated several ACLs for jack, Atlantic, \
chub, king, Spanish, and atka mackerel species.",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934406567`*^9, 3.8250232599285984`*^9, 3.8250234385889854`*^9, {
   3.8250235568550773`*^9, 3.825023650634104*^9}, 3.825023811443327*^9, {
   3.8250238929357877`*^9, 3.8250238957149534`*^9}, {3.8250240489993153`*^9, 
   3.825024057391852*^9}, {3.825024115256913*^9, 
   3.8250241781999254`*^9}},ExpressionUUID->"44895ff3-aedc-49cc-b1bf-\
214b0b34b901"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qmdcap", " ", "=", "180605093"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.804851805171688*^9, {
   3.8048961193381124`*^9, 3.804896138325565*^9}, {3.810035661841364*^9, 
   3.810035670228873*^9}, {3.825007865544701*^9, 3.8250078665234675`*^9}, {
   3.825024151566184*^9, 3.8250241781999254`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[82]:=",ExpressionUUID->"fc85e40d-813d-4459-9fa3-8bef78a8fce4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.6 Import Market Share Statistics", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8199018381766195`*^9, 3.8199018609792204`*^9}, 
   3.819901901056156*^9, 3.8199024672872863`*^9, 
   3.825024287532875*^9},ExpressionUUID->"aa55cf88-7c3e-4f9d-bbd3-\
d191f4c11cd2"],

Cell["Imports percent in market for unprocessed sardine", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812493252545861*^9, 3.812493267125186*^9}, 
   3.819901901056156*^9, {3.8250242026739826`*^9, 3.8250242033945427`*^9}, 
   3.825024287532875*^9},ExpressionUUID->"cb5f6345-f668-41e2-939a-\
35b4edd77e67"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qstu0", "/", 
   RowBox[{"(", 
    RowBox[{"qstu0", "+", 
     RowBox[{"(", 
      RowBox[{"qsdu0", "-", "qsdue0", "-", 
       RowBox[{"cr", " ", "qsdp0"}]}], ")"}]}], ")"}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812553355154831*^9, 3.812553378224863*^9}, 
   3.825024287532875*^9},
 CellLabel->"In[83]:=",ExpressionUUID->"26c97edf-5357-4b28-ae2b-e367fee89bac"],

Cell[BoxData["0.9396970092424366`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{
  3.812553392133732*^9, 3.8125534460268555`*^9, 3.812731704349012*^9, 
   3.81273302744571*^9, 3.812821237195101*^9, 3.8129267655958357`*^9, 
   3.81292712781769*^9, 3.8129275131766033`*^9, 3.812975339947261*^9, 
   3.8129756333775945`*^9, 3.8148206852455244`*^9, 3.8154767741080017`*^9, 
   3.8157742149992523`*^9, 3.8170195465027304`*^9, 3.817106781984259*^9, 
   3.8171068293029814`*^9, 3.8171068773140893`*^9, 3.818803379780863*^9, 
   3.824982998459875*^9, {3.8250242755618725`*^9, 3.825024287532875*^9}, 
   3.82507481528695*^9},
 CellLabel->"Out[83]=",ExpressionUUID->"8a818572-310c-4bc4-b852-d63ef62175d3"],

Cell["Imports percent in market for processed sardine", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812493252545861*^9, 3.812493267125186*^9}, 
   3.819901901056156*^9, {3.8250242115348835`*^9, 3.825024216022378*^9}, 
   3.825024287532875*^9},ExpressionUUID->"8489ec30-c0ac-416b-b687-\
4315e3651e96"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qstp0", "/", 
   RowBox[{"(", 
    RowBox[{"qstp0", "+", 
     RowBox[{"(", 
      RowBox[{"qsdp0", "-", "qsdpe0"}], ")"}]}], ")"}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812553402830097*^9, 3.8125534139167614`*^9}, 
   3.825024287532875*^9},
 CellLabel->"In[84]:=",ExpressionUUID->"b196eb43-e66e-4bcc-bbec-1a44c0528e87"],

Cell[BoxData["0.9987957618560366`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{
  3.8125534158332567`*^9, 3.8125534461719685`*^9, 3.8127317044621005`*^9, 
   3.8127330275678053`*^9, 3.812821237312192*^9, 3.812926765749956*^9, 
   3.8129271279327793`*^9, 3.812927513329722*^9, 3.8129753400253983`*^9, 
   3.8129756335494976`*^9, 3.8148206855017004`*^9, 3.815476774264278*^9, 
   3.81577421519737*^9, 3.8170195465167418`*^9, 3.8171067819962683`*^9, 
   3.817106829314991*^9, 3.8171068773260984`*^9, 3.818803379793873*^9, 
   3.824982998623002*^9, {3.8250242760052204`*^9, 3.8250242875338755`*^9}, 
   3.825074815443226*^9},
 CellLabel->"Out[84]=",ExpressionUUID->"baa7dda2-7fc7-4135-a7a7-cabf8a000261"],

Cell["Imports percent in market for unprocessed herring", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812493252545861*^9, 3.812493267125186*^9}, 
   3.819901901056156*^9, {3.8250242235682526`*^9, 3.825024224232771*^9}, 
   3.8250242875338755`*^9},ExpressionUUID->"68719266-1062-4c1b-b27a-\
23a43df92586"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qhtu0", "/", 
   RowBox[{"(", 
    RowBox[{"qhtu0", "+", 
     RowBox[{"(", 
      RowBox[{"qhdu0", "-", "qhdue0", "-", 
       RowBox[{"cr", " ", "qhdp0"}]}], ")"}]}], ")"}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812553355154831*^9, 3.812553378224863*^9}, {
   3.812553423448208*^9, 3.8125534339344025`*^9}, 3.8250242875338755`*^9},
 CellLabel->"In[85]:=",ExpressionUUID->"51abde27-af92-45c5-a591-a7443fbdcbd3"],

Cell[BoxData["0.058660263383417004`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{
  3.812553392133732*^9, 3.81255344630107*^9, 3.812731704570185*^9, 
   3.812733027681895*^9, 3.8128212374252796`*^9, 3.8129267659090796`*^9, 
   3.812927128090902*^9, 3.812927513477837*^9, 3.812975340134791*^9, 
   3.812975633737028*^9, 3.814820685802951*^9, 3.815476774420554*^9, 
   3.815774215364523*^9, 3.8170195465297513`*^9, 3.81710678201128*^9, 
   3.817106829328001*^9, 3.8171068773391085`*^9, 3.8188033798058825`*^9, 
   3.8249829987521024`*^9, {3.825024276136323*^9, 3.8250242875338755`*^9}, 
   3.8250748155526185`*^9},
 CellLabel->"Out[85]=",ExpressionUUID->"a35cfd0b-75bd-44d9-af91-5404b7e15bd1"],

Cell["Imports percent in market for processed herring", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812493252545861*^9, 3.812493267125186*^9}, 
   3.819901901056156*^9, {3.825024228371994*^9, 3.8250242314413853`*^9}, 
   3.8250242875338755`*^9},ExpressionUUID->"4b094860-81af-4f12-b669-\
3249c5227e22"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qhtp0", "/", 
   RowBox[{"(", 
    RowBox[{"qhtp0", "+", 
     RowBox[{"(", 
      RowBox[{"qhdp0", "-", "qhdpe0"}], ")"}]}], ")"}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812553402830097*^9, 3.812553442392014*^9}, 
   3.8250242875338755`*^9},
 CellLabel->"In[86]:=",ExpressionUUID->"20ee38db-a017-4b42-94b2-476449a492c5"],

Cell[BoxData["0.8050489294283056`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{
  3.8125534158332567`*^9, 3.8125534464261675`*^9, 3.8127317046842747`*^9, 
   3.8127330277999873`*^9, 3.812821237535365*^9, 3.812926766067213*^9, 
   3.8129271282460227`*^9, 3.8129275136369605`*^9, 3.8129753403067107`*^9, 
   3.8129756339089303`*^9, 3.814820686098188*^9, 3.8154767746080847`*^9, 
   3.8157742155326185`*^9, 3.817019546542762*^9, 3.8171067820242906`*^9, 
   3.8171068293410106`*^9, 3.8171068773521414`*^9, 3.818803379819893*^9, 
   3.8249829988852053`*^9, {3.8250242762624216`*^9, 3.8250242875338755`*^9}, 
   3.825074815708894*^9},
 CellLabel->"Out[86]=",ExpressionUUID->"d20a9bb6-a7e7-4e11-a255-5b4ca0995c8f"],

Cell["Imports percent in market for unprocessed anchovy", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812493252545861*^9, 3.812493267125186*^9}, 
   3.819901901056156*^9, {3.8250242359729147`*^9, 3.8250242384108124`*^9}, 
   3.8250242875338755`*^9},ExpressionUUID->"8ec91a21-cb47-4fb3-8835-\
90c5e8946897"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qatu0", "/", 
   RowBox[{"(", 
    RowBox[{"qatu0", "+", 
     RowBox[{"(", 
      RowBox[{"qadu0", "-", "qadue0", "-", 
       RowBox[{"cr", " ", "qadp0"}]}], ")"}]}], ")"}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812553355154831*^9, 3.812553378224863*^9}, {
   3.812553423448208*^9, 3.8125534339344025`*^9}, {3.8125535038820753`*^9, 
   3.812553511216808*^9}, 3.825024287534876*^9},
 CellLabel->"In[87]:=",ExpressionUUID->"b6eda0bc-28d5-4476-8dad-8069d73c989c"],

Cell[BoxData["0.16136093473792607`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{
  3.812553392133732*^9, 3.81255344630107*^9, 3.812553524487176*^9, 
   3.8127317047983637`*^9, 3.8127330279150777`*^9, 3.8128212376504545`*^9, 
   3.8129267662373343`*^9, 3.812927128400143*^9, 3.8129275137840877`*^9, 
   3.8129753404785976`*^9, 3.812975634096461*^9, 3.8148206863863707`*^9, 
   3.8154767747643614`*^9, 3.815774215699749*^9, 3.817019546556772*^9, 
   3.8171067820383015`*^9, 3.8171068293540792`*^9, 3.8171068773652925`*^9, 
   3.8188033798339443`*^9, 3.824982999018309*^9, {3.82502427633748*^9, 
   3.825024287534876*^9}, 3.8250748158495417`*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"f03c1698-e972-4d9a-b519-730767ea6494"],

Cell["Imports percent in market for processed anchovy", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812493252545861*^9, 3.812493267125186*^9}, 
   3.819901901056156*^9, {3.8250242440642133`*^9, 3.8250242462168922`*^9}, 
   3.825024287534876*^9},ExpressionUUID->"fc33bb92-0a12-4534-8e3c-\
d71b0cb4455a"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qatp0", "/", 
   RowBox[{"(", 
    RowBox[{"qatp0", "+", 
     RowBox[{"(", 
      RowBox[{"qadp0", "-", "qadpe0"}], ")"}]}], ")"}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812553402830097*^9, 3.812553442392014*^9}, {
   3.8125535139759626`*^9, 3.812553519971652*^9}, 3.825024287534876*^9},
 CellLabel->"In[88]:=",ExpressionUUID->"180d45ff-8508-4d6a-8759-a65dfd8c9b6b"],

Cell[BoxData["0.4366655446999572`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{
  3.8125534158332567`*^9, 3.8125534464261675`*^9, 3.8125535246342916`*^9, 
   3.812731704973501*^9, 3.8127330280301676`*^9, 3.812821237765544*^9, 
   3.812926766380469*^9, 3.812927128558267*^9, 3.812927513935192*^9, 
   3.8129753406505003`*^9, 3.812975634268382*^9, 3.814820686691613*^9, 
   3.815476774936265*^9, 3.815774215868889*^9, 3.81701954657032*^9, 
   3.8171067820523806`*^9, 3.817106829367196*^9, 3.8171068773783026`*^9, 
   3.8188033798469152`*^9, 3.824982999169427*^9, {3.825024276465581*^9, 
   3.825024287534876*^9}, 3.82507481599019*^9},
 CellLabel->"Out[88]=",ExpressionUUID->"9f90b99c-ab0b-4542-9c4f-15b837198437"],

Cell["Imports percent in market for unprocessed mackerel", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812493252545861*^9, 3.812493267125186*^9}, 
   3.819901901056156*^9, {3.8250242518422933`*^9, 3.825024252904125*^9}, 
   3.825024287534876*^9},ExpressionUUID->"c49ee32d-7110-40fb-80eb-\
3468c9a537c6"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qmtu0", "/", 
   RowBox[{"(", 
    RowBox[{"qmtu0", "+", 
     RowBox[{"(", 
      RowBox[{"qmdu0", "-", "qmdue0", "-", 
       RowBox[{"cr", " ", "qmdp0"}]}], ")"}]}], ")"}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812553355154831*^9, 3.812553378224863*^9}, {
   3.812553423448208*^9, 3.8125534339344025`*^9}, {3.8125535038820753`*^9, 
   3.812553511216808*^9}, {3.8125535433559237`*^9, 3.8125535535068617`*^9}, 
   3.825024287534876*^9},
 CellLabel->"In[89]:=",ExpressionUUID->"11bc5f2e-f864-4b5f-a818-6bd7f715c50b"],

Cell[BoxData["0.8576009452383343`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{
  3.812553392133732*^9, 3.81255344630107*^9, 3.812553524487176*^9, 
   3.8125535674757776`*^9, 3.8127317050855894`*^9, 3.812733028145258*^9, 
   3.8128212378786316`*^9, 3.8129267665335646`*^9, 3.8129271287133884`*^9, 
   3.8129275140893126`*^9, 3.812975340822403*^9, 3.812975634440278*^9, 
   3.8148206869117713`*^9, 3.8154767751081676`*^9, 3.8157742160380297`*^9, 
   3.817019546583711*^9, 3.81710678206548*^9, 3.8171068293792057`*^9, 
   3.8171068773913126`*^9, 3.818803379860925*^9, 3.824982999304531*^9, {
   3.8250242765416403`*^9, 3.825024287534876*^9}, 3.8250748161308365`*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"690b9bf3-29c9-452a-9c6a-3ce7e465e11c"],

Cell["Imports percent in market for processed mackerel", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812493252545861*^9, 3.812493267125186*^9}, 
   3.819901901056156*^9, {3.8250242589598684`*^9, 
   3.825024287535877*^9}},ExpressionUUID->"67e0f873-1e13-4475-a35e-\
702f6f8dfd68"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qmtp0", "/", 
   RowBox[{"(", 
    RowBox[{"qmtp0", "+", 
     RowBox[{"(", 
      RowBox[{"qmdp0", "-", "qmdpe0"}], ")"}]}], ")"}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.812553402830097*^9, 3.812553442392014*^9}, {
   3.8125535139759626`*^9, 3.812553519971652*^9}, {3.812553556727378*^9, 
   3.8125535636087546`*^9}, 3.825024287535877*^9},
 CellLabel->"In[90]:=",ExpressionUUID->"88cd67b6-e63a-4a64-b3a6-f6df36eefbbb"],

Cell[BoxData["0.3380099512830812`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{
  3.8125534158332567`*^9, 3.8125534464261675`*^9, 3.8125535246342916`*^9, 
   3.8125535676308985`*^9, 3.8127317051986775`*^9, 3.812733028259347*^9, 
   3.8128212379917197`*^9, 3.812926766676676*^9, 3.812927128862505*^9, 
   3.8129275142394285`*^9, 3.8129753409943056`*^9, 3.8129756346121697`*^9, 
   3.8148206870518885`*^9, 3.8154767752644444`*^9, 3.8157742162251663`*^9, 
   3.817019546595721*^9, 3.817106782079491*^9, 3.8171068293922157`*^9, 
   3.8171068774043226`*^9, 3.8188033798739357`*^9, 3.82498299943163*^9, {
   3.8250242766787477`*^9, 3.825024287535877*^9}, 3.825074816287113*^9},
 CellLabel->"Out[90]=",ExpressionUUID->"46a70965-e6c4-4522-b986-9572530c0aae"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3. Calibration",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.7954529786642447`*^9}, {
  3.79545386036082*^9, 3.7954538618860044`*^9}, {3.819900448697421*^9, 
  3.8199004491007357`*^9}},ExpressionUUID->"e502def5-8a63-4c3c-ad7c-\
370aa74ed64a"],

Cell["\<\
Baseline values of unprocessed and processed apparent consumption and imports\
\>", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7954541868300085`*^9, 3.7954542200368147`*^9}, {
  3.795455624690459*^9, 3.7954556275947175`*^9}, {3.795532637283266*^9, 
  3.7955326380308447`*^9}, {3.799794880332456*^9, 3.79979488120757*^9}, {
  3.801667655660522*^9, 3.801667670402505*^9}, {3.8199000703965473`*^9, 
  3.8199001199411907`*^9}},ExpressionUUID->"9bf2c48f-35a3-4d8f-94b2-\
74ffec7cb163"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vstu0", "=", 
   RowBox[{"qstu0", " ", "pstu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.8048519125993204`*^9, 3.804851917644553*^9}},
 CellLabel->"In[91]:=",ExpressionUUID->"9d5a52cf-3316-4cb2-80ab-9c9bede1d617"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vstp0", "=", 
   RowBox[{"qstp0", " ", "pstp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519143027067`*^9, 3.804851921426384*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"563be225-6049-49ee-806a-d676b042abd2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vhtu0", "=", 
   RowBox[{"qhtu0", " ", "phtu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851926580485*^9, 3.8048519296747103`*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"586a9c09-4290-443b-bf7d-c0d9a9d73e0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vhtp0", "=", 
   RowBox[{"qhtp0", " ", "phtp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519311436853`*^9, 3.804851933990306*^9}},
 CellLabel->"In[94]:=",ExpressionUUID->"64e92a99-a9c8-424b-ad08-340b3749b512"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vatu0", "=", 
   RowBox[{"qatu0", " ", "patu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851936162515*^9, 3.8048519393476534`*^9}},
 CellLabel->"In[95]:=",ExpressionUUID->"d41b583f-dae0-48e9-b4c3-be318f3fd670"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vatp0", "=", 
   RowBox[{"qatp0", " ", "patp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519407330923`*^9, 3.8048519441135435`*^9}},
 CellLabel->"In[96]:=",ExpressionUUID->"4ff425df-281f-4ea5-98ba-80b9dac98a0d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vmtu0", "=", 
   RowBox[{"qmtu0", " ", "pmtu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851948303916*^9, 3.804851950926388*^9}},
 CellLabel->"In[97]:=",ExpressionUUID->"bcd1b8c2-12df-4a34-b46e-55c2ab4cc24e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vmtp0", "=", 
   RowBox[{"qmtp0", " ", "pmtp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519523417597`*^9, 3.804851955436349*^9}},
 CellLabel->"In[98]:=",ExpressionUUID->"7ba43ca5-42d7-4dd1-9e4d-54130dec78d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vsdu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qsdu0", "-", "qsdue0", "-", 
      RowBox[{"cr", " ", "qsdp0"}]}], ")"}], " ", "psdu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.8048519638260803`*^9, 3.8048519716484485`*^9}, {
   3.8048598918387938`*^9, 3.804859912733159*^9}, {3.804860064780347*^9, 
   3.804860071891223*^9}, 3.8048664223456783`*^9},
 CellLabel->"In[99]:=",ExpressionUUID->"a3ab304f-2aee-4fbd-bfd7-6f5a12f02f88"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vsdp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qsdp0", "-", "qsdpe0"}], ")"}], " ", "psdp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.804851974426258*^9, 3.80485197968615*^9}},
 CellLabel->
  "In[100]:=",ExpressionUUID->"3f3f71a9-fce2-4be4-b505-60d2d9a2083c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vhdu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qhdu0", "-", "qhdue0", "-", 
      RowBox[{"cr", " ", "qhdp0"}]}], ")"}], " ", "phdu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.8048519828841496`*^9, 3.804851990206542*^9}, {
   3.8048598935265956`*^9, 3.8048599148897953`*^9}, {3.8048600789598665`*^9, 
   3.804860083476311*^9}, 3.804866425674345*^9},
 CellLabel->
  "In[101]:=",ExpressionUUID->"719d6bd9-ab83-433d-bc57-a6b508965f6b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vhdp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qhdp0", "-", "qhdpe0"}], ")"}], " ", "phdp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.804851992378751*^9, 3.8048520018629837`*^9}},
 CellLabel->
  "In[102]:=",ExpressionUUID->"ca4a1562-a6dc-469b-905d-0d39aef96b5a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vadu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qadu0", "-", "qadue0", "-", 
      RowBox[{"cr", " ", "qadp0"}]}], ")"}], " ", "padu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.804852007460396*^9, 3.804852013220827*^9}, {
   3.80485989505812*^9, 3.8048599170464315`*^9}, {3.8048600866018105`*^9, 
   3.8048600916988807`*^9}, 3.8048664286460667`*^9},
 CellLabel->
  "In[103]:=",ExpressionUUID->"12c30e9d-754a-45e0-8c39-1b72a9f6c4ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vadp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qadp0", "-", "qadpe0"}], ")"}], " ", "padp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.8048520162475986`*^9, 3.8048520205763884`*^9}},
 CellLabel->
  "In[104]:=",ExpressionUUID->"288ea92c-c9be-4ba0-82d7-1acdbbeb49ee"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vmdu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qmdu0", "-", "qmdue0", "-", 
      RowBox[{"cr", " ", "qmdp0"}]}], ")"}], " ", "pmdu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.804852022920974*^9, 3.804852030499457*^9}, {
   3.804859896652155*^9, 3.804859921734771*^9}, {3.8048600950900917`*^9, 
   3.8048600972310853`*^9}, 3.804866433404766*^9},
 CellLabel->
  "In[105]:=",ExpressionUUID->"b2ccd627-d7eb-4881-8b69-b0a9aa854d3c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vmdp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qmdp0", "-", "qmdpe0"}], ")"}], " ", "pmdp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.8048520323591175`*^9, 3.804852037110026*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"07cb80e4-b70d-4a54-9c85-400d2cb9ea9b"],

Cell[CellGroupData[{

Cell["3.1 Supply Parameters", "Subsubsection",
 CellChangeTimes->{{3.819902497376732*^9, 3.819902510893259*^9}, 
   3.8250246051964817`*^9},
 CellLabel->
  "In[207]:=",ExpressionUUID->"55c5feb8-4b96-4da8-a13c-0a8db5c1d911"],

Cell[BoxData[
 RowBox[{
  RowBox[{"esdu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"esd", " ", 
     FractionBox["qsdu0", 
      RowBox[{"(", 
       RowBox[{"qsdcap", "-", "qsdu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.804852083303175*^9, 3.804852090898363*^9}, 
   3.8250243522323627`*^9},
 CellLabel->
  "In[107]:=",ExpressionUUID->"251b4ab0-22c0-46e3-b8e5-e9aa3e6836c2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"asdu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qsdcap", "-", "qsdu0"}], ")"}], " ", 
    SuperscriptBox["psdu0", "esdu"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048520933987694`*^9, 
   3.804852099759162*^9}, 3.825024355447868*^9, 3.825024617778281*^9},
 CellLabel->
  "In[108]:=",ExpressionUUID->"84a21240-2395-4207-a627-0bd1de0b1bd2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ehdu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"ehd", " ", 
     FractionBox["qhdu0", 
      RowBox[{"(", 
       RowBox[{"qhdcap", "-", "qhdu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.8048521093589597`*^9, 3.804852115828997*^9}, 
   3.8250243575785227`*^9},
 CellLabel->
  "In[109]:=",ExpressionUUID->"ddefb4fb-ed0b-41c9-b34f-815fdb269d09"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ahdu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qhdcap", "-", "qhdu0"}], ")"}], " ", 
    SuperscriptBox["phdu0", "ehdu"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521184231625`*^9, 
   3.8048521249554644`*^9}, 3.8250243597131877`*^9, 3.825024617778281*^9},
 CellLabel->
  "In[110]:=",ExpressionUUID->"9804a220-ad8a-4ea2-b0a3-d983552dacc8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eadu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"ead", " ", 
     FractionBox["qadu0", 
      RowBox[{"(", 
       RowBox[{"qadcap", "-", "qadu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.8048521327848425`*^9, 3.8048521396333513`*^9}, 
   3.8250243616857233`*^9},
 CellLabel->
  "In[111]:=",ExpressionUUID->"f305acde-6487-41d5-8850-a22925249eb5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aadu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qadcap", "-", "qadu0"}], ")"}], " ", 
    SuperscriptBox["padu0", "eadu"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521436041384`*^9, 
   3.8048521498553686`*^9}, 3.825024368238823*^9, 3.825024617778281*^9},
 CellLabel->
  "In[112]:=",ExpressionUUID->"f5232fbe-62d7-4e00-986d-f2c32840b136"],

Cell[BoxData[
 RowBox[{
  RowBox[{"emdu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"emd", " ", 
     FractionBox["qmdu0", 
      RowBox[{"(", 
       RowBox[{"qmdcap", "-", "qmdu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.8048521589190774`*^9, 3.804852165998335*^9}, 
   3.8250243705055904`*^9},
 CellLabel->
  "In[113]:=",ExpressionUUID->"ac224861-1ffc-4908-a6d4-f00c1b91f388"],

Cell[BoxData[
 RowBox[{
  RowBox[{"amdu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qmdcap", "-", "qmdu0"}], ")"}], " ", 
    SuperscriptBox["pmdu0", "emdu"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521687650814`*^9, 
   3.8048521751254616`*^9}, 3.8250243771827908`*^9, 3.825024617778281*^9},
 CellLabel->
  "In[114]:=",ExpressionUUID->"22c1ee31-aa92-4f38-bac8-c199f7968ae9"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2 Demand Parameters", "Subsubsection",
 CellChangeTimes->{{3.819902513379201*^9, 3.8199025199032784`*^9}, 
   3.8250245970661526`*^9},
 CellLabel->
  "In[216]:=",ExpressionUUID->"8372d459-fe1f-48ec-8641-aee602b2820c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bstu", " ", "=", 
   RowBox[{
    FractionBox["vstu0", "vsdu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pstu0", "psdu0"], ")"}], 
     RowBox[{"sigmasu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852908773026*^9}, 
   3.8250244909924183`*^9},
 CellLabel->
  "In[115]:=",ExpressionUUID->"1bd69a31-8d5e-4be7-ac7b-526a6a7dc4b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdu0", 
       RowBox[{"1", "-", "sigmasu"}]], "+", 
      RowBox[{"bstu", " ", 
       SuperscriptBox["pstu0", 
        RowBox[{"1", "-", "sigmasu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, 3.825024493668502*^9},
 CellLabel->
  "In[116]:=",ExpressionUUID->"bfe09279-c02a-4e14-b37a-2ead85213dd7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bhtu", " ", "=", 
   RowBox[{
    FractionBox["vhtu0", "vhdu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["phtu0", "phdu0"], ")"}], 
     RowBox[{"sigmahu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.8048529305003295`*^9}, 
   3.825024496332576*^9},
 CellLabel->
  "In[117]:=",ExpressionUUID->"d2ca5df3-78b6-49e1-b854-f20b9894de8a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Phu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["phdu0", 
       RowBox[{"1", "-", "sigmahu"}]], "+", 
      RowBox[{"bhtu", " ", 
       SuperscriptBox["phtu0", 
        RowBox[{"1", "-", "sigmahu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmahu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, 3.8250244989826407`*^9},
 CellLabel->
  "In[118]:=",ExpressionUUID->"e9996e19-c9e2-4bad-80d6-e5d1f107f50b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"batu", " ", "=", 
   RowBox[{
    FractionBox["vatu0", "vadu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["patu0", "padu0"], ")"}], 
     RowBox[{"sigmaau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, 
   3.825024500966186*^9},
 CellLabel->
  "In[119]:=",ExpressionUUID->"385ca98f-830d-4059-a353-b4dd92eaff40"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pau0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padu0", 
       RowBox[{"1", "-", "sigmaau"}]], "+", 
      RowBox[{"batu", " ", 
       SuperscriptBox["patu0", 
        RowBox[{"1", "-", "sigmaau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, 3.8250245031769056`*^9},
 CellLabel->
  "In[120]:=",ExpressionUUID->"11633740-7877-4529-9267-5101c3b28f3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bmtu", " ", "=", 
   RowBox[{
    FractionBox["vmtu0", "vmdu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pmtu0", "pmdu0"], ")"}], 
     RowBox[{"sigmamu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.804853007174381*^9, 3.8048530190200768`*^9}, 3.8250245056128044`*^9},
 CellLabel->
  "In[121]:=",ExpressionUUID->"387dcf33-3dbb-4670-99ab-85ffff228603"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pmu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pmdu0", 
       RowBox[{"1", "-", "sigmamu"}]], "+", 
      RowBox[{"bmtu", " ", 
       SuperscriptBox["pmtu0", 
        RowBox[{"1", "-", "sigmamu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmamu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, 3.825024507653392*^9},
 CellLabel->
  "In[122]:=",ExpressionUUID->"764696a7-2ccb-4e84-8698-455b1318fc9e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bhu", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vhdu0", "+", "vhtu0"}], 
     RowBox[{"vsdu0", "+", "vstu0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Phu0", "Psu0"], ")"}], 
     RowBox[{"betau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, 
   3.8250245148059616`*^9},
 CellLabel->
  "In[123]:=",ExpressionUUID->"62eabe97-1954-43ae-855a-7d2c54b35cbd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bau", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vadu0", "+", "vatu0"}], 
     RowBox[{"vsdu0", "+", "vstu0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pau0", "Psu0"], ")"}], 
     RowBox[{"betau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.804853293988452*^9}, 
   3.8250245168365426`*^9},
 CellLabel->
  "In[124]:=",ExpressionUUID->"4d9b0a1f-c966-472a-b552-6af5401f68b8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bmu", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vmdu0", "+", "vmtu0"}], 
     RowBox[{"vsdu0", "+", "vstu0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pmu0", "Psu0"], ")"}], 
     RowBox[{"betau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.8048532815960116`*^9, 3.8048533048189335`*^9}, 3.8250245186569633`*^9},
 CellLabel->
  "In[125]:=",ExpressionUUID->"47587f17-c0fe-4f2d-a12a-ff180e9cd8e7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pu0", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Psu0", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bhu", " ", 
       SuperscriptBox["Phu0", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bau", " ", 
       SuperscriptBox["Pau0", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bmu", " ", 
       SuperscriptBox["Pmu0", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, 3.8250245206375036`*^9},
 CellLabel->
  "In[126]:=",ExpressionUUID->"e6724399-0426-4abd-bb4b-27370550b482"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bstp", " ", "=", 
   RowBox[{
    FractionBox["vstp0", "vsdp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pstp0", "psdp0"], ")"}], 
     RowBox[{"sigmasp", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852908773026*^9}, {
   3.8048533814497547`*^9, 3.8048533850606613`*^9}, 3.825024526837331*^9},
 CellLabel->
  "In[127]:=",ExpressionUUID->"379bd8ba-b8f0-4369-b43e-b6613eb75c99"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psp0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdp0", 
       RowBox[{"1", "-", "sigmasp"}]], "+", 
      RowBox[{"bstp", " ", 
       SuperscriptBox["pstp0", 
        RowBox[{"1", "-", "sigmasp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048533855138645`*^9, 3.804853387764236*^9}, 
   3.8250245295784664`*^9},
 CellLabel->
  "In[128]:=",ExpressionUUID->"1ed764e9-1c8e-4b4d-9273-7c8f56f9b844"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bhtp", " ", "=", 
   RowBox[{
    FractionBox["vhtp0", "vhdp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["phtp0", "phdp0"], ")"}], 
     RowBox[{"sigmahp", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.8048529305003295`*^9}, {
   3.8048533881740723`*^9, 3.804853389939992*^9}, 3.8250245318082047`*^9},
 CellLabel->
  "In[129]:=",ExpressionUUID->"29fbc036-d510-40fe-8daf-9600259594f0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Php0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["phdp0", 
       RowBox[{"1", "-", "sigmahp"}]], "+", 
      RowBox[{"bhtp", " ", 
       SuperscriptBox["phtp0", 
        RowBox[{"1", "-", "sigmahp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmahp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.8048533906588616`*^9, 
   3.804853392674816*^9}, 3.8250245344452543`*^9},
 CellLabel->
  "In[130]:=",ExpressionUUID->"d597280d-cf66-4efd-a4df-e8e3cfc822e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"batp", " ", "=", 
   RowBox[{
    FractionBox["vatp0", "vadp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["patp0", "padp0"], ")"}], 
     RowBox[{"sigmaap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.8048533930967607`*^9, 3.804853394675149*^9}, 3.8250245362216406`*^9},
 CellLabel->
  "In[131]:=",ExpressionUUID->"046a6855-34da-4a95-a501-75e89b292345"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pap0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padp0", 
       RowBox[{"1", "-", "sigmaap"}]], "+", 
      RowBox[{"batp", " ", 
       SuperscriptBox["patp0", 
        RowBox[{"1", "-", "sigmaap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048533952064857`*^9, 
   3.8048533971443033`*^9}, 3.8250245381191196`*^9},
 CellLabel->
  "In[132]:=",ExpressionUUID->"d22c127a-b4b1-4a89-8bd5-9291c05be00a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bmtp", " ", "=", 
   RowBox[{
    FractionBox["vmtp0", "vmdp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pmtp0", "pmdp0"], ")"}], 
     RowBox[{"sigmamp", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.804853007174381*^9, 3.8048530190200768`*^9}, {3.8048533974568553`*^9, 
   3.804853398894594*^9}, 3.825024540518985*^9},
 CellLabel->
  "In[133]:=",ExpressionUUID->"93b2d3b9-f4dc-4bec-b540-3dc836afe09b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pmp0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pmdp0", 
       RowBox[{"1", "-", "sigmamp"}]], "+", 
      RowBox[{"bmtp", " ", 
       SuperscriptBox["pmtp0", 
        RowBox[{"1", "-", "sigmamp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmamp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, 
   3.825024542535558*^9},
 CellLabel->
  "In[134]:=",ExpressionUUID->"ad032d2a-ff52-44d7-8d69-ecdf737d464c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bhp", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vhdp0", "+", "vhtp0"}], 
     RowBox[{"vsdp0", "+", "vstp0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Php0", "Psp0"], ")"}], 
     RowBox[{"betap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.804853425853657*^9, 3.804853428010266*^9}, 3.825024547396341*^9},
 CellLabel->
  "In[135]:=",ExpressionUUID->"8305e50c-adba-4ce2-96df-65790eba427b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bap", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vadp0", "+", "vatp0"}], 
     RowBox[{"vsdp0", "+", "vstp0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pap0", "Psp0"], ")"}], 
     RowBox[{"betap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.804853293988452*^9}, {
   3.8048534284009533`*^9, 3.80485342996371*^9}, 3.8250245493588715`*^9},
 CellLabel->
  "In[136]:=",ExpressionUUID->"54f686b0-44db-4784-8a4e-7cfac2c72f32"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bmp", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vmdp0", "+", "vmtp0"}], 
     RowBox[{"vsdp0", "+", "vstp0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pmp0", "Psp0"], ")"}], 
     RowBox[{"betap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.8048532815960116`*^9, 3.8048533048189335`*^9}, {3.804853430260635*^9, 
   3.8048534318233943`*^9}, 3.825024551982914*^9},
 CellLabel->
  "In[137]:=",ExpressionUUID->"abbcb4b4-51f3-478d-a36c-47dc2ecc337b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pp0", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Psp0", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bhp", " ", 
       SuperscriptBox["Php0", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bap", " ", 
       SuperscriptBox["Pap0", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bmp", " ", 
       SuperscriptBox["Pmp0", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048534322140846`*^9, 
   3.8048534358553085`*^9}, 3.8250245538793893`*^9},
 CellLabel->
  "In[138]:=",ExpressionUUID->"a4a909b7-206c-40c9-bf6f-7340e63204b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ku", "=", 
   FractionBox[
    RowBox[{"qstu0", " ", 
     SuperscriptBox["Pu0", 
      RowBox[{
       RowBox[{"-", "etau"}], "-", "betau", " "}]], 
     SuperscriptBox["Psu0", 
      RowBox[{"betau", "-", "sigmasu"}]], 
     SuperscriptBox["pstu0", "sigmasu"]}], "bstu"]}], ";"}]], "Input",
 CellChangeTimes->{{3.800140454488206*^9, 3.800140523176643*^9}, {
   3.800455058428173*^9, 3.800455063959334*^9}, {3.8006362513154964`*^9, 
   3.800636260384779*^9}, 3.8006363054963803`*^9, 3.800647348889147*^9, 
   3.8006960898303185`*^9, 3.800804256877533*^9, {3.8008043645295997`*^9, 
   3.800804364685875*^9}, {3.8008068728494596`*^9, 3.800806875974489*^9}, {
   3.8016604841908655`*^9, 3.8016604867536297`*^9}, {3.801663391117081*^9, 
   3.801663391882834*^9}, 3.801664413638791*^9, {3.8016647577403903`*^9, 
   3.801664759459405*^9}, {3.8016648404783707`*^9, 3.8016648805396347`*^9}, {
   3.801665135307444*^9, 3.801665211909813*^9}, 3.8016653900835795`*^9, {
   3.8016670898715615`*^9, 3.8016670989043036`*^9}, {3.80168887262052*^9, 
   3.8016888744489493`*^9}, {3.8016889608852425`*^9, 3.801689010426876*^9}, {
   3.8017784454569283`*^9, 3.801778458163327*^9}, 3.801778528743101*^9, {
   3.8017814934521255`*^9, 3.8017814938740683`*^9}, {3.8031140023071547`*^9, 
   3.803114014512789*^9}, {3.8031260626605997`*^9, 3.8031261061075296`*^9}, {
   3.804344640574292*^9, 3.804344672830389*^9}, {3.8048534574220657`*^9, 
   3.8048535141640887`*^9}, 3.8250245561591673`*^9},
 CellLabel->
  "In[139]:=",ExpressionUUID->"0f3e7553-f6e2-4c16-ad42-a622b32f2bcb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kp", "=", 
   FractionBox[
    RowBox[{"qstp0", " ", 
     SuperscriptBox["Pp0", 
      RowBox[{
       RowBox[{"-", "etap"}], "-", "betap"}]], " ", 
     SuperscriptBox["Psp0", 
      RowBox[{"betap", "-", "sigmasp"}]], 
     SuperscriptBox["pstp0", "sigmasp"]}], "bstp"]}], ";"}]], "Input",
 CellChangeTimes->{{3.801689038848219*^9, 3.8016890477090626`*^9}, 
   3.80177853075905*^9, 3.8031139983340187`*^9, {3.8031261513407984`*^9, 
   3.80312624801073*^9}, {3.8031284224239283`*^9, 3.8031284235638275`*^9}, {
   3.804344676926572*^9, 3.8043446965778627`*^9}, {3.80485352319683*^9, 
   3.8048535706159515`*^9}, 3.8250245593546553`*^9},
 CellLabel->
  "In[140]:=",ExpressionUUID->"3ef16ad7-9288-471b-b407-adece8171bc8"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4. New Equilibrium Calculation",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.7954529786642447`*^9}, {
  3.79545386036082*^9, 3.7954538618860044`*^9}, {3.795525436722562*^9, 
  3.795525448873003*^9}, {3.819900451316465*^9, 
  3.819900451678748*^9}},ExpressionUUID->"126bcfdb-2f4b-42f7-889f-\
d8f46341bccc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdu", 
       RowBox[{"1", "-", "sigmasu"}]], "+", 
      RowBox[{"bstu", " ", 
       SuperscriptBox["pstu", 
        RowBox[{"1", "-", "sigmasu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048537407717743`*^9, 3.804853751697942*^9}},
 CellLabel->
  "In[141]:=",ExpressionUUID->"ef893d96-bd08-4069-9c34-459925ad7abd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Phu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["phdu", 
       RowBox[{"1", "-", "sigmahu"}]], "+", 
      RowBox[{"bhtu", " ", 
       SuperscriptBox["phtu", 
        RowBox[{"1", "-", "sigmahu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmahu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.804853754104593*^9, 
   3.8048537632655916`*^9}},
 CellLabel->
  "In[142]:=",ExpressionUUID->"8ed78591-642f-4073-ae37-f3504a3aa756"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pau", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padu", 
       RowBox[{"1", "-", "sigmaau"}]], "+", 
      RowBox[{"batu", " ", 
       SuperscriptBox["patu", 
        RowBox[{"1", "-", "sigmaau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048537655159597`*^9, 
   3.8048537724008365`*^9}},
 CellLabel->
  "In[143]:=",ExpressionUUID->"ce99f432-061e-4019-ad09-c149f12ad464"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pmu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pmdu", 
       RowBox[{"1", "-", "sigmamu"}]], "+", 
      RowBox[{"bmtu", " ", 
       SuperscriptBox["pmtu", 
        RowBox[{"1", "-", "sigmamu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmamu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}},
 CellLabel->
  "In[144]:=",ExpressionUUID->"60236dba-2202-4d62-9dcb-89bd48daa64f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pu", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Psu", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bhu", " ", 
       SuperscriptBox["Phu", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bau", " ", 
       SuperscriptBox["Pau", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bmu", " ", 
       SuperscriptBox["Pmu", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048536729130955`*^9, 
   3.804853693916567*^9}},
 CellLabel->
  "In[145]:=",ExpressionUUID->"fcad075f-b133-4c8a-bbfe-1247200c7621"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psdp", "=", 
   FractionBox[
    RowBox[{"psdu", " ", "psdp0"}], "psdu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031106027958107`*^9, 3.8031106200452766`*^9}, 
   3.8031139807171125`*^9, {3.8048538603016443`*^9, 3.804853877601373*^9}},
 CellLabel->
  "In[146]:=",ExpressionUUID->"20adb099-fe29-44f3-8002-98212ddb4a67"],

Cell[BoxData[
 RowBox[{
  RowBox[{"phdp", "=", 
   FractionBox[
    RowBox[{"phdu", " ", "phdp0"}], "phdu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031106027958107`*^9, 3.8031106200452766`*^9}, 
   3.8031139807171125`*^9, {3.8048538603016443`*^9, 3.8048538983265047`*^9}},
 CellLabel->
  "In[147]:=",ExpressionUUID->"23f8d671-37dc-4151-9949-66fd776c3fb2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"padp", "=", 
   FractionBox[
    RowBox[{"padu", " ", "padp0"}], "padu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031106027958107`*^9, 3.8031106200452766`*^9}, 
   3.8031139807171125`*^9, {3.8048538603016443`*^9, 3.804853907051484*^9}},
 CellLabel->
  "In[148]:=",ExpressionUUID->"2a61f943-defe-466e-9826-0ea9a239ab59"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pmdp", "=", 
   FractionBox[
    RowBox[{"pmdu", " ", "pmdp0"}], "pmdu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031106027958107`*^9, 3.8031106200452766`*^9}, 
   3.8031139807171125`*^9, {3.8048538603016443`*^9, 3.804853877601373*^9}, {
   3.804853909817563*^9, 3.8048539155841417`*^9}},
 CellLabel->
  "In[149]:=",ExpressionUUID->"3a2e6051-8d58-45c7-9742-83a507bdd9ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psp", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdp", 
       RowBox[{"1", "-", "sigmasp"}]], "+", 
      RowBox[{"bstp", " ", 
       SuperscriptBox["pstp", 
        RowBox[{"1", "-", "sigmasp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048533855138645`*^9, 3.804853387764236*^9}, {
   3.804853813462556*^9, 3.804853819838611*^9}, 3.8048540877282963`*^9},
 CellLabel->
  "In[150]:=",ExpressionUUID->"9d050bb0-c02a-4827-8832-d05de9cd5771"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Php", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["phdp", 
       RowBox[{"1", "-", "sigmahp"}]], "+", 
      RowBox[{"bhtp", " ", 
       SuperscriptBox["phtp", 
        RowBox[{"1", "-", "sigmahp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmahp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.8048533906588616`*^9, 
   3.804853392674816*^9}, {3.8048538223073983`*^9, 3.8048538261666756`*^9}, 
   3.8048540893066835`*^9},
 CellLabel->
  "In[151]:=",ExpressionUUID->"a48f174d-0b4e-4016-89cb-12950409eed7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pap", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padp", 
       RowBox[{"1", "-", "sigmaap"}]], "+", 
      RowBox[{"batp", " ", 
       SuperscriptBox["patp", 
        RowBox[{"1", "-", "sigmaap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048533952064857`*^9, 
   3.8048533971443033`*^9}, {3.8048538294184713`*^9, 3.8048538335596733`*^9}, 
   3.8048540912601304`*^9},
 CellLabel->
  "In[152]:=",ExpressionUUID->"d25cd3d4-d9b3-4009-ac7e-4fadd097d429"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pmp", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pmdp", 
       RowBox[{"1", "-", "sigmamp"}]], "+", 
      RowBox[{"bmtp", " ", 
       SuperscriptBox["pmtp", 
        RowBox[{"1", "-", "sigmamp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmamp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.8048538356537657`*^9, 3.804853840279529*^9}, 3.804854093104184*^9},
 CellLabel->
  "In[153]:=",ExpressionUUID->"32ef4bb7-8042-4bd0-bd2d-98b82f2e0275"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pp", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Psp", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bhp", " ", 
       SuperscriptBox["Php", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bap", " ", 
       SuperscriptBox["Pap", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bmp", " ", 
       SuperscriptBox["Pmp", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048534322140846`*^9, 
   3.8048534358553085`*^9}, {3.8048536992339973`*^9, 3.8048537091388454`*^9}, 
   3.8048540746935024`*^9},
 CellLabel->
  "In[154]:=",ExpressionUUID->"f0685b32-fed0-4748-827d-4b13ae9f2b4c"],

Cell[TextData[StyleBox["Equilibrium equations",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8199002458925085`*^9, 
  3.819900248916869*^9}},ExpressionUUID->"0ad6664b-338c-43f8-a272-\
c331682cfee6"],

Cell["\<\
Supply (landings) of sardine = exports + consumer demand for unprocessed fish \
+ consumer demand for processed fish\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800413034212*^9}, 3.799855091636346*^9, {
   3.799884003726459*^9, 3.7998840232612796`*^9}, {3.800099320730234*^9, 
   3.800099324730491*^9}, {3.8199002189164705`*^9, 3.819900263780464*^9}, {
   3.819901722054987*^9, 3.8199017301532373`*^9}, {3.819901765100212*^9, 
   3.8199017660459433`*^9}, {3.825024731059498*^9, 
   3.8250247513252816`*^9}},ExpressionUUID->"05fa101c-2aa9-4143-a580-\
5be5505d66d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E1", "=", 
   RowBox[{
    RowBox[{"qsdcap", "-", 
     RowBox[{"asdu", " ", 
      SuperscriptBox["psdu", 
       RowBox[{"-", "esdu"}]]}]}], "\[Equal]", 
    RowBox[{"qsdue0", "+", 
     RowBox[{"cr", " ", "qsdpe0"}], "+", 
     RowBox[{"ku", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Psu", 
       RowBox[{"sigmasu", "-", "betau"}]], " ", 
      SuperscriptBox["psdu", 
       RowBox[{"-", "sigmasu"}]]}], "+", 
     RowBox[{"cr", " ", "kp", " ", 
      SuperscriptBox["Pp", 
       RowBox[{"etap", "+", "betap"}]], 
      SuperscriptBox["Psp", 
       RowBox[{"sigmasp", "-", "betap"}]], " ", 
      SuperscriptBox["psdp", 
       RowBox[{"-", "sigmasp"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.804854416639573*^9, 3.8048544212964177`*^9}, {
   3.8048603517476826`*^9, 3.8048603524352975`*^9}},
 CellLabel->
  "In[155]:=",ExpressionUUID->"7054bfa1-6724-4536-94f8-428722fa9818"],

Cell["\<\
Supply (landings) of herring = exports + consumer demand for unprocessed fish \
+ consumer demand for processed fish\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800413034212*^9}, 3.799855091636346*^9, {
   3.799884003726459*^9, 3.7998840232612796`*^9}, {3.800099320730234*^9, 
   3.800099324730491*^9}, {3.8199002189164705`*^9, 3.819900263780464*^9}, {
   3.819901722054987*^9, 3.8199017301532373`*^9}, {3.819901765100212*^9, 
   3.8199017660459433`*^9}, {3.825024731059498*^9, 
   3.8250247468788157`*^9}},ExpressionUUID->"5e32fe4a-2eea-4972-9471-\
4e63f2cc731d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E2", "=", 
   RowBox[{
    RowBox[{"qhdcap", "-", 
     RowBox[{"ahdu", " ", 
      SuperscriptBox["phdu", 
       RowBox[{"-", "ehdu"}]]}]}], "\[Equal]", 
    RowBox[{"qhdue0", "+", 
     RowBox[{"cr", " ", "qhdpe0"}], "+", 
     RowBox[{"ku", " ", "bhu", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Phu", 
       RowBox[{"sigmahu", "-", "betau"}]], " ", 
      SuperscriptBox["phdu", 
       RowBox[{"-", "sigmahu"}]]}], "+", 
     RowBox[{"cr", " ", "bhp", " ", "kp", " ", 
      SuperscriptBox["Pp", 
       RowBox[{"etap", "+", "betap"}]], 
      SuperscriptBox["Php", 
       RowBox[{"sigmahp", "-", "betap"}]], " ", 
      SuperscriptBox["phdp", 
       RowBox[{"-", "sigmahp"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541255705385`*^9, 3.8048541651264515`*^9}, {
   3.8048544272849865`*^9, 3.8048544302820015`*^9}, {3.8048546142370343`*^9, 
   3.804854615080909*^9}, {3.8048603568579025`*^9, 3.804860357420493*^9}, {
   3.8048606311455*^9, 3.804860631911248*^9}},
 CellLabel->
  "In[156]:=",ExpressionUUID->"8d9a5d54-6195-4864-9379-ebaa47dda552"],

Cell["\<\
Supply (landings) of anchovy = exports + consumer demand for unprocessed fish \
+ consumer demand for processed fish\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800413034212*^9}, 3.799855091636346*^9, {
   3.799884003726459*^9, 3.7998840232612796`*^9}, {3.800099320730234*^9, 
   3.800099324730491*^9}, {3.8199002189164705`*^9, 3.819900263780464*^9}, {
   3.819901722054987*^9, 3.8199017301532373`*^9}, {3.819901765100212*^9, 
   3.8199017660459433`*^9}, {3.825024731059498*^9, 
   3.82502475767222*^9}},ExpressionUUID->"7803ce6d-d2d7-435d-a1de-\
fdcddc6924b9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E3", "=", 
   RowBox[{
    RowBox[{"qadcap", "-", 
     RowBox[{"aadu", " ", 
      SuperscriptBox["padu", 
       RowBox[{"-", "eadu"}]]}]}], "\[Equal]", 
    RowBox[{"qadue0", "+", 
     RowBox[{"cr", " ", "qadpe0"}], "+", 
     RowBox[{"ku", " ", "bau", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Pau", 
       RowBox[{"sigmaau", "-", "betau"}]], " ", 
      SuperscriptBox["padu", 
       RowBox[{"-", "sigmaau"}]]}], "+", 
     RowBox[{"cr", " ", "bap", " ", "kp", " ", 
      SuperscriptBox["Pp", 
       RowBox[{"etap", "+", "betap"}]], 
      SuperscriptBox["Pap", 
       RowBox[{"sigmaap", "-", "betap"}]], " ", 
      SuperscriptBox["padp", 
       RowBox[{"-", "sigmaap"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541278209124`*^9, 3.804854127961561*^9}, {
   3.804854173974129*^9, 3.8048542013069344`*^9}, {3.8048544347821636`*^9, 
   3.804854437822094*^9}, {3.8048546184876595`*^9, 3.804854619268606*^9}, {
   3.804860360530382*^9, 3.804860361030465*^9}, {3.8048606435537367`*^9, 
   3.8048606448664465`*^9}},
 CellLabel->
  "In[157]:=",ExpressionUUID->"b0114ba0-c557-4d16-ae5b-21ff20f003b6"],

Cell["\<\
Supply (landings) of mackerel = exports + consumer demand for unprocessed \
fish + consumer demand for processed fish\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800413034212*^9}, 3.799855091636346*^9, {
   3.799884003726459*^9, 3.7998840232612796`*^9}, {3.800099320730234*^9, 
   3.800099324730491*^9}, {3.8199002189164705`*^9, 3.819900263780464*^9}, {
   3.819901722054987*^9, 3.8199017301532373`*^9}, {3.819901765100212*^9, 
   3.8199017660459433`*^9}, {3.825024731059498*^9, 3.8250247325286417`*^9}, {
   3.82502476304941*^9, 
   3.825024763949109*^9}},ExpressionUUID->"891033c0-7af6-4e67-890a-\
5a66af3ce0bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E4", "=", 
   RowBox[{
    RowBox[{"qmdcap", "-", 
     RowBox[{"amdu", " ", 
      SuperscriptBox["pmdu", 
       RowBox[{"-", "emdu"}]]}]}], "\[Equal]", 
    RowBox[{"qmdue0", "+", 
     RowBox[{"cr", " ", "qmdpe0"}], "+", 
     RowBox[{"ku", " ", "bmu", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Pmu", 
       RowBox[{"sigmamu", "-", "betau"}]], " ", 
      SuperscriptBox["pmdu", 
       RowBox[{"-", "sigmamu"}]]}], "+", 
     RowBox[{"cr", " ", "bmp", " ", "kp", " ", 
      SuperscriptBox["Pp", 
       RowBox[{"etap", "+", "betap"}]], 
      SuperscriptBox["Pmp", 
       RowBox[{"sigmamp", "-", "betap"}]], " ", 
      SuperscriptBox["pmdp", 
       RowBox[{"-", "sigmamp"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541303369503`*^9, 3.8048541304619713`*^9}, {
   3.8048542078548927`*^9, 3.8048542473983154`*^9}, {3.8048544408381042`*^9, 
   3.8048544472919245`*^9}, {3.8048546221752834`*^9, 
   3.8048546230035305`*^9}, {3.804860163075424*^9, 3.804860163434861*^9}, {
   3.804860364468531*^9, 3.8048603661250505`*^9}, {3.8048606546180067`*^9, 
   3.8048606554618917`*^9}},
 CellLabel->
  "In[158]:=",ExpressionUUID->"b96827f8-268f-402a-b86f-72a53198ccf1"],

Cell["\<\
Supply of imported unprocessed product = Demand for imported unprocessed \
product\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.7998012380597954`*^9}, {3.804854223408702*^9, 
  3.804854223455584*^9}, {3.80485425494967*^9, 3.8048542550121794`*^9}, {
  3.804854289806265*^9, 3.8048542955259604`*^9}, {3.8048543266944003`*^9, 
  3.804854326803794*^9}},ExpressionUUID->"f2222292-c02a-4dff-bfb0-\
5253e658f6aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E5", "=", 
   RowBox[{
    RowBox[{"qslu0", "+", 
     RowBox[{"repls", " ", "qsiu0"}]}], "\[Equal]", 
    RowBox[{"ku", " ", "bstu", " ", 
     SuperscriptBox["Pu", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Psu", 
      RowBox[{"sigmasu", "-", "betau"}]], "  ", 
     SuperscriptBox["pstu", 
      RowBox[{"-", "sigmasu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854469219143*^9}, {3.8057299207330923`*^9, 
   3.8057299208893676`*^9}},
 CellLabel->
  "In[159]:=",ExpressionUUID->"791f993f-332f-45c9-b74d-5610bfc47b08"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E6", "=", 
   RowBox[{
    RowBox[{"qhlu0", "+", 
     RowBox[{"replh", " ", "qhiu0"}]}], "\[Equal]", 
    RowBox[{"ku", " ", "bhtu", " ", "bhu", " ", 
     SuperscriptBox["Pu", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Phu", 
      RowBox[{"sigmahu", "-", "betau"}]], "  ", 
     SuperscriptBox["phtu", 
      RowBox[{"-", "sigmahu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.8048545129788523`*^9}, {3.804860514608667*^9, 
   3.8048605154838066`*^9}, {3.8057299237322087`*^9, 3.80572992404652*^9}},
 CellLabel->
  "In[160]:=",ExpressionUUID->"e0970f00-5295-4a08-929a-eb9fdaf290f2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E7", "=", 
   RowBox[{
    RowBox[{"qalu0", "+", 
     RowBox[{"repla", " ", "qaiu0"}]}], "\[Equal]", 
    RowBox[{"ku", " ", "batu", " ", "bau", " ", 
     SuperscriptBox["Pu", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Pau", 
      RowBox[{"sigmaau", "-", "betau"}]], "  ", 
     SuperscriptBox["patu", 
      RowBox[{"-", "sigmaau"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854535651602*^9}, {3.804860518781827*^9, 
   3.8048605197034464`*^9}, {3.8057299263281436`*^9, 3.8057299265000467`*^9}},
 CellLabel->
  "In[161]:=",ExpressionUUID->"ff7b668f-42fc-496d-9711-68ef3214bd65"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E8", "=", 
   RowBox[{
    RowBox[{"qmlu0", "+", 
     RowBox[{"replm", " ", "qmiu0"}]}], "\[Equal]", 
    RowBox[{"ku", " ", "bmtu", " ", "bmu", " ", 
     SuperscriptBox["Pu", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Pmu", 
      RowBox[{"sigmamu", "-", "betau"}]], "  ", 
     SuperscriptBox["pmtu", 
      RowBox[{"-", "sigmamu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854492241708*^9}, {3.8048545380175877`*^9, 
   3.8048545527071533`*^9}, {3.8048605221100817`*^9, 
   3.8048605232990365`*^9}, {3.805729928375351*^9, 3.8057299288910594`*^9}},
 CellLabel->
  "In[162]:=",ExpressionUUID->"d16e2950-660f-43e2-895a-44af17fb0b6a"],

Cell["\<\
Supply of imported processed product = Demand for imported processed product\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.7998012380597954`*^9}, {3.799884418200181*^9, 
  3.799884420684106*^9}, {3.8048542235337224`*^9, 3.8048542235649776`*^9}, {
  3.8048542551059437`*^9, 3.804854255152827*^9}, {3.8048543063260717`*^9, 
  3.804854311392005*^9}, {3.8048546319736*^9, 
  3.8048546323799095`*^9}},ExpressionUUID->"aee4aa60-9cad-4f3f-8312-\
69ed87061370"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E9", "=", 
   RowBox[{
    RowBox[{"qslp0", "+", 
     RowBox[{"repls", " ", "qsip0"}]}], "\[Equal]", 
    RowBox[{"kp", " ", "bstp", " ", 
     SuperscriptBox["Pp", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Psp", 
      RowBox[{"sigmasp", "-", "betap"}]], " ", 
     SuperscriptBox["pstp", 
      RowBox[{"-", "sigmasp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
  3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
  3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
  3.8048546364093094`*^9, 3.8048546757308216`*^9}, {3.805729931532113*^9, 
  3.805729931766526*^9}},
 CellLabel->
  "In[163]:=",ExpressionUUID->"dc442f99-2bf6-4cb3-b474-ca34a001692e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E10", "=", 
   RowBox[{
    RowBox[{"qhlp0", "+", 
     RowBox[{"replh", " ", "qhip0"}]}], "\[Equal]", 
    RowBox[{"kp", " ", "bhtp", " ", "bhp", " ", 
     SuperscriptBox["Pp", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Php", 
      RowBox[{"sigmahp", "-", "betap"}]], " ", 
     SuperscriptBox["phtp", 
      RowBox[{"-", "sigmahp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
  3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
  3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
  3.8048546364093094`*^9, 3.8048547075084224`*^9}, {3.804860454860574*^9, 
  3.804860461533553*^9}, {3.805729934029132*^9, 3.8057299342948*^9}},
 CellLabel->
  "In[164]:=",ExpressionUUID->"8fd0c066-a41d-4bb3-8941-1c1ea14cc382"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E11", "=", 
   RowBox[{
    RowBox[{"qalp0", "+", 
     RowBox[{"repla", " ", "qaip0"}]}], "\[Equal]", 
    RowBox[{"kp", " ", "batp", " ", "bap", " ", 
     SuperscriptBox["Pp", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pap", 
      RowBox[{"sigmaap", "-", "betap"}]], " ", 
     SuperscriptBox["patp", 
      RowBox[{"-", "sigmaap"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
  3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
  3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
  3.8048546364093094`*^9, 3.804854724823798*^9}, {3.804860465050977*^9, 
  3.804860465769847*^9}, {3.805729936904601*^9, 3.8057299370921326`*^9}},
 CellLabel->
  "In[165]:=",ExpressionUUID->"97c8f4b3-e25d-4002-9d3d-bf446eb05265"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E12", "=", 
   RowBox[{
    RowBox[{"qmlp0", "+", 
     RowBox[{"replm", " ", "qmip0"}]}], "\[Equal]", 
    RowBox[{"kp", " ", "bmtp", " ", "bmp", " ", 
     SuperscriptBox["Pp", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pmp", 
      RowBox[{"sigmamp", "-", "betap"}]], " ", 
     SuperscriptBox["pmtp", 
      RowBox[{"-", "sigmamp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
  3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
  3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
  3.8048546364093094`*^9, 3.804854691797214*^9}, {3.804854727667985*^9, 
  3.8048547417515974`*^9}, {3.804860470270588*^9, 3.8048604712707496`*^9}, {
  3.805729939064481*^9, 3.805729939345783*^9}},
 CellLabel->
  "In[166]:=",ExpressionUUID->"0940c008-f167-45b0-8f67-f75f70a7d4aa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "E1", ",", "E2", ",", "E3", ",", " ", "E4", ",", " ", "E5", ",", " ", 
     "E6", ",", "E7", ",", "E8", ",", "E9", ",", "E10", ",", "E11", ",", 
     "E12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"psdu", ",", "psdu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pstu", ",", "pstu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"phdu", ",", "phdu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"phtu", ",", "phtu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"padu", ",", "padu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"patu", ",", "patu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pmdu", ",", "pmdu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pmtu", ",", "pmtu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pstp", ",", "pstp0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"phtp", ",", "phtp0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"patp", ",", "patp0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pmtp", ",", "pmtp0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799801050741409*^9, 3.7998010802456255`*^9}, {
   3.799801592828159*^9, 3.799801634478999*^9}, {3.7998017203390927`*^9, 
   3.799801763344025*^9}, 3.7998021088038597`*^9, {3.799855159502365*^9, 
   3.799855165706504*^9}, {3.801692496821689*^9, 3.801692518577862*^9}, {
   3.801780123825697*^9, 3.8017801628874054`*^9}, {3.80178020897694*^9, 
   3.8017802303410735`*^9}, {3.804345075920143*^9, 3.8043451100366836`*^9}, {
   3.8048547484844165`*^9, 3.8048549152697835`*^9}},
 CellLabel->
  "In[167]:=",ExpressionUUID->"6340c5ef-1fdf-4a1b-8913-8de97b421861"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"psdu", "\[Rule]", "0.4698248689833804`"}], ",", 
   RowBox[{"pstu", "\[Rule]", "0.6931839787631027`"}], ",", 
   RowBox[{"phdu", "\[Rule]", "0.5023156103529453`"}], ",", 
   RowBox[{"phtu", "\[Rule]", "1.542590066625579`"}], ",", 
   RowBox[{"padu", "\[Rule]", "0.11630612629810917`"}], ",", 
   RowBox[{"patu", "\[Rule]", "2.5120600965454827`"}], ",", 
   RowBox[{"pmdu", "\[Rule]", "0.9152808236597434`"}], ",", 
   RowBox[{"pmtu", "\[Rule]", "2.923898110646735`"}], ",", 
   RowBox[{"pstp", "\[Rule]", "4.545543641024442`"}], ",", 
   RowBox[{"phtp", "\[Rule]", "3.9152118827485722`"}], ",", 
   RowBox[{"patp", "\[Rule]", "8.527242832257516`"}], ",", 
   RowBox[{"pmtp", "\[Rule]", "3.7929238538615873`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.799801093763195*^9, {3.7998016669393826`*^9, 3.799801696037279*^9}, {
   3.7998020915809345`*^9, 3.7998021123826103`*^9}, 3.799848486496959*^9, 
   3.7998493720505886`*^9, 3.7998495460808*^9, 3.7998495827852774`*^9, 
   3.7998508673590183`*^9, 3.7998510911466*^9, 3.799855179569358*^9, 
   3.7998552583267956`*^9, 3.7998567268243713`*^9, {3.799856759244939*^9, 
   3.799856772042405*^9}, 3.7998571935896273`*^9, {3.799857408768899*^9, 
   3.799857480047553*^9}, 3.7998575201979704`*^9, {3.799857622049017*^9, 
   3.7998576645100875`*^9}, 3.79985775764964*^9, 3.801660629881942*^9, {
   3.8016608170671644`*^9, 3.8016608355867376`*^9}, 3.801662762470487*^9, 
   3.8016634601520014`*^9, 3.8016642619493084`*^9, {3.8016643116509943`*^9, 
   3.801664333932659*^9}, 3.8016644580255985`*^9, 3.801665331312312*^9, 
   3.801665396193937*^9, 3.8016654271062555`*^9, {3.8016667203770294`*^9, 
   3.801666749521549*^9}, 3.8016667847731276`*^9, {3.8016669582001734`*^9, 
   3.8016669828621435`*^9}, 3.8016671121408663`*^9, 3.8016672254654093`*^9, 
   3.801667395428297*^9, 3.80166758146786*^9, 3.8016677818030624`*^9, {
   3.801667840912076*^9, 3.8016678618370447`*^9}, 3.801667932293232*^9, {
   3.8016681816615696`*^9, 3.801668203237288*^9}, {3.8016682671629763`*^9, 
   3.8016682942170086`*^9}, {3.801668343478133*^9, 3.8016683689058094`*^9}, 
   3.8016684195854483`*^9, 3.80166845156184*^9, 3.801668485767635*^9, 
   3.8016685398657312`*^9, 3.8016925768886733`*^9, 3.801692636059538*^9, 
   3.8016927417751255`*^9, 3.8016929474960947`*^9, 3.8016929983449326`*^9, 
   3.8016932252114334`*^9, 3.801693280035522*^9, 3.8016933902548666`*^9, 
   3.8016934841659365`*^9, 3.801776978095092*^9, 3.8017771960401382`*^9, 
   3.801777268025716*^9, 3.8017776446912208`*^9, 3.801778000507889*^9, 
   3.8017780698584113`*^9, {3.8017783088964415`*^9, 3.8017783339791546`*^9}, 
   3.801778651168253*^9, 3.801778711918086*^9, 3.801779136145438*^9, 
   3.801779246660454*^9, 3.801779504151821*^9, 3.801779547429063*^9, 
   3.8017796194290113`*^9, 3.8017797077018986`*^9, {3.80177977559*^9, 
   3.801779815288269*^9}, 3.801779851625734*^9, 3.80177989780993*^9, {
   3.801779938679492*^9, 3.8017799660435505`*^9}, {3.801780135110194*^9, 
   3.8017801586198745`*^9}, {3.8017802243244615`*^9, 3.8017802522196016`*^9}, 
   3.801780304944173*^9, 3.8017803423973784`*^9, {3.8017804415010777`*^9, 
   3.8017804699602876`*^9}, 3.8017805380749445`*^9, 3.801780578325031*^9, 
   3.801780663659497*^9, 3.8017811746938562`*^9, 3.8017812140865235`*^9, 
   3.8017819858354435`*^9, 3.801782032443123*^9, 3.8017820849493985`*^9, {
   3.801782213935169*^9, 3.80178224451851*^9}, 3.8030750831535826`*^9, 
   3.8030751502423997`*^9, 3.8030752588381195`*^9, 3.8030754031084967`*^9, 
   3.8030755051341305`*^9, 3.803113961115629*^9, 3.8031140809962687`*^9, 
   3.8031141435171995`*^9, 3.803114190749054*^9, 3.803114297354243*^9, 
   3.8031143933221292`*^9, 3.8031185684207845`*^9, 3.803118637884*^9, 
   3.8031187017608566`*^9, {3.803118746858054*^9, 3.8031187687481422`*^9}, 
   3.803118808171912*^9, 3.803120592520523*^9, 3.8031206304842153`*^9, 
   3.803124415843292*^9, 3.803124516631939*^9, 3.803124909992894*^9, 
   3.8031249912032137`*^9, 3.803125758705367*^9, 3.8031262530557327`*^9, 
   3.8031284818508377`*^9, 3.8031286688237686`*^9, 3.8032924984470205`*^9, 
   3.803303070796772*^9, 3.80330326390864*^9, 3.8033104006597986`*^9, 
   3.8033128919827037`*^9, 3.803313218397664*^9, 3.803391638515458*^9, 
   3.8033920558162465`*^9, 3.803392119387043*^9, 3.803392510423015*^9, 
   3.8033926215275464`*^9, 3.8033941576111856`*^9, 3.803394789895152*^9, 
   3.803394900344415*^9, 3.8033973159164147`*^9, 3.803397430778718*^9, 
   3.803398053956446*^9, 3.803398418579626*^9, 3.8033985809918175`*^9, 
   3.803509619550227*^9, 3.803510328359913*^9, 3.8035117198427258`*^9, 
   3.8035121794354076`*^9, 3.804345285159931*^9, 3.8043454965433917`*^9, 
   3.8043455348071623`*^9, 3.8043455684223137`*^9, 3.8043459767427797`*^9, 
   3.8043469002618847`*^9, 3.8043477435686226`*^9, {3.8043478444450955`*^9, 
   3.804347858324894*^9}, 3.8043478904178567`*^9, 3.8043479282573385`*^9, {
   3.804348235753111*^9, 3.8043482578112783`*^9}, 3.8043489366236033`*^9, 
   3.804349005898553*^9, 3.8043490995304046`*^9, 3.804519987755765*^9, 
   3.8045202903992214`*^9, 3.8045204186959352`*^9, 3.804520564470406*^9, 
   3.8045210416497726`*^9, 3.8045210802299166`*^9, 3.8045211592743473`*^9, 
   3.8045213926288996`*^9, 3.8045214707668962`*^9, 3.804545807943081*^9, 
   3.8045458824622107`*^9, 3.8045460962942696`*^9, 3.8045461951588993`*^9, 
   3.8045873498280363`*^9, 3.8045904449493504`*^9, 3.8045917103912177`*^9, 
   3.8045918180407963`*^9, 3.804858843193889*^9, 3.8048588862235484`*^9, 
   3.8048596627778664`*^9, 3.8048597491033964`*^9, 3.8048599633587866`*^9, 
   3.8048601102333293`*^9, 3.8048603793927994`*^9, 3.804860536316745*^9, 
   3.8048606683690643`*^9, 3.8048614891410294`*^9, 3.804865949529209*^9, 
   3.8048662731529274`*^9, 3.804866443758915*^9, 3.804867250226*^9, 
   3.8048811906914597`*^9, 3.8048952691744704`*^9, 3.804896148327177*^9, 
   3.8048969459086647`*^9, 3.805729980071905*^9, 3.805730598863989*^9, 
   3.8057312538678455`*^9, 3.8057577913749266`*^9, 3.806664880818141*^9, 
   3.806667860214843*^9, 3.806667969812989*^9, 3.8100333838279686`*^9, 
   3.810035736908621*^9, 3.812468119043789*^9, 3.812468388036994*^9, 
   3.812468504557049*^9, 3.812553254107133*^9, 3.812731709777257*^9, 
   3.8127330331011333`*^9, 3.81282124268237*^9, 3.8129267723941684`*^9, 
   3.8129271342106686`*^9, 3.812927520505309*^9, 3.812975347128721*^9, 
   3.8129756408788195`*^9, 3.814820693288607*^9, 3.8154767817498903`*^9, 
   3.8157742229764786`*^9, 3.8170195475157695`*^9, 3.8171067830005274`*^9, 
   3.8171068302171955`*^9, 3.8171068782221756`*^9, 3.8188033807886457`*^9, 
   3.825024798213791*^9, 3.8250748172872744`*^9},
 CellLabel->
  "Out[167]=",ExpressionUUID->"326b0dd9-2367-4106-818a-7fd5276fea38"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"psdu1", " ", "=", " ", 
   RowBox[{"psdu", "/.", "%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549276482487`*^9}},
 CellLabel->
  "In[168]:=",ExpressionUUID->"946f9cfe-6f47-48dd-8266-de1998056519"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pstu1", " ", "=", " ", 
   RowBox[{"pstu", "/.", "%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549332913156`*^9}},
 CellLabel->
  "In[169]:=",ExpressionUUID->"43559586-6a2c-42e9-a31e-8d54a991c323"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pstp1", " ", "=", " ", 
   RowBox[{"pstp", "/.", "%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.80485493651056*^9}},
 CellLabel->
  "In[170]:=",ExpressionUUID->"fe6319c4-183f-4cb1-8921-13252519ec27"],

Cell[BoxData[
 RowBox[{
  RowBox[{"phdu1", " ", "=", " ", 
   RowBox[{"phdu", "/.", "%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549495621114`*^9}, {3.804854982786557*^9, 3.804854983239752*^9}},
 CellLabel->
  "In[171]:=",ExpressionUUID->"9dc9d079-0605-42cf-9fae-d970b8bf9b15"],

Cell[BoxData[
 RowBox[{
  RowBox[{"phtu1", " ", "=", " ", 
   RowBox[{"phtu", "/.", "%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549504059906`*^9}, {3.8048549864902515`*^9, 3.804854986960324*^9}},
 CellLabel->
  "In[172]:=",ExpressionUUID->"52280ee1-ca06-46e2-8fd2-1ee3bf86a7bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"phtp1", " ", "=", " ", 
   RowBox[{"phtp", "/.", "%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.8048549519374757`*^9}, {3.8048549888981214`*^9, 3.804854989429453*^9}},
 CellLabel->
  "In[173]:=",ExpressionUUID->"16577354-fa8c-4ba9-a552-6e3f71acfce3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"padu1", " ", "=", " ", 
   RowBox[{"padu", "/.", "%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549948209057`*^9}},
 CellLabel->
  "In[174]:=",ExpressionUUID->"d8dba8ef-0920-4505-bdb4-adc27f532b87"],

Cell[BoxData[
 RowBox[{
  RowBox[{"patu1", " ", "=", " ", 
   RowBox[{"patu", "/.", "%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549332913156`*^9}, {3.8048549687687798`*^9, 3.8048549977743783`*^9}},
 CellLabel->
  "In[175]:=",ExpressionUUID->"bd09eadf-153e-4b02-a931-f9871574b095"],

Cell[BoxData[
 RowBox[{
  RowBox[{"patp1", " ", "=", " ", 
   RowBox[{"patp", "/.", "%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.80485493651056*^9}, {3.804854969784561*^9, 3.8048550007148633`*^9}},
 CellLabel->
  "In[176]:=",ExpressionUUID->"dbbea929-f638-498e-b75b-52c8fc05722d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pmdu1", " ", "=", " ", 
   RowBox[{"pmdu", "/.", "%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549276482487`*^9}, {3.804854975285405*^9, 3.804855007481864*^9}},
 CellLabel->
  "In[177]:=",ExpressionUUID->"ec51b3fd-7e7d-4c61-9972-2d851b2142ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pmtu1", " ", "=", " ", 
   RowBox[{"pmtu", "/.", "%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549332913156`*^9}, {3.804854976394951*^9, 3.8048549767231264`*^9}, {
  3.8048550098412547`*^9, 3.804855011638406*^9}},
 CellLabel->
  "In[178]:=",ExpressionUUID->"2d72f4c8-4704-4135-89b4-ae65638945c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pmtp1", " ", "=", " ", 
   RowBox[{"pmtp", "/.", "%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.80485493651056*^9}, {3.804854977160694*^9, 3.804854978739061*^9}, {
  3.8048550132320137`*^9, 3.8048550149197726`*^9}},
 CellLabel->
  "In[179]:=",ExpressionUUID->"e4ae86d0-0ecf-4d01-9a43-638ff4316501"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psdp1", "=", 
   FractionBox[
    RowBox[{"psdu1", " ", "psdp0"}], "psdu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.803113854588833*^9, 3.803113870126218*^9}, {
  3.803114384386155*^9, 3.8031143878348455`*^9}, {3.8043451406695185`*^9, 
  3.804345157554655*^9}, {3.804858147156853*^9, 3.804858152876525*^9}},
 CellLabel->
  "In[180]:=",ExpressionUUID->"91bd7d00-1d82-44fa-9b43-aa2c00886121"],

Cell[BoxData[
 RowBox[{
  RowBox[{"phdp1", "=", 
   FractionBox[
    RowBox[{"phdu1", " ", "phdp0"}], "phdu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8048581696293454`*^9, 3.8048581775525017`*^9}},
 CellLabel->
  "In[181]:=",ExpressionUUID->"3336e42b-db78-4360-b345-f0ee822506bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"padp1", "=", 
   FractionBox[
    RowBox[{"padu1", " ", "padp0"}], "padu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8048581818031883`*^9, 3.804858187819789*^9}},
 CellLabel->
  "In[182]:=",ExpressionUUID->"05ed3c06-fcef-484a-adbb-56a816fc8af8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pmdp1", "=", 
   FractionBox[
    RowBox[{"pmdu1", " ", "pmdp0"}], "pmdu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.80485819258607*^9, 3.804858199587202*^9}},
 CellLabel->
  "In[183]:=",ExpressionUUID->"9f6b8eb1-5805-4427-b26a-cef91f1526c5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdu1", 
       RowBox[{"1", "-", "sigmasu"}]], "+", 
      RowBox[{"bstu", " ", 
       SuperscriptBox["pstu1", 
        RowBox[{"1", "-", "sigmasu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048537407717743`*^9, 3.804853751697942*^9}, {
   3.804858232034235*^9, 3.8048582371444397`*^9}},
 CellLabel->
  "In[184]:=",ExpressionUUID->"827b48b7-cd55-4505-a89a-8bea05d601f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Phu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["phdu1", 
       RowBox[{"1", "-", "sigmahu"}]], "+", 
      RowBox[{"bhtu", " ", 
       SuperscriptBox["phtu1", 
        RowBox[{"1", "-", "sigmahu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmahu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.804853754104593*^9, 
   3.8048537632655916`*^9}, {3.8048582389728565`*^9, 3.8048582512496104`*^9}},
 CellLabel->
  "In[185]:=",ExpressionUUID->"10e0a844-12f0-4717-ae97-7bb0e70d876c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pau1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padu1", 
       RowBox[{"1", "-", "sigmaau"}]], "+", 
      RowBox[{"batu", " ", 
       SuperscriptBox["patu1", 
        RowBox[{"1", "-", "sigmaau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048537655159597`*^9, 
   3.8048537724008365`*^9}, {3.804858241066943*^9, 3.804858253249933*^9}},
 CellLabel->
  "In[186]:=",ExpressionUUID->"88b75a07-2f21-4492-b2d3-ed45dee10998"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pmu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pmdu1", 
       RowBox[{"1", "-", "sigmamu"}]], "+", 
      RowBox[{"bmtu", " ", 
       SuperscriptBox["pmtu1", 
        RowBox[{"1", "-", "sigmamu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmamu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}, {
   3.804858242871995*^9, 3.8048582551252365`*^9}},
 CellLabel->
  "In[187]:=",ExpressionUUID->"36baead3-72a4-46ae-9e7b-357bd3170f22"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pu1", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Psu1", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bhu", " ", 
       SuperscriptBox["Phu1", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bau", " ", 
       SuperscriptBox["Pau1", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bmu", " ", 
       SuperscriptBox["Pmu1", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048536729130955`*^9, 
   3.804853693916567*^9}, {3.804858258172606*^9, 3.804858267559837*^9}},
 CellLabel->
  "In[188]:=",ExpressionUUID->"2cf42da1-537d-47cf-a868-6ac8425005fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psp1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdp1", 
       RowBox[{"1", "-", "sigmasp"}]], "+", 
      RowBox[{"bstp", " ", 
       SuperscriptBox["pstp1", 
        RowBox[{"1", "-", "sigmasp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048533855138645`*^9, 3.804853387764236*^9}, {
   3.804853813462556*^9, 3.804853819838611*^9}, 3.8048540877282963`*^9, {
   3.804858269903962*^9, 3.804858273639639*^9}},
 CellLabel->
  "In[189]:=",ExpressionUUID->"6968501f-a00f-4eb4-b7de-e4b7523cd5a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Php1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["phdp1", 
       RowBox[{"1", "-", "sigmahp"}]], "+", 
      RowBox[{"bhtp", " ", 
       SuperscriptBox["phtp1", 
        RowBox[{"1", "-", "sigmahp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmahp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.8048533906588616`*^9, 
   3.804853392674816*^9}, {3.8048538223073983`*^9, 3.8048538261666756`*^9}, 
   3.8048540893066835`*^9, {3.8048582767495184`*^9, 3.8048582802344575`*^9}},
 CellLabel->
  "In[190]:=",ExpressionUUID->"50b2217b-a0f5-4ef2-a665-089b684d852b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pap1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padp1", 
       RowBox[{"1", "-", "sigmaap"}]], "+", 
      RowBox[{"batp", " ", 
       SuperscriptBox["patp1", 
        RowBox[{"1", "-", "sigmaap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048533952064857`*^9, 
   3.8048533971443033`*^9}, {3.8048538294184713`*^9, 3.8048538335596733`*^9}, 
   3.8048540912601304`*^9, {3.804858282906767*^9, 3.8048582862510543`*^9}},
 CellLabel->
  "In[191]:=",ExpressionUUID->"ca99b36d-0784-4f5c-abb4-899421699bbc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pmp1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pmdp1", 
       RowBox[{"1", "-", "sigmamp"}]], "+", 
      RowBox[{"bmtp", " ", 
       SuperscriptBox["pmtp1", 
        RowBox[{"1", "-", "sigmamp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmamp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.8048538356537657`*^9, 3.804853840279529*^9}, 3.804854093104184*^9, {
   3.8048582887367105`*^9, 3.8048582922681465`*^9}},
 CellLabel->
  "In[192]:=",ExpressionUUID->"cd104c3f-d515-420d-85d0-6d5fe0acf9eb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pp1", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Psp1", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bhp", " ", 
       SuperscriptBox["Php1", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bap", " ", 
       SuperscriptBox["Pap1", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bmp", " ", 
       SuperscriptBox["Pmp1", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048534322140846`*^9, 
   3.8048534358553085`*^9}, {3.8048536992339973`*^9, 3.8048537091388454`*^9}, 
   3.8048540746935024`*^9, {3.8048582965623837`*^9, 3.8048583071734004`*^9}},
 CellLabel->
  "In[193]:=",ExpressionUUID->"cf3a49b1-b3f6-48a3-98f1-2b28e692992d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qsdu1", "=", 
   RowBox[{"qsdcap", "-", 
    RowBox[{"asdu", " ", 
     SuperscriptBox["psdu1", 
      RowBox[{"-", "esdu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
  3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
  3.804858318066416*^9}},
 CellLabel->
  "In[194]:=",ExpressionUUID->"da2c9595-e3fc-4efc-8340-7fcfa41ee32f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qstu1", " ", "=", " ", 
   RowBox[{"qslu0", "+", 
    RowBox[{"repls", " ", "qsiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
  3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
  3.804858323051596*^9}, {3.8057299486644325`*^9, 3.8057299487894526`*^9}},
 CellLabel->
  "In[195]:=",ExpressionUUID->"968cd914-3f2c-4fc0-8be1-87db76fa5032"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qstp1", "=", 
   RowBox[{"qslp0", "+", 
    RowBox[{"repls", " ", "qsip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
  3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
  3.8048583295083256`*^9}, {3.805729951370614*^9, 3.8057299515113378`*^9}},
 CellLabel->
  "In[196]:=",ExpressionUUID->"5d201a59-15f3-4a9f-b1d9-6ab7b8e60249"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qsdp1", " ", "=", " ", 
   RowBox[{"qsdpe0", "+", 
    RowBox[{"kp", " ", 
     SuperscriptBox["Pp1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Psp1", 
      RowBox[{"sigmasp", "-", "betap"}]], " ", 
     SuperscriptBox["psdp1", 
      RowBox[{"-", "sigmasp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
  3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
  3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
  3.804858331686155*^9, 3.8048583574115205`*^9}},
 CellLabel->
  "In[197]:=",ExpressionUUID->"c5d80009-058b-43b9-95a0-97be06ff345a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qhdu1", "=", 
   RowBox[{"qhdcap", "-", 
    RowBox[{"ahdu", " ", 
     SuperscriptBox["phdu1", 
      RowBox[{"-", "ehdu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
  3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
  3.804858318066416*^9}, {3.8048583709925175`*^9, 3.8048583807603416`*^9}},
 CellLabel->
  "In[198]:=",ExpressionUUID->"3e642ed7-8a2a-4a7c-84b1-61256cf803c8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qhtu1", " ", "=", " ", 
   RowBox[{"qhlu0", "+", 
    RowBox[{"replh", " ", "qhiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
  3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
  3.804858323051596*^9}, {3.804858383088846*^9, 3.804858391482087*^9}, {
  3.80572995438673*^9, 3.8057299547305355`*^9}},
 CellLabel->
  "In[199]:=",ExpressionUUID->"14ae33cb-8dc4-47b0-bd6d-02367efb45db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qhtp1", "=", 
   RowBox[{"qhlp0", "+", 
    RowBox[{"replh", " ", "qhip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
  3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
  3.8048583295083256`*^9}, {3.8048583919821677`*^9, 3.8048583929823275`*^9}, {
  3.8057299572309413`*^9, 3.8057299573872166`*^9}},
 CellLabel->
  "In[200]:=",ExpressionUUID->"9653b559-0a51-4e27-a205-737b01a7f79d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qhdp1", " ", "=", " ", 
   RowBox[{"qhdpe0", "+", 
    RowBox[{"kp", " ", "bhp", " ", 
     SuperscriptBox["Pp1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Php1", 
      RowBox[{"sigmahp", "-", "betap"}]], " ", 
     SuperscriptBox["phdp1", 
      RowBox[{"-", "sigmahp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
  3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
  3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
  3.804858331686155*^9, 3.8048583574115205`*^9}, {3.8048583936074276`*^9, 
  3.804858404171567*^9}, {3.804860786055422*^9, 3.8048607864617367`*^9}},
 CellLabel->
  "In[201]:=",ExpressionUUID->"c8f582d1-1442-4d78-8704-4de7307105c1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qadu1", "=", 
   RowBox[{"qadcap", "-", 
    RowBox[{"aadu", " ", 
     SuperscriptBox["padu1", 
      RowBox[{"-", "eadu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
  3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
  3.804858318066416*^9}, {3.804858412220029*^9, 3.804858415017352*^9}},
 CellLabel->
  "In[202]:=",ExpressionUUID->"f9613ae5-8b16-4e0c-b27c-4a183e59636d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qatu1", " ", "=", " ", 
   RowBox[{"qalu0", "+", 
    RowBox[{"repla", " ", "qaiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
  3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
  3.804858323051596*^9}, {3.8048584155486903`*^9, 3.8048584170020504`*^9}, {
  3.8057299601735487`*^9, 3.8057299602985687`*^9}},
 CellLabel->
  "In[203]:=",ExpressionUUID->"11243cd2-b796-4e01-8542-850f98f840aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qatp1", "=", 
   RowBox[{"qalp0", "+", 
    RowBox[{"repla", " ", "qaip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
   3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
   3.8048583295083256`*^9}, {3.8048584174083652`*^9, 3.804858418330388*^9}, 
   3.8057299625758624`*^9},
 CellLabel->
  "In[204]:=",ExpressionUUID->"b63af19c-402b-4a43-8c33-41d4f5396395"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qadp1", " ", "=", " ", 
   RowBox[{"qadpe0", "+", 
    RowBox[{"kp", " ", "bap", " ", 
     SuperscriptBox["Pp1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pap1", 
      RowBox[{"sigmaap", "-", "betap"}]], " ", 
     SuperscriptBox["padp1", 
      RowBox[{"-", "sigmaap"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
  3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
  3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
  3.804858331686155*^9, 3.8048583574115205`*^9}, {3.804858419221157*^9, 
  3.804858427725051*^9}, {3.8048607895672665`*^9, 3.8048607922437763`*^9}},
 CellLabel->
  "In[205]:=",ExpressionUUID->"7ee696d2-f285-433f-80dc-784d4d3d5c14"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qmdu1", "=", 
   RowBox[{"qmdcap", "-", 
    RowBox[{"amdu", " ", 
     SuperscriptBox["pmdu1", 
      RowBox[{"-", "emdu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
  3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
  3.804858318066416*^9}, {3.8048584341925*^9, 3.804858435911532*^9}},
 CellLabel->
  "In[206]:=",ExpressionUUID->"888e3a2d-d307-4c7b-a13a-f42ecd52ab55"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qmtu1", " ", "=", " ", 
   RowBox[{"qmlu0", "+", 
    RowBox[{"replm", " ", "qmiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, {3.804858436286592*^9, 3.8048584368960643`*^9}, 
   3.805729965748258*^9},
 CellLabel->
  "In[207]:=",ExpressionUUID->"78166c8f-0a9e-4e78-90eb-12cf3e75d5d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qmtp1", "=", 
   RowBox[{"qmlp0", "+", 
    RowBox[{"replm", " ", "qmip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
  3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
  3.8048583295083256`*^9}, {3.804858437239869*^9, 3.804858437911852*^9}, {
  3.805729968217409*^9, 3.805729968920648*^9}},
 CellLabel->
  "In[208]:=",ExpressionUUID->"bff7468d-1892-44a1-ab13-c7d9e1e5d3b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qmdp1", " ", "=", " ", 
   RowBox[{"qmdpe0", "+", 
    RowBox[{"kp", " ", "bmp", " ", 
     SuperscriptBox["Pp1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pmp1", 
      RowBox[{"sigmamp", "-", "betap"}]], " ", 
     SuperscriptBox["pmdp1", 
      RowBox[{"-", "sigmamp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
  3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
  3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
  3.804858331686155*^9, 3.8048583574115205`*^9}, {3.8048584383181667`*^9, 
  3.804858445621817*^9}, {3.804860795771513*^9, 3.8048607983031683`*^9}},
 CellLabel->
  "In[209]:=",ExpressionUUID->"e5ee9f38-34c7-48ba-a642-b690f9fd2ef6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5. Results",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.7954529786642447`*^9}, {
  3.79545386036082*^9, 3.7954538618860044`*^9}, {3.795525436722562*^9, 
  3.795525448873003*^9}, {3.7998486591642857`*^9, 3.799848659976923*^9}, {
  3.8199004535482035`*^9, 
  3.8199004539735346`*^9}},ExpressionUUID->"8e4599eb-aefd-43a7-a3d0-\
3a00dd7828fe"],

Cell[TextData[StyleBox["Sardines",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, 
   3.825024839776162*^9},ExpressionUUID->"fa466ce1-cea8-4a8d-9b00-\
4b42818ede2f"],

Cell["\<\
Percent change in price of unprocessed domestic sardine production\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}, {3.825024847739361*^9, 3.8250248551481285`*^9}, {
  3.8250249035177937`*^9, 
  3.8250249099117746`*^9}},ExpressionUUID->"37b6f62e-ab42-474a-883b-\
a789278bd2e7"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"psdu1", "-", "psdu0"}], ")"}], "100"}], "psdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
  3.8048585992018385`*^9}},
 CellLabel->
  "In[210]:=",ExpressionUUID->"7851d6b9-66dd-4b24-bb64-9b1361450660"],

Cell[BoxData["4.927555017302953`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.804858843696556*^9, 3.8048588867233257`*^9, 
   3.804859663324854*^9, 3.804859749619121*^9, 3.804859963843249*^9, 
   3.804860110717795*^9, 3.804860380033531*^9, 3.8048605369574723`*^9, 
   3.8048606690003757`*^9, 3.8048614895786*^9, 3.8048659499980345`*^9, 
   3.8048662735904975`*^9, 3.8048664443215075`*^9, 3.804867250694828*^9, 
   3.8048811911602716`*^9, 3.8048952696276765`*^9, 3.804896148764747*^9, 
   3.8048969463462353`*^9, 3.805729980571986*^9, 3.8057305993640604`*^9, 
   3.805731254367955*^9, 3.8057577918750076`*^9, 3.8066648813025875`*^9, 
   3.8066667458267517`*^9, 3.8066678607618055`*^9, 3.806667970344324*^9, 
   3.810033384308341*^9, 3.810035737379987*^9, 3.812468119552184*^9, 
   3.812468388527378*^9, 3.812468505049435*^9, 3.8125532546465516`*^9, 
   3.812731710262638*^9, 3.8127330336135345`*^9, 3.812821243161742*^9, 
   3.812926772938553*^9, 3.8129271347400804`*^9, 3.812927521061742*^9, 
   3.8129753476581326`*^9, 3.8129756413476486`*^9, 3.8148206938690476`*^9, 
   3.8154767822656*^9, 3.815774223702997*^9, 3.817019547903084*^9, 
   3.8171067834054413`*^9, 3.817106830582168*^9, 3.8171068785845146`*^9, 
   3.818803381159935*^9, 3.8250250035076632`*^9, 3.825074817881122*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[210]=",ExpressionUUID->"427d7ead-cfb4-48f9-bbd2-9db2371c2552"]
}, Open  ]],

Cell["Percent change in quantity of domestic sardine landings", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
  3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
  3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, {
  3.8066652810440006`*^9, 3.806665281872264*^9}, {3.825024873844692*^9, 
  3.825024877565589*^9}},ExpressionUUID->"ff34ab77-1d9f-4ec0-ba1d-\
cae076d2ebb1"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qsdu1", "-", "qsdu0"}], ")"}], "100"}], "qsdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}},
 CellLabel->
  "In[211]:=",ExpressionUUID->"12284875-4e6e-4aaf-8a4e-b74c3485c4eb"],

Cell[BoxData["4.793415334424031`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.804858843837203*^9, 3.8048588868952274`*^9, 
   3.8048596634655075`*^9, 3.804859749775401*^9, 3.804859963983899*^9, 
   3.804860110889693*^9, 3.804860380189807*^9, 3.8048605370981197`*^9, 
   3.804860669156651*^9, 3.804861489672364*^9, 3.8048659501230545`*^9, 
   3.804866273731145*^9, 3.8048664444309*^9, 3.804867250819849*^9, 
   3.8048811912696643`*^9, 3.804895269705816*^9, 3.80489614887414*^9, 
   3.8048969464556475`*^9, 3.805729980697006*^9, 3.8057305995047054`*^9, 
   3.805731254492983*^9, 3.8057577920156555`*^9, 3.8066648814119806`*^9, 
   3.8066667460299115`*^9, 3.8066678609277554`*^9, 3.806667970484972*^9, 
   3.8100333844184265`*^9, 3.8100357375140915`*^9, 3.8124681196662726`*^9, 
   3.8124683886614833`*^9, 3.812468505177535*^9, 3.812553254763651*^9, 
   3.812731710385734*^9, 3.8127330337476387`*^9, 3.8128212432738295`*^9, 
   3.812926773066653*^9, 3.8129271348911977`*^9, 3.8129275212218657`*^9, 
   3.8129753477662177`*^9, 3.8129756415039253`*^9, 3.814820694019162*^9, 
   3.8154767824218764`*^9, 3.8157742239011517`*^9, 3.8170195479190965`*^9, 
   3.8171067834174433`*^9, 3.8171068305961795`*^9, 3.817106878597579*^9, 
   3.8188033811749463`*^9, 3.8250250036317596`*^9, 3.825074817974886*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[211]=",ExpressionUUID->"82f76b57-0cc3-4de1-a211-a5cce3e89a02"]
}, Open  ]],

Cell["Change in landings (in kg)", "Text",
 CellChangeTimes->{{3.819901014842124*^9, 
  3.819901018390876*^9}},ExpressionUUID->"b16a44f7-d416-47fd-90d5-\
3627674c26c5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qsdu1", "-", "qsdu0"}]], "Input",
 CellLabel->
  "In[212]:=",ExpressionUUID->"f1e6e02b-61e9-4306-b591-07651b893853"],

Cell[BoxData["48173.82411096152`"], "Output",
 CellChangeTimes->{3.815476788704164*^9, 3.815774231891396*^9, 
  3.817019548607972*^9, 3.8171067840503855`*^9, 3.817106831148345*^9, 
  3.817106879158753*^9, 3.8188033818224497`*^9, 3.825025009004942*^9, 
  3.825074818115535*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[212]=",ExpressionUUID->"37ca9bb2-2839-4529-aefd-c6736b7f5b64"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 3.80485427153401*^9}, {
  3.8250248847701983`*^9, 3.8250249161396255`*^9}, {3.825074161507101*^9, 
  3.825074162501876*^9}},ExpressionUUID->"fc388840-19e8-4dd3-9747-\
f8ff5f18cc62"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"psdp1", "-", "psdp0"}], ")"}], "100"}], "psdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
  3.8048586124851284`*^9}},
 CellLabel->
  "In[213]:=",ExpressionUUID->"c01ee3c4-d5c4-4b0f-ad48-10861ea850e0"],

Cell[BoxData["4.927555017302948`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.8048588439778495`*^9, 3.8048588870515013`*^9, 
   3.804859663606161*^9, 3.804859749916053*^9, 3.804859964124549*^9, 
   3.8048601110426407`*^9, 3.8048603803304553`*^9, 3.8048605372700224`*^9, 
   3.804860669297299*^9, 3.8048614897661295`*^9, 3.8048659502480745`*^9, 
   3.8048662738718495`*^9, 3.804866444540292*^9, 3.804867250929243*^9, 
   3.804881191363453*^9, 3.8048952697839546`*^9, 3.804896148983532*^9, 
   3.8048969465650415`*^9, 3.8057299807907715`*^9, 3.8057305996140957`*^9, 
   3.8057312546176443`*^9, 3.8057577921250477`*^9, 3.8066648815213737`*^9, 
   3.806666746154992*^9, 3.8066678610527754`*^9, 3.806667970609992*^9, 
   3.8100333845225077`*^9, 3.810035737641189*^9, 3.8124681197893686`*^9, 
   3.812468388787582*^9, 3.8124685052986298`*^9, 3.8125532548457427`*^9, 
   3.8127317104948196`*^9, 3.8127330338797417`*^9, 3.812821243380913*^9, 
   3.8129267731877465`*^9, 3.8129271350323076`*^9, 3.812927521365978*^9, 
   3.8129753478763027`*^9, 3.812975641644574*^9, 3.8148206941462584`*^9, 
   3.8154767825781527`*^9, 3.8157742240652957`*^9, 3.8170195479321065`*^9, 
   3.817106783429453*^9, 3.8171068306091895`*^9, 3.8171068786115627`*^9, 
   3.818803381188957*^9, 3.8250250037458487`*^9, 3.825074818240555*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[213]=",ExpressionUUID->"e113471b-4c37-44bb-8ee1-87eae8d90811"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
  3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
  3.804854255481004*^9, 3.8048542778511686`*^9}, {3.825024922029213*^9, 
  3.8250249236474705`*^9}, {3.8250741678055873`*^9, 
  3.8250741688549547`*^9}},ExpressionUUID->"7abf6cfa-d615-4f2a-b170-\
479ece4c4f53"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qsdp1", "-", "qsdp0"}], ")"}], "100"}], "qsdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}},
 CellLabel->
  "In[214]:=",ExpressionUUID->"3b33f5e5-576c-4782-ba04-8feac09ec40f"],

Cell[BoxData["8.936051169158652`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.8048588441185026`*^9, 3.804858887207775*^9, 
   3.804859663746849*^9, 3.804859750072333*^9, 3.8048599642808266`*^9, 
   3.8048601111989183`*^9, 3.8048603804867315`*^9, 3.804860537426297*^9, 
   3.804860669453575*^9, 3.804861489891162*^9, 3.804865950357467*^9, 
   3.804866273981185*^9, 3.804866444665313*^9, 3.8048672510230074`*^9, 
   3.8048811914728217`*^9, 3.804895269877722*^9, 3.8048961490929246`*^9, 
   3.8048969466744184`*^9, 3.8057299809001637`*^9, 3.805730599739114*^9, 
   3.805731254742672*^9, 3.8057577922500687`*^9, 3.806664881630767*^9, 
   3.806666746279953*^9, 3.806667861177796*^9, 3.806667970735012*^9, 
   3.810033384624587*^9, 3.810035737765286*^9, 3.812468119899454*^9, 
   3.8124683889126797`*^9, 3.812468505420726*^9, 3.812553254954791*^9, 
   3.8127317106219206`*^9, 3.8127330339928293`*^9, 3.812821243489998*^9, 
   3.8129267733088408`*^9, 3.8129271351694136`*^9, 3.812927521508088*^9, 
   3.812975348023223*^9, 3.8129756417852297`*^9, 3.814820694284363*^9, 
   3.815476782718824*^9, 3.8157742242214055`*^9, 3.8170195479471183`*^9, 
   3.817106783441462*^9, 3.8171068306211987`*^9, 3.817106878623544*^9, 
   3.8188033812029686`*^9, 3.825025003854933*^9, 3.8250748183655744`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[214]=",ExpressionUUID->"9bd3657d-3c7e-428b-9a76-c5c4cbae5ddc"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.8057300002942157`*^9, 3.805730015355893*^9}, {
   3.8066652174634976`*^9, 3.8066652201614285`*^9}, {3.8157740545890727`*^9, 
   3.8157740551895294`*^9}, 
   3.8250249357018604`*^9},ExpressionUUID->"7483b4ce-215e-46b7-a578-\
b2b730327ca1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmasu"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"psdu1", " ", 
     RowBox[{"(", 
      RowBox[{"qsdu1", "-", "qsdue0", "-", 
       RowBox[{"cr", " ", "qsdp1"}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"psdu0", " ", 
     RowBox[{"(", 
      RowBox[{"qsdu0", "-", "qsdue0", "-", 
       RowBox[{"cr", " ", "qsdp0"}]}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.8057300177232914`*^9, 3.8057300557466383`*^9}, {
  3.8066648558390408`*^9, 3.806664907888223*^9}},
 CellLabel->
  "In[215]:=",ExpressionUUID->"45299919-636f-46e3-9255-7b7ebc1c8d27"],

Cell[BoxData["6398.652103483836`"], "Output",
 CellChangeTimes->{
  3.805730090816584*^9, 3.8057306003485756`*^9, 3.8057312553365517`*^9, 
   3.8057577928595424`*^9, {3.806664882193361*^9, 3.8066649089352736`*^9}, 
   3.8066667469206853`*^9, 3.80666786178727*^9, 3.80666797137574*^9, 
   3.8100333851499944`*^9, 3.810035738393773*^9, 3.8124681204628916`*^9, 
   3.8124683895501757`*^9, 3.8124685060372086`*^9, 3.8125532555002155`*^9, 
   3.812731711183359*^9, 3.8127330345602703`*^9, 3.8128212440484324`*^9, 
   3.8129267739353275`*^9, 3.8129271358609505`*^9, 3.8129275216421924`*^9, 
   3.8129753481794977`*^9, 3.8129756419258738`*^9, 3.814820694403453*^9, 
   3.815476782875077*^9, 3.815774224378533*^9, 3.817019547961152*^9, 
   3.8171067834535303`*^9, 3.8171068306342087`*^9, 3.8171068786365542`*^9, 
   3.8188033812149773`*^9, 3.825025003964018*^9, 3.8250748185062227`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[215]=",ExpressionUUID->"5d8a9bd4-dad6-42ea-beee-f86ebf97a6a8"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.8057300588565187`*^9, 3.8057300659357986`*^9}, 
   3.8066644887009315`*^9, {3.8157740578866034`*^9, 3.8157740587042418`*^9}, {
   3.8250251099775743`*^9, 
   3.8250251156169662`*^9}},ExpressionUUID->"f2469fde-eb3a-4942-953b-\
aac4516c64e3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmasp"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"psdp1", " ", 
     RowBox[{"(", 
      RowBox[{"qsdp1", "-", "qsdpe0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"psdp0", " ", 
     RowBox[{"(", 
      RowBox[{"qsdp0", "-", "qsdpe0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.8057300679517508`*^9, 3.8057300874566574`*^9}, {
  3.8128212851599936`*^9, 3.812821300777146*^9}},
 CellLabel->
  "In[216]:=",ExpressionUUID->"6d67e3c8-2acd-40c0-9d6b-23bf2a043ed9"],

Cell[BoxData["1093.5544219266899`"], "Output",
 CellChangeTimes->{3.8057300882849207`*^9, 3.8057306004736214`*^9, 
  3.805731255461604*^9, 3.805757792968935*^9, 3.8066648823027763`*^9, 
  3.8066667470695357`*^9, 3.806667861912289*^9, 3.8066679715007606`*^9, 
  3.810033385250072*^9, 3.810035738514867*^9, 3.812468120575979*^9, 
  3.8124683896722703`*^9, 3.8124685061583023`*^9, 3.812553255612302*^9, 
  3.8127317112964473`*^9, 3.8127330346743593`*^9, 3.8128212441615205`*^9, 
  3.812821301509738*^9, 3.812926774062426*^9, 3.8129271360120687`*^9, 
  3.812927521782301*^9, 3.812975348320146*^9, 3.812975642082145*^9, 
  3.8148206945635743`*^9, 3.8154767830157256`*^9, 3.8157742247618237`*^9, 
  3.817019547989252*^9, 3.8171067834796166`*^9, 3.817106830659297*^9, 
  3.817106878662181*^9, 3.818803381239997*^9, 3.825025004188192*^9, 
  3.825074818631243*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[216]=",ExpressionUUID->"005c7d19-6c14-4289-94d4-8fb991e022f1"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"5ed542e3-d498-4e4c-a4dd-\
1b360d55e7d3"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pstu1", "-", "pstu0"}], ")"}], "100"}], "pstu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
  3.8048586228946285`*^9}},
 CellLabel->
  "In[217]:=",ExpressionUUID->"a7a9764c-bf66-49ef-939e-40c84233ba43"],

Cell[BoxData["8.052696198911137`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.804858844259143*^9, 3.8048588873484216`*^9, 
   3.8048596638874693`*^9, 3.8048597502286253`*^9, 3.8048599644214773`*^9, 
   3.804860111339567*^9, 3.80486038062738*^9, 3.8048605375982*^9, 
   3.804860669609849*^9, 3.8048614900161695`*^9, 3.80486595046686*^9, 
   3.804866274106205*^9, 3.804866444774705*^9, 3.804867251163656*^9, 
   3.8048811915822144`*^9, 3.8048952699714885`*^9, 3.804896149217945*^9, 
   3.8048969467994328`*^9, 3.805729981009563*^9, 3.805730599864132*^9, 
   3.8057312548520703`*^9, 3.8057577923750887`*^9, 3.8066648817557883`*^9, 
   3.806666746420602*^9, 3.8066678613028164`*^9, 3.80666797087566*^9, 
   3.810033384725665*^9, 3.8100357378963876`*^9, 3.8124681200095396`*^9, 
   3.8124683890357757`*^9, 3.812468505542821*^9, 3.8125532550618744`*^9, 
   3.812731710732005*^9, 3.8127330341099205`*^9, 3.81282124360909*^9, 
   3.8129267734309654`*^9, 3.8129271353125253`*^9, 3.8129275219344196`*^9, 
   3.8129753484764214`*^9, 3.8129756422240686`*^9, 3.814820694710699*^9, 
   3.8154767831563735`*^9, 3.8157742249199953`*^9, 3.8170195480042477`*^9, 
   3.817106783492627*^9, 3.81710683067182*^9, 3.8171068786752343`*^9, 
   3.8188033812550087`*^9, 3.8250250042972765`*^9, 3.825074818771891*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[217]=",ExpressionUUID->"a8258cb8-feab-4851-85a3-967eebdf399a"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
  3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
  3.8048542553403563`*^9, 
  3.8048542677330275`*^9}},ExpressionUUID->"82273b4d-e264-45a3-9a5a-\
0b30019357d7"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qstu1", "-", "qstu0"}], ")"}], "100"}], "qstu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}},
 CellLabel->
  "In[218]:=",ExpressionUUID->"0d15ba49-a590-43d3-aca9-29acdb783728"],

Cell[BoxData[
 RowBox[{"-", "13.744233819458888`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588444154167`*^9, 3.804858887504696*^9, 
   3.804859664043751*^9, 3.804859750369265*^9, 3.804859964562127*^9, 
   3.8048601114958444`*^9, 3.8048603807992835`*^9, 3.8048605377544746`*^9, 
   3.804860669766124*^9, 3.8048614901255617`*^9, 3.804865950576252*^9, 
   3.8048662742155976`*^9, 3.804866444899753*^9, 3.8048672512730494`*^9, 
   3.804881191675979*^9, 3.8048952700652666`*^9, 3.804896149327338*^9, 
   3.804896946908837*^9, 3.805729981103322*^9, 3.805730599973522*^9, 
   3.8057312549770985`*^9, 3.805757792484482*^9, 3.8066648818808503`*^9, 
   3.80666674656125*^9, 3.8066678614278364`*^9, 3.80666797100068*^9, 
   3.810033384828745*^9, 3.810035738017481*^9, 3.8124681201226273`*^9, 
   3.812468389164876*^9, 3.812468505662915*^9, 3.81255325517196*^9, 
   3.8127317108420916`*^9, 3.8127330342220078`*^9, 3.812821243720212*^9, 
   3.812926773555032*^9, 3.8129271354496317`*^9, 3.8129275220745287`*^9, 
   3.812975348632697*^9, 3.8129756423803444`*^9, 3.814820694855851*^9, 
   3.8154767833126493`*^9, 3.815774225078082*^9, 3.817019548018258*^9, 
   3.8171067835056367`*^9, 3.8171068306848307`*^9, 3.8171068786882443`*^9, 
   3.8188033812680426`*^9, 3.82502500440436*^9, 3.8250748188969107`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[218]=",ExpressionUUID->"719164b0-5da3-485e-b3e4-ed2852e2b584"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"e23a3c21-0a78-47af-802c-\
c364f4f91f5f"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pstp1", "-", "pstp0"}], ")"}], "100"}], "pstp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
  3.804858633427496*^9}},
 CellLabel->
  "In[219]:=",ExpressionUUID->"ec6af1d0-396f-4dba-8cea-a3941b570226"],

Cell[BoxData["8.903468227096878`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.8048588445560637`*^9, 3.8048588876453424`*^9, 3.8048596642000327`*^9, 
   3.8048597505412283`*^9, 3.8048599647027774`*^9, 3.8048601116364937`*^9, 
   3.8048603809555593`*^9, 3.804860537895122*^9, 3.8048606699223995`*^9, 
   3.804861490219328*^9, 3.804865950685644*^9, 3.8048662743249903`*^9, 
   3.8048664449934893`*^9, 3.8048672513824425`*^9, 3.804881191769744*^9, 
   3.8048952701590223`*^9, 3.804896149436783*^9, 3.804896947018218*^9, 
   3.8057299811970873`*^9, 3.8057306000985403`*^9, 3.805731255086519*^9, 
   3.8057577926251297`*^9, 3.806664881974575*^9, 3.806666746670643*^9, 
   3.8066678615372286`*^9, 3.8066679711257*^9, 3.8100333849318247`*^9, 
   3.810035738140583*^9, 3.8124681202367153`*^9, 3.8124683892909737`*^9, 
   3.8124685057830095`*^9, 3.812553255279051*^9, 3.8127317109531784`*^9, 
   3.8127330343330936`*^9, 3.812821243827259*^9, 3.812926773686134*^9, 
   3.8129271355887394`*^9, 3.8129275222116346`*^9, 3.812975348773345*^9, 
   3.812975642520999*^9, 3.8148206949979043`*^9, 3.8154767834532976`*^9, 
   3.815774225239209*^9, 3.81701954803327*^9, 3.8171067835196476`*^9, 
   3.8171068306968393`*^9, 3.817106878701285*^9, 3.8188033812820487`*^9, 
   3.825025004513445*^9, 3.8250748190219307`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[219]=",ExpressionUUID->"37ec2dd2-161b-42a9-8332-1016538bc854"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
  3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
  3.804854223908785*^9}, {3.8048542555122595`*^9, 
  3.804854280414089*^9}},ExpressionUUID->"f799dbdf-4080-49d8-a20e-\
90387fa96e77"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qstp1", "-", "qstp0"}], ")"}], "100"}], "qstp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}},
 CellLabel->
  "In[220]:=",ExpressionUUID->"efe2e1f7-5f4b-4f80-a068-3179b4d26ead"],

Cell[BoxData[
 RowBox[{"-", "14.689143182838677`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.80485884469671*^9, 3.804858887785989*^9, 3.8048596643406863`*^9, 
   3.8048597506974525`*^9, 3.804859964859055*^9, 3.8048601117927704`*^9, 
   3.8048603810962067`*^9, 3.8048605380513973`*^9, 3.804860670063046*^9, 
   3.804861490328724*^9, 3.804865950795037*^9, 3.8048662744343824`*^9, 
   3.8048664451185102`*^9, 3.8048672515074635`*^9, 3.804881191863509*^9, 
   3.8048952702527895`*^9, 3.8048961495461226`*^9, 3.804896947143239*^9, 
   3.8057299812908525`*^9, 3.805730600239185*^9, 3.8057312552271533`*^9, 
   3.805757792734522*^9, 3.806664882083968*^9, 3.8066667467956643`*^9, 
   3.8066678616622486`*^9, 3.806667971266348*^9, 3.8100333850359077`*^9, 
   3.810035738263673*^9, 3.812468120349804*^9, 3.8124683894170713`*^9, 
   3.8124685059171143`*^9, 3.812553255395133*^9, 3.812731711069269*^9, 
   3.8127330344471827`*^9, 3.812821243936344*^9, 3.812926773812232*^9, 
   3.8129271357258463`*^9, 3.81292752234674*^9, 3.8129753489139924`*^9, 
   3.812975642677267*^9, 3.8148206951480217`*^9, 3.8154767836095734`*^9, 
   3.8157742253933177`*^9, 3.817019548047281*^9, 3.8171067835336585`*^9, 
   3.8171068307078485`*^9, 3.8171068787132645`*^9, 3.8188033812960405`*^9, 
   3.8250250046365404`*^9, 3.8250748191625795`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[220]=",ExpressionUUID->"a958d773-26ce-4325-a238-7ed237078c5b"]
}, Open  ]],

Cell[TextData[StyleBox["Herring",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, {3.8048586570286355`*^9, 3.8048586579193974`*^9}, 
   3.8250249974519463`*^9},ExpressionUUID->"3c230a6e-b45f-406a-b862-\
d16c7d588e39"],

Cell["\<\
Percent change in price of unprocessed domestic herring production\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}, {3.8250250344127293`*^9, 
  3.8250250386510277`*^9}},ExpressionUUID->"d31b970b-01b3-4a91-a1a6-\
1f6a8fc987d5"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"phdu1", "-", "phdu0"}], ")"}], "100"}], "phdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
  3.8048585992018385`*^9}, {3.804858707793745*^9, 3.804858709669033*^9}},
 CellLabel->
  "In[221]:=",ExpressionUUID->"00ca3398-e60a-4f27-9f2f-ebb60f90afab"],

Cell[BoxData["1.742546805777322`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.8048588448373566`*^9, 3.8048588879266357`*^9, 
   3.8048596644969683`*^9, 3.804859750838105*^9, 3.804859965019943*^9, 
   3.804860111964675*^9, 3.8048603812524815`*^9, 3.8048605381920447`*^9, 
   3.804860670219321*^9, 3.804861490422487*^9, 3.8048659509044294`*^9, 
   3.8048662745594025`*^9, 3.8048664452122755`*^9, 3.8048672516168933`*^9, 
   3.8048811919729013`*^9, 3.8048952703465557`*^9, 3.804896149655515*^9, 
   3.804896947252631*^9, 3.8057299814315004`*^9, 3.805730600582984*^9, 
   3.805731255570979*^9, 3.8057577930939555`*^9, 3.8066648824121466`*^9, 
   3.806666747210184*^9, 3.8066678620373096`*^9, 3.80666797162578*^9, 
   3.810033385355153*^9, 3.8100357386359615`*^9, 3.8124681206850643`*^9, 
   3.8124683897933645`*^9, 3.812468506279396*^9, 3.812553255721387*^9, 
   3.812731711410537*^9, 3.812733034799457*^9, 3.8128212442796125`*^9, 
   3.8129267741815186`*^9, 3.8129271361471734`*^9, 3.812927522497857*^9, 
   3.8129753490702677`*^9, 3.812975642817915*^9, 3.814820695302147*^9, 
   3.8154767837658496`*^9, 3.8157742255544553`*^9, 3.817019548062292*^9, 
   3.8171067835471964`*^9, 3.8171068307188573`*^9, 3.8171068787252736`*^9, 
   3.8188033813110523`*^9, 3.825025004746626*^9, 3.825074819287599*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[221]=",ExpressionUUID->"a519167a-5c26-4f08-8644-ac82aaed2183"]
}, Open  ]],

Cell["Percent change in quantity of domestic herring landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
  3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
  3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, {
  3.8066654553072577`*^9, 3.8066654565887194`*^9}, {3.825025047296764*^9, 
  3.82502504902711*^9}},ExpressionUUID->"e62e74d7-9a4e-444a-8002-\
5e78b3fe9904"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qhdu1", "-", "qhdu0"}], ")"}], "100"}], "qhdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.8048587148420916`*^9, 3.8048587164829683`*^9}},
 CellLabel->
  "In[222]:=",ExpressionUUID->"ea07afa0-19bc-4d7b-a798-fbd50f5b1b9b"],

Cell[BoxData["3.4253695852008277`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.80485884497801*^9, 3.804858888051656*^9, 
   3.804859664637623*^9, 3.804859750994385*^9, 3.8048599651660595`*^9, 
   3.8048601121053247`*^9, 3.8048603814087563`*^9, 3.804860538363948*^9, 
   3.804860670359969*^9, 3.804861490563135*^9, 3.8048659510138216`*^9, 
   3.804866274668795*^9, 3.8048664453372965`*^9, 3.8048672517262497`*^9, 
   3.8048811920666666`*^9, 3.8048952704403224`*^9, 3.8048961497805357`*^9, 
   3.8048969473620243`*^9, 3.8057299815252657`*^9, 3.805730600692374*^9, 
   3.805731255680378*^9, 3.805757793203348*^9, 3.806664882505911*^9, 
   3.8066667473195777`*^9, 3.8066678621623287`*^9, 3.806667971750801*^9, 
   3.810033385462237*^9, 3.810035738756055*^9, 3.8124681208091607`*^9, 
   3.8124683899124565`*^9, 3.8124685064004908`*^9, 3.8125532558314724`*^9, 
   3.8127317115226245`*^9, 3.81273303491855*^9, 3.812821244389699*^9, 
   3.8129267743056145`*^9, 3.812927136288283*^9, 3.8129275226389666`*^9, 
   3.812975349210916*^9, 3.812975642989818*^9, 3.8148206954502497`*^9, 
   3.815476783922126*^9, 3.815774225752605*^9, 3.8170195480768447`*^9, 
   3.817106783560885*^9, 3.8171068307298656`*^9, 3.8171068787362823`*^9, 
   3.818803381326064*^9, 3.825025004858714*^9, 3.82507481941262*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[222]=",ExpressionUUID->"d765596c-a0c7-4eb1-b731-43ab5a2ca47e"]
}, Open  ]],

Cell["Change in landings (in kg)", "Text",
 CellChangeTimes->{{3.819901014842124*^9, 
  3.819901018390876*^9}},ExpressionUUID->"bbeaf817-3386-4352-a281-\
d5458907893d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qhdu1", "-", "qhdu0"}]], "Input",
 CellChangeTimes->{{3.8250747741528206`*^9, 3.825074776112494*^9}},
 CellLabel->
  "In[223]:=",ExpressionUUID->"3eacf8c4-eeda-46b6-8f9c-85730357cbee"],

Cell[BoxData["2.2853723335501403`*^6"], "Output",
 CellChangeTimes->{3.815476788704164*^9, 3.815774231891396*^9, 
  3.817019548607972*^9, 3.8171067840503855`*^9, 3.817106831148345*^9, 
  3.817106879158753*^9, 3.8188033818224497`*^9, 3.825025009004942*^9, 
  3.825074819553268*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[223]=",ExpressionUUID->"a2b08fea-9964-4130-92a0-a20ea7afd039"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 
  3.80485427153401*^9}},ExpressionUUID->"74709d3e-c995-4aa7-a7fe-\
8d66933766b1"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"phdp1", "-", "phdp0"}], ")"}], "100"}], "phdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
  3.8048586124851284`*^9}, {3.8048587237965918`*^9, 3.804858725653945*^9}},
 CellLabel->
  "In[224]:=",ExpressionUUID->"a7b058b0-b67f-46ad-9eac-b1634f448551"],

Cell[BoxData["1.7425468057773223`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.8048588451232333`*^9, 3.804858888207929*^9, 
   3.804859664778276*^9, 3.8048597511350365`*^9, 3.8048599653141775`*^9, 
   3.8048601122616014`*^9, 3.804860381565032*^9, 3.8048605385514774`*^9, 
   3.804860670516244*^9, 3.804861490656901*^9, 3.80486595112325*^9, 
   3.8048662747938147`*^9, 3.8048664454310617`*^9, 3.8048672518512707`*^9, 
   3.8048811921604753`*^9, 3.804895270549718*^9, 3.804896149889929*^9, 
   3.8048969474714165`*^9, 3.8057299816346583`*^9, 3.805730600817393*^9, 
   3.8057312558054056`*^9, 3.805757793312741*^9, 3.806664882615305*^9, 
   3.8066667474445987`*^9, 3.8066678622873497`*^9, 3.806667971891448*^9, 
   3.81003338557032*^9, 3.8100357388891582`*^9, 3.8124681209232497`*^9, 
   3.8124683900375547`*^9, 3.812468506522586*^9, 3.812553255942559*^9, 
   3.812731711646722*^9, 3.8127330350336404`*^9, 3.8128212445037885`*^9, 
   3.81292677442771*^9, 3.812927136436408*^9, 3.8129275227810774`*^9, 
   3.8129753493671913`*^9, 3.8129756431304655`*^9, 3.814820695595357*^9, 
   3.8154767840784016`*^9, 3.8157742259207344`*^9, 3.817019548090937*^9, 
   3.8171067835748944`*^9, 3.8171068307408743`*^9, 3.8171068787473035`*^9, 
   3.818803381341076*^9, 3.8250250049688044`*^9, 3.8250748196782875`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[224]=",ExpressionUUID->"f13f0871-ac63-4196-af82-a1139958ce6a"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
  3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
  3.804854255481004*^9, 
  3.8048542778511686`*^9}},ExpressionUUID->"4eddad94-7d11-490a-a946-\
fa0004029ced"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qhdp1", "-", "qhdp0"}], ")"}], "100"}], "qhdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}, {
  3.804858773231639*^9, 3.804858774231792*^9}},
 CellLabel->
  "In[225]:=",ExpressionUUID->"3fb76938-949c-45e7-b678-fb85bf19b336"],

Cell[BoxData["15.944354222686771`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.80485884526388*^9, 3.804858888348575*^9, 
   3.804859664934558*^9, 3.804859751291317*^9, 3.8048599654602933`*^9, 
   3.804860112417878*^9, 3.8048603817056828`*^9, 3.8048605386921253`*^9, 
   3.8048606706725187`*^9, 3.804861490766294*^9, 3.804865951232607*^9, 
   3.8048662749344625`*^9, 3.8048664455404553`*^9, 3.804867251960664*^9, 
   3.804881192269824*^9, 3.804895270643484*^9, 3.804896149999321*^9, 
   3.804896947580855*^9, 3.805729981744051*^9, 3.8057306009580374`*^9, 
   3.8057312559148045`*^9, 3.8057577934377613`*^9, 3.806664882724696*^9, 
   3.8066667475539913`*^9, 3.8066678624280214`*^9, 3.8066679720320964`*^9, 
   3.810033385709429*^9, 3.810035739023278*^9, 3.8124681210373373`*^9, 
   3.8124683901586494`*^9, 3.8124685066426787`*^9, 3.812553256056647*^9, 
   3.8127317117598104`*^9, 3.812733035152734*^9, 3.812821244629887*^9, 
   3.8129267745548086`*^9, 3.8129271365945215`*^9, 3.8129275229191847`*^9, 
   3.8129753495424185`*^9, 3.812975643276761*^9, 3.8148206957204833`*^9, 
   3.8154767842346773`*^9, 3.815774226094881*^9, 3.817019548104948*^9, 
   3.817106783588905*^9, 3.8171068307524185`*^9, 3.8171068787593484`*^9, 
   3.8188033813550863`*^9, 3.825025005080888*^9, 3.8250748198033085`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[225]=",ExpressionUUID->"5cd1917b-7437-44aa-94aa-20d8a728f339"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.8057300002942157`*^9, 3.805730015355893*^9}, 
   3.8066652302444677`*^9, {3.815774075108223*^9, 3.8157740756495852`*^9}, {
   3.825025084985156*^9, 
   3.8250250892794547`*^9}},ExpressionUUID->"216f7476-c13d-407d-a618-\
47697736b100"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmahu"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"phdu1", " ", 
     RowBox[{"(", 
      RowBox[{"qhdu1", "-", "qhdue0", "-", 
       RowBox[{"cr", " ", "qhdp1"}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"phdu0", " ", 
     RowBox[{"(", 
      RowBox[{"qhdu0", "-", "qhdue0", "-", 
       RowBox[{"cr", " ", "qhdp0"}]}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.8057300177232914`*^9, 3.8057300557466383`*^9}, {
  3.8057302131421704`*^9, 3.8057302204723687`*^9}, {3.806665464199357*^9, 
  3.806665481219983*^9}},
 CellLabel->
  "In[226]:=",ExpressionUUID->"fdd1bfd6-e063-4429-805c-498f8f5fcaae"],

Cell[BoxData["161472.4159853989`"], "Output",
 CellChangeTimes->{3.805730090816584*^9, 3.805730233927182*^9, 
  3.805730601583127*^9, 3.8057312565532103`*^9, 3.8057577940784903`*^9, 
  3.8066648833197513`*^9, 3.806665482751489*^9, 3.806666748194724*^9, 
  3.80666786303747*^9, 3.8066679727197065`*^9, 3.8100333863489246`*^9, 
  3.810035739655752*^9, 3.8124681216077805`*^9, 3.8124683907841396`*^9, 
  3.812468507251153*^9, 3.8125532566300926`*^9, 3.8127317123302574`*^9, 
  3.812733035744197*^9, 3.812821245220348*^9, 3.812926775229333*^9, 
  3.81292713736512*^9, 3.812927523058293*^9, 3.8129753496830664`*^9, 
  3.8129756434330373`*^9, 3.8148206958535676`*^9, 3.815476784390954*^9, 
  3.8157742262740054`*^9, 3.8170195481449785`*^9, 3.8171067836179276`*^9, 
  3.817106830763526*^9, 3.817106878770415*^9, 3.818803381369097*^9, 
  3.825025005192976*^9, 3.8250748199283447`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[226]=",ExpressionUUID->"7360b09a-94f9-4c7e-9615-9ecab83f91d0"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.8057300588565187`*^9, 3.8057300659357986`*^9}, 
   3.8066644951094637`*^9, {3.8157740786629477`*^9, 3.8157740797848153`*^9}, 
   3.825025131682478*^9},ExpressionUUID->"9fc79298-c450-4fb1-bc2b-\
261b41170394"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmahp"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"phdp1", " ", 
     RowBox[{"(", 
      RowBox[{"qhdp1", "-", "qhdpe0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"phdp0", " ", 
     RowBox[{"(", 
      RowBox[{"qhdp0", "-", "qhdpe0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.8057300679517508`*^9, 3.8057300874566574`*^9}, {
  3.80573022306639*^9, 3.805730230520576*^9}, {3.8128213169266148`*^9, 
  3.8128213300887547`*^9}},
 CellLabel->
  "In[227]:=",ExpressionUUID->"9d0b1007-fa5e-4e98-a9fd-8a892f812585"],

Cell[BoxData["76908.50533118918`"], "Output",
 CellChangeTimes->{3.8057300882849207`*^9, 3.805730231880093*^9, 
  3.8057306016925173`*^9, 3.805731256662609*^9, 3.805757794187883*^9, 
  3.806664883429145*^9, 3.806666748319745*^9, 3.8066678631781178`*^9, 
  3.8066679728447266`*^9, 3.810033386457009*^9, 3.810035739776847*^9, 
  3.8124681217228703`*^9, 3.812468390907236*^9, 3.8124685073702464`*^9, 
  3.8125532567411795`*^9, 3.812731712443346*^9, 3.8127330358712964`*^9, 
  3.812821245340441*^9, 3.812821330845337*^9, 3.81292677536744*^9, 
  3.812927137526246*^9, 3.8129275231954145`*^9, 3.8129753498237143`*^9, 
  3.81297564360494*^9, 3.814820695977648*^9, 3.815476784531602*^9, 
  3.815774226720375*^9, 3.817019548172515*^9, 3.8171067836459665`*^9, 
  3.817106830786544*^9, 3.8171068787934327`*^9, 3.81880338139812*^9, 
  3.825025005419153*^9, 3.8250748200533485`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[227]=",ExpressionUUID->"a302ee65-f883-49d2-9afd-611cbb6462de"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"dea2e921-ee46-4743-ab05-\
a7e3945b6a26"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"phtu1", "-", "phtu0"}], ")"}], "100"}], "phtu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
  3.8048586228946285`*^9}, {3.8048587279378014`*^9, 3.804858729797462*^9}},
 CellLabel->
  "In[228]:=",ExpressionUUID->"f484b1cf-f337-48dc-b352-e79d65e44fd2"],

Cell[BoxData["2.817403395647519`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.804858845404583*^9, 3.8048588885048494`*^9, 
   3.804859665075212*^9, 3.8048597514319687`*^9, 3.804859965603407*^9, 
   3.804860112558527*^9, 3.804860381877582*^9, 3.8048605388484*^9, 
   3.8048606708287935`*^9, 3.8048614909069424`*^9, 3.804865951357627*^9, 
   3.8048662750438547`*^9, 3.804866445649886*^9, 3.804867252070057*^9, 
   3.8048811923635893`*^9, 3.804895270768507*^9, 3.8048961501087136`*^9, 
   3.8048969476902018`*^9, 3.805729981853444*^9, 3.8057306010674286`*^9, 
   3.805731256039832*^9, 3.8057577935471535`*^9, 3.8066648828509245`*^9, 
   3.8066667476790123`*^9, 3.8066678625530167`*^9, 3.806667972172744*^9, 
   3.8100333858345256`*^9, 3.8100357391473584`*^9, 3.8124681211474237`*^9, 
   3.8124683902837477`*^9, 3.812468506764774*^9, 3.812553256166733*^9, 
   3.812731711874901*^9, 3.8127330352718267`*^9, 3.812821244744978*^9, 
   3.8129267746829157`*^9, 3.812927136753644*^9, 3.8129275233325057`*^9, 
   3.8129753499799895`*^9, 3.8129756437455873`*^9, 3.814820696122761*^9, 
   3.8154767846878777`*^9, 3.815774226980569*^9, 3.8170195481875944`*^9, 
   3.8171067836591187`*^9, 3.817106830799554*^9, 3.8171068788054914`*^9, 
   3.818803381412131*^9, 3.82502500553024*^9, 3.8250748201939964`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[228]=",ExpressionUUID->"e6b36338-f399-4b1d-8fff-3742363a3c52"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
  3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
  3.8048542553403563`*^9, 
  3.8048542677330275`*^9}},ExpressionUUID->"9a48f72c-e683-4eef-a766-\
d6eafcb44256"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qhtu1", "-", "qhtu0"}], ")"}], "100"}], "qhtu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.8048587746537323`*^9, 3.8048587754194756`*^9}},
 CellLabel->
  "In[229]:=",ExpressionUUID->"17d0570a-d752-44e3-b70f-5ed7e347d13e"],

Cell[BoxData[
 RowBox[{"-", "3.593751969433978`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588455608006`*^9, 3.8048588886454954`*^9, 
   3.804859665231494*^9, 3.804859751588249*^9, 3.8048599657555275`*^9, 
   3.8048601127148046`*^9, 3.8048603820338573`*^9, 3.804860539004675*^9, 
   3.804860670985069*^9, 3.8048614911257286`*^9, 3.8048659514670196`*^9, 
   3.804866275153248*^9, 3.804866445790497*^9, 3.804867252195078*^9, 
   3.8048811924886093`*^9, 3.804895270877902*^9, 3.8048961502181063`*^9, 
   3.804896947799594*^9, 3.8057299819628363`*^9, 3.805730601176819*^9, 
   3.8057312561468706`*^9, 3.805757793719057*^9, 3.8066648829759445`*^9, 
   3.806666747788406*^9, 3.8066678626780367`*^9, 3.8066679723133907`*^9, 
   3.810033385963626*^9, 3.8100357392784595`*^9, 3.812468121261512*^9, 
   3.8124683904058433`*^9, 3.8124685068838663`*^9, 3.8125532562798204`*^9, 
   3.812731711991992*^9, 3.8127330353889184`*^9, 3.812821244862069*^9, 
   3.812926774830023*^9, 3.812927136921775*^9, 3.812927523471614*^9, 
   3.8129753501362653`*^9, 3.812975643901862*^9, 3.8148206962898836`*^9, 
   3.8154767848441534`*^9, 3.815774227163729*^9, 3.8170195482026052`*^9, 
   3.81710678367313*^9, 3.8171068308116093`*^9, 3.8171068788184524`*^9, 
   3.818803381427142*^9, 3.825025005664345*^9, 3.8250748203190165`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[229]=",ExpressionUUID->"25c5fcef-d9e3-4c54-9391-dcb25442c468"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"6f46316a-26e2-4291-a63f-\
5ef5c6a7794c"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"phtp1", "-", "phtp0"}], ")"}], "100"}], "phtp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
  3.804858633427496*^9}, {3.804858731626238*^9, 3.804858732688901*^9}},
 CellLabel->
  "In[230]:=",ExpressionUUID->"db586c54-20d0-41e4-9765-405464a7d02b"],

Cell[BoxData["4.209458532697699`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.804858845701447*^9, 3.80485888880177*^9, 3.804859665387776*^9, 
   3.804859751728901*^9, 3.8048599659046464`*^9, 3.8048601128710814`*^9, 
   3.8048603821901336`*^9, 3.8048605391609497`*^9, 3.804860671141344*^9, 
   3.8048614912663765`*^9, 3.8048659515764117`*^9, 3.804866275262643*^9, 
   3.804866445884262*^9, 3.804867252304471*^9, 3.804881192582374*^9, 
   3.804895270971669*^9, 3.8048961503431263`*^9, 3.804896947924615*^9, 
   3.8057299820566015`*^9, 3.8057306013487186`*^9, 3.805731256303156*^9, 
   3.805757793844077*^9, 3.8066648831009645`*^9, 3.8066667478977985`*^9, 
   3.806667862803057*^9, 3.806667972454039*^9, 3.8100333860767136`*^9, 
   3.810035739409562*^9, 3.812468121376626*^9, 3.8124683905329423`*^9, 
   3.8124685070119705`*^9, 3.8125532564029164`*^9, 3.812731712107082*^9, 
   3.812733035508012*^9, 3.812821244978194*^9, 3.8129267749561205`*^9, 
   3.812927137075938*^9, 3.812927523616727*^9, 3.812975350261286*^9, 
   3.8129756440529833`*^9, 3.8148206964399977`*^9, 3.81547678500043*^9, 
   3.815774227338842*^9, 3.817019548217617*^9, 3.8171067836871405`*^9, 
   3.8171068308245735`*^9, 3.817106878831463*^9, 3.8188033814411535`*^9, 
   3.8250250057834377`*^9, 3.825074820444037*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[230]=",ExpressionUUID->"d6badffe-8916-472b-895d-83a43bcb6328"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
  3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
  3.804854223908785*^9}, {3.8048542555122595`*^9, 
  3.804854280414089*^9}},ExpressionUUID->"c0839bdc-fe31-4602-a763-\
d373a33c6f16"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qhtp1", "-", "qhtp0"}], ")"}], "100"}], "qhtp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.804858776153962*^9, 3.804858777294763*^9}},
 CellLabel->
  "In[231]:=",ExpressionUUID->"837a0856-9802-469c-8aee-bc228d453609"],

Cell[BoxData[
 RowBox[{"-", "3.47234700314361`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.8048588458420935`*^9, 3.804858888926789*^9, 3.8048596655284295`*^9, 
   3.8048597518851805`*^9, 3.804859966064773*^9, 3.8048601130273585`*^9, 
   3.804860382346409*^9, 3.8048605393172245`*^9, 3.804860671281991*^9, 
   3.80486149137577*^9, 3.8048659516858044`*^9, 3.804866275372032*^9, 
   3.804866446009283*^9, 3.804867252413864*^9, 3.8048811926917667`*^9, 
   3.8048952710810633`*^9, 3.8048961504525194`*^9, 3.804896948034007*^9, 
   3.8057299821503873`*^9, 3.805730601458109*^9, 3.8057312564282303`*^9, 
   3.8057577939534693`*^9, 3.8066648832103577`*^9, 3.8066667480228205`*^9, 
   3.80666786291245*^9, 3.8066679725790586`*^9, 3.8100333862248287`*^9, 
   3.810035739533658*^9, 3.8124681214906893`*^9, 3.8124683906640453`*^9, 
   3.812468507131059*^9, 3.8125532565170293`*^9, 3.8127317122192154`*^9, 
   3.8127330356261044`*^9, 3.8128212451022563`*^9, 3.81292677508422*^9, 
   3.8129271372210073`*^9, 3.8129275237518377`*^9, 3.8129753504019327`*^9, 
   3.812975644205087*^9, 3.8148206965961742`*^9, 3.815476785156706*^9, 
   3.815774227509971*^9, 3.8170195482326293`*^9, 3.817106783701152*^9, 
   3.817106830836583*^9, 3.817106878844473*^9, 3.8188033814561653`*^9, 
   3.8250250059025307`*^9, 3.825074820600312*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[231]=",ExpressionUUID->"df2802e7-8958-441b-a32a-3e3926221cdd"]
}, Open  ]],

Cell[TextData[StyleBox["Anchovy",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
  3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
  3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
  3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
  3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
  3.8048584943088517`*^9}, {3.804858665201766*^9, 3.804858666686369*^9}, {
  3.8250251707108727`*^9, 
  3.8250251736711783`*^9}},ExpressionUUID->"0ba7f740-1ccf-4c0a-8976-\
8f2466cded3a"],

Cell["\<\
Percent change in price of unprocessed domestic anchovy production\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}, {3.8250740470529747`*^9, 
  3.8250740501256514`*^9}},ExpressionUUID->"3d66264f-629c-44c5-9dbd-\
5d67f5927cbd"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"padu1", "-", "padu0"}], ")"}], "100"}], "padu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
  3.8048585992018385`*^9}, {3.8048587385491753`*^9, 3.8048587395967627`*^9}},
 CellLabel->
  "In[232]:=",ExpressionUUID->"2a02d074-8b67-4ef2-97ac-70841c84a99d"],

Cell[BoxData["2.128190469060844`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.8048588459827404`*^9, 3.8048588890674353`*^9, 
   3.8048596656690836`*^9, 3.804859752041461*^9, 3.80485996621189*^9, 
   3.8048601131836357`*^9, 3.8048603824870806`*^9, 3.804860539504755*^9, 
   3.804860671438266*^9, 3.8048614914695363`*^9, 3.8048659517951965`*^9, 
   3.804866275497053*^9, 3.8048664461030483`*^9, 3.8048672525232573`*^9, 
   3.8048811927855315`*^9, 3.8048952711748304`*^9, 3.8048961505619116`*^9, 
   3.8048969481434*^9, 3.8057299822753873`*^9, 3.8057306018175354`*^9, 
   3.8057312567876368`*^9, 3.8057577943129034`*^9, 3.8066648835385637`*^9, 
   3.806666748444766*^9, 3.806667863303138*^9, 3.8066679729697466`*^9, 
   3.8100333865671005`*^9, 3.81003573989694*^9, 3.812468121845966*^9, 
   3.812468391031333*^9, 3.812468507491341*^9, 3.812553256853266*^9, 
   3.812731712566442*^9, 3.81273303599039*^9, 3.8128212454625363`*^9, 
   3.8129267754955397`*^9, 3.81292713769738*^9, 3.812927523886938*^9, 
   3.8129753505582085`*^9, 3.8129756443552036`*^9, 3.8148206967652454`*^9, 
   3.815476785312982*^9, 3.8157742276751003`*^9, 3.817019548247641*^9, 
   3.8171067837151623`*^9, 3.8171068308506165`*^9, 3.817106878857516*^9, 
   3.8188033814701757`*^9, 3.825025006019621*^9, 3.8250748207253323`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[232]=",ExpressionUUID->"9df60852-59b7-47b8-bc2a-f7f1fde0374b"]
}, Open  ]],

Cell["Percent change in quantity of domestic anchovy landings", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
  3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
  3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, {
  3.806665491944352*^9, 3.806665493132045*^9}, {3.8250741028476057`*^9, 
  3.825074107285056*^9}},ExpressionUUID->"0fe098be-b29f-4ce6-bab0-\
f04522167f30"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qadu1", "-", "qadu0"}], ")"}], "100"}], "qadu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.804858781717317*^9, 3.80485878271747*^9}},
 CellLabel->
  "In[233]:=",ExpressionUUID->"7d4c9a37-f057-46db-b5c4-4cfdb1bc79f0"],

Cell[BoxData["9.994818570043995`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.8048588461233864`*^9, 3.804858889208082*^9, 
   3.8048596658097377`*^9, 3.8048597521977406`*^9, 3.804859966359081*^9, 
   3.8048601133242846`*^9, 3.804860382643334*^9, 3.8048605396610303`*^9, 
   3.8048606715945415`*^9, 3.804861491578929*^9, 3.8048659519045897`*^9, 
   3.8048662756220727`*^9, 3.804866446228069*^9, 3.804867252632651*^9, 
   3.804881192894924*^9, 3.804895271284257*^9, 3.8048961506713037`*^9, 
   3.8048969482527924`*^9, 3.8057299823691607`*^9, 3.805730601926938*^9, 
   3.8057312568970356`*^9, 3.805757794422296*^9, 3.806664883647931*^9, 
   3.8066667485541587`*^9, 3.806667863412532*^9, 3.8066679731573334`*^9, 
   3.810033386676179*^9, 3.810035740032045*^9, 3.8124681219600544`*^9, 
   3.8124683911574316`*^9, 3.8124685076124973`*^9, 3.812553256966354*^9, 
   3.8127317126895385`*^9, 3.8127330361064806`*^9, 3.8128212455886345`*^9, 
   3.8129267756196356`*^9, 3.8129271378485403`*^9, 3.812927524026047*^9, 
   3.812975350698857*^9, 3.8129756445093756`*^9, 3.814820696917364*^9, 
   3.815476785469258*^9, 3.8157742278422346`*^9, 3.8170195482626524`*^9, 
   3.8171067837291737`*^9, 3.8171068308627615`*^9, 3.8171068788706493`*^9, 
   3.8188033814861884`*^9, 3.8250250061377125`*^9, 3.825074820850353*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[233]=",ExpressionUUID->"39d4c44b-0283-440e-889e-077f072ce42c"]
}, Open  ]],

Cell["Change in landings (in kg)", "Text",
 CellChangeTimes->{{3.819901014842124*^9, 
  3.819901018390876*^9}},ExpressionUUID->"12516431-8f01-4aae-a5a5-\
533e43c0d231"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qadu1", "-", "qadu0"}]], "Input",
 CellChangeTimes->{{3.8250747881301813`*^9, 3.8250747919276724`*^9}},
 CellLabel->
  "In[234]:=",ExpressionUUID->"12c4bf56-0561-48ef-8455-9d9123416dfa"],

Cell[BoxData["1.7351005037596375`*^6"], "Output",
 CellChangeTimes->{3.815476788704164*^9, 3.815774231891396*^9, 
  3.817019548607972*^9, 3.8171067840503855`*^9, 3.817106831148345*^9, 
  3.817106879158753*^9, 3.8188033818224497`*^9, 3.825025009004942*^9, 
  3.8250748209753733`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[234]=",ExpressionUUID->"4759d009-2ebe-4b8a-8c64-dc6b75eb6672"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 
  3.80485427153401*^9}},ExpressionUUID->"7de371d5-81f7-476d-9f31-\
0363bd80cce3"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"padp1", "-", "padp0"}], ")"}], "100"}], "padp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
  3.8048586124851284`*^9}, {3.804858740206231*^9, 3.804858741003228*^9}},
 CellLabel->
  "In[235]:=",ExpressionUUID->"505233e9-3de1-4a29-9d0e-86ea14ae24b7"],

Cell[BoxData["2.1281904690608355`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.804858846279661*^9, 3.804858889348729*^9, 
   3.8048596659503913`*^9, 3.804859752338393*^9, 3.80485996649973*^9, 
   3.8048601134805613`*^9, 3.804860382783988*^9, 3.804860539801677*^9, 
   3.8048606717351885`*^9, 3.8048614916726947`*^9, 3.8048659520296097`*^9, 
   3.8048662757314653`*^9, 3.8048664463218336`*^9, 3.8048672527420435`*^9, 
   3.8048811929886894`*^9, 3.80489527139362*^9, 3.804896150780697*^9, 
   3.8048969483621855`*^9, 3.805729982541055*^9, 3.805730602051944*^9, 
   3.8057312570220633`*^9, 3.8057577945473166`*^9, 3.806664883757324*^9, 
   3.806666748679401*^9, 3.8066678635375504`*^9, 3.806667973282297*^9, 
   3.8100333867862644`*^9, 3.8100357401541395`*^9, 3.8124681220721416`*^9, 
   3.812468391280528*^9, 3.812468507736533*^9, 3.812553257083446*^9, 
   3.81273171280663*^9, 3.812733036226575*^9, 3.812821245723739*^9, 
   3.812926775748736*^9, 3.812927137998616*^9, 3.8129275241681585`*^9, 
   3.8129753508238773`*^9, 3.812975644654437*^9, 3.814820697072532*^9, 
   3.815476785609906*^9, 3.8157742280504074`*^9, 3.817019548279216*^9, 
   3.817106783743184*^9, 3.8171068308757715`*^9, 3.8171068788836603`*^9, 
   3.818803381502201*^9, 3.8250250062548037`*^9, 3.8250748211003942`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[235]=",ExpressionUUID->"baa044e0-3365-4255-8fe1-ed5010856ff3"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
  3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
  3.804854255481004*^9, 
  3.8048542778511686`*^9}},ExpressionUUID->"8ae1ed5b-0ea8-45f8-946d-\
944ec7d06db1"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qadp1", "-", "qadp0"}], ")"}], "100"}], "qadp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}, {
  3.8048587831862926`*^9, 3.804858783952036*^9}},
 CellLabel->
  "In[236]:=",ExpressionUUID->"5fd82f32-b684-4fbb-930c-804e026d4a08"],

Cell[BoxData["12.231146563418818`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.804858846420307*^9, 3.8048588894893756`*^9, 
   3.804859666091045*^9, 3.804859752494673*^9, 3.8048599666403804`*^9, 
   3.8048601136212463`*^9, 3.804860382940258*^9, 3.8048605399579525`*^9, 
   3.804860671907091*^9, 3.8048614917664604`*^9, 3.804865952139002*^9, 
   3.804866275856485*^9, 3.804866446446854*^9, 3.8048672528514366`*^9, 
   3.8048811930980816`*^9, 3.8048952714873867`*^9, 3.8048961508900895`*^9, 
   3.8048969484715776`*^9, 3.805729982650448*^9, 3.805730602161335*^9, 
   3.805731257131462*^9, 3.805757794656709*^9, 3.806664883882345*^9, 
   3.806666748796883*^9, 3.8066678636625705`*^9, 3.806667973407317*^9, 
   3.810033386906358*^9, 3.8100357402732325`*^9, 3.812468122189233*^9, 
   3.8124683914036245`*^9, 3.8124685078556266`*^9, 3.8125532571995354`*^9, 
   3.8127317129237213`*^9, 3.812733036345668*^9, 3.8128212458418307`*^9, 
   3.812926775884842*^9, 3.8129271381497345`*^9, 3.8129275243152742`*^9, 
   3.812975350964526*^9, 3.8129756448005505`*^9, 3.8148206972216277`*^9, 
   3.815476785766182*^9, 3.815774228260562*^9, 3.8170195482934904`*^9, 
   3.8171067837572684`*^9, 3.8171068308887815`*^9, 3.8171068788966694`*^9, 
   3.8188033815162115`*^9, 3.8250250063718944`*^9, 3.825074821225414*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[236]=",ExpressionUUID->"db4f1d08-e4d7-4fbe-8b3f-b7f37daeb6b9"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.8057300002942157`*^9, 3.805730015355893*^9}, 
   3.806665235418315*^9, {3.815774084973836*^9, 3.8157740855252633`*^9}, 
   3.825074182360567*^9},ExpressionUUID->"1ea986bf-0641-4b29-910f-\
b481f6dc2d18"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmaau"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"padu1", " ", 
     RowBox[{"(", 
      RowBox[{"qadu1", "-", "qadue0", "-", 
       RowBox[{"cr", " ", "qadp1"}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"padu0", " ", 
     RowBox[{"(", 
      RowBox[{"qadu0", "-", "qadue0", "-", 
       RowBox[{"cr", " ", "qadp0"}]}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.8057300177232914`*^9, 3.8057300557466383`*^9}, {
  3.8057302425163307`*^9, 3.80573025301312*^9}, {3.8066655047852564`*^9, 
  3.8066655197547483`*^9}},
 CellLabel->
  "In[237]:=",ExpressionUUID->"3a01bb7f-87ae-4339-ab1a-e1b6615b2ec3"],

Cell[BoxData["20661.22519458916`"], "Output",
 CellChangeTimes->{3.805730090816584*^9, 3.8057306028020515`*^9, 
  3.8057312577722282`*^9, 3.805757795297442*^9, 3.8066648844293118`*^9, 
  3.806665521473817*^9, 3.806666749437611*^9, 3.80666786429416*^9, 
  3.806667974048045*^9, 3.810033387474799*^9, 3.8100357408887095`*^9, 
  3.812468122787698*^9, 3.8124683920171046`*^9, 3.812468508483118*^9, 
  3.812553257792996*^9, 3.81273171352219*^9, 3.8127330369541445`*^9, 
  3.812821246438294*^9, 3.8129267765173335`*^9, 3.812927138858286*^9, 
  3.812927524449379*^9, 3.812975351120803*^9, 3.8129756449417734`*^9, 
  3.814820697374713*^9, 3.8154767859224577`*^9, 3.815774228422729*^9, 
  3.8170195483084555`*^9, 3.8171067837703433`*^9, 3.817106830900791*^9, 
  3.8171068789096794`*^9, 3.8188033815302224`*^9, 3.8250250064899864`*^9, 
  3.8250748213504343`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[237]=",ExpressionUUID->"155f2192-b5e7-4c20-9ac3-eb2433d910e8"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.8057300588565187`*^9, 3.8057300659357986`*^9}, {
   3.80666447394985*^9, 3.8066644778567467`*^9}, {3.815774087810034*^9, 
   3.8157740884795527`*^9}, 
   3.8250742021337953`*^9},ExpressionUUID->"7eb8e5fd-fa3c-4931-86af-\
7687f0c33f0b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmaap"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"padp1", " ", 
     RowBox[{"(", 
      RowBox[{"qadp1", "-", "qadpe0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"padp0", " ", 
     RowBox[{"(", 
      RowBox[{"qadp0", "-", "qadpe0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.8057300679517508`*^9, 3.8057300874566574`*^9}, {
  3.805730255325876*^9, 3.8057302625266027`*^9}, {3.812821361302801*^9, 
  3.8128213725544767`*^9}},
 CellLabel->
  "In[238]:=",ExpressionUUID->"e15c2f09-7824-4d8f-aa66-ccd853958e18"],

Cell[BoxData["86128.44126476326`"], "Output",
 CellChangeTimes->{3.8057300882849207`*^9, 3.805730602911442*^9, 
  3.8057312578972554`*^9, 3.8057577954224787`*^9, 3.806664884538705*^9, 
  3.8066667495626383`*^9, 3.80666786441918*^9, 3.806667974219948*^9, 
  3.810033387587887*^9, 3.8100357410178223`*^9, 3.812468122915797*^9, 
  3.8124683921391993`*^9, 3.8124685086022115`*^9, 3.812553257911088*^9, 
  3.812731713646287*^9, 3.8127330370752397`*^9, 3.812821246554384*^9, 
  3.8128213734191484`*^9, 3.8129267766424303`*^9, 3.812927138993391*^9, 
  3.812927524584484*^9, 3.8129753512614727`*^9, 3.812975645082421*^9, 
  3.814820697524831*^9, 3.815476786078734*^9, 3.8157742287559447`*^9, 
  3.817019548336477*^9, 3.817106783797364*^9, 3.81710683092481*^9, 
  3.817106878934699*^9, 3.8188033815582447`*^9, 3.8250250067702045`*^9, 
  3.825074821485467*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[238]=",ExpressionUUID->"74e06423-c242-4cf9-9f38-6ecbb53552c8"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"595cd19d-1187-4444-8116-\
3c5f95c9094e"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"patu1", "-", "patu0"}], ")"}], "100"}], "patu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
  3.8048586228946285`*^9}, {3.8048587414876785`*^9, 3.8048587423628125`*^9}},
 CellLabel->
  "In[239]:=",ExpressionUUID->"54ef8831-e826-4661-bf9d-4173471e7600"],

Cell[BoxData["4.995970648037135`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.8048588465765815`*^9, 3.804858889630022*^9, 
   3.8048596662473273`*^9, 3.8048597526353245`*^9, 3.8048599667810307`*^9, 
   3.8048601137774878`*^9, 3.804860383112162*^9, 3.8048605401142273`*^9, 
   3.804860672047739*^9, 3.8048614918758535`*^9, 3.804865952232767*^9, 
   3.8048662759658775`*^9, 3.8048664465406685`*^9, 3.80486725296095*^9, 
   3.804881193191847*^9, 3.804895271581153*^9, 3.80489615101511*^9, 
   3.8048969485809703`*^9, 3.8057299827754683`*^9, 3.8057306022707367`*^9, 
   3.8057312572564898`*^9, 3.805757794812985*^9, 3.8066648839917383`*^9, 
   3.806666748906295*^9, 3.806667863776742*^9, 3.8066679735323367`*^9, 
   3.810033387018444*^9, 3.8100357403933253`*^9, 3.812468122306324*^9, 
   3.812468391528723*^9, 3.812468507973719*^9, 3.812553257316626*^9, 
   3.812731713039813*^9, 3.8127330364637604`*^9, 3.812821245960923*^9, 
   3.8129267760129414`*^9, 3.8129271382918453`*^9, 3.8129275247386045`*^9, 
   3.8129753514021273`*^9, 3.812975645223068*^9, 3.8148206976789436`*^9, 
   3.81547678623501*^9, 3.815774228918085*^9, 3.817019548351488*^9, 
   3.8171067838113747`*^9, 3.817106830936819*^9, 3.8171068789457073`*^9, 
   3.8188033815732555`*^9, 3.825025006890298*^9, 3.825074821626116*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[239]=",ExpressionUUID->"40ef3cec-7595-48a8-96ff-d5e98a1774e8"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
  3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
  3.8048542553403563`*^9, 
  3.8048542677330275`*^9}},ExpressionUUID->"0d1da58d-1aa7-4703-9e86-\
87f82453e588"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qatu1", "-", "qatu0"}], ")"}], "100"}], "qatu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.804858784498994*^9, 3.8048587856866765`*^9}},
 CellLabel->
  "In[240]:=",ExpressionUUID->"8550f87b-1995-4769-afe4-52aa757c92e5"],

Cell[BoxData[
 RowBox[{"-", "7.085849025537137`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.804858846717228*^9, 3.804858889770669*^9, 
   3.804859666387981*^9, 3.804859752807233*^9, 3.8048599669373083`*^9, 
   3.8048601139337645`*^9, 3.8048603832684374`*^9, 3.8048605402705026`*^9, 
   3.804860672204014*^9, 3.8048614919852467`*^9, 3.804865952357787*^9, 
   3.8048662760752697`*^9, 3.804866446665639*^9, 3.804867253070223*^9, 
   3.8048811933012834`*^9, 3.804895271690548*^9, 3.804896151124502*^9, 
   3.804896948690363*^9, 3.805729982884861*^9, 3.805730602426998*^9, 
   3.805731257397146*^9, 3.805757794938006*^9, 3.8066648841011314`*^9, 
   3.8066667490312963`*^9, 3.8066678639017615`*^9, 3.806667973672985*^9, 
   3.810033387129531*^9, 3.8100357405224257`*^9, 3.81246812243042*^9, 
   3.8124683916498175`*^9, 3.812468508112852*^9, 3.812553257442724*^9, 
   3.812731713158906*^9, 3.8127330365828543`*^9, 3.812821246080016*^9, 
   3.812926776139039*^9, 3.812927138435958*^9, 3.812927524878713*^9, 
   3.8129753515427675`*^9, 3.8129756453637238`*^9, 3.814820697852081*^9, 
   3.815476786391286*^9, 3.8157742290781965`*^9, 3.817019548367532*^9, 
   3.817106783825386*^9, 3.817106830947856*^9, 3.817106878957246*^9, 
   3.818803381587267*^9, 3.8250250070103908`*^9, 3.8250748217511454`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[240]=",ExpressionUUID->"84f45014-45a0-4495-a3dd-c4dd584121ba"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"64be1c49-a58d-4f9b-bf04-\
f2b3f67564ff"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"patp1", "-", "patp0"}], ")"}], "100"}], "patp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
  3.804858633427496*^9}, {3.804858743050418*^9, 3.8048587439411793`*^9}},
 CellLabel->
  "In[241]:=",ExpressionUUID->"0033ad0d-1379-457a-9dc2-1a86231bb164"],

Cell[BoxData["5.964681503091311`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.804858846857889*^9, 3.804858889926943*^9, 3.804859666544263*^9, 
   3.8048597529478846`*^9, 3.804859967093587*^9, 3.804860114090042*^9, 
   3.804860383409086*^9, 3.80486054041115*^9, 3.8048606723602886`*^9, 
   3.8048614920947437`*^9, 3.8048659524671793`*^9, 3.804866276184663*^9, 
   3.8048664467594037`*^9, 3.804867253179615*^9, 3.8048811934106317`*^9, 
   3.804895271799943*^9, 3.8048961512338953`*^9, 3.8048969487997556`*^9, 
   3.805729982994254*^9, 3.8057306025520153`*^9, 3.805731257522173*^9, 
   3.8057577950630274`*^9, 3.806664884210525*^9, 3.80666674914071*^9, 
   3.806667864011154*^9, 3.8066679738136325`*^9, 3.810033387249624*^9, 
   3.8100357406475224`*^9, 3.8124681225515137`*^9, 3.812468391777918*^9, 
   3.8124685082349243`*^9, 3.812553257557839*^9, 3.8127317132850266`*^9, 
   3.8127330367029476`*^9, 3.812821246199108*^9, 3.8129267762641363`*^9, 
   3.8129271385770674`*^9, 3.8129275250168204`*^9, 3.812975351699025*^9, 
   3.812975645519992*^9, 3.814820698005208*^9, 3.8154767865475616`*^9, 
   3.8157742292493305`*^9, 3.817019548383085*^9, 3.8171067838383965`*^9, 
   3.817106830959402*^9, 3.8171068789701924`*^9, 3.8188033816032796`*^9, 
   3.825025007131485*^9, 3.825074821876155*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[241]=",ExpressionUUID->"c42043a2-7bed-4995-b991-dcb4e5763333"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
  3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
  3.804854223908785*^9}, {3.8048542555122595`*^9, 
  3.804854280414089*^9}},ExpressionUUID->"1287b6cf-c7e5-4552-a2a6-\
c873534b38be"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qatp1", "-", "qatp0"}], ")"}], "100"}], "qatp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.8048587864211645`*^9, 3.804858787812003*^9}},
 CellLabel->
  "In[242]:=",ExpressionUUID->"04e6fdef-ca93-4416-a1ff-70212c4de514"],

Cell[BoxData[
 RowBox[{"-", "8.154598445317767`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.804858846998521*^9, 3.8048588900675893`*^9, 3.8048596666849174`*^9, 
   3.8048597530885797`*^9, 3.8048599672342367`*^9, 3.804860114246319*^9, 
   3.804860383565363*^9, 3.8048605405830526`*^9, 3.8048606725165644`*^9, 
   3.804861492204033*^9, 3.804865952576572*^9, 3.804866276294055*^9, 
   3.804866446884424*^9, 3.804867253320263*^9, 3.8048811935200243`*^9, 
   3.8048952719093375`*^9, 3.8048961513589153`*^9, 3.8048969488935204`*^9, 
   3.8057299831036468`*^9, 3.8057306026770334`*^9, 3.8057312576472006`*^9, 
   3.805757795188049*^9, 3.8066648843199177`*^9, 3.8066667493125916`*^9, 
   3.806667864153512*^9, 3.8066679739386525`*^9, 3.8100333873617105`*^9, 
   3.8100357407686167`*^9, 3.8124681226696057`*^9, 3.8124683918970113`*^9, 
   3.8124685083620234`*^9, 3.8125532576739035`*^9, 3.812731713405099*^9, 
   3.812733036824043*^9, 3.8128212463192015`*^9, 3.8129267763912535`*^9, 
   3.8129271387201786`*^9, 3.812927525147922*^9, 3.812975351839673*^9, 
   3.812975645660639*^9, 3.814820698163308*^9, 3.8154767866882105`*^9, 
   3.815774229423488*^9, 3.8170195483981123`*^9, 3.8171067838534613`*^9, 
   3.8171068309710045`*^9, 3.817106878982202*^9, 3.81880338161729*^9, 
   3.825025007248576*^9, 3.825074822001176*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[242]=",ExpressionUUID->"5c9f6884-075e-465b-9217-39f106fa6829"]
}, Open  ]],

Cell[TextData[StyleBox["Mackerel",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, {3.804858674828244*^9, 3.8048586759846716`*^9}, 
   3.8253516039430885`*^9},ExpressionUUID->"0da5a705-ebaa-47a5-9c78-\
216be9b445f4"],

Cell["\<\
Percent change in price of unprocessed domestic mackerel production\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}, {3.825074056228397*^9, 
  3.82507406146647*^9}},ExpressionUUID->"d6dd7271-b8f9-4b87-8e07-\
d998adc6d6c9"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pmdu1", "-", "pmdu0"}], ")"}], "100"}], "pmdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
  3.8048585992018385`*^9}, {3.8048587486137724`*^9, 3.804858750004611*^9}},
 CellLabel->
  "In[243]:=",ExpressionUUID->"eac04235-9dae-4c9d-9d14-9beadbe1df28"],

Cell[BoxData["1.2584100461138`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.804858847139168*^9, 3.804858890192608*^9, 
   3.804859666825571*^9, 3.8048597532291985`*^9, 3.8048599673748865`*^9, 
   3.804860114402596*^9, 3.8048603837216387`*^9, 3.8048605407393417`*^9, 
   3.8048606726728387`*^9, 3.804861492313425*^9, 3.8048659526859646`*^9, 
   3.8048662764034476`*^9, 3.8048664469938164`*^9, 3.8048672534297056`*^9, 
   3.8048811936294165`*^9, 3.804895272018732*^9, 3.8048961514683075`*^9, 
   3.8048969490185413`*^9, 3.80572998321304*^9, 3.805730603020832*^9, 
   3.8057312580222836`*^9, 3.8057577955474844`*^9, 3.806664884663726*^9, 
   3.8066667496876526`*^9, 3.8066678645442*^9, 3.806667974360628*^9, 
   3.810033387699973*^9, 3.810035741155916*^9, 3.8124681230358906`*^9, 
   3.8124683922603035`*^9, 3.8124685087233057`*^9, 3.8125532580311813`*^9, 
   3.812731713778389*^9, 3.8127330371953335`*^9, 3.8128212466734767`*^9, 
   3.8129267767705297`*^9, 3.8129271391305637`*^9, 3.812927525281026*^9, 
   3.8129753519879246`*^9, 3.8129756458169146`*^9, 3.814820698322427*^9, 
   3.8154767868444867`*^9, 3.8157742295856256`*^9, 3.817019548413124*^9, 
   3.817106783866553*^9, 3.8171068309830136`*^9, 3.8171068789932103`*^9, 
   3.8188033816333027`*^9, 3.825025007367668*^9, 3.825074822126196*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[243]=",ExpressionUUID->"53d9e532-4f86-497e-bd3c-3ad14476697a"]
}, Open  ]],

Cell["Percent change in quantity of domestic mackerel landings", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
  3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
  3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, {
  3.806665533633375*^9, 3.806665535644561*^9}, {3.8250741127937093`*^9, 
  3.825074116875883*^9}},ExpressionUUID->"6ab2d942-3780-4d10-a84d-\
bca6c00b9067"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qmdu1", "-", "qmdu0"}], ")"}], "100"}], "qmdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.804858792627643*^9, 3.804858798896052*^9}},
 CellLabel->
  "In[244]:=",ExpressionUUID->"699c7382-61c3-4087-9ac8-2d4750e55a95"],

Cell[BoxData["6.073269708963724`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.8048588472798543`*^9, 3.8048588903332553`*^9, 
   3.8048596669662247`*^9, 3.8048597533854685`*^9, 3.8048599675155373`*^9, 
   3.8048601145432453`*^9, 3.8048603838622866`*^9, 3.8048605408956027`*^9, 
   3.804860672829114*^9, 3.804861492438445*^9, 3.8048659527953568`*^9, 
   3.8048662765128403`*^9, 3.8048664471032095`*^9, 3.804867253539048*^9, 
   3.804881193738809*^9, 3.804895272128127*^9, 3.8048961515777006`*^9, 
   3.8048969491279335`*^9, 3.8057299833224325`*^9, 3.805730603130223*^9, 
   3.805731258131682*^9, 3.8057577956568775`*^9, 3.806664884773119*^9, 
   3.8066667498126736`*^9, 3.806667864653592*^9, 3.8066679744856405`*^9, 
   3.8100333878130608`*^9, 3.8100357412750096`*^9, 3.812468123157019*^9, 
   3.812468392381431*^9, 3.812468508840398*^9, 3.812553258149273*^9, 
   3.8127317138994827`*^9, 3.812733037319431*^9, 3.8128212468006315`*^9, 
   3.812926776916643*^9, 3.8129271392776113`*^9, 3.8129275254131794`*^9, 
   3.812975352150051*^9, 3.812975645957609*^9, 3.8148206984765453`*^9, 
   3.8154767870007615`*^9, 3.815774229760766*^9, 3.8170195484291363`*^9, 
   3.817106783880564*^9, 3.8171068309950233`*^9, 3.8171068790052195`*^9, 
   3.8188033816483145`*^9, 3.8250250074887624`*^9, 3.825074822251216*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[244]=",ExpressionUUID->"5112a693-4ec1-412c-b0c3-2180ec5b3f70"]
}, Open  ]],

Cell["Change in landings (in kg)", "Text",
 CellChangeTimes->{{3.819901014842124*^9, 
  3.819901018390876*^9}},ExpressionUUID->"1c0b0ab4-c65f-4eda-ba76-\
bfb5b4f1fc8c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qmdu1", "-", "qmdu0"}]], "Input",
 CellChangeTimes->{{3.825074799507327*^9, 3.825074801523279*^9}},
 CellLabel->
  "In[245]:=",ExpressionUUID->"d25db11c-bb5c-4f3d-8833-b0fc310153ac"],

Cell[BoxData["5.303981328062981`*^6"], "Output",
 CellChangeTimes->{3.815476788704164*^9, 3.815774231891396*^9, 
  3.817019548607972*^9, 3.8171067840503855`*^9, 3.817106831148345*^9, 
  3.817106879158753*^9, 3.8188033818224497`*^9, 3.825025009004942*^9, 
  3.8250748223762364`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[245]=",ExpressionUUID->"a9984cab-78fe-4d20-bbd8-fc8e27a5e2c3"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 
  3.80485427153401*^9}},ExpressionUUID->"d2845b1f-67a4-4183-b6ef-\
b498601995fd"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pmdp1", "-", "pmdp0"}], ")"}], "100"}], "pmdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
  3.8048586124851284`*^9}, {3.804858750567197*^9, 3.8048587511610384`*^9}},
 CellLabel->
  "In[246]:=",ExpressionUUID->"7c1759df-3d72-4500-860c-2dd4c373c9a0"],

Cell[BoxData["1.2584100461137986`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.804858847436088*^9, 3.8048588904739017`*^9, 
   3.8048596671068783`*^9, 3.804859753526121*^9, 3.804859967671815*^9, 
   3.804860114699522*^9, 3.80486038403419*^9, 3.8048605410518775`*^9, 
   3.8048606730010166`*^9, 3.8048614925478373`*^9, 3.80486595290475*^9, 
   3.804866276622233*^9, 3.8048664472126026`*^9, 3.8048672536484404`*^9, 
   3.8048811938325744`*^9, 3.8048952722375216`*^9, 3.804896151687093*^9, 
   3.8048969492373266`*^9, 3.805729983431825*^9, 3.8057306032552414`*^9, 
   3.80573125825671*^9, 3.805757795781898*^9, 3.806664884882512*^9, 
   3.806666749922067*^9, 3.806667864778612*^9, 3.8066679746106358`*^9, 
   3.810033387925148*^9, 3.810035741396104*^9, 3.8124681232930903`*^9, 
   3.812468392509487*^9, 3.8124685089614925`*^9, 3.8125532582663984`*^9, 
   3.812731714019576*^9, 3.8127330374405255`*^9, 3.8128212469186673`*^9, 
   3.812926777042742*^9, 3.812927139418721*^9, 3.8129275255472326`*^9, 
   3.812975352290159*^9, 3.8129756460982103`*^9, 3.8148206986316643`*^9, 
   3.8154767871570363`*^9, 3.8157742299308777`*^9, 3.817019548444148*^9, 
   3.8171067838935738`*^9, 3.8171068310070324`*^9, 3.8171068790162287`*^9, 
   3.818803381663326*^9, 3.8250250076088552`*^9, 3.8250748225012617`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[246]=",ExpressionUUID->"1c6905ef-5cee-40d2-954f-29846abf09a7"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
  3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
  3.804854255481004*^9, 
  3.8048542778511686`*^9}},ExpressionUUID->"312e9735-b698-47d1-8a41-\
0d85b37f1f59"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qmdp1", "-", "qmdp0"}], ")"}], "100"}], "qmdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}, {
  3.8048587995680304`*^9, 3.8048588001931267`*^9}},
 CellLabel->
  "In[247]:=",ExpressionUUID->"bf9dee48-da0c-4799-9b7a-a8cf2a44140f"],

Cell[BoxData["11.678405043049949`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.8048588475923624`*^9, 3.8048588906145487`*^9, 
   3.8048596672475457`*^9, 3.8048597536824007`*^9, 3.8048599678124647`*^9, 
   3.8048601148557987`*^9, 3.8048603841904664`*^9, 3.804860541192525*^9, 
   3.804860673141664*^9, 3.80486149265723*^9, 3.804865953014142*^9, 
   3.8048662767316256`*^9, 3.8048664473219957`*^9, 3.804867253757833*^9, 
   3.8048811939419665`*^9, 3.804895272346916*^9, 3.8048961517964897`*^9, 
   3.804896949346719*^9, 3.8057299836037273`*^9, 3.8057306033646317`*^9, 
   3.8057312583661084`*^9, 3.8057577959381733`*^9, 3.806664885007533*^9, 
   3.806666750047088*^9, 3.806667864903632*^9, 3.806667974751283*^9, 
   3.8100333880402374`*^9, 3.8100357415171976`*^9, 3.812468123410181*^9, 
   3.8124683926325827`*^9, 3.812468509080586*^9, 3.812553258385456*^9, 
   3.8127317141396694`*^9, 3.812733037561633*^9, 3.81282124703776*^9, 
   3.8129267771698413`*^9, 3.8129271395668793`*^9, 3.81292752568534*^9, 
   3.812975352431269*^9, 3.812975646254486*^9, 3.814820698790781*^9, 
   3.8154767873133116`*^9, 3.815774230145034*^9, 3.8170195484581594`*^9, 
   3.8171067839075847`*^9, 3.8171068310190525`*^9, 3.8171068790272365`*^9, 
   3.8188033816783376`*^9, 3.825025007728949*^9, 3.825074822641905*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[247]=",ExpressionUUID->"b2aa07ff-8bb5-479a-89fc-13fccff853ee"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.8057300002942157`*^9, 3.805730015355893*^9}, 
   3.8066652403410068`*^9, {3.815774093884719*^9, 3.8157740944752064`*^9}, 
   3.8250741871472635`*^9},ExpressionUUID->"76740a0a-60a9-4d1f-8b97-\
a43b13a4e01e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "sigmamu"}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pmdu1", " ", 
      RowBox[{"(", 
       RowBox[{"qmdu1", "-", "qmdue0", "-", 
        RowBox[{"cr", " ", "qmdp1"}]}], ")"}]}], " ", "-", " ", 
     RowBox[{"pmdu0", " ", 
      RowBox[{"(", 
       RowBox[{"qmdu0", "-", "qmdue0", "-", 
        RowBox[{"cr", " ", "qmdp0"}]}], ")"}]}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8057300177232914`*^9, 3.8057300557466383`*^9}, {
   3.805730270965039*^9, 3.8057302796690135`*^9}, {3.8057311629976764`*^9, 
   3.8057311711395903`*^9}, {3.8066655483192253`*^9, 3.8066655644668813`*^9}, 
   3.825074848859544*^9},
 CellLabel->
  "In[256]:=",ExpressionUUID->"c08c8fcd-39d1-42a9-99bb-7ac22e1ace69"],

Cell[BoxData["72830.7914285633`"], "Output",
 CellChangeTimes->{
  3.805730090816584*^9, 3.805730604020976*^9, 3.8057311724991817`*^9, 
   3.8057312589912457`*^9, 3.8057577965476475`*^9, 3.8066648855857553`*^9, 
   3.806665566753168*^9, 3.8066667506878195`*^9, 3.806667865497478*^9, 
   3.806667975491397*^9, 3.810033388629695*^9, 3.810035742111658*^9, 
   3.812468124014651*^9, 3.8124683932670774`*^9, 3.8124685096840587`*^9, 
   3.8125532590089407`*^9, 3.8127317147571516`*^9, 3.812733038194116*^9, 
   3.812821247634223*^9, 3.8129267778233533`*^9, 3.8129271403134165`*^9, 
   3.8129275258254485`*^9, 3.8129753525703773`*^9, 3.812975646395134*^9, 
   3.814820698962922*^9, 3.815476787469586*^9, 3.8157742303232107`*^9, 
   3.8170195484731884`*^9, 3.8171067839215956`*^9, 3.8171068310330524`*^9, 
   3.8171068790392456`*^9, 3.8188033816923485`*^9, 3.825025007891075*^9, {
   3.825074822772192*^9, 3.825074852406995*^9}},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[256]=",ExpressionUUID->"68a82730-6e9c-4d2d-8f23-013625cfcd5d"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.8057300588565187`*^9, 3.8057300659357986`*^9}, 
   3.806664503243363*^9, {3.8157740966218557`*^9, 3.8157740971832747`*^9}, 
   3.8250742073468723`*^9},ExpressionUUID->"3bc32221-f774-4346-88b3-\
e4a514c49c39"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "sigmamp"}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pmdp1", " ", 
      RowBox[{"(", 
       RowBox[{"qmdp1", "-", "qmdpe0"}], ")"}]}], " ", "-", " ", 
     RowBox[{"pmdp0", " ", 
      RowBox[{"(", 
       RowBox[{"qmdp0", "-", "qmdpe0"}], ")"}]}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8057300679517508`*^9, 3.8057300874566574`*^9}, {
   3.805730282247436*^9, 3.8057302889838142`*^9}, {3.8057311812035837`*^9, 
   3.805731186095003*^9}, {3.8128213971045856`*^9, 3.8128214089267836`*^9}, 
   3.8250748454324036`*^9},
 CellLabel->
  "In[257]:=",ExpressionUUID->"45d4a662-3305-4e34-89c4-8e1b3412c432"],

Cell[BoxData["2.0394638553385716`*^6"], "Output",
 CellChangeTimes->{3.8057300882849207`*^9, 3.805730604145995*^9, 
  3.8057311865482016`*^9, 3.8057312591006446`*^9, 3.8057577966726675`*^9, 
  3.806664885695148*^9, 3.8066667507972136`*^9, 3.806667865622498*^9, 
  3.806667975600789*^9, 3.810033388743784*^9, 3.8100357422397585`*^9, 
  3.8124681241357446`*^9, 3.812468393391175*^9, 3.812468509803152*^9, 
  3.8125532591300344`*^9, 3.8127317148942585`*^9, 3.8127330383222165`*^9, 
  3.8128212477553177`*^9, 3.8128214098565097`*^9, 3.8129267779774857`*^9, 
  3.8129271404465194`*^9, 3.812927525959553*^9, 3.8129753527195053`*^9, 
  3.812975646551409*^9, 3.814820699122032*^9, 3.8154767876102333`*^9, 
  3.8157742306804523`*^9, 3.8170195485022783`*^9, 3.8171067839496527`*^9, 
  3.8171068310596743`*^9, 3.817106879065853*^9, 3.81880338171937*^9, 
  3.825025008133263*^9, 3.825074822897212*^9, 3.8250748551208005`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[257]=",ExpressionUUID->"822b81d2-4f25-46a2-88b1-f85f39c610a0"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"44538c4e-1e32-4e62-83c8-\
b7718d9697ea"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pmtu1", "-", "pmtu0"}], ")"}], "100"}], "pmtu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
  3.8048586228946285`*^9}, {3.804858751489214*^9, 3.8048587520986824`*^9}},
 CellLabel->
  "In[250]:=",ExpressionUUID->"4b5f3777-f0ec-482e-99c6-1607ad258f3c"],

Cell[BoxData["5.742177939718174`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.8048588477330093`*^9, 3.8048588907551947`*^9, 
   3.8048596674038343`*^9, 3.804859753823053*^9, 3.8048599679531155`*^9, 
   3.804860114996448*^9, 3.8048603843467426`*^9, 3.8048605413487997`*^9, 
   3.804860673297939*^9, 3.8048614927666225`*^9, 3.8048659531235347`*^9, 
   3.8048662768410177`*^9, 3.804866447431389*^9, 3.804867253867225*^9, 
   3.804881194051359*^9, 3.804895272440683*^9, 3.804896151905878*^9, 
   3.804896949456112*^9, 3.8057299837131205`*^9, 3.8057306035209045`*^9, 
   3.8057312585223927`*^9, 3.8057577960631933`*^9, 3.806664885116927*^9, 
   3.8066667501721573`*^9, 3.806667865013053*^9, 3.8066679748819237`*^9, 
   3.810033388151324*^9, 3.8100357416382914`*^9, 3.8124681235292735`*^9, 
   3.8124683927576804`*^9, 3.812468509207686*^9, 3.812553258521562*^9, 
   3.8127317142637663`*^9, 3.812733037681715*^9, 3.8128212471518717`*^9, 
   3.812926777304947*^9, 3.8129271397179546`*^9, 3.8129275260966587`*^9, 
   3.8129753528606033`*^9, 3.8129756467076845`*^9, 3.814820699280183*^9, 
   3.8154767877665086`*^9, 3.815774230845585*^9, 3.81701954851729*^9, 
   3.817106783964771*^9, 3.817106831072279*^9, 3.817106879078149*^9, 
   3.8188033817343807`*^9, 3.8250250082533565`*^9, 3.825074823022232*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[250]=",ExpressionUUID->"a27f7eb3-bbab-49a1-8bec-1195726559c5"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
  3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
  3.8048542553403563`*^9, 
  3.8048542677330275`*^9}},ExpressionUUID->"7d0cf9a0-3acd-42fb-ac58-\
b758e20e9bab"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qmtu1", "-", "qmtu0"}], ")"}], "100"}], "qmtu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.804858800630694*^9, 3.8048588012870445`*^9}},
 CellLabel->
  "In[251]:=",ExpressionUUID->"5f50749e-a91c-4991-99cb-2687d628f86c"],

Cell[BoxData[
 RowBox[{"-", "8.649946295890818`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588478736553`*^9, 3.8048588909114695`*^9, 
   3.8048596675600967`*^9, 3.804859753963705*^9, 3.804859968109393*^9, 
   3.804860115168353*^9, 3.8048603844873915`*^9, 3.8048605415207024`*^9, 
   3.8048606734385867`*^9, 3.8048614928760147`*^9, 3.804865953232927*^9, 
   3.8048662769660378`*^9, 3.8048664475407825`*^9, 3.804867253961108*^9, 
   3.8048811941607513`*^9, 3.804895272550078*^9, 3.8048961520152717`*^9, 
   3.804896949565504*^9, 3.8057299838381405`*^9, 3.805730603661549*^9, 
   3.805731258647421*^9, 3.8057577961725864`*^9, 3.8066648852263193`*^9, 
   3.806666750281502*^9, 3.8066678651536727`*^9, 3.8066679750069437`*^9, 
   3.8100333882784224`*^9, 3.8100357417573843`*^9, 3.812468123647365*^9, 
   3.812468392892785*^9, 3.812468509326779*^9, 3.8125532586436567`*^9, 
   3.812731714381858*^9, 3.8127330378048105`*^9, 3.812821247271942*^9, 
   3.8129267774330473`*^9, 3.8129271398670692`*^9, 3.8129275262307634`*^9, 
   3.8129753529922886`*^9, 3.8129756468483334`*^9, 3.8148206994372816`*^9, 
   3.815476787922784*^9, 3.815774231017725*^9, 3.817019548532302*^9, 
   3.8171067839787817`*^9, 3.81710683108629*^9, 3.817106879092181*^9, 
   3.8188033817493925`*^9, 3.8250250083734493`*^9, 3.825074823147253*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[251]=",ExpressionUUID->"af21acf7-0eb5-4ca1-958e-3098fd129a9e"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"e745e36a-4f70-481c-8fb6-\
6bb8fe578131"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pmtp1", "-", "pmtp0"}], ")"}], "100"}], "pmtp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
  3.804858633427496*^9}, {3.804858752504995*^9, 3.804858754192754*^9}},
 CellLabel->
  "In[252]:=",ExpressionUUID->"305151c4-d677-4e89-8ccb-7d1d76c8b5ed"],

Cell[BoxData["4.310673670213997`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.8048588480143023`*^9, 3.8048588910677433`*^9, 3.8048596677007504`*^9, 
   3.8048597541199846`*^9, 3.804859968250043*^9, 3.804860115309002*^9, 
   3.8048603846436667`*^9, 3.804860541708233*^9, 3.804860673594861*^9, 
   3.804861492985408*^9, 3.804865953357947*^9, 3.8048662770754304`*^9, 
   3.804866447650175*^9, 3.804867254086011*^9, 3.8048811942701445`*^9, 
   3.8048952726594725`*^9, 3.8048961521246634`*^9, 3.8048969496748967`*^9, 
   3.8057299839475336`*^9, 3.805730603786567*^9, 3.8057312587568192`*^9, 
   3.8057577962976065`*^9, 3.806664885351341*^9, 3.8066667504221506`*^9, 
   3.8066678652630653`*^9, 3.8066679751475916`*^9, 3.8100333883955135`*^9, 
   3.8100357418774776`*^9, 3.8124681237674584`*^9, 3.812468393017883*^9, 
   3.8124685094438705`*^9, 3.8125532587667522`*^9, 3.8127317145049543`*^9, 
   3.812733037929909*^9, 3.8128212473900337`*^9, 3.8129267775611477`*^9, 
   3.812927140014184*^9, 3.8129275263698716`*^9, 3.8129753531798186`*^9, 
   3.8129756469889817`*^9, 3.8148206995643682`*^9, 3.8154767880946875`*^9, 
   3.8157742312038565`*^9, 3.817019548548314*^9, 3.8171067839917917`*^9, 
   3.8171068310983286`*^9, 3.8171068791071715`*^9, 3.818803381763404*^9, 
   3.8250250084935427`*^9, 3.825074823272273*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[252]=",ExpressionUUID->"071d8939-6e11-4e2b-a51c-9bacb13d1590"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
  3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
  3.804854223908785*^9}, {3.8048542555122595`*^9, 
  3.804854280414089*^9}},ExpressionUUID->"e36a07fd-56c3-4cfb-8912-\
9cdfc5e191d1"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qmtp1", "-", "qmtp0"}], ")"}], "100"}], "qmtp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.804858801740239*^9, 3.8048588038343105`*^9}},
 CellLabel->
  "In[253]:=",ExpressionUUID->"8aa73854-3a13-4f13-ad44-e3ae30c9c42c"],

Cell[BoxData[
 RowBox[{"-", "11.395838006470267`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.804858848154949*^9, 3.804858891192762*^9, 3.8048596678726606`*^9, 
   3.804859754260637*^9, 3.80485996839496*^9, 3.804860115465279*^9, 
   3.804860384799943*^9, 3.80486054184888*^9, 3.80486067373553*^9, 
   3.80486149309489*^9, 3.804865953482967*^9, 3.804866277169195*^9, 
   3.804866447759568*^9, 3.804867254195405*^9, 3.8048811943795366`*^9, 
   3.804895272768914*^9, 3.8048961522340565`*^9, 3.8048969497842894`*^9, 
   3.8057299840569267`*^9, 3.805730603895958*^9, 3.805731258881847*^9, 
   3.805757796438255*^9, 3.806664885476362*^9, 3.8066667505627995`*^9, 
   3.8066678653880854`*^9, 3.8066679753351216`*^9, 3.8100333885096016`*^9, 
   3.8100357419955688`*^9, 3.812468123887552*^9, 3.8124683931439815`*^9, 
   3.812468509564974*^9, 3.8125532588878465`*^9, 3.8127317146320534`*^9, 
   3.8127330380670166`*^9, 3.8128212475111275`*^9, 3.812926777693251*^9, 
   3.8129271401632996`*^9, 3.812927526503976*^9, 3.812975353320467*^9, 
   3.812975647129631*^9, 3.814820699692465*^9, 3.815476788250963*^9, 
   3.815774231377014*^9, 3.817019548563332*^9, 3.8171067840068035`*^9, 
   3.817106831111309*^9, 3.8171068791191807`*^9, 3.818803381779416*^9, 
   3.825025008615638*^9, 3.825074823397293*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[253]=",ExpressionUUID->"360a62c4-4841-4279-bb61-a58ea2ec3661"]
}, Open  ]],

Cell[TextData[StyleBox["Price Indexes",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
  3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
  3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
  3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
  3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
  3.8048584943088517`*^9}, {3.804858674828244*^9, 
  3.8048586889112*^9}},ExpressionUUID->"13815c13-7ce0-400f-bac6-d5bef354e17d"],

Cell["Percent change in unprocessed price index", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998489833914266`*^9, 3.79984901086983*^9}, {3.7998491773192368`*^9, 
   3.79984917888201*^9}, {3.7998492779954705`*^9, 3.799849344403957*^9}, {
   3.799855217193923*^9, 3.7998552176158657`*^9}, 3.804345400385578*^9, {
   3.8043488808930616`*^9, 3.8043489145962877`*^9}, {3.8048542237212534`*^9, 
   3.8048542237212534`*^9}, {3.8048542553091016`*^9, 
   3.8048542553091016`*^9}},ExpressionUUID->"8d6f960c-cea6-4ac7-9d42-\
3184797329a6"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Pu1", "-", "Pu0"}], ")"}], "100"}], "Pu0"]], "Input",
 CellChangeTimes->{{3.79984918480492*^9, 3.799849273791636*^9}, {
  3.7998552126150475`*^9, 3.7998552128807173`*^9}, {3.8017816587699327`*^9, 
  3.8017816805942984`*^9}, {3.804345394438952*^9, 3.8043453971470623`*^9}, {
  3.804348884814114*^9, 3.804348889233554*^9}},
 CellLabel->
  "In[254]:=",ExpressionUUID->"4be7ba51-cceb-4e00-9209-e3ee85fa7c30"],

Cell[BoxData["4.56925300374753`"], "Output",
 CellChangeTimes->{
  3.7998492746667833`*^9, 3.7998495923806477`*^9, 3.7998508747820983`*^9, 
   3.7998510932094183`*^9, 3.7998552215383844`*^9, 3.7998552591406136`*^9, 
   3.799856732964707*^9, 3.7998567782777624`*^9, 3.799857195292985*^9, {
   3.79985741126893*^9, 3.799857481157101*^9}, 3.7998575225746374`*^9, {
   3.799857623596133*^9, 3.799857665541498*^9}, 3.7998577599781284`*^9, {
   3.8016608497619348`*^9, 3.801660862874851*^9}, 3.801662764470834*^9, 
   3.8016634678095245`*^9, 3.8016642628400764`*^9, {3.801664312666783*^9, 
   3.8016643351216216`*^9}, 3.801664460338441*^9, {3.8016653833153267`*^9, 
   3.8016653970378222`*^9}, 3.8016654290440674`*^9, {3.801666723097561*^9, 
   3.8016667511780653`*^9}, 3.8016667864140167`*^9, {3.801666960325522*^9, 
   3.8016669841279755`*^9}, 3.801667113594228*^9, 3.8016672275438757`*^9, 
   3.8016673978818293`*^9, 3.8016675839057274`*^9, {3.8016678479599924`*^9, 
   3.8016678631653695`*^9}, 3.8016679342935286`*^9, {3.801668183552487*^9, 
   3.8016682040499134`*^9}, {3.801668269038266*^9, 3.8016682954359474`*^9}, {
   3.801668345072152*^9, 3.801668369796582*^9}, 3.801668420866907*^9, 
   3.8016684524994974`*^9, 3.801668487394171*^9, 3.801668541287839*^9, 
   3.801692587562277*^9, 3.80169264102909*^9, 3.8016927462307262`*^9, 
   3.8016929523093896`*^9, 3.8016932298288126`*^9, 3.801693287020975*^9, 
   3.8016933968966064`*^9, 3.801693489102943*^9, 3.801776983907366*^9, 
   3.8017772015105257`*^9, 3.801777273900032*^9, 3.8017776517080097`*^9, 
   3.8017780057445364`*^9, 3.801778074046605*^9, 3.8017783131783795`*^9, 
   3.8017783439221983`*^9, 3.8017786553876815`*^9, 3.801779138145771*^9, 
   3.8017792488796043`*^9, 3.801779506310661*^9, 3.8017795492418423`*^9, 
   3.8017796217887506`*^9, 3.801779709371714*^9, 3.801779817116694*^9, 
   3.8017798533916473`*^9, 3.801779899000266*^9, {3.8017799405079165`*^9, 
   3.801779967450033*^9}, 3.8017802560183163`*^9, 3.801780306746418*^9, 
   3.801780344211422*^9, {3.8017804439702563`*^9, 3.8017804721700673`*^9}, 
   3.8017805409035826`*^9, 3.8017805802003374`*^9, 3.8017806656129417`*^9, 
   3.8017811762878675`*^9, 3.801781222587922*^9, 3.801781688096794*^9, {
   3.8017819978231897`*^9, 3.801782035287342*^9}, 3.8017820890438232`*^9, {
   3.8017822319383073`*^9, 3.8017822491911564`*^9}, 3.8030750870008593`*^9, 
   3.8030751540073695`*^9, 3.803075259202407*^9, 3.8030754034217415`*^9, 
   3.8030755054493756`*^9, 3.8031139645613594`*^9, 3.803114084480019*^9, 
   3.8031141469538784`*^9, 3.803114191096325*^9, 3.803114297645469*^9, 
   3.803114393611354*^9, 3.8031185696297293`*^9, 3.803118638170224*^9, 
   3.803118702047079*^9, {3.8031187473594465`*^9, 3.803118769043373*^9}, 
   3.80311880845013*^9, 3.8031205934932847`*^9, 3.803120630774397*^9, 
   3.8031244174185233`*^9, 3.8031245169131594`*^9, 3.8031249102831197`*^9, 
   3.803124991509452*^9, 3.803125759075655*^9, 3.803126253346963*^9, 
   3.803128483130848*^9, 3.8031286690979834`*^9, 3.8032924987962933`*^9, 
   3.803303084561537*^9, 3.8033032747697845`*^9, 3.8033104115209475`*^9, 
   3.803312901030964*^9, 3.803313231275567*^9, 3.803391647600006*^9, 
   3.803392062973687*^9, 3.8033921283218317`*^9, 3.803392520065557*^9, 
   3.8033926306852746`*^9, 3.8033944589630575`*^9, 3.8033947991320267`*^9, 
   3.803394914026799*^9, 3.803397326004096*^9, 3.8033974445483875`*^9, 
   3.8033980677407513`*^9, 3.8033984374911313`*^9, 3.803398591318152*^9, 
   3.8035096208316846`*^9, 3.8035103296726255`*^9, 3.803511721217949*^9, 
   3.803512180748121*^9, 3.804345496959716*^9, 3.804345535141422*^9, 
   3.8043455688236265`*^9, 3.8043459771150684`*^9, 3.804346900651185*^9, 
   3.804347743976942*^9, {3.8043478447983723`*^9, 3.8043478587622347`*^9}, 
   3.8043478907551184`*^9, 3.8043479285926*^9, {3.8043482361294065`*^9, 
   3.804348258143536*^9}, 3.804348936898817*^9, 3.804349006147746*^9, 
   3.8043490998016157`*^9, 3.8045199879901805`*^9, 3.804520290649263*^9, 
   3.8045204189345813`*^9, 3.8045205647204466`*^9, 3.804521041946695*^9, 
   3.8045210804643292`*^9, 3.8045211595556393`*^9, 3.8045213929101944`*^9, 
   3.8045214710169363`*^9, 3.8045458082556286`*^9, 3.8045458827903852`*^9, 
   3.804546096639233*^9, 3.8045461955027046`*^9, 3.8045873500938845`*^9, 
   3.804590445246277*^9, 3.80459171067251*^9, 3.8045918182908363`*^9, 
   3.804858848295595*^9, 3.8048588913334084`*^9, 3.8048596680133142`*^9, 
   3.804859754401289*^9, 3.80485996853561*^9, 3.8048601156215563`*^9, 
   3.8048603849562187`*^9, 3.804860542005155*^9, 3.8048606738917837`*^9, 
   3.804861493206768*^9, 3.8048659536079865`*^9, 3.8048662772785873`*^9, 
   3.804866447868962*^9, 3.8048672543047976`*^9, 3.8048811944889293`*^9, 
   3.8048952728938904`*^9, 3.8048961523434486`*^9, 3.804896949893682*^9, 
   3.805729984166319*^9, 3.8057306042553864`*^9, 3.805731259225672*^9, 
   3.80575779678207*^9, 3.8066648858201694`*^9, 3.8066667509222493`*^9, 
   3.8066678657631464`*^9, 3.806667975725809*^9, 3.8100333888578715`*^9, 
   3.810035742362854*^9, 3.812468124257839*^9, 3.8124683935112686`*^9, 
   3.8124685099212446`*^9, 3.8125532592551317`*^9, 3.8127317150213585`*^9, 
   3.812733038698511*^9, 3.812821247881453*^9, 3.812926778112579*^9, 
   3.8129271405876293`*^9, 3.8129275266370792`*^9, 3.812975353476742*^9, 
   3.8129756472715087`*^9, 3.8148206998205624`*^9, 3.8154767883916116`*^9, 
   3.815774231540141*^9, 3.8170195485788836`*^9, 3.817106784020814*^9, 
   3.8171068311243196`*^9, 3.8171068791331916`*^9, 3.8188033817934265`*^9, 
   3.8250250087397346`*^9, 3.8250748235223136`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[254]=",ExpressionUUID->"48a703b4-d115-4def-9a55-5cbb1d39fc5d"]
}, Open  ]],

Cell["Percent change in processed price index", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8043489043563223`*^9, 3.80434890819631*^9}, {3.8048542238619013`*^9, 
  3.8048542238619013`*^9}, {3.804854255465377*^9, 
  3.804854255465377*^9}},ExpressionUUID->"c459d460-c983-4424-b98e-\
d057822b1f1b"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Pp1", "-", "Pp0"}], ")"}], "100"}], "Pp0"]], "Input",
 CellLabel->
  "In[255]:=",ExpressionUUID->"ea1630c7-69ec-469b-95ed-58312d9bf06e"],

Cell[BoxData["4.972503979345086`"], "Output",
 CellChangeTimes->CompressedData["
1:eJwVxV1IU2EcB+CjU8jCSWoHsgWnZCZlpWtbFrt5jcL1rbmyGEQ6ydychSYJ
0pDwAzaLSnFhYWhLkJOwNdCCYl5k0WpFqNTRBGnWgtegwAIz1/938fBsqqgr
rUoQBOEAydyiZYXlnHVPvDFjp6vFgpWd7eNuOuullWNnrGoZ71X3qT10OGw+
iDfMiMdwbvFSOQ7cz2nEmjXfXTjPkF7hpc2HbHasuSy14Ydi8y18oSU8JNO/
5/zbh+nrybNhrERKPuHAYqqp4DRnjdvqGC6rbe3HXadKHuFf2eIrnBi9ouDO
O9nL+OnWF2k6ejSlSMLxjUNtONRgDOppS408g4OR+E+cPvb2pIFu8p3QmuhY
lpS8jw78U9fj/PWhKdz/YZVXOcNZkeyex99Ga3ZP0872u3kxeun5M3HAyplR
NRfH03aT+wG9suevF8/r+j6nVXJ2tOGdai3tyPU8Dp7nTNLrJ7GvdOwLXr3L
sX+W3tFjqzZUc5akU1KN9I1MQTpHN+UUD3bR7wd6JvDmex+Tuulhpj8r07b8
hWu413PVXuDg7HDHzfFLtZwd0f5JVDk5+5FyO6PyImfN2gS5k45Yo37c64uO
4IWvT8TX9ZytK9SsDLo4E0YWj4fo/2lbFRI=
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[255]=",ExpressionUUID->"ffcc378a-779b-412e-9358-5ede4e5b565b"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{851, 676},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 1487, 28, 196, "Title",ExpressionUUID->"801921a0-034a-43a0-82ec-dcdaf955be7a"],
Cell[2070, 52, 5310, 76, 478, "Text",ExpressionUUID->"f0b295dd-f91c-483d-b6ca-da78d06e7819"],
Cell[7383, 130, 225, 4, 28, "Input",ExpressionUUID->"0c777ea8-191a-4659-be18-f91ea0d0ffda"],
Cell[CellGroupData[{
Cell[7633, 138, 375, 6, 62, "Section",ExpressionUUID->"e96e59ff-4f99-46b0-8141-97bb85c5e783"],
Cell[CellGroupData[{
Cell[8033, 148, 381, 7, 43, "Subsubsection",ExpressionUUID->"36f1d069-9e60-47fe-944f-3d46d93bc2b7",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[8417, 157, 555, 8, 48, "Text",ExpressionUUID->"3e7f441b-c404-4d77-b05c-440c2c0e20ef",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[8975, 167, 1149, 21, 33, "Text",ExpressionUUID->"f78bda85-40b2-4149-bb25-a6cc46c630d6",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[10127, 190, 1814, 26, 44, "Input",ExpressionUUID->"0d44e1c6-e9d4-484e-888a-97e11d7e3438",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[11944, 218, 1188, 21, 33, "Text",ExpressionUUID->"b37b650e-a17b-4e87-9952-51ad9ceedb32",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[13135, 241, 1864, 27, 44, "Input",ExpressionUUID->"2db00afb-2db9-4f8d-b635-efd25d598ba2",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[15002, 270, 1201, 22, 33, "Text",ExpressionUUID->"69b49a6e-2825-4d87-b4ad-ad9ada03bb4d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[16206, 294, 1824, 27, 44, "Input",ExpressionUUID->"68e3b805-5eb8-437a-a7f8-432c5dc38fa6",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[18033, 323, 1240, 22, 33, "Text",ExpressionUUID->"4edd4f8f-8cfd-4a1b-b8fe-29f75eb7f019",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[19276, 347, 1897, 28, 44, "Input",ExpressionUUID->"2d53b917-3bb8-4216-97a2-5728876c05b0",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[21176, 377, 1201, 22, 33, "Text",ExpressionUUID->"c57c3269-221e-4ee9-abd4-2bcaf6b11529",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[22380, 401, 1823, 27, 44, "Input",ExpressionUUID->"8ce1a048-b83e-4f20-84d6-e5ec15b6f8ef",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[24206, 430, 1238, 22, 33, "Text",ExpressionUUID->"c6f8303c-c267-4f20-a568-2e35ce70f364",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[25447, 454, 1847, 27, 44, "Input",ExpressionUUID->"d25950bb-8a53-4244-b786-111775e2873b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[27297, 483, 1205, 22, 33, "Text",ExpressionUUID->"831362de-d808-4975-bf49-016ef7debc53",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[28505, 507, 1825, 26, 44, "Input",ExpressionUUID->"055efbdb-f3e0-4860-881d-c7aa622d1cfb",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[30333, 535, 1292, 22, 33, "Text",ExpressionUUID->"1de89b03-9b1a-4638-b139-83b9a727d7f9",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[31628, 559, 1856, 27, 44, "Input",ExpressionUUID->"634e6d9f-798a-4eec-aa52-d43e4534b1a9",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[33521, 591, 433, 8, 43, "Subsubsection",ExpressionUUID->"15f452e6-d489-4c7a-a831-1523a9049dbe",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[33957, 601, 585, 9, 30, "Text",ExpressionUUID->"10e61272-e8eb-4a92-9e23-2ceead6b8a8f",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[34545, 612, 1199, 21, 33, "Text",ExpressionUUID->"ca749f20-babd-4cae-9cdd-32c597337e02",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[35747, 635, 1665, 24, 44, "Input",ExpressionUUID->"032c980e-ebad-4d4e-8127-df2782b438fd",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[37415, 661, 1254, 22, 33, "Text",ExpressionUUID->"25c2a9cd-6d54-4cd1-8cb6-aa67dd64a560",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[38672, 685, 1670, 24, 44, "Input",ExpressionUUID->"fd7a3398-1416-478f-ab09-0f728be2ac6a",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[40379, 714, 525, 8, 43, "Subsubsection",ExpressionUUID->"96cf782b-13a7-43de-8308-f00615cea5ca",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[40907, 724, 541, 8, 30, "Text",ExpressionUUID->"b7907907-4ad8-4f22-a3b9-1ccff4acff46",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[41451, 734, 976, 15, 34, "Text",ExpressionUUID->"d9010a8d-269c-409d-87bb-3a17d8b809bd",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[42430, 751, 1114, 18, 44, "Input",ExpressionUUID->"27835e5a-02b3-4138-b277-7ab38eb701e7",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[43547, 771, 846, 14, 34, "Text",ExpressionUUID->"dfc88d43-fa3a-4b19-9406-5673cf2abd78",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[44396, 787, 1113, 18, 44, "Input",ExpressionUUID->"2c5e7f74-9a89-4ceb-8daa-2687f3a43f10",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[45546, 810, 572, 9, 43, "Subsubsection",ExpressionUUID->"06422778-09b4-480b-889a-6b8868a92f5e",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[46121, 821, 854, 12, 48, "Text",ExpressionUUID->"fc27f0d3-736e-4342-adf0-887321523fef",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[46978, 835, 1118, 19, 34, "Text",ExpressionUUID->"54df29dd-63b6-4dfe-ae21-a854f55d7518",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[48099, 856, 3029, 46, 44, "Input",ExpressionUUID->"e71883ba-93a1-4219-bd68-67879f88fe63",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[51131, 904, 1118, 19, 34, "Text",ExpressionUUID->"44c07241-9d58-4849-864f-83f0aa6a6962",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[52252, 925, 2860, 41, 44, "Input",ExpressionUUID->"0e18a7d4-8fb2-4ced-909c-3413ff8556fe",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[55115, 968, 1170, 20, 34, "Text",ExpressionUUID->"ff64f6d0-3cae-46f5-b93b-2df56fdb9935",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[56288, 990, 2892, 42, 44, "Input",ExpressionUUID->"7465d23f-f8c3-4f77-a89e-814ec6dd6ef5",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[59183, 1034, 1172, 20, 34, "Text",ExpressionUUID->"8f79e8eb-364e-4645-af5e-08fa3b56a048",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[60358, 1056, 2895, 42, 44, "Input",ExpressionUUID->"cc0bc1ac-d58b-488a-b50e-37b05eb85d04",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[63290, 1103, 615, 9, 43, "Subsubsection",ExpressionUUID->"a4c19597-a956-4d47-b33a-2e05160e9758",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[63908, 1114, 585, 9, 30, "Text",ExpressionUUID->"88a33b7b-b69c-43e4-a11c-8d4ee25cbbce",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[64496, 1125, 921, 14, 34, "Text",ExpressionUUID->"db6987eb-0e05-401c-b00a-057ce9de43f5",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[65420, 1141, 2355, 34, 44, "Input",ExpressionUUID->"0e61cea0-3282-45a7-bd8e-9e8e785d69eb",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[67778, 1177, 917, 14, 34, "Text",ExpressionUUID->"91eb547e-5ee0-4dcd-b4c1-98bc27ce55b7",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[68698, 1193, 2364, 34, 44, "Input",ExpressionUUID->"daaf0596-c33a-4587-81b3-e028c2d51607",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[71065, 1229, 917, 14, 34, "Text",ExpressionUUID->"9bfdab0d-22e5-4118-807c-6fdecc82ee3e",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[71985, 1245, 2290, 33, 44, "Input",ExpressionUUID->"61c0c99e-cd47-4677-a666-19e1cd12c8f5",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[74278, 1280, 922, 14, 34, "Text",ExpressionUUID->"a235a056-7d5e-4248-9ede-429a18bb62f4",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[75203, 1296, 2290, 33, 44, "Input",ExpressionUUID->"c77200e6-564e-48a4-9d46-75e553d26040",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[77530, 1334, 707, 11, 43, "Subsubsection",ExpressionUUID->"ec2bb41e-29b7-4a5d-b443-f21a75702f06",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[78240, 1347, 622, 9, 30, "Text",ExpressionUUID->"c125caf2-f3cc-4c41-8397-f7fd0c54b59c",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[78865, 1358, 2435, 35, 44, "Input",ExpressionUUID->"53379da6-b7f9-4200-b622-21275c340c98",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[81349, 1399, 445, 7, 62, "Section",ExpressionUUID->"d4695fb3-0a18-49e6-835a-b22ed7f295ac"],
Cell[CellGroupData[{
Cell[81819, 1410, 423, 7, 43, "Subsubsection",ExpressionUUID->"b6c27210-9183-49b2-be67-fc2df293ddda",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[82245, 1419, 776, 12, 84, "Text",ExpressionUUID->"04d83cbe-5516-46f5-b4b8-b781d5ac2e29",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[83024, 1433, 550, 9, 34, "Text",ExpressionUUID->"2b5f3e83-7e35-4acf-98b4-430eeba265e4",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[83577, 1444, 997, 17, 44, "Input",ExpressionUUID->"400c8e39-93cb-4fef-a9fb-41930d195d3f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[84577, 1463, 1755, 28, 47, "Input",ExpressionUUID->"cfe43c25-be78-4227-bac0-674e47880d70",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[86335, 1493, 550, 9, 34, "Text",ExpressionUUID->"b528d670-b0bf-4367-9dd3-5becbbd0b094",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[86888, 1504, 994, 17, 44, "Input",ExpressionUUID->"4ecde827-d0a5-44ad-8f2a-1ab84264d7b8",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[87885, 1523, 1782, 28, 47, "Input",ExpressionUUID->"fc8eb168-ab40-4abf-a2f7-a6c4a5fe0448",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[89670, 1553, 552, 9, 34, "Text",ExpressionUUID->"23537e42-f22b-4d4a-b814-07c78ce53216",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[90225, 1564, 998, 17, 44, "Input",ExpressionUUID->"6682d775-94cf-4a53-8c9a-592c4584bd42",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[91226, 1583, 1779, 28, 47, "Input",ExpressionUUID->"5c93ef97-317b-45bc-930c-7ed4a5083bcf",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[93008, 1613, 549, 9, 34, "Text",ExpressionUUID->"2b07763f-3cfd-4858-b497-e8fb0b404ccf",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[93560, 1624, 996, 17, 44, "Input",ExpressionUUID->"aba9680d-c0d7-4bcf-aed7-0787606061b0",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[94559, 1643, 1820, 29, 47, "Input",ExpressionUUID->"a81323c0-f581-4d29-94ee-cd5c44c14b81",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[96416, 1677, 488, 8, 43, "Subsubsection",ExpressionUUID->"d26a83b2-cfac-4241-a654-e88df3ce54b3",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[96907, 1687, 1144, 16, 138, "Text",ExpressionUUID->"e57cf532-9da8-4855-9e40-46e0c11ef26f",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[98054, 1705, 842, 13, 34, "Text",ExpressionUUID->"3702204a-2207-4fb1-8ddd-7ae37503c070",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[98899, 1720, 1021, 17, 44, "Input",ExpressionUUID->"24e0d001-9c3c-4664-b4e5-84955a14c169",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[99923, 1739, 1227, 21, 47, "Input",ExpressionUUID->"f518a895-fc64-4c1b-8016-df1a33c9f6f1",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[101153, 1762, 842, 13, 34, "Text",ExpressionUUID->"5e5a9bf6-4421-4411-a4a8-fa63622ab566",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[101998, 1777, 1022, 17, 44, "Input",ExpressionUUID->"6561412e-06fd-4c57-ae93-47270a6df98e",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[103023, 1796, 1251, 21, 47, "Input",ExpressionUUID->"09c8ff30-42fd-4efc-951c-d2cfbedd4dcc",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[104277, 1819, 840, 13, 34, "Text",ExpressionUUID->"74fef3b2-0c62-4723-8c84-1fb7b6453b0a",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[105120, 1834, 1022, 17, 44, "Input",ExpressionUUID->"abd93098-806c-4525-be8c-4d88e9e76f05",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[106145, 1853, 1227, 21, 47, "Input",ExpressionUUID->"c11b0971-44f2-457e-a56f-d2e8e07d9df7",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[107375, 1876, 892, 14, 34, "Text",ExpressionUUID->"8358122a-dcdf-4af8-b13c-6d4facc289fc",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[108270, 1892, 1025, 17, 44, "Input",ExpressionUUID->"99c6e44e-061a-4ff5-961c-12a04ff14f1d",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[109298, 1911, 1225, 21, 47, "Input",ExpressionUUID->"b2da8702-0316-46b8-9356-5aa032c6c832",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[110560, 1937, 466, 7, 43, "Subsubsection",ExpressionUUID->"b021c4ce-bcc6-4034-9232-8fda8d1adcb9",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[111029, 1946, 550, 8, 30, "Text",ExpressionUUID->"8465ec6c-fd6d-4cd2-be59-f3c94e338e2e",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[111582, 1956, 724, 11, 34, "Text",ExpressionUUID->"df7d710e-e2ce-4964-912d-2d1215c1f9bf",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[112309, 1969, 329, 5, 34, "Text",ExpressionUUID->"21e9dddf-955e-4046-8c7d-1f061d77ced8",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[112641, 1976, 1388, 23, 44, "Input",ExpressionUUID->"ae10a51e-203c-49fc-b34c-3bab85f2f593",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[114032, 2001, 1537, 25, 47, "Input",ExpressionUUID->"bbe25b2d-bbf5-45c8-98c1-b268a76c3c79",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[115572, 2028, 379, 6, 34, "Text",ExpressionUUID->"b8fe53e8-ab34-480d-9453-8980ed3108bb",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[115954, 2036, 1450, 24, 44, "Input",ExpressionUUID->"9485f714-e9cc-42a5-989a-eec3da2d3d9d",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[117407, 2062, 1587, 25, 47, "Input",ExpressionUUID->"780be44e-d362-41c6-bc75-eb26841e8c10",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[118997, 2089, 393, 6, 34, "Text",ExpressionUUID->"e618723c-91d6-459c-9306-7dcf820ef40d",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[119393, 2097, 1447, 24, 44, "Input",ExpressionUUID->"fcb4851d-56ab-49c4-a7ef-580097bba28d",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[120843, 2123, 1607, 27, 44, "Input",ExpressionUUID->"5869e936-4b85-417d-9535-9acd134d3627",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[122453, 2152, 777, 12, 34, "Text",ExpressionUUID->"576b77e5-2f40-4970-a883-73790c3eea83",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[123233, 2166, 325, 5, 34, "Text",ExpressionUUID->"2897e784-5bd0-4cfa-9275-23952dc2873f",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[123561, 2173, 1356, 23, 44, "Input",ExpressionUUID->"4f31d8a3-142a-4e41-9984-1a88a6f968f4",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[124920, 2198, 1583, 26, 47, "Input",ExpressionUUID->"3ff847f8-e519-4d22-a466-267ec672c9ff",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[126506, 2226, 372, 6, 34, "Text",ExpressionUUID->"f66ff504-57ee-4e29-9ef1-608946c61119",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[126881, 2234, 1453, 24, 44, "Input",ExpressionUUID->"29350a81-3a4a-4b4b-a909-8f3dc67795fb",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[128337, 2260, 1591, 25, 47, "Input",ExpressionUUID->"6af3a0db-6bd1-4bd8-b13c-06058f2aad81",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[129931, 2287, 389, 6, 34, "Text",ExpressionUUID->"200ae52d-9f29-437a-ba63-690385364d99",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[130323, 2295, 1431, 24, 44, "Input",ExpressionUUID->"49bbfc31-81e6-46c1-a11b-7bf50613d980",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[131757, 2321, 1586, 26, 44, "Input",ExpressionUUID->"21327809-8401-4b20-ae5b-310e4df12604",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[133346, 2349, 779, 12, 34, "Text",ExpressionUUID->"5796d752-9475-4edc-aaae-7a3e78b3f9f5",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[134128, 2363, 329, 5, 34, "Text",ExpressionUUID->"bf2b7532-8dcf-4a44-ae68-73baf8480531",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[134460, 2370, 1296, 22, 44, "Input",ExpressionUUID->"8ccfd944-c19b-49ca-bd97-ae7982c4c14d",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[135759, 2394, 1564, 25, 47, "Input",ExpressionUUID->"8b465579-3011-4468-9c89-a2f6795256be",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[137326, 2421, 374, 6, 34, "Text",ExpressionUUID->"6820d8ff-b589-4ea4-ae6f-2b35693ba7fb",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[137703, 2429, 1452, 24, 44, "Input",ExpressionUUID->"e01165ce-f1d5-466c-bd97-2cfeb5fb52a7",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[139158, 2455, 1612, 25, 47, "Input",ExpressionUUID->"cf846bbd-4358-4ded-a3bd-51431faf16f0",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[140773, 2482, 421, 7, 34, "Text",ExpressionUUID->"9d5d74ed-5fb4-49f2-9b01-d522648cd8a3",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[141197, 2491, 1424, 24, 44, "Input",ExpressionUUID->"adf09bb8-ba09-42d4-8fa1-3851ed8f03f8",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[142624, 2517, 1584, 26, 44, "Input",ExpressionUUID->"eecac173-9bd3-4c06-b1be-e9c182499ee0",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[144211, 2545, 776, 12, 34, "Text",ExpressionUUID->"70ff68f7-73ff-4517-9eeb-5a1051171f3e",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[144990, 2559, 323, 5, 34, "Text",ExpressionUUID->"04f5fbb3-11b5-4ce2-ae21-563112d1444e",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[145316, 2566, 1493, 26, 44, "Input",ExpressionUUID->"371d9049-7ce7-40f7-b41b-29c4bc91fb4b",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[146812, 2594, 1504, 24, 47, "Input",ExpressionUUID->"aac04036-7655-40bb-aad7-1dc7991d1003",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[148319, 2620, 371, 6, 34, "Text",ExpressionUUID->"d77feda2-b240-4e67-b4fa-cff0d2e4c083",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[148693, 2628, 1457, 24, 44, "Input",ExpressionUUID->"fc53ee63-8e40-4683-b321-8821e0a01696",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[150153, 2654, 1637, 26, 47, "Input",ExpressionUUID->"a19c8c06-1203-453b-97b9-81d7697dca09",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[151793, 2682, 423, 7, 34, "Text",ExpressionUUID->"7171352e-8d71-4f6a-b1d6-30fb4a0fa74d",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[152219, 2691, 1460, 25, 44, "Input",ExpressionUUID->"7d33a6af-ed15-4356-8e81-ee1b51ecb618",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[153682, 2718, 1617, 27, 44, "Input",ExpressionUUID->"35bf12f1-9497-43a8-93f9-a343c7e57c0a",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[155302, 2747, 503, 8, 34, "Text",ExpressionUUID->"cd6f868f-52a1-4b7d-bdd8-1e0c25075729",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[155808, 2757, 743, 12, 28, "Input",ExpressionUUID->"411685ec-4e7e-4e82-ae79-6c9d904a1b83",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[156554, 2771, 619, 10, 28, "Input",ExpressionUUID->"34e10a13-0897-4126-a042-cb29ac11441b",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[157176, 2783, 741, 12, 28, "Input",ExpressionUUID->"6db908f8-9ec3-41b6-8085-74a4b5f16e26",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[157920, 2797, 619, 10, 28, "Input",ExpressionUUID->"47372b87-46e4-4e84-abb6-b4b18d167dd3",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[158542, 2809, 743, 12, 28, "Input",ExpressionUUID->"5cef1721-b569-43ee-b7b4-73bb1e65ec8f",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[159288, 2823, 669, 11, 28, "Input",ExpressionUUID->"72241c77-9f0f-489b-8a81-f6b0d3b357f1",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[159960, 2836, 793, 13, 28, "Input",ExpressionUUID->"7642a00a-7e5c-4224-8711-9ffc11e1be68",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[160756, 2851, 667, 11, 28, "Input",ExpressionUUID->"912b37a4-b188-4750-8262-c62c624d05cf",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[161460, 2867, 504, 8, 43, "Subsubsection",ExpressionUUID->"aa24486a-5d0a-4f46-8242-567c41c34ef1",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[161967, 2877, 700, 10, 66, "Text",ExpressionUUID->"e0770484-edb2-46de-b58c-215c4beeab57",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[162670, 2889, 842, 15, 44, "Input",ExpressionUUID->"d36c758b-7ed8-4713-92ae-51ee7315a7bf",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[163515, 2906, 646, 12, 44, "Input",ExpressionUUID->"f5a00f2e-1382-4412-b39c-d22462e02472",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[164164, 2920, 947, 16, 44, "Input",ExpressionUUID->"ebbcdefa-e8b4-418d-bbcc-8a1406b8ea24",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[165114, 2938, 756, 13, 44, "Input",ExpressionUUID->"3302594c-3311-486c-975d-02c4f6420f26",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[165873, 2953, 893, 15, 44, "Input",ExpressionUUID->"1673fb4d-d680-490d-a146-b94de2c1ce9e",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[166769, 2970, 709, 13, 44, "Input",ExpressionUUID->"6a1cb2bd-9ccd-4c6e-a7ca-0c0cc8e3fd86",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[167481, 2985, 895, 15, 44, "Input",ExpressionUUID->"778b1d34-2b16-4641-afe4-958ffaa66eba",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[168379, 3002, 709, 13, 44, "Input",ExpressionUUID->"17bf2afb-74a4-4899-a403-1ee2cb2495d4",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[169125, 3020, 500, 8, 43, "Subsubsection",ExpressionUUID->"0ced3238-6152-456e-ae55-92955302da4c",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[169628, 3030, 388, 6, 34, "Text",ExpressionUUID->"a58a66f0-a95b-487b-8515-59a08e11f104",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[170019, 3038, 473, 8, 30, "Text",ExpressionUUID->"919b1cdc-78c3-4722-9e42-640189488d70",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[170495, 3048, 1403, 22, 44, "Input",ExpressionUUID->"802c6b9b-1962-431d-b17b-a621193520c7",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[171901, 3072, 390, 6, 34, "Text",ExpressionUUID->"d009db3a-da57-4c3a-9848-44742eaef7df",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[172294, 3080, 544, 9, 30, "Text",ExpressionUUID->"422530ff-18da-4d53-abf8-b618ec1dd26c",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[172841, 3091, 1329, 21, 44, "Input",ExpressionUUID->"cb959750-59dd-405b-8ff0-098877582c11",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[174173, 3114, 388, 6, 34, "Text",ExpressionUUID->"077c3aa7-41d8-4cfa-97ed-200128de5ce3",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[174564, 3122, 709, 12, 48, "Text",ExpressionUUID->"ec69fdba-0c82-41f3-a5d6-c7f09f46d0ac",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[175276, 3136, 1280, 20, 44, "Input",ExpressionUUID->"63bde8db-8dca-4231-b99b-9dc06652c0ae",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[176559, 3158, 391, 6, 34, "Text",ExpressionUUID->"502055fe-4923-4c04-b0e1-a40cb5edfc91",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[176953, 3166, 660, 11, 30, "Text",ExpressionUUID->"44895ff3-aedc-49cc-b1bf-214b0b34b901",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[177616, 3179, 1328, 21, 44, "Input",ExpressionUUID->"fc85e40d-813d-4459-9fa3-8bef78a8fce4",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[178981, 3205, 366, 6, 43, "Subsubsection",ExpressionUUID->"aa55cf88-7c3e-4f9d-bbd3-d191f4c11cd2",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[179350, 3213, 345, 5, 34, "Text",ExpressionUUID->"cb5f6345-f668-41e2-939a-35b4edd77e67",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[179698, 3220, 465, 11, 28, "Input",ExpressionUUID->"26c97edf-5357-4b28-ae2b-e367fee89bac",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[180166, 3233, 736, 11, 32, "Output",ExpressionUUID->"8a818572-310c-4bc4-b852-d63ef62175d3",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[180905, 3246, 341, 5, 34, "Text",ExpressionUUID->"8489ec30-c0ac-416b-b687-4315e3651e96",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[181249, 3253, 424, 10, 28, "Input",ExpressionUUID->"b196eb43-e66e-4bcc-bbec-1a44c0528e87",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[181676, 3265, 742, 11, 32, "Output",ExpressionUUID->"baa7dda2-7fc7-4135-a7a7-cabf8a000261",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[182421, 3278, 345, 5, 34, "Text",ExpressionUUID->"68719266-1062-4c1b-b27a-23a43df92586",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[182769, 3285, 515, 11, 28, "Input",ExpressionUUID->"51abde27-af92-45c5-a591-a7443fbdcbd3",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[183287, 3298, 733, 11, 32, "Output",ExpressionUUID->"a35cfd0b-75bd-44d9-af91-5404b7e15bd1",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[184023, 3311, 343, 5, 34, "Text",ExpressionUUID->"4b094860-81af-4f12-b669-3249c5227e22",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[184369, 3318, 424, 10, 28, "Input",ExpressionUUID->"20ee38db-a017-4b42-94b2-476449a492c5",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[184796, 3330, 749, 11, 32, "Output",ExpressionUUID->"d20a9bb6-a7e7-4e11-a255-5b4ca0995c8f",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[185548, 3343, 347, 5, 34, "Text",ExpressionUUID->"8ec91a21-cb47-4fb3-8835-90c5e8946897",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[185898, 3350, 565, 12, 28, "Input",ExpressionUUID->"b6eda0bc-28d5-4476-8dad-8069d73c989c",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[186466, 3364, 764, 11, 32, "Output",ExpressionUUID->"f03c1698-e972-4d9a-b519-730767ea6494",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[187233, 3377, 343, 5, 34, "Text",ExpressionUUID->"fc33bb92-0a12-4534-8e3c-d71b0cb4455a",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[187579, 3384, 470, 10, 28, "Input",ExpressionUUID->"180d45ff-8508-4d6a-8759-a65dfd8c9b6b",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[188052, 3396, 753, 11, 32, "Output",ExpressionUUID->"9f90b99c-ab0b-4542-9c4f-15b837198437",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[188808, 3409, 344, 5, 34, "Text",ExpressionUUID->"c49ee32d-7110-40fb-80eb-3468c9a537c6",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[189155, 3416, 619, 13, 28, "Input",ExpressionUUID->"11bc5f2e-f864-4b5f-a818-6bd7f715c50b",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[189777, 3431, 785, 11, 32, "Output",ExpressionUUID->"690b9bf3-29c9-452a-9c6a-3ce7e465e11c",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[190565, 3444, 320, 5, 34, "Text",ExpressionUUID->"67e0f873-1e13-4475-a35e-702f6f8dfd68",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[190888, 3451, 522, 11, 28, "Input",ExpressionUUID->"88cd67b6-e63a-4a64-b3a6-f6df36eefbbb",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[191413, 3464, 792, 11, 32, "Output",ExpressionUUID->"46a70965-e6c4-4522-b986-9572530c0aae",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[192254, 3481, 446, 7, 62, "Section",ExpressionUUID->"e502def5-8a63-4c3c-ad7c-370aa74ed64a"],
Cell[192703, 3490, 532, 9, 34, "Text",ExpressionUUID->"9bf2c48f-35a3-4d8f-94b2-74ffec7cb163",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[193238, 3501, 838, 13, 28, "Input",ExpressionUUID->"9d5a52cf-3316-4cb2-80ab-9c9bede1d617"],
Cell[194079, 3516, 910, 14, 28, "Input",ExpressionUUID->"563be225-6049-49ee-806a-d676b042abd2"],
Cell[194992, 3532, 838, 13, 28, "Input",ExpressionUUID->"586a9c09-4290-443b-bf7d-c0d9a9d73e0a"],
Cell[195833, 3547, 910, 14, 28, "Input",ExpressionUUID->"64e92a99-a9c8-424b-ad08-340b3749b512"],
Cell[196746, 3563, 838, 13, 28, "Input",ExpressionUUID->"d41b583f-dae0-48e9-b4c3-be318f3fd670"],
Cell[197587, 3578, 912, 14, 28, "Input",ExpressionUUID->"4ff425df-281f-4ea5-98ba-80b9dac98a0d"],
Cell[198502, 3594, 836, 13, 28, "Input",ExpressionUUID->"bcd1b8c2-12df-4a34-b46e-55c2ab4cc24e"],
Cell[199341, 3609, 910, 14, 28, "Input",ExpressionUUID->"7ba43ca5-42d7-4dd1-9e4d-54130dec78d9"],
Cell[200254, 3625, 1416, 23, 28, "Input",ExpressionUUID->"a3ab304f-2aee-4fbd-bfd7-6f5a12f02f88"],
Cell[201673, 3650, 1153, 21, 28, "Input",ExpressionUUID->"3f3f71a9-fce2-4be4-b505-60d2d9a2083c"],
Cell[202829, 3673, 1420, 24, 28, "Input",ExpressionUUID->"719d6bd9-ab83-433d-bc57-a6b508965f6b"],
Cell[204252, 3699, 1156, 21, 28, "Input",ExpressionUUID->"ca4a1562-a6dc-469b-905d-0d39aef96b5a"],
Cell[205411, 3722, 1419, 24, 28, "Input",ExpressionUUID->"12c30e9d-754a-45e0-8c39-1b72a9f6c4ad"],
Cell[206833, 3748, 1158, 21, 28, "Input",ExpressionUUID->"288ea92c-c9be-4ba0-82d7-1acdbbeb49ee"],
Cell[207994, 3771, 1416, 24, 28, "Input",ExpressionUUID->"b2ccd627-d7eb-4881-8b69-b0a9aa854d3c"],
Cell[209413, 3797, 1156, 21, 28, "Input",ExpressionUUID->"07cb80e4-b70d-4a54-9c85-400d2cb9ea9b"],
Cell[CellGroupData[{
Cell[210594, 3822, 223, 4, 44, "Subsubsection",ExpressionUUID->"55c5feb8-4b96-4da8-a13c-0a8db5c1d911"],
Cell[210820, 3828, 783, 16, 48, "Input",ExpressionUUID->"251b4ab0-22c0-46e3-b8e5-e9aa3e6836c2"],
Cell[211606, 3846, 1632, 26, 28, "Input",ExpressionUUID->"84a21240-2395-4207-a627-0bd1de0b1bd2"],
Cell[213241, 3874, 785, 16, 48, "Input",ExpressionUUID->"ddefb4fb-ed0b-41c9-b34f-815fdb269d09"],
Cell[214029, 3892, 1636, 26, 28, "Input",ExpressionUUID->"9804a220-ad8a-4ea2-b0a3-d983552dacc8"],
Cell[215668, 3920, 787, 16, 48, "Input",ExpressionUUID->"f305acde-6487-41d5-8850-a22925249eb5"],
Cell[216458, 3938, 1634, 26, 28, "Input",ExpressionUUID->"f5232fbe-62d7-4e00-986d-f2c32840b136"],
Cell[218095, 3966, 785, 16, 48, "Input",ExpressionUUID->"ac224861-1ffc-4908-a6d4-f00c1b91f388"],
Cell[218883, 3984, 1636, 26, 28, "Input",ExpressionUUID->"22c1ee31-aa92-4f38-bac8-c199f7968ae9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[220556, 4015, 225, 4, 44, "Subsubsection",ExpressionUUID->"8372d459-fe1f-48ec-8641-aee602b2820c"],
Cell[220784, 4021, 2371, 38, 49, "Input",ExpressionUUID->"1bd69a31-8d5e-4be7-ac7b-526a6a7dc4b5"],
Cell[223158, 4061, 875, 20, 41, "Input",ExpressionUUID->"bfe09279-c02a-4e14-b37a-2ead85213dd7"],
Cell[224036, 4083, 2371, 38, 49, "Input",ExpressionUUID->"d2ca5df3-78b6-49e1-b854-f20b9894de8a"],
Cell[226410, 4123, 901, 20, 41, "Input",ExpressionUUID->"e9996e19-c9e2-4bad-80d6-e5d1f107f50b"],
Cell[227314, 4145, 2369, 38, 49, "Input",ExpressionUUID->"385ca98f-830d-4059-a353-b4dd92eaff40"],
Cell[229686, 4185, 899, 20, 41, "Input",ExpressionUUID->"11633740-7877-4529-9267-5101c3b28f3f"],
Cell[230588, 4207, 2419, 38, 49, "Input",ExpressionUUID->"387dcf33-3dbb-4670-99ab-85ffff228603"],
Cell[233010, 4247, 948, 21, 41, "Input",ExpressionUUID->"764696a7-2ccb-4e84-8698-455b1318fc9e"],
Cell[233961, 4270, 625, 16, 46, "Input",ExpressionUUID->"62eabe97-1954-43ae-855a-7d2c54b35cbd"],
Cell[234589, 4288, 623, 16, 47, "Input",ExpressionUUID->"4d9b0a1f-c966-472a-b552-6af5401f68b8"],
Cell[235215, 4306, 675, 16, 47, "Input",ExpressionUUID->"47587f17-c0fe-4f2d-a12a-ff180e9cd8e7"],
Cell[235893, 4324, 1096, 26, 39, "Input",ExpressionUUID->"e6724399-0426-4abd-bb4b-27370550b482"],
Cell[236992, 4352, 2419, 38, 49, "Input",ExpressionUUID->"379bd8ba-b8f0-4369-b43e-b6613eb75c99"],
Cell[239414, 4392, 929, 21, 41, "Input",ExpressionUUID->"1ed764e9-1c8e-4b4d-9273-7c8f56f9b844"],
Cell[240346, 4415, 2421, 38, 49, "Input",ExpressionUUID->"29fbc036-d510-40fe-8daf-9600259594f0"],
Cell[242770, 4455, 953, 21, 41, "Input",ExpressionUUID->"d597280d-cf66-4efd-a4df-e8e3cfc822e5"],
Cell[243726, 4478, 2419, 38, 49, "Input",ExpressionUUID->"046a6855-34da-4a95-a501-75e89b292345"],
Cell[246148, 4518, 953, 21, 41, "Input",ExpressionUUID->"d22c127a-b4b1-4a89-8bd5-9291c05be00a"],
Cell[247104, 4541, 2469, 39, 49, "Input",ExpressionUUID->"93b2d3b9-f4dc-4bec-b540-3dc836afe09b"],
Cell[249576, 4582, 1000, 22, 41, "Input",ExpressionUUID->"ad032d2a-ff52-44d7-8d69-ecdf737d464c"],
Cell[250579, 4606, 669, 16, 49, "Input",ExpressionUUID->"8305e50c-adba-4ce2-96df-65790eba427b"],
Cell[251251, 4624, 670, 16, 49, "Input",ExpressionUUID->"54f686b0-44db-4784-8a4e-7cfac2c72f32"],
Cell[251924, 4642, 725, 17, 49, "Input",ExpressionUUID->"abbcb4b4-51f3-478d-a36c-47dc2ecc337b"],
Cell[252652, 4661, 1150, 27, 41, "Input",ExpressionUUID->"a4a909b7-206c-40c9-bf6f-7340e63204b5"],
Cell[253805, 4690, 1587, 28, 47, "Input",ExpressionUUID->"0f3e7553-f6e2-4c16-ad42-a622b32f2bcb"],
Cell[255395, 4720, 755, 17, 50, "Input",ExpressionUUID->"3ef16ad7-9288-471b-b407-adece8171bc8"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[256199, 4743, 509, 8, 62, "Section",ExpressionUUID->"126bcfdb-2f4b-42f7-889f-d8f46341bccc"],
Cell[256711, 4753, 898, 20, 41, "Input",ExpressionUUID->"ef893d96-bd08-4069-9c34-459925ad7abd"],
Cell[257612, 4775, 926, 21, 41, "Input",ExpressionUUID->"8ed78591-642f-4073-ae37-f3504a3aa756"],
Cell[258541, 4798, 926, 21, 41, "Input",ExpressionUUID->"ce99f432-061e-4019-ad09-c149f12ad464"],
Cell[259470, 4821, 971, 21, 41, "Input",ExpressionUUID->"60236dba-2202-4d62-9dcb-89bd48daa64f"],
Cell[260444, 4844, 1119, 27, 39, "Input",ExpressionUUID->"fcad075f-b133-4c8a-bbfe-1247200c7621"],
Cell[261566, 4873, 357, 8, 48, "Input",ExpressionUUID->"20adb099-fe29-44f3-8002-98212ddb4a67"],
Cell[261926, 4883, 359, 8, 48, "Input",ExpressionUUID->"23f8d671-37dc-4151-9949-66fd776c3fb2"],
Cell[262288, 4893, 357, 8, 48, "Input",ExpressionUUID->"2a61f943-defe-466e-9826-0ea9a239ab59"],
Cell[262648, 4903, 409, 9, 48, "Input",ExpressionUUID->"3a2e6051-8d58-45c7-9742-83a507bdd9ba"],
Cell[263060, 4914, 972, 21, 41, "Input",ExpressionUUID->"9d050bb0-c02a-4827-8832-d05de9cd5771"],
Cell[264035, 4937, 1004, 22, 41, "Input",ExpressionUUID->"a48f174d-0b4e-4016-89cb-12950409eed7"],
Cell[265042, 4961, 1004, 22, 41, "Input",ExpressionUUID->"d25cd3d4-d9b3-4009-ac7e-4fadd097d429"],
Cell[266049, 4985, 1045, 22, 41, "Input",ExpressionUUID->"32ef4bb7-8042-4bd0-bd2d-98b82f2e0275"],
Cell[267097, 5009, 1199, 28, 41, "Input",ExpressionUUID->"f0685b32-fed0-4748-827d-4b13ae9f2b4c"],
Cell[268299, 5039, 206, 4, 34, "Text",ExpressionUUID->"0ad6664b-338c-43f8-a272-c331682cfee6"],
Cell[268508, 5045, 647, 11, 56, "Text",ExpressionUUID->"05fa101c-2aa9-4143-a580-5be5505d66d0"],
Cell[269158, 5058, 1360, 32, 48, "Input",ExpressionUUID->"7054bfa1-6724-4536-94f8-428722fa9818"],
Cell[270521, 5092, 647, 11, 56, "Text",ExpressionUUID->"5e32fe4a-2eea-4972-9471-4e63f2cc731d"],
Cell[271171, 5105, 1534, 34, 67, "Input",ExpressionUUID->"8d9a5d54-6195-4864-9379-ebaa47dda552"],
Cell[272708, 5141, 644, 11, 56, "Text",ExpressionUUID->"7803ce6d-d2d7-435d-a1de-fdcddc6924b9"],
Cell[273355, 5154, 1586, 35, 67, "Input",ExpressionUUID->"b0114ba0-c557-4d16-ae5b-21ff20f003b6"],
Cell[274944, 5191, 697, 12, 56, "Text",ExpressionUUID->"891033c0-7af6-4e67-890a-5a66af3ce0bc"],
Cell[275644, 5205, 1646, 36, 67, "Input",ExpressionUUID->"b96827f8-268f-402a-b86f-72a53198ccf1"],
Cell[277293, 5243, 632, 11, 34, "Text",ExpressionUUID->"f2222292-c02a-4dff-bfb0-5253e658f6aa"],
Cell[277928, 5256, 918, 21, 28, "Input",ExpressionUUID->"791f993f-332f-45c9-b74d-5610bfc47b08"],
Cell[278849, 5279, 977, 21, 28, "Input",ExpressionUUID->"e0970f00-5295-4a08-929a-eb9fdaf290f2"],
Cell[279829, 5302, 978, 21, 28, "Input",ExpressionUUID->"ff7b668f-42fc-496d-9711-68ef3214bd65"],
Cell[280810, 5325, 1032, 22, 28, "Input",ExpressionUUID->"d16e2950-660f-43e2-895a-44af17fb0b6a"],
Cell[281845, 5349, 678, 11, 34, "Text",ExpressionUUID->"aee4aa60-9cad-4f3f-8312-69ed87061370"],
Cell[282526, 5362, 807, 19, 28, "Input",ExpressionUUID->"dc442f99-2bf6-4cb3-b474-ca34a001692e"],
Cell[283336, 5383, 864, 19, 28, "Input",ExpressionUUID->"8fd0c066-a41d-4bb3-8941-1c1ea14cc382"],
Cell[284203, 5404, 866, 19, 28, "Input",ExpressionUUID->"97c8f4b3-e25d-4002-9d3d-bf446eb05265"],
Cell[285072, 5425, 917, 20, 28, "Input",ExpressionUUID->"0940c008-f167-45b0-8f67-f75f70a7d4aa"],
Cell[CellGroupData[{
Cell[286014, 5449, 1640, 40, 86, "Input",ExpressionUUID->"6340c5ef-1fdf-4a1b-8913-8de97b421861"],
Cell[287657, 5491, 6761, 97, 71, "Output",ExpressionUUID->"326b0dd9-2367-4106-818a-7fd5276fea38"]
}, Open  ]],
Cell[294433, 5591, 366, 8, 28, "Input",ExpressionUUID->"946f9cfe-6f47-48dd-8266-de1998056519"],
Cell[294802, 5601, 365, 8, 28, "Input",ExpressionUUID->"43559586-6a2c-42e9-a31e-8d54a991c323"],
Cell[295170, 5611, 362, 8, 28, "Input",ExpressionUUID->"fe6319c4-183f-4cb1-8921-13252519ec27"],
Cell[295535, 5621, 415, 8, 28, "Input",ExpressionUUID->"9dc9d079-0605-42cf-9fae-d970b8bf9b15"],
Cell[295953, 5631, 416, 8, 28, "Input",ExpressionUUID->"52280ee1-ca06-46e2-8fd2-1ee3bf86a7bf"],
Cell[296372, 5641, 416, 8, 28, "Input",ExpressionUUID->"16577354-fa8c-4ba9-a552-6e3f71acfce3"],
Cell[296791, 5651, 372, 8, 28, "Input",ExpressionUUID->"d8dba8ef-0920-4505-bdb4-adc27f532b87"],
Cell[297166, 5661, 421, 8, 28, "Input",ExpressionUUID->"bd09eadf-153e-4b02-a931-f9871574b095"],
Cell[297590, 5671, 416, 8, 28, "Input",ExpressionUUID->"dbbea929-f638-498e-b75b-52c8fc05722d"],
Cell[298009, 5681, 421, 8, 28, "Input",ExpressionUUID->"ec51b3fd-7e7d-4c61-9972-2d851b2142ff"],
Cell[298433, 5691, 473, 9, 28, "Input",ExpressionUUID->"2d72f4c8-4704-4135-89b4-ae65638945c4"],
Cell[298909, 5702, 470, 9, 28, "Input",ExpressionUUID->"e4ae86d0-0ecf-4d01-9a43-638ff4316501"],
Cell[299382, 5713, 427, 9, 48, "Input",ExpressionUUID->"91bd7d00-1d82-44fa-9b43-aa2c00886121"],
Cell[299812, 5724, 283, 7, 48, "Input",ExpressionUUID->"3336e42b-db78-4360-b345-f0ee822506bc"],
Cell[300098, 5733, 281, 7, 48, "Input",ExpressionUUID->"05ed3c06-fcef-484a-adbb-56a816fc8af8"],
Cell[300382, 5742, 278, 7, 48, "Input",ExpressionUUID->"9f6b8eb1-5805-4427-b26a-cef91f1526c5"],
Cell[300663, 5751, 953, 21, 41, "Input",ExpressionUUID->"827b48b7-cd55-4505-a89a-8bea05d601f9"],
Cell[301619, 5774, 979, 21, 41, "Input",ExpressionUUID->"10e0a844-12f0-4717-ae97-7bb0e70d876c"],
Cell[302601, 5797, 975, 21, 41, "Input",ExpressionUUID->"88b75a07-2f21-4492-b2d3-ed45dee10998"],
Cell[303579, 5820, 1026, 22, 41, "Input",ExpressionUUID->"36baead3-72a4-46ae-9e7b-357bd3170f22"],
Cell[304608, 5844, 1170, 27, 39, "Input",ExpressionUUID->"2cf42da1-537d-47cf-a868-6ac8425005fa"],
Cell[305781, 5873, 1025, 22, 41, "Input",ExpressionUUID->"6968501f-a00f-4eb4-b7de-e4b7523cd5a7"],
Cell[306809, 5897, 1057, 22, 41, "Input",ExpressionUUID->"50b2217b-a0f5-4ef2-a665-089b684d852b"],
Cell[307869, 5921, 1055, 22, 41, "Input",ExpressionUUID->"ca99b36d-0784-4f5c-abb4-899421699bbc"],
Cell[308927, 5945, 1102, 23, 41, "Input",ExpressionUUID->"cd104c3f-d515-420d-85d0-6d5fe0acf9eb"],
Cell[310032, 5970, 1254, 28, 41, "Input",ExpressionUUID->"cf3a49b1-b3f6-48a3-98f1-2b28e692992d"],
Cell[311289, 6000, 437, 11, 28, "Input",ExpressionUUID->"da2c9595-e3fc-4efc-8340-7fcfa41ee32f"],
Cell[311729, 6013, 445, 9, 28, "Input",ExpressionUUID->"968cd914-3f2c-4fc0-8be1-87db76fa5032"],
Cell[312177, 6024, 439, 9, 28, "Input",ExpressionUUID->"5d201a59-15f3-4a9f-b1d9-6ab7b8e60249"],
Cell[312619, 6035, 689, 16, 28, "Input",ExpressionUUID->"c5d80009-058b-43b9-95a0-97be06ff345a"],
Cell[313311, 6053, 487, 11, 28, "Input",ExpressionUUID->"3e642ed7-8a2a-4a7c-84b1-61256cf803c8"],
Cell[313801, 6066, 491, 10, 28, "Input",ExpressionUUID->"14ae33cb-8dc4-47b0-bd6d-02367efb45db"],
Cell[314295, 6078, 494, 10, 28, "Input",ExpressionUUID->"9653b559-0a51-4e27-a205-737b01a7f79d"],
Cell[314792, 6090, 800, 17, 28, "Input",ExpressionUUID->"c8f582d1-1442-4d78-8704-4de7307105c1"],
Cell[315595, 6109, 483, 11, 28, "Input",ExpressionUUID->"f9613ae5-8b16-4e0c-b27c-4a183e59636d"],
Cell[316081, 6122, 498, 10, 28, "Input",ExpressionUUID->"11243cd2-b796-4e01-8542-850f98f840aa"],
Cell[316582, 6134, 469, 10, 28, "Input",ExpressionUUID->"b63af19c-402b-4a43-8c33-41d4f5396395"],
Cell[317054, 6146, 800, 17, 28, "Input",ExpressionUUID->"7ee696d2-f285-433f-80dc-784d4d3d5c14"],
Cell[317857, 6165, 481, 11, 28, "Input",ExpressionUUID->"888e3a2d-d307-4c7b-a13a-f42ecd52ab55"],
Cell[318341, 6178, 471, 10, 28, "Input",ExpressionUUID->"78166c8f-0a9e-4e78-90eb-12cf3e75d5d0"],
Cell[318815, 6190, 486, 10, 28, "Input",ExpressionUUID->"bff7468d-1892-44a1-ab13-c7d9e1e5d3b5"],
Cell[319304, 6202, 800, 17, 28, "Input",ExpressionUUID->"e5ee9f38-34c7-48ba-a642-b690f9fd2ef6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[320141, 6224, 544, 9, 62, "Section",ExpressionUUID->"8e4599eb-aefd-43a7-a3d0-3a00dd7828fe"],
Cell[320688, 6235, 922, 14, 34, "Text",ExpressionUUID->"fa466ce1-cea8-4a8d-9b00-4b42818ede2f"],
Cell[321613, 6251, 867, 14, 34, "Text",ExpressionUUID->"37b6f62e-ab42-474a-883b-a789278bd2e7"],
Cell[CellGroupData[{
Cell[322505, 6269, 378, 9, 48, "Input",ExpressionUUID->"7851d6b9-66dd-4b24-bb64-9b1361450660"],
Cell[322886, 6280, 5699, 79, 48, "Output",ExpressionUUID->"427d7ead-cfb4-48f9-bbd2-9db2371c2552"]
}, Open  ]],
Cell[328600, 6362, 881, 12, 34, "Text",ExpressionUUID->"ff34ab77-1d9f-4ec0-ba1d-cae076d2ebb1"],
Cell[CellGroupData[{
Cell[329506, 6378, 424, 9, 48, "Input",ExpressionUUID->"12284875-4e6e-4aaf-8a4e-b74c3485c4eb"],
Cell[329933, 6389, 5704, 79, 48, "Output",ExpressionUUID->"82f76b57-0cc3-4de1-a211-a5cce3e89a02"]
}, Open  ]],
Cell[335652, 6471, 168, 3, 34, "Text",ExpressionUUID->"b16a44f7-d416-47fd-90d5-3627674c26c5"],
Cell[CellGroupData[{
Cell[335845, 6478, 140, 3, 28, "Input",ExpressionUUID->"f1e6e02b-61e9-4306-b591-07651b893853"],
Cell[335988, 6483, 397, 7, 48, "Output",ExpressionUUID->"37ca9bb2-2839-4529-aefd-c6736b7f5b64"]
}, Open  ]],
Cell[336400, 6493, 899, 12, 34, "Text",ExpressionUUID->"fc388840-19e8-4dd3-9747-f8ff5f18cc62"],
Cell[CellGroupData[{
Cell[337324, 6509, 379, 9, 48, "Input",ExpressionUUID->"c01ee3c4-d5c4-4b0f-ad48-10861ea850e0"],
Cell[337706, 6520, 5728, 79, 48, "Output",ExpressionUUID->"e113471b-4c37-44bb-8ee1-87eae8d90811"]
}, Open  ]],
Cell[343449, 6602, 951, 13, 34, "Text",ExpressionUUID->"7abf6cfa-d615-4f2a-b170-479ece4c4f53"],
Cell[CellGroupData[{
Cell[344425, 6619, 431, 9, 48, "Input",ExpressionUUID->"3b33f5e5-576c-4782-ba04-8feac09ec40f"],
Cell[344859, 6630, 5695, 79, 48, "Output",ExpressionUUID->"9bd3657d-3c7e-428b-9a76-c5c4cbae5ddc"]
}, Open  ]],
Cell[350569, 6712, 328, 5, 34, "Text",ExpressionUUID->"7483b4ce-215e-46b7-a578-b2b730327ca1"],
Cell[CellGroupData[{
Cell[350922, 6721, 626, 17, 28, "Input",ExpressionUUID->"45299919-636f-46e3-9255-7b7ebc1c8d27"],
Cell[351551, 6740, 999, 15, 48, "Output",ExpressionUUID->"5d8a9bd4-dad6-42ea-beee-f86ebf97a6a8"]
}, Open  ]],
Cell[352565, 6758, 328, 5, 34, "Text",ExpressionUUID->"f2469fde-eb3a-4942-953b-aac4516c64e3"],
Cell[CellGroupData[{
Cell[352918, 6767, 540, 15, 28, "Input",ExpressionUUID->"6d67e3c8-2acd-40c0-9d6b-23bf2a043ed9"],
Cell[353461, 6784, 976, 15, 48, "Output",ExpressionUUID->"005c7d19-6c14-4289-94d4-8fb991e022f1"]
}, Open  ]],
Cell[354452, 6802, 789, 11, 34, "Text",ExpressionUUID->"5ed542e3-d498-4e4c-a4dd-1b360d55e7d3"],
Cell[CellGroupData[{
Cell[355266, 6817, 385, 9, 47, "Input",ExpressionUUID->"a7a9764c-bf66-49ef-939e-40c84233ba43"],
Cell[355654, 6828, 5693, 79, 48, "Output",ExpressionUUID->"a8258cb8-feab-4851-85a3-967eebdf399a"]
}, Open  ]],
Cell[361362, 6910, 837, 12, 34, "Text",ExpressionUUID->"82273b4d-e264-45a3-9a5a-0b30019357d7"],
Cell[CellGroupData[{
Cell[362224, 6926, 431, 9, 47, "Input",ExpressionUUID->"0d15ba49-a590-43d3-aca9-29acdb783728"],
Cell[362658, 6937, 5708, 80, 48, "Output",ExpressionUUID->"719164b0-5da3-485e-b3e4-ed2852e2b584"]
}, Open  ]],
Cell[368381, 7020, 733, 10, 34, "Text",ExpressionUUID->"e23a3c21-0a78-47af-802c-c364f4f91f5f"],
Cell[CellGroupData[{
Cell[369139, 7034, 379, 9, 47, "Input",ExpressionUUID->"ec6af1d0-396f-4dba-8cea-a3941b570226"],
Cell[369521, 7045, 5662, 79, 48, "Output",ExpressionUUID->"37ec2dd2-161b-42a9-8332-1016538bc854"]
}, Open  ]],
Cell[375198, 7127, 783, 11, 34, "Text",ExpressionUUID->"f799dbdf-4080-49d8-a20e-90387fa96e77"],
Cell[CellGroupData[{
Cell[376006, 7142, 423, 9, 47, "Input",ExpressionUUID->"efe2e1f7-5f4b-4f80-a068-3179b4d26ead"],
Cell[376432, 7153, 5680, 80, 48, "Output",ExpressionUUID->"a958d773-26ce-4325-a238-7ed237078c5b"]
}, Open  ]],
Cell[382127, 7236, 973, 14, 34, "Text",ExpressionUUID->"3c230a6e-b45f-406a-b862-d16c7d588e39"],
Cell[383103, 7252, 816, 13, 34, "Text",ExpressionUUID->"d31b970b-01b3-4a91-a1a6-1f6a8fc987d5"],
Cell[CellGroupData[{
Cell[383944, 7269, 424, 9, 48, "Input",ExpressionUUID->"00ca3398-e60a-4f27-9f2f-ebb60f90afab"],
Cell[384371, 7280, 5712, 79, 48, "Output",ExpressionUUID->"a519167a-5c26-4f08-8644-ac82aaed2183"]
}, Open  ]],
Cell[390098, 7362, 883, 12, 34, "Text",ExpressionUUID->"e62e74d7-9a4e-444a-8002-5e78b3fe9904"],
Cell[CellGroupData[{
Cell[391006, 7378, 477, 10, 48, "Input",ExpressionUUID->"ea07afa0-19bc-4d7b-a798-fbd50f5b1b9b"],
Cell[391486, 7390, 5697, 79, 48, "Output",ExpressionUUID->"d765596c-a0c7-4eb1-b731-43ab5a2ca47e"]
}, Open  ]],
Cell[397198, 7472, 168, 3, 34, "Text",ExpressionUUID->"bbeaf817-3386-4352-a281-d5458907893d"],
Cell[CellGroupData[{
Cell[397391, 7479, 208, 4, 28, "Input",ExpressionUUID->"3eacf8c4-eeda-46b6-8f9c-85730357cbee"],
Cell[397602, 7485, 401, 7, 48, "Output",ExpressionUUID->"a2b08fea-9964-4130-92a0-a20ea7afd039"]
}, Open  ]],
Cell[398018, 7495, 800, 11, 34, "Text",ExpressionUUID->"74709d3e-c995-4aa7-a7fe-8d66933766b1"],
Cell[CellGroupData[{
Cell[398843, 7510, 427, 9, 48, "Input",ExpressionUUID->"a7b058b0-b67f-46ad-9eac-b1634f448551"],
Cell[399273, 7521, 5720, 79, 48, "Output",ExpressionUUID->"f13f0871-ac63-4196-af82-a1139958ce6a"]
}, Open  ]],
Cell[405008, 7603, 847, 12, 34, "Text",ExpressionUUID->"4eddad94-7d11-490a-a946-fa0004029ced"],
Cell[CellGroupData[{
Cell[405880, 7619, 480, 10, 48, "Input",ExpressionUUID->"3fb76938-949c-45e7-b678-fb85bf19b336"],
Cell[406363, 7631, 5705, 79, 48, "Output",ExpressionUUID->"5cd1917b-7437-44aa-94aa-20d8a728f339"]
}, Open  ]],
Cell[412083, 7713, 324, 5, 34, "Text",ExpressionUUID->"216f7476-c13d-407d-a618-47697736b100"],
Cell[CellGroupData[{
Cell[412432, 7722, 677, 18, 28, "Input",ExpressionUUID->"fdd1bfd6-e063-4429-805c-498f8f5fcaae"],
Cell[413112, 7742, 997, 15, 48, "Output",ExpressionUUID->"7360b09a-94f9-4c7e-9615-9ecab83f91d0"]
}, Open  ]],
Cell[414124, 7760, 296, 4, 34, "Text",ExpressionUUID->"9fc79298-c450-4fb1-bc2b-261b41170394"],
Cell[CellGroupData[{
Cell[414445, 7768, 590, 16, 28, "Input",ExpressionUUID->"9d0b1007-fa5e-4e98-a9fd-8a892f812585"],
Cell[415038, 7786, 990, 15, 48, "Output",ExpressionUUID->"a302ee65-f883-49d2-9afd-611cbb6462de"]
}, Open  ]],
Cell[416043, 7804, 789, 11, 34, "Text",ExpressionUUID->"dea2e921-ee46-4743-ab05-a7e3945b6a26"],
Cell[CellGroupData[{
Cell[416857, 7819, 433, 9, 48, "Input",ExpressionUUID->"f484b1cf-f337-48dc-b352-e79d65e44fd2"],
Cell[417293, 7830, 5695, 79, 48, "Output",ExpressionUUID->"e6b36338-f399-4b1d-8fff-3742363a3c52"]
}, Open  ]],
Cell[423003, 7912, 837, 12, 34, "Text",ExpressionUUID->"9a48f72c-e683-4eef-a766-d6eafcb44256"],
Cell[CellGroupData[{
Cell[423865, 7928, 484, 10, 48, "Input",ExpressionUUID->"17d0570a-d752-44e3-b70f-5ed7e347d13e"],
Cell[424352, 7940, 5716, 80, 48, "Output",ExpressionUUID->"25c5fcef-d9e3-4c54-9391-dcb25442c468"]
}, Open  ]],
Cell[430083, 8023, 733, 10, 34, "Text",ExpressionUUID->"6f46316a-26e2-4291-a63f-5ef5c6a7794c"],
Cell[CellGroupData[{
Cell[430841, 8037, 425, 9, 48, "Input",ExpressionUUID->"db586c54-20d0-41e4-9765-405464a7d02b"],
Cell[431269, 8048, 5647, 79, 48, "Output",ExpressionUUID->"d6badffe-8916-472b-895d-83a43bcb6328"]
}, Open  ]],
Cell[436931, 8130, 783, 11, 34, "Text",ExpressionUUID->"c0839bdc-fe31-4602-a763-d373a33c6f16"],
Cell[CellGroupData[{
Cell[437739, 8145, 472, 10, 48, "Input",ExpressionUUID->"837a0856-9802-469c-8aee-bc228d453609"],
Cell[438214, 8157, 5677, 80, 48, "Output",ExpressionUUID->"df2802e7-8958-441b-a32a-3e3926221cdd"]
}, Open  ]],
Cell[443906, 8240, 987, 15, 34, "Text",ExpressionUUID->"0ba7f740-1ccf-4c0a-8976-8f2466cded3a"],
Cell[444896, 8257, 816, 13, 34, "Text",ExpressionUUID->"3d66264f-629c-44c5-9dbd-5d67f5927cbd"],
Cell[CellGroupData[{
Cell[445737, 8274, 428, 9, 48, "Input",ExpressionUUID->"2a02d074-8b67-4ef2-97ac-70841c84a99d"],
Cell[446168, 8285, 5709, 79, 48, "Output",ExpressionUUID->"9df60852-59b7-47b8-bc2a-f7f1fde0374b"]
}, Open  ]],
Cell[451892, 8367, 881, 12, 34, "Text",ExpressionUUID->"0fe098be-b29f-4ce6-bab0-f04522167f30"],
Cell[CellGroupData[{
Cell[452798, 8383, 472, 10, 48, "Input",ExpressionUUID->"7d4c9a37-f057-46db-b5c4-4cfdb1bc79f0"],
Cell[453273, 8395, 5711, 79, 48, "Output",ExpressionUUID->"39d4c44b-0283-440e-889e-077f072ce42c"]
}, Open  ]],
Cell[458999, 8477, 168, 3, 34, "Text",ExpressionUUID->"12516431-8f01-4aae-a5a5-533e43c0d231"],
Cell[CellGroupData[{
Cell[459192, 8484, 210, 4, 28, "Input",ExpressionUUID->"12c4bf56-0561-48ef-8455-9d9123416dfa"],
Cell[459405, 8490, 403, 7, 48, "Output",ExpressionUUID->"4759d009-2ebe-4b8a-8c64-dc6b75eb6672"]
}, Open  ]],
Cell[459823, 8500, 800, 11, 34, "Text",ExpressionUUID->"7de371d5-81f7-476d-9f31-0363bd80cce3"],
Cell[CellGroupData[{
Cell[460648, 8515, 425, 9, 48, "Input",ExpressionUUID->"505233e9-3de1-4a29-9d0e-86ea14ae24b7"],
Cell[461076, 8526, 5708, 79, 48, "Output",ExpressionUUID->"baa044e0-3365-4255-8fe1-ed5010856ff3"]
}, Open  ]],
Cell[466799, 8608, 847, 12, 34, "Text",ExpressionUUID->"8ae1ed5b-0ea8-45f8-946d-944ec7d06db1"],
Cell[CellGroupData[{
Cell[467671, 8624, 482, 10, 48, "Input",ExpressionUUID->"5fd82f32-b684-4fbb-930c-804e026d4a08"],
Cell[468156, 8636, 5708, 79, 48, "Output",ExpressionUUID->"db4f1d08-e4d7-4fbe-8b3f-b7f37daeb6b9"]
}, Open  ]],
Cell[473879, 8718, 292, 4, 34, "Text",ExpressionUUID->"1ea986bf-0641-4b29-910f-b481f6dc2d18"],
Cell[CellGroupData[{
Cell[474196, 8726, 678, 18, 28, "Input",ExpressionUUID->"3a01bb7f-87ae-4339-ab1a-e1b6615b2ec3"],
Cell[474877, 8746, 973, 15, 48, "Output",ExpressionUUID->"155f2192-b5e7-4c20-9ac3-eb2433d910e8"]
}, Open  ]],
Cell[475865, 8764, 323, 5, 34, "Text",ExpressionUUID->"7eb8e5fd-fa3c-4931-86af-7687f0c33f0b"],
Cell[CellGroupData[{
Cell[476213, 8773, 591, 16, 28, "Input",ExpressionUUID->"e15c2f09-7824-4d8f-aa66-ccd853958e18"],
Cell[476807, 8791, 971, 15, 48, "Output",ExpressionUUID->"74e06423-c242-4cf9-9f38-6ecbb53552c8"]
}, Open  ]],
Cell[477793, 8809, 789, 11, 34, "Text",ExpressionUUID->"595cd19d-1187-4444-8116-3c5f95c9094e"],
Cell[CellGroupData[{
Cell[478607, 8824, 435, 9, 47, "Input",ExpressionUUID->"54ef8831-e826-4661-bf9d-4173471e7600"],
Cell[479045, 8835, 5691, 79, 48, "Output",ExpressionUUID->"40ef3cec-7595-48a8-96ff-d5e98a1774e8"]
}, Open  ]],
Cell[484751, 8917, 837, 12, 34, "Text",ExpressionUUID->"0d1da58d-1aa7-4703-9e86-87f82453e588"],
Cell[CellGroupData[{
Cell[485613, 8933, 482, 10, 47, "Input",ExpressionUUID->"8550f87b-1995-4769-afe4-52aa757c92e5"],
Cell[486098, 8945, 5700, 80, 48, "Output",ExpressionUUID->"84f45014-45a0-4495-a3dd-c4dd584121ba"]
}, Open  ]],
Cell[491813, 9028, 733, 10, 34, "Text",ExpressionUUID->"64be1c49-a58d-4f9b-bf04-f2b3f67564ff"],
Cell[CellGroupData[{
Cell[492571, 9042, 427, 9, 47, "Input",ExpressionUUID->"0033ad0d-1379-457a-9dc2-1a86231bb164"],
Cell[493001, 9053, 5651, 79, 48, "Output",ExpressionUUID->"c42043a2-7bed-4995-b991-dcb4e5763333"]
}, Open  ]],
Cell[498667, 9135, 783, 11, 34, "Text",ExpressionUUID->"1287b6cf-c7e5-4552-a2a6-c873534b38be"],
Cell[CellGroupData[{
Cell[499475, 9150, 474, 10, 47, "Input",ExpressionUUID->"04e6fdef-ca93-4416-a1ff-70212c4de514"],
Cell[499952, 9162, 5680, 80, 48, "Output",ExpressionUUID->"5c9f6884-075e-465b-9217-39f106fa6829"]
}, Open  ]],
Cell[505647, 9245, 972, 14, 34, "Text",ExpressionUUID->"0da5a705-ebaa-47a5-9c78-216be9b445f4"],
Cell[506622, 9261, 812, 13, 34, "Text",ExpressionUUID->"d6dd7271-b8f9-4b87-8e07-d998adc6d6c9"],
Cell[CellGroupData[{
Cell[507459, 9278, 426, 9, 48, "Input",ExpressionUUID->"eac04235-9dae-4c9d-9d14-9beadbe1df28"],
Cell[507888, 9289, 5712, 79, 48, "Output",ExpressionUUID->"53d9e532-4f86-497e-bd3c-3ad14476697a"]
}, Open  ]],
Cell[513615, 9371, 882, 12, 34, "Text",ExpressionUUID->"6ab2d942-3780-4d10-a84d-bca6c00b9067"],
Cell[CellGroupData[{
Cell[514522, 9387, 473, 10, 48, "Input",ExpressionUUID->"699c7382-61c3-4087-9ac8-2d4750e55a95"],
Cell[514998, 9399, 5711, 79, 48, "Output",ExpressionUUID->"5112a693-4ec1-412c-b0c3-2180ec5b3f70"]
}, Open  ]],
Cell[520724, 9481, 168, 3, 34, "Text",ExpressionUUID->"1c0b0ab4-c65f-4eda-ba76-bfb5b4f1fc8c"],
Cell[CellGroupData[{
Cell[520917, 9488, 206, 4, 28, "Input",ExpressionUUID->"d25db11c-bb5c-4f3d-8833-b0fc310153ac"],
Cell[521126, 9494, 402, 7, 48, "Output",ExpressionUUID->"a9984cab-78fe-4d20-bbd8-fc8e27a5e2c3"]
}, Open  ]],
Cell[521543, 9504, 800, 11, 34, "Text",ExpressionUUID->"d2845b1f-67a4-4183-b6ef-b498601995fd"],
Cell[CellGroupData[{
Cell[522368, 9519, 427, 9, 48, "Input",ExpressionUUID->"7c1759df-3d72-4500-860c-2dd4c373c9a0"],
Cell[522798, 9530, 5716, 79, 48, "Output",ExpressionUUID->"1c6905ef-5cee-40d2-954f-29846abf09a7"]
}, Open  ]],
Cell[528529, 9612, 847, 12, 34, "Text",ExpressionUUID->"312e9735-b698-47d1-8a41-0d85b37f1f59"],
Cell[CellGroupData[{
Cell[529401, 9628, 484, 10, 48, "Input",ExpressionUUID->"bf9dee48-da0c-4799-9b7a-a8cf2a44140f"],
Cell[529888, 9640, 5705, 79, 48, "Output",ExpressionUUID->"b2aa07ff-8bb5-479a-89fc-13fccff853ee"]
}, Open  ]],
Cell[535608, 9722, 296, 4, 34, "Text",ExpressionUUID->"76740a0a-60a9-4d1f-8b97-a43b13a4e01e"],
Cell[CellGroupData[{
Cell[535929, 9730, 797, 20, 48, "Input",ExpressionUUID->"c08c8fcd-39d1-42a9-99bb-7ac22e1ace69"],
Cell[536729, 9752, 1042, 16, 48, "Output",ExpressionUUID->"68a82730-6e9c-4d2d-8f23-013625cfcd5d"]
}, Open  ]],
Cell[537786, 9771, 296, 4, 34, "Text",ExpressionUUID->"3bc32221-f774-4346-88b3-e4a514c49c39"],
Cell[CellGroupData[{
Cell[538107, 9779, 709, 18, 28, "Input",ExpressionUUID->"45d4a662-3305-4e34-89c4-8e1b3412c432"],
Cell[538819, 9799, 1034, 15, 48, "Output",ExpressionUUID->"822b81d2-4f25-46a2-88b1-f85f39c610a0"]
}, Open  ]],
Cell[539868, 9817, 789, 11, 34, "Text",ExpressionUUID->"44538c4e-1e32-4e62-83c8-b7718d9697ea"],
Cell[CellGroupData[{
Cell[540682, 9832, 433, 9, 47, "Input",ExpressionUUID->"4b5f3777-f0ec-482e-99c6-1607ad258f3c"],
Cell[541118, 9843, 5697, 79, 48, "Output",ExpressionUUID->"a27f7eb3-bbab-49a1-8bec-1195726559c5"]
}, Open  ]],
Cell[546830, 9925, 837, 12, 34, "Text",ExpressionUUID->"7d0cf9a0-3acd-42fb-ac58-b758e20e9bab"],
Cell[CellGroupData[{
Cell[547692, 9941, 482, 10, 47, "Input",ExpressionUUID->"5f50749e-a91c-4991-99cb-2687d628f86c"],
Cell[548177, 9953, 5722, 80, 48, "Output",ExpressionUUID->"af21acf7-0eb5-4ca1-958e-3098fd129a9e"]
}, Open  ]],
Cell[553914, 10036, 733, 10, 34, "Text",ExpressionUUID->"e745e36a-4f70-481c-8fb6-6bb8fe578131"],
Cell[CellGroupData[{
Cell[554672, 10050, 425, 9, 47, "Input",ExpressionUUID->"305151c4-d677-4e89-8ccb-7d1d76c8b5ed"],
Cell[555100, 10061, 5673, 79, 48, "Output",ExpressionUUID->"071d8939-6e11-4e2b-a51c-9bacb13d1590"]
}, Open  ]],
Cell[560788, 10143, 783, 11, 34, "Text",ExpressionUUID->"e36a07fd-56c3-4cfb-8912-9cdfc5e191d1"],
Cell[CellGroupData[{
Cell[561596, 10158, 474, 10, 47, "Input",ExpressionUUID->"8aa73854-3a13-4f13-ad44-e3ae30c9c42c"],
Cell[562073, 10170, 5656, 80, 48, "Output",ExpressionUUID->"360a62c4-4841-4279-bb61-a58ea2ec3661"]
}, Open  ]],
Cell[567744, 10253, 936, 13, 34, "Text",ExpressionUUID->"13815c13-7ce0-400f-bac6-d5bef354e17d"],
Cell[568683, 10268, 1021, 14, 34, "Text",ExpressionUUID->"8d6f960c-cea6-4ac7-9d42-3184797329a6"],
Cell[CellGroupData[{
Cell[569729, 10286, 473, 10, 44, "Input",ExpressionUUID->"4be7ba51-cceb-4e00-9209-e3ee85fa7c30"],
Cell[570205, 10298, 5698, 79, 48, "Output",ExpressionUUID->"48a703b4-d115-4def-9a55-5cbb1d39fc5d"]
}, Open  ]],
Cell[575918, 10380, 774, 11, 34, "Text",ExpressionUUID->"c459d460-c983-4424-b98e-d057822b1f1b"],
Cell[CellGroupData[{
Cell[576717, 10395, 205, 6, 47, "Input",ExpressionUUID->"ea1630c7-69ec-469b-95ed-58312d9bf06e"],
Cell[576925, 10403, 856, 16, 48, "Output",ExpressionUUID->"ffcc378a-779b-412e-9358-5ede4e5b565b"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

