(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    379767,       6599]
NotebookOptionsPosition[    350236,       6181]
NotebookOutlinePosition[    350576,       6196]
CellTagsIndexPosition[    350533,       6193]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["IUU Fishing: Economic Effects of IUU Imports on U.S. Commercial \
Fishers\n",
  FontSize->36],
 StyleBox["Species: American lobster, spiny lobster",
  FontSize->24],
 StyleBox["\n",
  FontSize->18],
 StyleBox["Model Release",
  FontSize->18,
  FontSlant->"Italic"]
}], "Title",
 CellChangeTimes->{{3.7159437701501894`*^9, 3.715943776742571*^9}, {
   3.7160177883406353`*^9, 3.716017799612287*^9}, {3.716044926298222*^9, 
   3.7160449278653135`*^9}, {3.7167127367223215`*^9, 3.716712737322365*^9}, {
   3.716716446852584*^9, 3.716716448548705*^9}, {3.717141741657609*^9, 
   3.717141743761731*^9}, {3.717937945363772*^9, 3.7179379529402757`*^9}, {
   3.7185331704286838`*^9, 3.7185331826684923`*^9}, {3.7185539001319838`*^9, 
   3.7185539082355175`*^9}, {3.7847892842210164`*^9, 
   3.7847892988406277`*^9}, {3.787835927539494*^9, 3.7878359285709715`*^9}, {
   3.7879338873743715`*^9, 3.7879338874784536`*^9}, {3.791201099377099*^9, 
   3.7912011013376207`*^9}, 3.7954520024204845`*^9, {3.798810740721634*^9, 
   3.798810744523918*^9}, {3.799789945142694*^9, 3.7997899492227287`*^9}, {
   3.7998541778687954`*^9, 3.7998541814351215`*^9}, {3.8016687240812187`*^9, 
   3.8016687246281986`*^9}, {3.8017788040189447`*^9, 
   3.8017788092541156`*^9}, {3.819664877798711*^9, 3.819664951849766*^9}, {
   3.8199010796026187`*^9, 3.8199010810067167`*^9}, {3.8250901762188387`*^9, 
   3.8250901839389944`*^9}},ExpressionUUID->"d2b2e88b-412d-4daf-b693-\
8efdf54ef634"],

Cell[TextData[{
 StyleBox["Read Me :",
  FontWeight->"Bold"],
 "\nThis model accompanies the USITC report, ",
 StyleBox["Seafood Obtained via Illegal, Unreported, and Unregulated Fishing: \
U.S. Imports and Economic Impact on U.S. Commercial Fisheries",
  FontSlant->"Italic"],
 ", Inv. 332-575. The report includes a quantitative analysis of the economic \
impact of IUU imports on U.S. commercial fishers and U.S. commercial fishing \
production, trade, and prices. Economic effects are modeled by species, with \
each species-level model customized to fit the unique features of the U.S. \
domestic industry. Consumers of seafood products choose between domestic \
marine-capture sources, imports, and in some models, domestic aquaculture \
products. Imports include both legal and IUU sources that enter the U.S. at \
the same price, so consumers cannot distinguish an IUU from non-IUU product. \
2018 data is used to establish an initial equilibrium with imports of IUU \
products included in the baseline. The model then removes the IUU imports, as \
estimated in chapter 3, and solves for a new equilibrium absent those \
products. \n\nIn the lobster model, there are domestic and imported  \
varieties of American (true) and spiny (rock) lobster species. The model \
includes cross-species substitution, so relative price changes in one species \
affects the other species. Annual catch limits (ACLs) are enforced in the \
model so modeled increases in domestic landings cannot exceed their legal \
limits. Catch limits are modeled as a vertical asymptote directly in the \
supply equation and not as a constraint. Both unprocessed and processed \
lobster markets are modeled.\n\nData inputs in the simulation are in the \
BLUE-shaded cells (with sources for the input data listed in the cell above). \
Outputs are in the GREEN-shaded cells. The white cells are intermediate \
calculations. "
}], "Text",
 CellChangeTimes->{{3.8151793544957237`*^9, 3.8151793654382553`*^9}, {
   3.815180147319877*^9, 3.8151801612046986`*^9}, 3.8193117353392124`*^9, {
   3.819364667233782*^9, 3.819364673128374*^9}, {3.819364986036234*^9, 
   3.81936502379967*^9}, {3.8193652789237294`*^9, 3.819365313721591*^9}, {
   3.819365363147914*^9, 3.819365382037648*^9}, {3.8193654602015305`*^9, 
   3.8193655738330727`*^9}, {3.819365634647441*^9, 3.8193657347144046`*^9}, {
   3.8193659700247307`*^9, 3.819365970554162*^9}, 3.8193660018247957`*^9, {
   3.819366258029726*^9, 3.819366301792824*^9}, {3.819366347287284*^9, 
   3.819366415704628*^9}, {3.8193664545638943`*^9, 3.819366511109967*^9}, {
   3.819366610713606*^9, 3.8193669391806083`*^9}, {3.8193669763456044`*^9, 
   3.8193670889590435`*^9}, {3.819367863082618*^9, 3.8193678631977077`*^9}, {
   3.819400007994233*^9, 3.819400030667904*^9}, {3.819400277598463*^9, 
   3.8194002936449785`*^9}, {3.8194011542913923`*^9, 
   3.8194012480694838`*^9}, {3.8194013222643557`*^9, 
   3.8194013264886327`*^9}, {3.8194013868456955`*^9, 
   3.8194013890784397`*^9}, {3.819401463985852*^9, 3.819401508238408*^9}, {
   3.8194019318657284`*^9, 3.8194019329005365`*^9}, {3.819665080356598*^9, 
   3.8196650954828777`*^9}, {3.8196652430795116`*^9, 3.819665263767852*^9}, {
   3.8196694045310993`*^9, 3.819669946270366*^9}, {3.819669976834861*^9, 
   3.8196705383246193`*^9}, {3.819670606948246*^9, 3.819670798460183*^9}, {
   3.819670860785177*^9, 3.8196709679574733`*^9}, {3.8196710056524982`*^9, 
   3.819671491943797*^9}, 3.819671563400182*^9, {3.819672484886944*^9, 
   3.8196724859338183`*^9}, {3.8199011533041058`*^9, 
   3.8199012321717076`*^9}, {3.8199021437167053`*^9, 3.819902144786538*^9}, {
   3.819904727337638*^9, 3.8199047710337067`*^9}, {3.820012303009897*^9, 
   3.820012307046046*^9}, {3.820012457109111*^9, 3.820012461730715*^9}, {
   3.821228471311254*^9, 3.821228478115568*^9}, {3.821228583604739*^9, 
   3.8212286069008274`*^9}, {3.821254034767659*^9, 3.8212540557230434`*^9}, {
   3.8212540945664053`*^9, 3.8212541288301916`*^9}, {3.821254184887725*^9, 
   3.8212542155085*^9}, {3.8250758438958745`*^9, 3.825075844469709*^9}, {
   3.825090295714201*^9, 3.8250903140839868`*^9}, {3.8250904049782844`*^9, 
   3.825090460778966*^9}, {3.8254090018188057`*^9, 3.825409020478303*^9}, 
   3.825409074210106*^9, {3.8254095471339684`*^9, 3.825409547555298*^9}},
 FontSize->12,
 Background->GrayLevel[
  0.85],ExpressionUUID->"ded1986f-8993-437c-847e-5eafe9b068cf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ClearAll", "[", "f", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.791207469588732*^9, 3.7912074737709374`*^9}},
 CellLabel->
  "In[119]:=",ExpressionUUID->"0c777ea8-191a-4659-be18-f91ea0d0ffda"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1. Model Parameters",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.795452962713849*^9}, {
  3.8196715794204283`*^9, 
  3.8196715805723763`*^9}},ExpressionUUID->"d71ac8e8-e851-4193-bf90-\
47327a6dd4ff"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.1 Within-Species Elasticity of Substitution", \
"Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.819814333471882*^9, 3.8198143380684657`*^9}, 
   3.825091280816696*^9, {3.8252568202711163`*^9, 
   3.8252568273326483`*^9}},ExpressionUUID->"2817593e-79b6-4a56-9a16-\
b6d64551836b"],

Cell[TextData[StyleBox["Source: USITC\[CloseCurlyQuote]s econometric \
estimation using the trade cost method in Riker (2020). More information can \
be found in the technical appendix (appendix I). ",
 FontSize->12]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, 3.819672507377739*^9},
 FontSlant->"Italic",ExpressionUUID->"4e4a0823-4889-4f02-80db-3d69c49e9c7e"],

Cell["Coldwater lobster", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252567827228603`*^9, 
   3.8252567852298174`*^9}},ExpressionUUID->"af0bd7ae-da5b-470b-b108-\
b5d440caf772"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmac", " ", "=", "3.047522"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.807372832112838*^9, 3.8073728490860496`*^9}, {
   3.8078871672525544`*^9, 3.8078871687215505`*^9}, {3.8109074300275764`*^9, 
   3.8109074397382326`*^9}, {3.812966911944523*^9, 3.812966934622287*^9}, {
   3.8129669766808467`*^9, 3.8129669772434416`*^9}, 3.812968193195546*^9, 
   3.8129689279563503`*^9, 3.8252567944811015`*^9, 3.825257056357689*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[120]:=",ExpressionUUID->"e187ba23-5877-47a9-b403-9771c122b111"],

Cell["Warmwater lobster", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.825256786667946*^9, 3.8252567891849127`*^9}, 
   3.825257056357689*^9},ExpressionUUID->"0c683e20-e6b4-4f00-8658-\
6d7602cddda9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigman", " ", "=", " ", "16.64799"}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.807372851816176*^9, 3.80737286229937*^9}, {
   3.8078871719720936`*^9, 3.807887172925378*^9}, {3.812818679569171*^9, 
   3.812818688286955*^9}, {3.8128187363953924`*^9, 3.8128187386391416`*^9}, {
   3.8129669382795997`*^9, 3.8129669831037765`*^9}, {3.812967828435688*^9, 
   3.8129678394214964`*^9}, 3.8129681982289295`*^9, 3.8129689327858796`*^9, {
   3.825256797854683*^9, 3.825256798458149*^9}, 3.825257056357689*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[121]:=",ExpressionUUID->"4e618303-f802-4bb1-a914-80696ff1b87a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.2 Cross-Species Elasticity of Substitution", \
"Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, 3.8196725148810096`*^9, {
   3.8198143408736553`*^9, 3.819814345001872*^9}, 
   3.825179976742489*^9},ExpressionUUID->"87c399f4-3e97-4172-85cc-\
186c7682399f"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate and Interviews with \
Industry Participants.",
 FontSize->12]], "Text",
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725148810096`*^9, 3.820012465372556*^9, {3.8200125245600863`*^9, 
   3.8200125375572243`*^9}, 3.8251799767435226`*^9},
 FontSlant->"Italic",ExpressionUUID->"59a61570-26e2-416c-a81b-2cc3ae8dcc26"],

Cell["Unprocessed products", "Text",
 CellChangeTimes->{{3.8252568586189375`*^9, 
  3.825256862883266*^9}},ExpressionUUID->"77afa9cd-cc59-4b6e-b428-\
b5dcf7468315"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"betau", "=", "1.50"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.7997907022612257`*^9, 
   3.799790709387388*^9}, 3.7997908508541403`*^9, {3.8016879044513836`*^9, 
   3.801687907933004*^9}, {3.80434351778264*^9, 3.804343518580264*^9}, {
   3.804345558282427*^9, 3.8043455585966744`*^9}, {3.804346895174925*^9, 
   3.8043468962187347`*^9}, 3.804586879762295*^9, 3.8048512543836975`*^9, {
   3.804851294142619*^9, 3.8048513020969067`*^9}, {3.8048596891343603`*^9, 
   3.8048596894469223`*^9}, {3.804866261943138*^9, 3.804866262021276*^9}, {
   3.8078857186822305`*^9, 3.807885719135425*^9}, {3.812967978957473*^9, 
   3.8129680077434416`*^9}, {3.812976719172824*^9, 3.8129767192978573`*^9}, {
   3.8129768690689573`*^9, 3.8129768694728365`*^9}, 3.825256803519148*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[122]:=",ExpressionUUID->"45be8dc0-b9d4-4d0f-a0da-e6c1cfe04bbc"],

Cell["Processed products", "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
  3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
  3.7916399673924417`*^9}, {3.7916399989748077`*^9, 3.7916400007431717`*^9}, {
  3.7954520831018844`*^9, 3.795452119837143*^9}, {3.7954523619018683`*^9, 
  3.795452362542366*^9}, {3.7988095955521545`*^9, 3.7988095975004187`*^9}, {
  3.799061778490183*^9, 3.7990617986470795`*^9}, {3.799790675748479*^9, 
  3.799790699725906*^9}, {3.804343511914075*^9, 3.804343512199299*^9}, {
  3.804343554793436*^9, 3.8043435554239297`*^9}, {3.804851268872862*^9, 
  3.804851284484761*^9}, {3.8067651310164886`*^9, 3.806765131266529*^9}, {
  3.825256869926727*^9, 
  3.8252568723636675`*^9}},ExpressionUUID->"889b1e8d-9dc0-459f-b333-\
770d3f6645e2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"betap", "=", "3.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.7997907022612257`*^9, 
   3.799790709387388*^9}, 3.7997908508541403`*^9, {3.8016879044513836`*^9, 
   3.801687907933004*^9}, {3.80434351778264*^9, 3.804343518580264*^9}, {
   3.804345558282427*^9, 3.8043455585966744`*^9}, {3.804346895174925*^9, 
   3.8043468962187347`*^9}, 3.804586879762295*^9, 3.8048512543836975`*^9, {
   3.8048512977994776`*^9, 3.8048513053474474`*^9}, {3.8048596921193275`*^9, 
   3.8048596924318895`*^9}, {3.8129767217200527`*^9, 
   3.8129767235975714`*^9}, {3.8129768718169727`*^9, 3.8129768722053146`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[123]:=",ExpressionUUID->"c6d174b2-4072-4602-bf86-ac72813840e5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.3 Industry Price Elasticity of Demand", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, 3.8196725271002216`*^9, {3.819814291546197*^9, 
   3.819814297331707*^9}, {3.8198143479321556`*^9, 3.8198143530561504`*^9}, {
   3.8250868257749405`*^9, 3.8250868258999605`*^9}, 3.8250869675488243`*^9, {
   3.825257050437127*^9, 
   3.8252570589367094`*^9}},ExpressionUUID->"c8295b7c-4f31-46c4-ab62-\
b68a3a53efaf"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate.",
 FontSize->12]], "Text",
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725271002216`*^9, 3.820012468652115*^9, {3.8200125463901167`*^9, 
   3.8200125607253003`*^9}, 3.8250869675488243`*^9, 3.825257050437127*^9},
 FontSlant->"Italic",ExpressionUUID->"c54f1830-a44e-4153-81d6-a7c0c3c7e59d"],

Cell["Unprocessed products", "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.82509147684973*^9, 
   3.8252570504380865`*^9},ExpressionUUID->"8b8425c4-54a7-4b99-bbae-\
9361e4edf62b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"etau", "=", " ", 
   RowBox[{"-", "1"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, 
   3.8016643791586046`*^9, {3.801780399382991*^9, 3.8017804002581425`*^9}, 
   3.803110491929274*^9, 3.8043441862548213`*^9, 3.82509147684973*^9, 
   3.8252570504380865`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[124]:=",ExpressionUUID->"5076e941-d581-47fe-82e7-6640b4c1f980"],

Cell["Processed products", "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790699725906*^9}, {3.804343511914075*^9, 
   3.804343512199299*^9}, {3.804343554793436*^9, 3.8043435554239297`*^9}, {
   3.8073102761655755`*^9, 3.8073102764808226`*^9}, {3.8250913970257435`*^9, 
   3.8250914002616787`*^9}, 3.82509147684973*^9, 
   3.8252570504380865`*^9},ExpressionUUID->"25d3293f-b9cd-4261-a7f4-\
b22d3656fd04"],

Cell[BoxData[
 RowBox[{
  RowBox[{"etap", "=", " ", 
   RowBox[{"-", "1"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016643791586046`*^9, 3.801664387008879*^9}, {3.80178040319617*^9, 
   3.801780404211971*^9}, 3.804344182385809*^9, 3.82509147684973*^9, 
   3.8252570504380865`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[125]:=",ExpressionUUID->"2d81b003-4ca7-430a-8b2d-e325db131038"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.4 Illegal Imports Replacement Rates", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, {3.81967219811668*^9, 3.819672213143815*^9}, 
   3.819672537084565*^9, {3.819814300125886*^9, 3.8198143058253307`*^9}, {
   3.8198143561535683`*^9, 3.8198143611354523`*^9}, 3.825086880742647*^9, 
   3.8250869724717035`*^9, {3.8252570504380865`*^9, 
   3.8252570668889027`*^9}},ExpressionUUID->"7c739ecf-54e8-499e-8dc2-\
9ddbab8adf8c"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate.  Further discussion on \
qualitative factors and rate determination can be found in appendix I of the \
USITC\[CloseCurlyQuote]s report.",
 FontSize->12]], "Text",
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196723427492237`*^9, 3.8196725370855665`*^9, {3.819815993710532*^9, 
   3.819815996531728*^9}, {3.8198381383987584`*^9, 3.819838144753663*^9}, {
   3.8198382402870555`*^9, 3.8198383754614663`*^9}, 3.8200124721278267`*^9, {
   3.820012579354833*^9, 3.8200125899691114`*^9}, 3.8250869724717035`*^9, 
   3.8252570504391*^9},
 FontSlant->"Italic",ExpressionUUID->"a45e12f9-61ed-46f6-9809-46e910ffef49"],

Cell["True lobster imports", "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.82509147684973*^9, 3.8251078289879203`*^9, {3.8252569288745823`*^9, 
   3.825256931486635*^9}, {3.8252570354894896`*^9, 
   3.8252570504391*^9}},ExpressionUUID->"4565c44d-15af-43c8-941f-\
ca6c776e2df8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"replt", " ", "=", "0.3"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662885297171*^9}, {3.8016683902542915`*^9, 
   3.801668392194314*^9}, {3.801668476343513*^9, 3.8016684764529057`*^9}, {
   3.8016685159337964`*^9, 3.801668531426852*^9}, 3.801692415143248*^9, {
   3.8016926196184893`*^9, 3.801692619774764*^9}, {3.801780289233728*^9, 
   3.8017802906278515`*^9}, 3.8033028464480004`*^9, 3.8033032141861067`*^9, {
   3.80339474346602*^9, 3.803394743762943*^9}, {3.8033948509102745`*^9, 
   3.80339485100404*^9}, 3.803397269400152*^9, 3.804343569032516*^9, {
   3.8043441779843903`*^9, 3.8043441785348186`*^9}, {3.804345528212033*^9, 
   3.8043455283191147`*^9}, {3.8043482483389072`*^9, 3.804348250335457*^9}, {
   3.804348999502578*^9, 3.8043489995996523`*^9}, {3.8043490925820007`*^9, 
   3.8043490927291145`*^9}, {3.80451933962536*^9, 3.804519339859774*^9}, {
   3.8045205567782145`*^9, 3.804520557247041*^9}, {3.804521073038145*^9, 
   3.8045210732569275`*^9}, {3.804521152663441*^9, 3.804521152757205*^9}, {
   3.804521464187267*^9, 3.8045214643279123`*^9}, {3.804545874319066*^9, 
   3.8045458744753385`*^9}, {3.8045460890897703`*^9, 
   3.8045460891835356`*^9}, {3.804546190142262*^9, 3.804546190595456*^9}, {
   3.8045868865938334`*^9, 3.8045868868282475`*^9}, {3.8045916336063304`*^9, 
   3.8045916336844664`*^9}, {3.804591811382941*^9, 3.804591811507962*^9}, 
   3.8048513408389482`*^9, {3.804858869583768*^9, 3.8048588697400417`*^9}, {
   3.8048672372703323`*^9, 3.8048672375047445`*^9}, 3.8048969343130455`*^9, {
   3.805017086905365*^9, 3.805017089015106*^9}, {3.805637808410037*^9, 
   3.8056378090038867`*^9}, {3.80563784962342*^9, 3.805637850060994*^9}, {
   3.8056379572848544`*^9, 3.805637967093734*^9}, 3.8056380038482428`*^9, 
   3.8067651675468597`*^9, {3.8067652233706646`*^9, 3.80676522358945*^9}, 
   3.806835112673317*^9, 3.806835311760007*^9, 3.806835419104725*^9, 
   3.806835539339687*^9, 3.806836545726241*^9, 3.8068390894028497`*^9, 
   3.8068396390947533`*^9, 3.807371191952701*^9, {3.807371230675852*^9, 
   3.8073712340434704`*^9}, {3.8074594003560953`*^9, 
   3.8074594011236906`*^9}, {3.807532068793538*^9, 3.8075320757977495`*^9}, {
   3.8075321714176083`*^9, 3.8075321717457857`*^9}, {3.807532958822853*^9, 
   3.8075329589322457`*^9}, {3.807533250005719*^9, 3.807533250646449*^9}, {
   3.8078871809422693`*^9, 3.807887182723811*^9}, {3.80788757365107*^9, 
   3.8078875738229723`*^9}, {3.8078877758023825`*^9, 3.807887775927402*^9}, {
   3.8078886676822605`*^9, 3.807888667776024*^9}, {3.8100492074990516`*^9, 
   3.8100492075861187`*^9}, 3.812472961444321*^9, 3.8252569387392483`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[126]:=",ExpressionUUID->"c1974cde-0bee-4337-89d4-4d8be79bede4"],

Cell["Rock lobster imports", "Text",
 CellChangeTimes->{{3.8252569336452756`*^9, 3.825256935723917*^9}, {
  3.825257038355691*^9, 
  3.8252570393694787`*^9}},ExpressionUUID->"5b4d84a0-f222-4101-b6c7-\
5a4ebb8ce1fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"replr", " ", "=", "0.3"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662888928058*^9}, {3.8016683952885675`*^9, 
   3.8016683957417665`*^9}, {3.801668478875883*^9, 3.801668478985276*^9}, {
   3.8016685230652122`*^9, 3.8016685337553577`*^9}, 3.8016924179886847`*^9, {
   3.801692616946184*^9, 3.8016926170868325`*^9}, {3.801780293582797*^9, 
   3.8017802946923575`*^9}, 3.8033028505850444`*^9, {3.8033032081382475`*^9, 
   3.8033032184211392`*^9}, 3.80339474828187*^9, {3.803394853256654*^9, 
   3.8033948533973007`*^9}, 3.8033972714877625`*^9, {3.8043435722129936`*^9, 
   3.8043435734429483`*^9}, {3.8043441746958294`*^9, 
   3.8043441752562647`*^9}, {3.8043455309101295`*^9, 3.804345531017213*^9}, {
   3.80434825300554*^9, 3.8043482532307134`*^9}, {3.8043490017373157`*^9, 
   3.8043490018544083`*^9}, {3.8043490949148126`*^9, 
   3.8043490950228963`*^9}, {3.804519342578964*^9, 3.80451934279775*^9}, {
   3.804520559891337*^9, 3.80452056018826*^9}, {3.804521075397897*^9, 
   3.804521075741864*^9}, {3.804521154945324*^9, 3.804521155070345*^9}, {
   3.8045214667892885`*^9, 3.804521466896373*^9}, {3.804545877273263*^9, 
   3.804545877492049*^9}, {3.8045460915435076`*^9, 3.804546091652898*^9}, {
   3.8045461863758335`*^9, 3.8045461875168595`*^9}, {3.8045868894228296`*^9, 
   3.804586889625988*^9}, {3.8045916357474985`*^9, 3.804591635841265*^9}, {
   3.8045918139304185`*^9, 3.804591814102498*^9}, 3.8048513430267563`*^9, {
   3.804858875065585*^9, 3.804858875190604*^9}, {3.804867240348963*^9, 
   3.8048672406146297`*^9}, 3.804896936438388*^9, {3.805017091984372*^9, 
   3.805017093687793*^9}, {3.805637855297874*^9, 3.805637855782327*^9}, {
   3.805637981691862*^9, 3.8056380055232553`*^9}, 3.8067651703906827`*^9, {
   3.8067652262617545`*^9, 3.80676522654305*^9}, 3.806835114407971*^9, 
   3.8068353134634132`*^9, 3.806835420761252*^9, 3.806835542934036*^9, 
   3.806836548351675*^9, 3.806839091274314*^9, 3.806839641073295*^9, 
   3.8073712052100267`*^9, {3.8073712402172785`*^9, 3.807371240698653*^9}, {
   3.807459404057976*^9, 3.807459404530342*^9}, {3.8075320706389103`*^9, 
   3.807532073185384*^9}, {3.807532174582962*^9, 3.807532176308832*^9}, {
   3.807532961120099*^9, 3.807532961229493*^9}, {3.807533253193377*^9, 
   3.807533253271515*^9}, {3.807887184349083*^9, 3.8078871860056105`*^9}, {
   3.8078875763702574`*^9, 3.8078875765421596`*^9}, {3.8078877785540543`*^9, 
   3.8078877791791544`*^9}, {3.8078886698794127`*^9, 3.807888670017517*^9}, {
   3.810049209536633*^9, 3.81004921004803*^9}, 3.8124729648509827`*^9, {
   3.8252569416875534`*^9, 3.8252569419687433`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[127]:=",ExpressionUUID->"8416828b-6e0d-4043-b421-691ce31c4cb1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.5 Price Elasticity of Supply", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, {3.81967219811668*^9, 3.819672213143815*^9}, {
   3.819672363407755*^9, 3.819672372555518*^9}, 3.8196725593450384`*^9, {
   3.8198143101346893`*^9, 3.8198143131120086`*^9}, {3.8198143634432487`*^9, 
   3.8198143660582876`*^9}, {3.82508688282111*^9, 3.82508688294613*^9}, 
   3.825086976244356*^9, 3.825091580357998*^9, {3.8252570504391*^9, 
   3.8252570696130323`*^9}},ExpressionUUID->"f8339f84-e49d-436f-a389-\
e71673f4d8ce"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate and Interviews with \
Industry Participants.",
 FontSize->12]], "Text",
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725593450384`*^9, 3.8200124748939843`*^9, {3.8200126204719076`*^9, 
   3.820012620846199*^9}, 3.825086976244356*^9, 3.825091580357998*^9, 
   3.8252570504391*^9},
 FontSlant->"Italic",ExpressionUUID->"e87dd23c-c367-4ac0-9304-7d5d4a331962"],

Cell["American lobster", "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.82509147684973*^9, {3.825091561649296*^9, 3.825091580357998*^9}, {
   3.8252569728917875`*^9, 3.8252569774283237`*^9}, 
   3.8252570504391*^9},ExpressionUUID->"484e6aac-9186-4168-9405-72364f09a3f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ead", " ", "=", "5.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, 3.8048513547315273`*^9, {
   3.8048597028089485`*^9, 3.8048597031058826`*^9}, 3.8050172286041574`*^9, {
   3.806765235780514*^9, 3.806765235889906*^9}, 3.807371291718371*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[128]:=",ExpressionUUID->"0e61cea0-3282-45a7-bd8e-9e8e785d69eb"],

Cell["Spiny lobster", "Text",
 CellChangeTimes->{{3.8252569785692453`*^9, 
  3.8252569810831556`*^9}},ExpressionUUID->"3a3ae47a-4e65-4b69-898b-\
78063599371a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"esd", " ", "=", "5.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8048513547315273`*^9, 
   3.804851365641842*^9}, {3.8048597057626595`*^9, 3.804859706091468*^9}, 
   3.8050172421063824`*^9, {3.8067652386447334`*^9, 3.8067652387541256`*^9}, {
   3.8073712980272827`*^9, 3.807371298302496*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[129]:=",ExpressionUUID->"daaf0596-c33a-4587-81b3-e028c2d51607"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2. Data Inputs",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.795452962713849*^9}, {
  3.8196715794204283`*^9, 3.8196715805723763`*^9}, {3.819672652231064*^9, 
  3.819672658049889*^9}},ExpressionUUID->"795a1d4e-5478-405a-9590-\
a6564398b6f1"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.1 U.S. Landings Quantities and Prices", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672709332239*^9}, 
   3.819814602882104*^9, 
   3.8250870892047157`*^9},ExpressionUUID->"fbdce3df-ed6c-496d-bedd-\
478a269481cc"],

Cell[TextData[StyleBox["Source: National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries).\
\[NonBreakingSpace]Fisheries of the United States 2018. Current Fishery \
Statistics No. 2018. U.S. Department of Commerce. Silver Spring MD:\
\[NonBreakingSpace]NOAA,\[NonBreakingSpace]February 2020. \
https://www.fisheries.noaa.gov/resource/document/fisheries-united-states-2018-\
report.\[NonBreakingSpace]",
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, 
   3.819814602882104*^9, {3.8198155788251867`*^9, 3.8198155811910124`*^9}, 
   3.8250870892047157`*^9},
 FontSize->12,ExpressionUUID->"39279e1b-8b0e-47a6-b252-e315fc37af3b"],

Cell["American lobster landings", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8252571820003915`*^9, 3.825257183885853*^9}, {
   3.825257298265074*^9, 3.8252572990166397`*^9}, 
   3.825409209665896*^9},ExpressionUUID->"0ca75514-fc43-42c2-accb-\
0e42b6cc7eda"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadu0", " ", "=", "66305000.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.8048514547791586`*^9, {
   3.804858998862688*^9, 3.8048590002413826`*^9}, 3.8050173226703215`*^9, {
   3.8050221654427185`*^9, 3.8050221715374117`*^9}, 3.8067653569966908`*^9, {
   3.806765406997158*^9, 3.8067654255226603`*^9}, {3.8068319989216657`*^9, 
   3.8068320015627327`*^9}, {3.806834147404319*^9, 3.80683414798254*^9}, {
   3.8073714146170473`*^9, 3.8073714154336815`*^9}, {3.8073714587804284`*^9, 
   3.807371460985143*^9}, {3.807453442306591*^9, 3.8074534428370028`*^9}, {
   3.825257160339574*^9, 3.8252571616736436`*^9}, 3.825409209665896*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[130]:=",ExpressionUUID->"400c8e39-93cb-4fef-a9fb-41930d195d3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"padu0", " ", "=", "9.4145"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}], " "}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, 
   3.8048516657287436`*^9, {3.804859289924417*^9, 3.804859293881085*^9}, 
   3.8050178536388817`*^9, {3.8050225182495184`*^9, 3.8050225241723566`*^9}, 
   3.8067662214541273`*^9, {3.806766763184125*^9, 3.8067667642114534`*^9}, 
   3.8068363150159225`*^9, {3.8073719933392773`*^9, 3.807371995593034*^9}, {
   3.825257164543844*^9, 3.825257166654457*^9}, 3.825409209665896*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[131]:=",ExpressionUUID->"cfe43c25-be78-4227-bac0-674e47880d70"],

Cell["Spiny lobster landings", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8252571861446147`*^9, 3.8252571876918125`*^9}, {
   3.825257300861082*^9, 3.8252573016396947`*^9}, 
   3.825409209665896*^9},ExpressionUUID->"e1e61a7d-5945-4ec8-812a-\
eda529f850ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdu0", " ", "=", "3379911.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.8048514568888445`*^9, {
   3.804859007321229*^9, 3.804859009274654*^9}, 3.8050173371426563`*^9, {
   3.805022177647732*^9, 3.8050221804450397`*^9}, {3.8067653602003455`*^9, 
   3.806765360340994*^9}, {3.8067654321826496`*^9, 3.806765433604763*^9}, {
   3.806831973009885*^9, 3.806831975213378*^9}, {3.806834150905658*^9, 
   3.8068341516085234`*^9}, {3.807371420190386*^9, 3.807371470290389*^9}, {
   3.807453445683219*^9, 3.8074534461846085`*^9}, {3.8252571697378883`*^9, 
   3.8252571706385555`*^9}, 3.825409209665896*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[132]:=",ExpressionUUID->"4ecde827-d0a5-44ad-8f2a-1ab84264d7b8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"psdu0", " ", "=", "18.5898"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.8048516736382985`*^9}, {3.8048592982724123`*^9, 
   3.80485930216366*^9}, 3.8050178642343397`*^9, {3.8050225293919544`*^9, 
   3.8050225352691364`*^9}, 3.8067666040100727`*^9, {3.806766772356678*^9, 
   3.806766773700653*^9}, 3.8068363234964*^9, {3.8073719843212566`*^9, 
   3.8073720026535287`*^9}, {3.82525717332368*^9, 3.8252571758856597`*^9}, 
   3.825409209666893*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[133]:=",ExpressionUUID->"fc8eb168-ab40-4abf-a2f7-a6c4a5fe0448"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.2 U.S. Processing Production Quantities and \
Prices", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672733348008*^9}, {
   3.8196727961837325`*^9, 3.8196728038250227`*^9}, 3.819814751753172*^9, 
   3.8249808810930777`*^9, 
   3.8254092222697544`*^9},ExpressionUUID->"58d1864b-63d2-4ac0-9ab7-\
e1ac53d09b11"],

Cell[TextData[StyleBox["Sources:\n National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries).\
\[NonBreakingSpace]Fisheries of the United States 2018. Current Fishery \
Statistics No. 2018. U.S. Department of Commerce. Silver Spring MD:\
\[NonBreakingSpace]NOAA,\[NonBreakingSpace]February 2020. \
https://www.fisheries.noaa.gov/resource/document/fisheries-united-states-2018-\
report.\[NonBreakingSpace] \n\nNational Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries). NOAA \
Processed Products database. Accessed September 1, \
2020.https://www.fisheries.noaa.gov/foss/f?p=215:3:5412288074334::NO:::",
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, {
   3.819814602882104*^9, 3.819814670599902*^9}, {3.8198147375350885`*^9, 
   3.819814751753172*^9}, {3.8198155956591797`*^9, 3.8198155972494073`*^9}, 
   3.8249808810930777`*^9, {3.8254092222697544`*^9, 3.82540926298663*^9}},
 FontSize->12,ExpressionUUID->"3f522b1e-d6a8-445d-957f-1f7b7d0f6d7f"],

Cell["Processed American lobster", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8252572474082675`*^9, 3.8252572546829915`*^9}, 
   3.8254092222697544`*^9},ExpressionUUID->"e22b65ca-0d01-4663-9a3d-\
79b2b10442b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadp0", " ", "=", "3807745.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.804851484318285*^9, {3.8048590605689173`*^9, 3.8048590667730417`*^9}, 
   3.8050173975775113`*^9, 3.805022232784355*^9, 3.8050224930197735`*^9, {
   3.8050232180903654`*^9, 3.805023241085371*^9}, {3.805023632655447*^9, 
   3.8050236356424956`*^9}, 3.8056458386741605`*^9, {3.805645871183111*^9, 
   3.8056458757007465`*^9}, {3.8067656082497215`*^9, 3.806765608366813*^9}, {
   3.8067656810295963`*^9, 3.806765683116229*^9}, {3.806834183944996*^9, 
   3.8068341845202856`*^9}, {3.807371491220681*^9, 3.8073715172809677`*^9}, 
   3.8073719425927744`*^9, {3.807453448834673*^9, 3.807453449335061*^9}, {
   3.8252572313887997`*^9, 3.825257232227457*^9}, 3.8254092222697544`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[134]:=",ExpressionUUID->"6561412e-06fd-4c57-ae93-47270a6df98e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"padp0", " ", "=", "43.8205"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}], " "}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, 
   3.8048516657287436`*^9, {3.804859289924417*^9, 3.804859293881085*^9}, 
   3.8050178536388817`*^9, {3.8050225182495184`*^9, 3.8050225241723566`*^9}, 
   3.8067662214541273`*^9, {3.806766763184125*^9, 3.8067667642114534`*^9}, 
   3.8068363150159225`*^9, {3.8073719933392773`*^9, 3.807371995593034*^9}, {
   3.8073721810834255`*^9, 3.8073722125289063`*^9}, {3.825257235009606*^9, 
   3.8252572371633153`*^9}, 3.8254092222697544`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[135]:=",ExpressionUUID->"b500756c-56aa-4933-bf28-26ff15c812df"],

Cell["Processed spiny lobster", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.8252572571979437`*^9, 3.8252572627102556`*^9}, 
   3.8254092222697544`*^9},ExpressionUUID->"7d8e623d-6a9d-4b24-8417-\
56762dbbc581"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdp0", " ", "=", "1247109.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.804851485974779*^9, {3.8048590710549765`*^9, 3.804859073899182*^9}, 
   3.80502223606614*^9, 3.805022494144955*^9, {3.8050232199500046`*^9, 
   3.8050232477426076`*^9}, 3.805645842097738*^9, {3.805645882358735*^9, 
   3.8056458856249104`*^9}, {3.8067656106425915`*^9, 
   3.8067656109668427`*^9}, {3.8067656880200605`*^9, 3.806765692106251*^9}, {
   3.8068341871273413`*^9, 3.806834187454748*^9}, {3.807371502336336*^9, 
   3.8073715290771523`*^9}, 3.807371946157546*^9, {3.8074534543579674`*^9, 
   3.807453454810321*^9}, {3.8252572398864202`*^9, 3.825257240000505*^9}, 
   3.8254092222707553`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[136]:=",ExpressionUUID->"abd93098-806c-4525-be8c-4d88e9e76f05"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"psdp0", " ", "=", "21.48835"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}], " "}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.8048516736382985`*^9}, {3.8048592982724123`*^9, 
   3.80485930216366*^9}, 3.8050178642343397`*^9, {3.8050225293919544`*^9, 
   3.8050225352691364`*^9}, 3.8067666040100727`*^9, {3.806766772356678*^9, 
   3.806766773700653*^9}, 3.8068363234964*^9, {3.8073719843212566`*^9, 
   3.8073720026535287`*^9}, {3.807372189532005*^9, 3.8073722154822054`*^9}, {
   3.825257242879726*^9, 3.825257245073457*^9}, 3.8254092222707553`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[137]:=",ExpressionUUID->"ebcd232e-c795-4bc1-a40e-cba3ff4afb1c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.3 Import Quantities and Prices", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672733348008*^9}, {
   3.819672809477676*^9, 3.8196728096938534`*^9}, 3.8198152044580364`*^9, {
   3.825087082314872*^9, 3.825087082408637*^9}, 3.8250872592046723`*^9, 
   3.825178301369998*^9, 
   3.8254092826770296`*^9},ExpressionUUID->"9f10f444-ddc7-48bd-88d7-\
8153ec7e4711"],

Cell[TextData[StyleBox["Source: IUU Estimate Database as described in Chapter \
3 of the report. ",
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, 
   3.819814602882104*^9, {3.8198147741606445`*^9, 3.8198147935287457`*^9}, 
   3.8198152044580364`*^9, 3.820012478192554*^9, {3.8208559831037273`*^9, 
   3.8208560402321887`*^9}, 3.8250871025311413`*^9, 3.8250872592046723`*^9, 
   3.8254092826780653`*^9},
 FontSize->12,ExpressionUUID->"7224716d-5dc4-4c93-8771-4160d39caef0"],

Cell["Total imports, unprocessed true lobster", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, 3.8250872592046723`*^9, {3.8251073358252196`*^9, 
   3.825107338716461*^9}, {3.825257313055621*^9, 3.8252573322316236`*^9}, 
   3.8254092826780653`*^9},ExpressionUUID->"31ae3b95-4ea8-419a-bb07-\
29c5b1772b9d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qttu0", " ", "=", 
    StyleBox["42154957",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.804851506634692*^9, {
   3.8048591212377567`*^9, 3.8048591249079113`*^9}, 3.8050174723254375`*^9, {
   3.8050222788917065`*^9, 3.805022281860938*^9}, {3.8056461739322014`*^9, 
   3.805646177617194*^9}, {3.806765736972315*^9, 3.806765737208499*^9}, {
   3.806765782146613*^9, 3.8067657845484924`*^9}, {3.8068342168185606`*^9, 
   3.8068342172224846`*^9}, 3.8073715657447004`*^9, {3.8073715971921797`*^9, 
   3.80737160065788*^9}, {3.807371952193246*^9, 3.807371954249849*^9}, {
   3.807453460600828*^9, 3.8074534612002935`*^9}, {3.8124730019039288`*^9, 
   3.8124730028386583`*^9}, {3.8170174007977996`*^9, 3.8170174082910023`*^9}, 
   3.8170174445556326`*^9, {3.817017475285564*^9, 3.8170174854783487`*^9}, {
   3.8188011845135145`*^9, 3.818801184657626*^9}, 3.8252573576505256`*^9, {
   3.825257553031229*^9, 3.825257553916912*^9}, 3.8254092826780653`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[138]:=",ExpressionUUID->"371d9049-7ce7-40f7-b41b-29c4bc91fb4b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pttu0", " ", "=", "21.9998"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851748049161*^9, {3.8048593936292486`*^9, 
   3.804859397458267*^9}, 3.805018113388355*^9, {3.8050226422134104`*^9, 
   3.8050226466203794`*^9}, {3.8056655591158066`*^9, 3.805665559787795*^9}, {
   3.806767012086607*^9, 3.8067670122741385`*^9}, {3.8067670493522654`*^9, 
   3.8067670500398808`*^9}, 3.80683636360534*^9, 3.8073720379369955`*^9, {
   3.807372090384822*^9, 3.8073720935262675`*^9}, {3.812473089967687*^9, 
   3.8124730900947857`*^9}, {3.817017809397198*^9, 3.817017814734833*^9}, {
   3.8170178647786355`*^9, 3.8170178868632574`*^9}, {3.818801375294573*^9, 
   3.818801375462703*^9}, {3.8252576250405416`*^9, 3.82525766610867*^9}, 
   3.8254092826780653`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[139]:=",ExpressionUUID->"aac04036-7655-40bb-aad7-1dc7991d1003"],

Cell["Total imports, unprocessed rock lobster", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.825257334823697*^9, 3.8252573406352196`*^9}, 
   3.8254092826780653`*^9},ExpressionUUID->"18b427f4-cad5-417f-a746-\
17a06e3f07a4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qrtu0", " ", "=", 
    StyleBox["6938435",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.804851506634692*^9, {
   3.8048591212377567`*^9, 3.8048591249079113`*^9}, {3.8050174723254375`*^9, 
   3.8050174834066176`*^9}, {3.8050222868930087`*^9, 3.805022290552119*^9}, {
   3.8056461840458636`*^9, 3.80564618843721*^9}, 3.806765527700594*^9, {
   3.8067657419251842`*^9, 3.806765742161369*^9}, {3.8067657893142157`*^9, 
   3.8067657927508984`*^9}, 3.806832190116372*^9, {3.8068342206466613`*^9, 
   3.8068342210808277`*^9}, {3.807371576063732*^9, 3.807371610474521*^9}, {
   3.8073719580417995`*^9, 3.8073719610041056`*^9}, {3.8074534637112494`*^9, 
   3.8074534642816925`*^9}, {3.8124730092096386`*^9, 
   3.8124730113352966`*^9}, {3.8170174177479744`*^9, 
   3.8170174414635916`*^9}, {3.8170175124281425`*^9, 3.817017541927514*^9}, {
   3.81880121287257*^9, 3.818801214145568*^9}, {3.8252573704795823`*^9, 
   3.825257380822668*^9}, 3.8252575571884775`*^9, 3.8254092826780653`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[140]:=",ExpressionUUID->"e3583c1c-0b7d-498c-9dc9-be43612a7e2d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"prtu0", " ", "=", "33.2254"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851748049161*^9, {3.8048593936292486`*^9, 
   3.804859397458267*^9}, {3.805018113388355*^9, 3.805018121905187*^9}, {
   3.8050226512323885`*^9, 3.8050226559050236`*^9}, {3.8067670145770597`*^9, 
   3.8067670148131976`*^9}, {3.806767058151041*^9, 3.80676705874489*^9}, 
   3.806836367480982*^9, 3.807372048266035*^9, {3.8073720986262407`*^9, 
   3.807372101914798*^9}, {3.8124730961214676`*^9, 3.812473098503318*^9}, {
   3.817017821653694*^9, 3.817017826543086*^9}, {3.817017942141184*^9, 
   3.8170179847320433`*^9}, 3.8188013971876917`*^9, {3.8252576407288136`*^9, 
   3.8252576615040693`*^9}, 3.8254092826780653`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[141]:=",ExpressionUUID->"8abd3c2c-fa5f-4fa9-b775-f67376897e53"],

Cell["Total imports, processed true lobster", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, {3.799791442102678*^9, 
   3.7997914423839736`*^9}, {3.804343678512698*^9, 3.804343679783687*^9}, {
   3.804520355853136*^9, 3.804520357118967*^9}, {3.8067655896682005`*^9, 
   3.806765590004464*^9}, {3.8252573185069017`*^9, 3.8252573258086004`*^9}, 
   3.8254092826790247`*^9},ExpressionUUID->"d9aa3b4d-191b-46e8-b6d9-\
0c7164d1e004"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qttp0", " ", "=", 
    StyleBox["7447010",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.804851523748412*^9, {3.8048591766858854`*^9, 
   3.80485918053025*^9}, 3.805017523488247*^9, {3.8050223529375687`*^9, 
   3.8050223554223504`*^9}, {3.80564624818703*^9, 3.805646251328046*^9}, {
   3.806765989152381*^9, 3.8067659894366035`*^9}, {3.806766029787133*^9, 
   3.8067660338633165`*^9}, {3.806834237283357*^9, 3.806834237650164*^9}, 
   3.8073716427816706`*^9, {3.807371673017212*^9, 3.8073716768672075`*^9}, {
   3.8074534703283997`*^9, 3.807453471430256*^9}, {3.812473022412948*^9, 
   3.812473024666712*^9}, {3.817017433704573*^9, 3.8170174630650487`*^9}, {
   3.8170174958316774`*^9, 3.817017500800125*^9}, {3.825257392673916*^9, 
   3.8252573972114973`*^9}, {3.8252574369353848`*^9, 3.8252574395834885`*^9}, 
   3.825257558348374*^9, 3.8254092826790247`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[142]:=",ExpressionUUID->"fc53ee63-8e40-4683-b321-8821e0a01696"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pttp0", " ", "=", "32.1337"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.804851783996252*^9, {
   3.8048594463590517`*^9, 3.8048594494689245`*^9}, {3.804859487327943*^9, 
   3.8048594931426477`*^9}, {3.8048659293832474`*^9, 3.8048659328369255`*^9}, 
   3.8050182854886165`*^9, {3.8050230503825045`*^9, 3.8050230545861716`*^9}, {
   3.805665743000533*^9, 3.8056657436142235`*^9}, {3.806767353506043*^9, 
   3.806767353709202*^9}, {3.8067673997591276`*^9, 3.8067674007891197`*^9}, 
   3.806836421326826*^9, 3.8073722425913067`*^9, {3.807372294613803*^9, 
   3.8073722987490263`*^9}, {3.8124731073561954`*^9, 
   3.8124731089994717`*^9}, {3.817017832245675*^9, 3.817017836762433*^9}, {
   3.817017908927368*^9, 3.8170179159096594`*^9}, {3.8252576720703344`*^9, 
   3.8252576850104957`*^9}, 3.8254092826790247`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[143]:=",ExpressionUUID->"a19c8c06-1203-453b-97b9-81d7697dca09"],

Cell["Total imports, processed rock lobster", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.825257343772691*^9, 3.8252573538035088`*^9}, 
   3.8254092826790247`*^9},ExpressionUUID->"5542ff37-707a-4950-9052-\
2ac9c9c57645"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qrtp0", " ", "=", 
    StyleBox["115772",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.804851523748412*^9, {3.8048591766858854`*^9, 
   3.80485918053025*^9}, {3.805017523488247*^9, 3.8050175307081823`*^9}, {
   3.8050223611106586`*^9, 3.8050223632985163`*^9}, {3.805646256795086*^9, 
   3.805646259346697*^9}, {3.806765991810455*^9, 3.8067659920466394`*^9}, {
   3.806766038914263*^9, 3.8067660420557213`*^9}, {3.8068342402673197`*^9, 
   3.8068342406715107`*^9}, {3.807371654134508*^9, 3.8073716865157185`*^9}, {
   3.807453474227434*^9, 3.807453474688792*^9}, {3.8124730309496183`*^9, 
   3.812473033174358*^9}, {3.8170174504100404`*^9, 3.8170174553762856`*^9}, {
   3.817017551583276*^9, 3.8170175728095984`*^9}, {3.825257451020403*^9, 
   3.825257454275961*^9}, 3.8252575606371794`*^9, 3.8254092826790247`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[144]:=",ExpressionUUID->"aaf62327-53e1-464d-9269-855cd6a8d47e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"prtp0", " ", "=", "22.2281"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.804851783996252*^9, {
   3.8048594463590517`*^9, 3.8048594494689245`*^9}, {3.804859487327943*^9, 
   3.8048594931426477`*^9}, {3.8048659293832474`*^9, 
   3.8048659328369255`*^9}, {3.8050182854886165`*^9, 
   3.8050182941251855`*^9}, {3.805023059946237*^9, 3.8050230631497755`*^9}, {
   3.8056657522159815`*^9, 3.805665753372402*^9}, {3.806767356208233*^9, 
   3.806767356459547*^9}, {3.8067674115529585`*^9, 3.80676741200616*^9}, 
   3.806836426140125*^9, 3.8073722524669943`*^9, {3.807372302391861*^9, 
   3.807372305828536*^9}, {3.812473114425687*^9, 3.8124731151042137`*^9}, {
   3.817017840719659*^9, 3.8170178476981907`*^9}, {3.817018010188755*^9, 
   3.8170180590722475`*^9}, 3.8188014380286274`*^9, {3.825257688431161*^9, 
   3.825257704223496*^9}, 3.8254092826790247`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[145]:=",ExpressionUUID->"830979a0-2024-4f7e-94ef-e6fd5d545f12"],

Cell["Total illegal imports, unprocessed ", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.799061046869288*^9, 3.799061055183115*^9}, {
   3.799791360292451*^9, 3.7997913701233187`*^9}, {3.7997916952904463`*^9, 
   3.7997916955561147`*^9}, 3.8016622985338755`*^9, {3.801662893960458*^9, 
   3.8016628969889317`*^9}, {3.8043437035121446`*^9, 
   3.8043437052855263`*^9}, {3.8067655927506084`*^9, 3.806765593036831*^9}, 
   3.8252574936818013`*^9, 
   3.8254092826790247`*^9},ExpressionUUID->"9d1598b7-ef35-4a1a-bc39-\
af1981762772"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qtiu0", " ", "=", 
    StyleBox["1624161",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.804851544345194*^9, {3.804859222792143*^9, 
   3.8048592281838903`*^9}, 3.805017601499572*^9, {3.805022415979398*^9, 
   3.805022417932844*^9}, {3.8056463334000163`*^9, 3.8056463354941115`*^9}, {
   3.8067660804267025`*^9, 3.8067661036161985`*^9}, {3.806834263250675*^9, 
   3.806834263573552*^9}, {3.8073717497969823`*^9, 3.807371772727832*^9}, {
   3.807453484231221*^9, 3.807453484673564*^9}, {3.812473049027743*^9, 
   3.8124730524534197`*^9}, {3.8170176321165495`*^9, 
   3.8170176378628445`*^9}, {3.817017691526613*^9, 3.8170176973940535`*^9}, {
   3.8252575100595984`*^9, 3.8252575105189667`*^9}, 3.825257562085291*^9, 
   3.825409282680034*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[146]:=",ExpressionUUID->"7d33a6af-ed15-4356-8e81-ee1b51ecb618"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qriu0", " ", "=", 
    StyleBox["1512807",
     FontColor->GrayLevel[0]]}], ";"}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.804851544345194*^9, {3.804859222792143*^9, 
   3.8048592281838903`*^9}, {3.805017601499572*^9, 3.8050176145309644`*^9}, {
   3.8050224245056534`*^9, 3.80502242658412*^9}, {3.805646340307399*^9, 
   3.8056463430450153`*^9}, {3.806766083173852*^9, 3.8067661197165565`*^9}, {
   3.806834266754854*^9, 3.8068342670986605`*^9}, {3.8073717578822737`*^9, 
   3.8073717801616197`*^9}, {3.807453486988368*^9, 3.807453487715933*^9}, {
   3.812473056648693*^9, 3.8124730596410303`*^9}, {3.817017641902898*^9, 
   3.8170176486204386`*^9}, {3.817017718143061*^9, 3.8170177219066725`*^9}, 
   3.8188013146411476`*^9, {3.825257513352173*^9, 3.8252575135353136`*^9}, 
   3.8252575631351166`*^9, 3.825409282680034*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[147]:=",ExpressionUUID->"d335b394-b7ba-460c-8916-2bfed61ddef4"],

Cell["Total illegal imports, processed", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.799061046869288*^9, 3.799061055183115*^9}, {
   3.799791360292451*^9, 3.799791397069314*^9}, {3.7997916867548366`*^9, 
   3.799791689442959*^9}, 3.801662286828817*^9, {3.8016629009271145`*^9, 
   3.801662902052309*^9}, {3.804343718154539*^9, 3.8043437215701966`*^9}, {
   3.8067655944049006`*^9, 3.806765594779194*^9}, 3.8252574961437483`*^9, 
   3.825409282680034*^9},ExpressionUUID->"4ad3ea4e-94c7-4ae2-a004-\
83c9bd8ee64d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qtip0", " ", "=", 
    StyleBox["287400",
     FontColor->GrayLevel[0]]}], ";"}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515613793716`*^9, {3.804859261769577*^9, 3.8048592662859316`*^9}, 
   3.8050176541599693`*^9, {3.8050224656385655`*^9, 3.8050224672325726`*^9}, {
   3.805646383822101*^9, 3.80564638584033*^9}, {3.806766140787306*^9, 
   3.806766141021719*^9}, {3.806766186631192*^9, 3.8067661887721605`*^9}, {
   3.8068342829952335`*^9, 3.806834283323414*^9}, {3.807371811697173*^9, 
   3.8073718335762186`*^9}, {3.80745349686305*^9, 3.807453497315404*^9}, {
   3.8124730653234696`*^9, 3.812473066700547*^9}, {3.817017652379374*^9, 
   3.817017657255933*^9}, {3.8170177072367926`*^9, 3.8170177104665875`*^9}, 
   3.8252575164566526`*^9, 3.8252575646783214`*^9, 3.825409282680034*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[148]:=",ExpressionUUID->"35bf12f1-9497-43a8-93f9-a343c7e57c0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qrip0", " ", "=", 
    StyleBox["13629",
     FontColor->GrayLevel[0]]}], ";"}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515613793716`*^9, {3.804859261769577*^9, 3.8048592662859316`*^9}, {
   3.8050176541599693`*^9, 3.8050176622706776`*^9}, {3.8050224736086135`*^9, 
   3.805022474483754*^9}, {3.806766143475238*^9, 3.806766143709651*^9}, {
   3.8067661948056383`*^9, 3.806766198119275*^9}, {3.8068342856717997`*^9, 
   3.806834285984372*^9}, {3.807371820879317*^9, 3.8073718396910057`*^9}, {
   3.807453500171628*^9, 3.8074535006339893`*^9}, {3.8124730699500856`*^9, 
   3.812473071141015*^9}, {3.8170176610646944`*^9, 3.8170176673964005`*^9}, {
   3.8170177291773157`*^9, 3.817017732614997*^9}, 3.8252575190266466`*^9, 
   3.8252575656961203`*^9, 3.825409282680034*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[149]:=",ExpressionUUID->"5c57897c-e6e0-4547-adec-f264f983fc1c"],

Cell["Calculation of legal imports ", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.799061046869288*^9, 3.799061055183115*^9}, {
   3.799791360292451*^9, 3.7997914000229187`*^9}, {3.799791698056525*^9, 
   3.7997916983378224`*^9}, {3.7997917503203683`*^9, 3.799791755353649*^9}, {
   3.800692812549324*^9, 3.800692822846528*^9}, 3.825257575004424*^9, 
   3.825409282680034*^9},ExpressionUUID->"cd6f868f-52a1-4b7d-bdd8-\
1e0c25075729"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qtlu0", " ", "=", " ", 
   RowBox[{"qttu0", "-", "qtiu0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516110447454`*^9}, {
   3.804851645028388*^9, 3.8048516486545525`*^9}, 3.8050174723254375`*^9, 
   3.805017601499572*^9, 3.805017705706191*^9, {3.8067666475387836`*^9, 
   3.8067666523377275`*^9}, 3.8073715657497044`*^9, 3.8073717497989836`*^9, 
   3.807371892194543*^9, 3.825257577174116*^9, 3.825409282680034*^9},
 CellLabel->
  "In[150]:=",ExpressionUUID->"7642a00a-7e5c-4224-8711-9ffc11e1be68"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qtlp0", " ", "=", " ", 
   RowBox[{"qttp0", "-", "qtip0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516144799304`*^9}, {3.8048516517171288`*^9, 3.804851653045458*^9}, 
   3.805017523503875*^9, 3.8050176541599693`*^9, {3.8050177690133715`*^9, 
   3.80501776909151*^9}, {3.80676665546325*^9, 3.806766660471738*^9}, 
   3.8073716427866745`*^9, 3.807371811699175*^9, 3.807371901524803*^9, 
   3.825257578789359*^9, 3.825409282680034*^9},
 CellLabel->
  "In[151]:=",ExpressionUUID->"912b37a4-b188-4750-8262-c62c624d05cf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qrlu0", " ", "=", " ", 
   RowBox[{"qrtu0", "-", "qriu0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516110447454`*^9}, {
   3.804851645028388*^9, 3.8048516486545525`*^9}, 3.8050174723254375`*^9, 
   3.805017601499572*^9, 3.805017705706191*^9, {3.805017779297551*^9, 
   3.8050177851734924`*^9}, {3.806766664377368*^9, 3.806766668653369*^9}, 
   3.807371576068736*^9, 3.8073717578842754`*^9, 3.807371919758997*^9, 
   3.82525758034659*^9, 3.8254092826810274`*^9},
 CellLabel->
  "In[152]:=",ExpressionUUID->"b2292b82-0665-4f04-80e1-a2dee86e9765"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qrlp0", " ", "=", " ", 
   RowBox[{"qrtp0", "-", "qrip0"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.},
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516144799304`*^9}, {3.8048516517171288`*^9, 3.804851653045458*^9}, 
   3.805017523503875*^9, 3.8050176541599693`*^9, {3.8050177690133715`*^9, 
   3.805017793223928*^9}, {3.806766671622616*^9, 3.8067666779986753`*^9}, 
   3.8073716541385107`*^9, 3.807371820881318*^9, 3.8073719111442957`*^9, 
   3.8252575815885534`*^9, 3.8254092826810274`*^9},
 CellLabel->
  "In[153]:=",ExpressionUUID->"2f08f5a1-311d-43ce-870b-fb2dfac7f219"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.4 Export Quantities", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672744603273*^9}, {
   3.8196728121258554`*^9, 3.8196728122829847`*^9}, {3.819815211108224*^9, 
   3.8198152128205585`*^9}, 3.81981526037964*^9, {3.825087245811554*^9, 
   3.8250872459365745`*^9}, 3.8251077687681923`*^9, 3.8251783054961834`*^9, 
   3.8254092884735675`*^9},ExpressionUUID->"c77e5d06-f1d8-4350-8e77-\
87365306630b"],

Cell[TextData[StyleBox["Source:National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries). NOAA US \
Trade in Fishery Products database. Accessed September 1, 2020. \
https://foss.nmfs.noaa.gov/apexfoss/f?p=215:2:14884747663545::NO",
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, 
   3.819814602882104*^9, {3.8198147741606445`*^9, 3.8198147935287457`*^9}, {
   3.819815219280593*^9, 3.81981526037964*^9}, {3.819815772355571*^9, 
   3.8198157737996855`*^9}, 3.8251077687681923`*^9, 3.8254092884735675`*^9},
 FontSize->12,ExpressionUUID->"0919bd74-ac92-4ede-a4ad-3c13fc557bbe"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadue0", " ", "=", "49445965"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.8048518506428456`*^9}, 3.805018387688871*^9, {
   3.805023130413168*^9, 3.8050231336479807`*^9}, 3.8067662301460323`*^9, {
   3.806767656937772*^9, 3.8067676608067927`*^9}, {3.806834315302986*^9, 
   3.806834315662419*^9}, {3.8073724077528768`*^9, 3.8073724119961834`*^9}, {
   3.825257776122735*^9, 3.8252577770174365`*^9}, 3.8254092884735675`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[154]:=",ExpressionUUID->"d36c758b-7ed8-4713-92ae-51ee7315a7bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadpe0", " ", "=", "282882"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.8048518506428456`*^9}, 3.805018387688871*^9, {
   3.805023130413168*^9, 3.8050231336479807`*^9}, 3.8067662301460323`*^9, {
   3.806767656937772*^9, 3.8067676608067927`*^9}, {3.806834315302986*^9, 
   3.806834315662419*^9}, {3.8073723932505894`*^9, 3.807372393396703*^9}, {
   3.8073724253375673`*^9, 3.807372427316104*^9}, 3.825257780084835*^9, 
   3.8254092884735675`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[155]:=",ExpressionUUID->"0e506b29-bfc7-4479-8fc4-8cfa6b23b871"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdue0", " ", "=", "315293"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.8048518633108516`*^9}, {3.804859565020601*^9, 
   3.8048595675211444`*^9}, 3.8050184291651025`*^9, 3.805018466468952*^9, {
   3.8050231373516073`*^9, 3.805023140305151*^9}, {3.806767607638239*^9, 
   3.8067676077953825`*^9}, {3.806767668703966*^9, 3.806767672090616*^9}, {
   3.806834318489034*^9, 3.8068343188244753`*^9}, {3.807372437359927*^9, 
   3.8073724396236863`*^9}, 3.807372474845104*^9, 3.82525778125175*^9, 
   3.8254092884745555`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[156]:=",ExpressionUUID->"ebbcdefa-e8b4-418d-bbcc-8a1406b8ea24"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdpe0", " ", "=", "  ", "0"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.},
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.804851865652524*^9}, {
   3.8048595759473476`*^9, 3.8048595789792566`*^9}, 3.8050184188980236`*^9, 
   3.805018469422534*^9, {3.806767612029669*^9, 3.80676761210773*^9}, {
   3.8067676834935265`*^9, 3.8067676858163443`*^9}, {3.8068343214811664`*^9, 
   3.8068343218562264`*^9}, 3.807372448978969*^9, 3.807372484247424*^9, 
   3.8252577825437584`*^9, 3.8254092884745555`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[157]:=",ExpressionUUID->"3302594c-3311-486c-975d-02c4f6420f26"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.5 Catch Limits", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672709332239*^9}, {
   3.819672747951029*^9, 3.819672752938134*^9}, {3.819672814932173*^9, 
   3.8196728150802965`*^9}, 3.8198153194016666`*^9, {3.825087365955282*^9, 
   3.8250873760433283`*^9}, 3.8251077801615553`*^9, 3.8251783091840515`*^9, 
   3.8254092982281885`*^9},ExpressionUUID->"20494cf4-adab-4dbb-8350-\
dbdf64a8c10d"],

Cell["American lobster", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.825257801256399*^9, 3.8252578040465813`*^9}, 
   3.82540929822919*^9},ExpressionUUID->"185ead6d-f6bb-434f-afe3-\
ef00a1d5122e"],

Cell[TextData[StyleBox["No aggregate ACL available, inserted arbitrarily high \
limit so it doesn\[CloseCurlyQuote]t affect calculation.",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934406567`*^9, {3.825087327099436*^9, 3.8250873282263136`*^9}, 
   3.825087365955282*^9, 3.825087544360035*^9, {3.8251076094113555`*^9, 
   3.825107615150221*^9}, {3.825107713090966*^9, 3.825107715732587*^9}, 
   3.8251077801615553`*^9, {3.8252577956329994`*^9, 3.825257798222023*^9}, 
   3.82540929822919*^9},ExpressionUUID->"1f50a929-70ab-44fe-a73d-\
75504f21a74b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadcap", " ", "=", "400000000.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.804851796545054*^9, 
   3.8048952007649207`*^9, {3.804895250483545*^9, 3.8048952544374237`*^9}, {
   3.8050183281629877`*^9, 3.805018342993407*^9}, {3.805023083589896*^9, 
   3.8050230976888266`*^9}, {3.805665773734192*^9, 3.80566577395298*^9}, 
   3.8067662239728813`*^9, {3.806834296407627*^9, 3.8068342968474436`*^9}, 
   3.8073723143481636`*^9, {3.8073723459147387`*^9, 3.8073723673294106`*^9}, {
   3.8141741188535347`*^9, 3.814174119072322*^9}, {3.8252578094518085`*^9, 
   3.825257809562896*^9}, 3.82540929822919*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[158]:=",ExpressionUUID->"802c6b9b-1962-431d-b17b-a621193520c7"],

Cell["Spiny lobster", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.825257812210969*^9, 3.8252578138722677`*^9}, 
   3.82540929822919*^9},ExpressionUUID->"07927045-5790-40c2-813e-\
6a2d1eab9036"],

Cell[TextData[StyleBox["Sources:\nNOAA, \[OpenCurlyDoubleQuote]Fisheries of \
the Caribbean, Gulf of Mexico, and South Atlantic; Spiny Lobster Fishery of \
the Gulf of Mexico and South Atlantic Regions; Regulatory Amendment,\
\[CloseCurlyDoubleQuote] Federal Register, June 22, 2018, \
https://www.federalregister.gov/documents/2018/06/22/2018-13400/fisheries-of-\
the-caribbean-gulf-of-mexico-and-south-atlantic-spiny-lobster-fishery-of-the-\
gulf-of.\n\n\[OpenCurlyDoubleQuote]Annual Catch Limits (ACLs) and \
Accountability Measures (AMs) for Caribbean Island Management Areas/Caribbean \
EEZ.,\[CloseCurlyDoubleQuote] LII / Legal Information Institute, accessed \
November 19, 2020, https://www.law.cornell.edu/cfr/text/50/622.12.",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934406567`*^9, {3.825087327099436*^9, 3.8250873282263136`*^9}, 
   3.825087365955282*^9, 3.825087544360035*^9, {3.8251076094113555`*^9, 
   3.825107615150221*^9}, {3.825107713090966*^9, 3.825107715732587*^9}, 
   3.8251077801615553`*^9, {3.8252577956329994`*^9, 3.8252578565134463`*^9}, 
   3.82540929822919*^9},ExpressionUUID->"3a8f1040-8e3f-4a1f-8d8e-\
1a3dca91edf6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdcap", " ", "=", "4403157.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.},
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.8048517992485948`*^9, {
   3.8048952270850687`*^9, 3.8048952446230383`*^9}, {3.805018338242672*^9, 
   3.8050183454469113`*^9}, 3.8050231013143167`*^9, {3.8056657763909063`*^9, 
   3.805665776531555*^9}, {3.8067675511110563`*^9, 3.8067675512481637`*^9}, {
   3.8068342994728765`*^9, 3.8068342998323116`*^9}, {3.8073723169271727`*^9, 
   3.8073723430485063`*^9}, {3.8252578265631576`*^9, 3.8252578274018097`*^9}, 
   3.82540929822919*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[159]:=",ExpressionUUID->"cb959750-59dd-405b-8ff0-098877582c11"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.6 Import Market Share Statistics", "Subsection",
 FontSize->18]], "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.8199018381766195`*^9, 3.8199018609792204`*^9}, 
   3.819901901056156*^9, 3.8199024672872863`*^9, {3.825087356571492*^9, 
   3.8250873787787514`*^9}, 3.8251077863213964`*^9, {3.825178311928185*^9, 
   3.825178312126339*^9}, 
   3.825409309076688*^9},ExpressionUUID->"0bcfb45d-7762-443a-8819-\
6c1bda987ce2"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qttu0", "/", 
   RowBox[{"(", 
    RowBox[{"qttu0", "+", "qadu0", "-", "qadue0"}], ")"}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.812671672938323*^9, 3.812671754827257*^9}, 
   3.825409309076688*^9},
 CellLabel->
  "In[160]:=",ExpressionUUID->"9bd5a9f7-6a53-4209-b795-7ed16c734d0a"],

Cell[BoxData["0.7143213934756355`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.8126717553516645`*^9, 3.8126717592687073`*^9}, 
   3.8128184399697075`*^9, 3.812818692343112*^9, 3.8128187423540287`*^9, 
   3.8129669879170647`*^9, 3.812967843287199*^9, 3.8129679719440536`*^9, 
   3.8129682031664486`*^9, 3.812968693710553*^9, 3.8129689373960037`*^9, 
   3.812976728785758*^9, 3.8129768769420443`*^9, 3.8154797182367735`*^9, 
   3.8157758712814903`*^9, 3.8157759473318768`*^9, 3.817018087090192*^9, 
   3.818801462010378*^9, 3.8252581681412573`*^9, 3.825409309076688*^9, 
   3.8254093550196505`*^9},
 CellLabel->
  "Out[160]=",ExpressionUUID->"23c27096-7d2d-45fd-a7c7-7a704a6fe537"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qttp0", "/", 
   RowBox[{"(", 
    RowBox[{"qttp0", "+", "qadp0", "-", "qadpe0"}], ")"}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.812671672938323*^9, 3.8126717866099463`*^9}, 
   3.825409309076688*^9},
 CellLabel->
  "In[161]:=",ExpressionUUID->"d5614ce3-fad6-47e4-88e0-0d4d74431e46"],

Cell[BoxData["0.6787364381632927`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.8126717553516645`*^9, 3.8126717886251817`*^9}, 
   3.812818440056774*^9, 3.8128186924351845`*^9, 3.812818742451103*^9, 
   3.81296698801083*^9, 3.812967843412218*^9, 3.812967972063754*^9, 
   3.812968203292702*^9, 3.8129686938355737`*^9, 3.812968937505396*^9, 
   3.8129767289263763`*^9, 3.812976877102146*^9, 3.8154797183461666`*^9, 
   3.8157758714126067`*^9, 3.8157759474619827`*^9, 3.8170180871022005`*^9, 
   3.818801462021386*^9, 3.8252581682933483`*^9, 3.825409309076688*^9, 
   3.82540935515278*^9},
 CellLabel->
  "Out[161]=",ExpressionUUID->"d50ee5ff-4fc1-4d3b-8c24-ccd361893c6d"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qrtu0", "/", 
   RowBox[{"(", 
    RowBox[{"qrtu0", "+", "qsdu0", "-", "qsdue0"}], ")"}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.812671672938323*^9, 3.812671754827257*^9}, {
   3.8126718029352984`*^9, 3.812671809345278*^9}, 3.8254093090776896`*^9},
 CellLabel->
  "In[162]:=",ExpressionUUID->"2864af37-e549-430c-9e06-d2f8451f20b7"],

Cell[BoxData["0.6936317342315391`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.8126717553516645`*^9, 3.8126717592687073`*^9}, 
   3.812671821438672*^9, 3.8128184401358366`*^9, 3.812818692522252*^9, 
   3.8128187425491796`*^9, 3.8129669880889673`*^9, 3.812967843537239*^9, 
   3.812967972200428*^9, 3.8129682034020944`*^9, 3.8129686939449887`*^9, 
   3.812968937614788*^9, 3.812976729067029*^9, 3.8129768772523136`*^9, 
   3.815479718471187*^9, 3.8157758715366917`*^9, 3.815775947587076*^9, 
   3.817018087114211*^9, 3.818801462034397*^9, 3.825258168363403*^9, 
   3.8254093090776896`*^9, 3.825409355310856*^9},
 CellLabel->
  "Out[162]=",ExpressionUUID->"4916e431-0e57-4a29-bdb2-27f39bdc82d7"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qrtp0", "/", 
   RowBox[{"(", 
    RowBox[{"qrtp0", "+", "qsdp0", "-", "qsdpe0"}], ")"}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.812671672938323*^9, 3.8126718189647503`*^9}, 
   3.8254093090776896`*^9},
 CellLabel->
  "In[163]:=",ExpressionUUID->"0e236d69-eac0-4597-a69b-d2da31542bbd"],

Cell[BoxData["0.08494652137640776`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.},
 CellChangeTimes->{{3.8126717553516645`*^9, 3.8126717886251817`*^9}, 
   3.812671823408202*^9, 3.8128184402158985`*^9, 3.8128186926303363`*^9, 
   3.8128187426382494`*^9, 3.8129669881827326`*^9, 3.8129678436466317`*^9, 
   3.812967972308197*^9, 3.8129682035114884`*^9, 3.812968694054359*^9, 
   3.8129689377241817`*^9, 3.8129767292076807`*^9, 3.8129768774085636`*^9, 
   3.81547971858058*^9, 3.815775871664811*^9, 3.8157759477351913`*^9, 
   3.817018087126766*^9, 3.818801462047407*^9, 3.825258168479533*^9, 
   3.8254093090786815`*^9, 3.825409355454966*^9},
 CellLabel->
  "Out[163]=",ExpressionUUID->"dc132945-2d78-430f-935f-0971f14105e8"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3. Calibration",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.7954529786642447`*^9}, {
  3.79545386036082*^9, 3.7954538618860044`*^9}, {3.819900448697421*^9, 
  3.8199004491007357`*^9}},ExpressionUUID->"090a6d96-50fc-4f0a-9c97-\
b55f50ce848a"],

Cell["Baseline values of domestic apparent consumption and imports", "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7954541868300085`*^9, 3.7954542200368147`*^9}, {
  3.795455624690459*^9, 3.7954556275947175`*^9}, {3.795532637283266*^9, 
  3.7955326380308447`*^9}, {3.799794880332456*^9, 3.79979488120757*^9}, {
  3.801667655660522*^9, 3.801667670402505*^9}, {3.8199000703965473`*^9, 
  3.8199001199411907`*^9}, {3.8250875854467816`*^9, 
  3.825087593229326*^9}},ExpressionUUID->"7bcc55d1-51bf-4c8b-8d08-\
10dbd38a5ae0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vttu0", "=", 
   RowBox[{"qttu0", " ", "pttu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851948303916*^9, 3.804851950926388*^9}, 
   3.8050174723410645`*^9, 3.805018113403982*^9, 3.8050185702579627`*^9, {
   3.806768085830998*^9, 3.8067680867547207`*^9}, 3.8073715657517056`*^9, {
   3.8073720379399977`*^9, 3.8073720379409986`*^9}, 3.8073727557687893`*^9, 
   3.8074562762267885`*^9},
 CellLabel->
  "In[164]:=",ExpressionUUID->"bcd1b8c2-12df-4a34-b46e-55c2ab4cc24e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vttp0", "=", 
   RowBox[{"qttp0", " ", "pttp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519523417597`*^9, 3.804851955436349*^9}, 3.805017523503875*^9, 
   3.8050182854886165`*^9, 3.805018578479169*^9, {3.806768087287137*^9, 
   3.806768088596162*^9}, 3.8073716427897005`*^9, {3.8073722425933094`*^9, 
   3.80737224259531*^9}, 3.8073727579544935`*^9, 3.8074562788458285`*^9},
 CellLabel->
  "In[165]:=",ExpressionUUID->"7ba43ca5-42d7-4dd1-9e4d-54130dec78d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vrtu0", "=", 
   RowBox[{"qrtu0", " ", "prtu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851948303916*^9, 3.804851950926388*^9}, 
   3.8050174723410645`*^9, 3.805018113403982*^9, {3.8050185702579627`*^9, 
   3.8050186149235363`*^9}, {3.806768108614807*^9, 3.806768109548538*^9}, 
   3.807371576070737*^9, {3.8073720482680364`*^9, 3.8073720482690372`*^9}, 
   3.807372760190232*^9, 3.807456281237692*^9},
 CellLabel->
  "In[166]:=",ExpressionUUID->"a670896e-3a79-4021-8343-54a5ece8d061"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vrtp0", "=", 
   RowBox[{"qrtp0", " ", "prtp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519523417597`*^9, 3.804851955436349*^9}, 3.805017523503875*^9, 
   3.8050182854886165`*^9, {3.805018578479169*^9, 3.8050186102353115`*^9}, {
   3.806768109952854*^9, 3.8067681108585615`*^9}, 3.807371654141514*^9, {
   3.8073722524689956`*^9, 3.8073722524699965`*^9}, 3.807372762358919*^9, 
   3.807456283325313*^9},
 CellLabel->
  "In[167]:=",ExpressionUUID->"e277d6ca-3f55-4be1-9d33-c1ff6a01c5a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vadu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qadu0", "-", "qadue0"}], ")"}], " ", "padu0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.8048519638260803`*^9, 3.8048519716484485`*^9}, {
   3.8048598918387938`*^9, 3.804859912733159*^9}, {3.804860064780347*^9, 
   3.804860071891223*^9}, 3.8048664223456783`*^9, 3.805017322685949*^9, 
   3.80501738938866*^9, 3.8050178536388817`*^9, 3.805018387688871*^9, 
   3.805018727270131*^9, {3.805025120899139*^9, 3.8050251367937717`*^9}, 
   3.8050252580605593`*^9, 3.805665863356492*^9, {3.806766234381547*^9, 
   3.8067662361710587`*^9}, {3.806768033988475*^9, 3.806768062827016*^9}, 
   3.806832458677179*^9, {3.8073725819604893`*^9, 3.807372586350908*^9}, 
   3.8073727644435444`*^9, 3.8075309687981396`*^9, 3.8252566482576747`*^9},
 CellLabel->
  "In[168]:=",ExpressionUUID->"a3ab304f-2aee-4fbd-bfd7-6f5a12f02f88"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vadp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qadp0", "-", "qadpe0"}], ")"}], " ", "padp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.8048520323591175`*^9, 3.804852037110026*^9}, 3.8050174161743164`*^9, 
   3.805018163879826*^9, 3.8050184579051275`*^9, 3.805018865715522*^9, {
   3.805018922906186*^9, 3.80501893122008*^9}, 3.8056658784229183`*^9, {
   3.806768228648225*^9, 3.806768230547699*^9}, 3.80683252666142*^9, {
   3.807372595272854*^9, 3.8073726067617955`*^9}, 3.807372766669278*^9, 
   3.8252566525249915`*^9},
 CellLabel->
  "In[169]:=",ExpressionUUID->"39bf3198-00de-45df-a1be-3f7603e2375e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vsdu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qsdu0", "-", "qsdue0"}], ")"}], " ", "psdu0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.804852022920974*^9, 3.804852030499457*^9}, {
   3.804859896652155*^9, 3.804859921734771*^9}, {3.8048600950900917`*^9, 
   3.8048600972310853`*^9}, 3.804866433404766*^9, 3.80501735923965*^9, 
   3.8050174161586895`*^9, 3.805017872688827*^9, 3.805018443417308*^9, 
   3.805018858088605*^9, {3.8050189086090927`*^9, 3.8050189207964573`*^9}, {
   3.805025198060874*^9, 3.805025202280357*^9}, 3.8050252760635777`*^9, 
   3.805665872969016*^9, {3.80676822628439*^9, 3.8067682281548424`*^9}, 
   3.806832524401739*^9, 3.8073727689830756`*^9, 3.807530973657385*^9, 
   3.8252566539691296`*^9},
 CellLabel->
  "In[170]:=",ExpressionUUID->"452c9f24-2134-4294-98c5-98d220bcf96c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vsdp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qsdp0", "-", "qsdpe0"}], ")"}], " ", "psdp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.8048520323591175`*^9, 3.804852037110026*^9}, 3.8050174161743164`*^9, 
   3.805018163879826*^9, 3.8050184579051275`*^9, 3.805018865715522*^9, {
   3.805018922906186*^9, 3.80501893122008*^9}, 3.8056658784229183`*^9, {
   3.806768228648225*^9, 3.806768230547699*^9}, 3.80683252666142*^9, 
   3.8073727717101994`*^9, 3.825256655261117*^9},
 CellLabel->
  "In[171]:=",ExpressionUUID->"ebbbcfd0-9681-4755-aac2-3374db013fbe"],

Cell[CellGroupData[{

Cell["3.1 Supply Parameters", "Subsubsection",
 CellChangeTimes->{{3.819902497376732*^9, 3.819902510893259*^9}, 
   3.8250876058265457`*^9},ExpressionUUID->"22d0e65b-838e-4777-8c88-\
7f76411ad0e1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eadu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"ead", " ", 
     FractionBox["qadu0", 
      RowBox[{"(", 
       RowBox[{"qadcap", "-", "qadu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.804852083303175*^9, 3.804852090898363*^9}, {
   3.805017228666668*^9, 3.805017228666668*^9}, {3.805017322685949*^9, 
   3.805017322685949*^9}, 3.8050183281629877`*^9, {3.8067662415466795`*^9, 
   3.8067662448054667`*^9}, 3.807371291723375*^9, 3.8073726333875213`*^9, 
   3.825256668570533*^9},
 CellLabel->
  "In[172]:=",ExpressionUUID->"251b4ab0-22c0-46e3-b8e5-e9aa3e6836c2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aadu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qadcap", "-", "qadu0"}], ")"}], " ", 
    SuperscriptBox["padu0", "eadu"]}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048520933987694`*^9, 
   3.804852099759162*^9}, 3.805017228682296*^9, 3.805017322685949*^9, 
   3.8050178536388817`*^9, 3.8050183281629877`*^9, 3.805018972205937*^9, {
   3.806766245508704*^9, 3.806766247493399*^9}, 3.807372633390524*^9, 
   3.825256670222888*^9},
 CellLabel->
  "In[173]:=",ExpressionUUID->"84a21240-2395-4207-a627-0bd1de0b1bd2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"esdu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"esd", " ", 
     FractionBox["qsdu0", 
      RowBox[{"(", 
       RowBox[{"qsdcap", "-", "qsdu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.8048521093589597`*^9, 3.804852115828997*^9}, {
   3.80501724212201*^9, 3.80501724212201*^9}, {3.805017337158284*^9, 
   3.805017337158284*^9}, 3.805018338242672*^9, {3.8067684152658606`*^9, 
   3.8067684169223766`*^9}, {3.8073713156730175`*^9, 3.807371315675019*^9}, {
   3.807371445132804*^9, 3.807371445134805*^9}, 3.8073723285692377`*^9, 
   3.8252566715908947`*^9},
 CellLabel->
  "In[174]:=",ExpressionUUID->"ddefb4fb-ed0b-41c9-b34f-815fdb269d09"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"asdu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qsdcap", "-", "qsdu0"}], ")"}], " ", 
    SuperscriptBox["psdu0", "esdu"]}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521184231625`*^9, 
   3.8048521249554644`*^9}, 3.80501724212201*^9, 3.805017337158284*^9, 
   3.8050178642343397`*^9, 3.805018338258299*^9, 3.8050189849580746`*^9, {
   3.8067684173599467`*^9, 3.806768419188366*^9}, 3.80737131567702*^9, 
   3.8073714451358056`*^9, 3.8073719843262606`*^9, 3.807372328570239*^9, 
   3.807372655515748*^9, 3.8252566729079275`*^9},
 CellLabel->
  "In[175]:=",ExpressionUUID->"9804a220-ad8a-4ea2-b0a3-d983552dacc8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aadp", " ", "=", " ", 
   RowBox[{"qadp0", " ", 
    SuperscriptBox["padp0", 
     RowBox[{"-", "ead"}]]}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048520933987694`*^9, 
   3.804852099759162*^9}, 3.805017228682296*^9, 3.805017322685949*^9, 
   3.8050178536388817`*^9, 3.8050183281629877`*^9, 3.805018972205937*^9, {
   3.806766245508704*^9, 3.806766247493399*^9}, 3.807372633390524*^9, {
   3.807530989802887*^9, 3.8075310133595843`*^9}, {3.80753104370317*^9, 
   3.8075310544549165`*^9}, 3.8075321384046726`*^9, 3.8252566742479825`*^9},
 CellLabel->
  "In[176]:=",ExpressionUUID->"bc3c59fe-1a5a-4620-b777-5193481a7c20"],

Cell[BoxData[
 RowBox[{
  RowBox[{"asdp", " ", "=", " ", 
   RowBox[{"qsdp0", " ", 
    SuperscriptBox["psdp0", 
     RowBox[{"-", "esd"}]]}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521184231625`*^9, 
   3.8048521249554644`*^9}, 3.80501724212201*^9, 3.805017337158284*^9, 
   3.8050178642343397`*^9, 3.805018338258299*^9, 3.8050189849580746`*^9, {
   3.8067684173599467`*^9, 3.806768419188366*^9}, 3.80737131567702*^9, 
   3.8073714451358056`*^9, 3.8073719843262606`*^9, 3.807372328570239*^9, 
   3.807372655515748*^9, {3.807530993162809*^9, 3.807531057314561*^9}, 
   3.8075321427335043`*^9, 3.825256675564005*^9},
 CellLabel->
  "In[177]:=",ExpressionUUID->"5f10e891-dfc6-4792-ad06-a5c8539015a5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2 Demand Parameters", "Subsubsection",
 CellChangeTimes->{{3.819902513379201*^9, 3.8199025199032784`*^9}, 
   3.8250876191725216`*^9},ExpressionUUID->"764cfc7f-4169-418e-9916-\
e02e7bded345"],

Cell[BoxData[
 RowBox[{
  RowBox[{"btu", " ", "=", 
   RowBox[{
    FractionBox["vttu0", "vadu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pttu0", "padu0"], ")"}], 
     RowBox[{"sigmac", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8073729273703146`*^9, 3.807372934548935*^9}},
 CellLabel->
  "In[178]:=",ExpressionUUID->"34c2bdbf-9703-407d-a3dc-bdf6109d5ebe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padu0", 
       RowBox[{"1", "-", "sigmac"}]], "+", 
      RowBox[{"btu", " ", 
       SuperscriptBox["pttu0", 
        RowBox[{"1", "-", "sigmac"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmac"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8049544298763714`*^9, 3.8049544298763714`*^9}, 
   3.8050178536545095`*^9, 3.8050180911664543`*^9, {3.8050196031952763`*^9, 
   3.805019614619006*^9}, {3.806764855581185*^9, 3.806764855581185*^9}, {
   3.8067662514444556`*^9, 3.8067662527884216`*^9}, {3.806832604894101*^9, 
   3.8068326118481846`*^9}, {3.8073729437351265`*^9, 3.807372986008688*^9}, {
   3.8073730547972403`*^9, 3.8073730605797434`*^9}, 3.807886900682838*^9, {
   3.807887202930168*^9, 3.8078872064620094`*^9}, 3.8252566855938635`*^9},
 CellLabel->
  "In[179]:=",ExpressionUUID->"9e69d06c-6caf-46db-bda6-a3faf4148c88"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bru", " ", "=", 
   RowBox[{
    FractionBox["vrtu0", "vsdu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["prtu0", "psdu0"], ")"}], 
     RowBox[{"sigman", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852908773026*^9}, 
   3.804954429860744*^9, 3.8050178536388817`*^9, 3.8050180911508274`*^9, 
   3.805018527670006*^9, 3.805018727270131*^9, 3.8050196031952763`*^9, 
   3.806764855581185*^9, {3.806766248790482*^9, 3.8067662507126665`*^9}, {
   3.8068325963302846`*^9, 3.8068325967991133`*^9}, {3.8073726993858986`*^9, 
   3.8073727142884984`*^9}, {3.807372806797514*^9, 3.8073728098588977`*^9}, {
   3.807372870186545*^9, 3.8073729207651725`*^9}, {3.80737299744059*^9, 
   3.807373012872602*^9}, {3.807373071728422*^9, 3.8073730720226526`*^9}},
 CellLabel->
  "In[180]:=",ExpressionUUID->"366feb00-9bf5-4990-95a3-a7a110168717"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pnu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdu0", 
       RowBox[{"1", "-", "sigman"}]], "+", 
      RowBox[{"bru", " ", 
       SuperscriptBox["prtu0", 
        RowBox[{"1", "-", "sigman"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigman"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8049544298763714`*^9, 3.8049544298763714`*^9}, 
   3.8050178536545095`*^9, 3.8050180911664543`*^9, {3.8050196031952763`*^9, 
   3.805019614619006*^9}, {3.806764855581185*^9, 3.806764855581185*^9}, {
   3.8067662514444556`*^9, 3.8067662527884216`*^9}, {3.806832604894101*^9, 
   3.8068326118481846`*^9}, {3.8073729437351265`*^9, 3.807372986008688*^9}, {
   3.80737302670437*^9, 3.8073730661730986`*^9}, {3.8078872095406485`*^9, 
   3.807887211322197*^9}, 3.8252566884561176`*^9},
 CellLabel->
  "In[181]:=",ExpressionUUID->"43a9bcc6-6d6d-4177-a452-ad251c4b00f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsu", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vrtu0", "+", "vsdu0"}], 
     RowBox[{"vadu0", "+", "vttu0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pnu0", "Pcu0"], ")"}], 
     RowBox[{"betau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.805018527670006*^9, 3.8050185566621103`*^9}, {3.805018727285775*^9, 
   3.8050187442272134`*^9}, {3.8050187967043133`*^9, 3.8050187992359776`*^9}, 
   3.805019614619006*^9, 3.8050196452264185`*^9, 3.805019802540661*^9, {
   3.806766253225992*^9, 3.8067662541991515`*^9}, {3.8067691749605126`*^9, 
   3.806769177132744*^9}, {3.807373089848527*^9, 3.8073731369501963`*^9}, 
   3.8078869414796352`*^9, 3.825256694418765*^9},
 CellLabel->
  "In[182]:=",ExpressionUUID->"ead5963f-2b2a-45a5-8c0e-2269dfb14f41"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pu0", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pcu0", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bsu", " ", 
       SuperscriptBox["Pnu0", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, 3.8050196146346335`*^9, 
   3.8050196452264185`*^9, 3.8050196847698293`*^9, {3.805019802540661*^9, 
   3.8050198551991177`*^9}, {3.805640058914117*^9, 3.805640067666767*^9}, 
   3.806766260935816*^9, {3.806769261515285*^9, 3.8067692861381626`*^9}, {
   3.80737314651264*^9, 3.807373173686798*^9}, 3.825256692446225*^9},
 CellLabel->
  "In[183]:=",ExpressionUUID->"a8ffdad4-a19d-4acd-9f6d-4ed4d842efd6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"btp", " ", "=", 
   RowBox[{
    FractionBox["vttp0", "vadp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pttp0", "padp0"], ")"}], 
     RowBox[{"sigmac", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8073729273703146`*^9, 3.807372934548935*^9}, {
  3.807373209513686*^9, 3.807373211078906*^9}},
 CellLabel->
  "In[184]:=",ExpressionUUID->"36403031-0b54-4e3f-b978-34490e792346"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Pcp0", " ", "=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["padp0", 
        RowBox[{"1", "-", "sigmac"}]], "+", 
       RowBox[{"btp", " ", 
        SuperscriptBox["pttp0", 
         RowBox[{"1", "-", "sigmac"}]]}]}], ")"}], 
     FractionBox["1", 
      RowBox[{"1", "-", "sigmac"}]]]}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8049544298763714`*^9, 3.8049544298763714`*^9}, 
   3.8050178536545095`*^9, 3.8050180911664543`*^9, {3.8050196031952763`*^9, 
   3.805019614619006*^9}, {3.806764855581185*^9, 3.806764855581185*^9}, {
   3.8067662514444556`*^9, 3.8067662527884216`*^9}, {3.806832604894101*^9, 
   3.8068326118481846`*^9}, {3.8073729437351265`*^9, 3.807372986008688*^9}, {
   3.8073730547972403`*^9, 3.8073730605797434`*^9}, {3.8073732117414227`*^9, 
   3.8073732143665314`*^9}, 3.8078869306334105`*^9, {3.8078872151522017`*^9, 
   3.807887217818158*^9}, 3.8252566983118057`*^9},
 CellLabel->
  "In[185]:=",ExpressionUUID->"bfe09279-c02a-4e14-b37a-2ead85213dd7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"brp", " ", "=", 
   RowBox[{
    FractionBox["vrtp0", "vsdp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["prtp0", "psdp0"], ")"}], 
     RowBox[{"sigman", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852908773026*^9}, 
   3.804954429860744*^9, 3.8050178536388817`*^9, 3.8050180911508274`*^9, 
   3.805018527670006*^9, 3.805018727270131*^9, 3.8050196031952763`*^9, 
   3.806764855581185*^9, {3.806766248790482*^9, 3.8067662507126665`*^9}, {
   3.8068325963302846`*^9, 3.8068325967991133`*^9}, {3.8073726993858986`*^9, 
   3.8073727142884984`*^9}, {3.807372806797514*^9, 3.8073728098588977`*^9}, {
   3.807372870186545*^9, 3.8073729207651725`*^9}, {3.80737299744059*^9, 
   3.807373012872602*^9}, {3.807373071728422*^9, 3.8073730720226526`*^9}, {
   3.807373215041992*^9, 3.8073732165962*^9}},
 CellLabel->
  "In[186]:=",ExpressionUUID->"c032c0bb-88fc-4890-aaa4-791e8693396f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pnp0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdp0", 
       RowBox[{"1", "-", "sigman"}]], "+", 
      RowBox[{"brp", " ", 
       SuperscriptBox["prtp0", 
        RowBox[{"1", "-", "sigman"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigman"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8049544298763714`*^9, 3.8049544298763714`*^9}, 
   3.8050178536545095`*^9, 3.8050180911664543`*^9, {3.8050196031952763`*^9, 
   3.805019614619006*^9}, {3.806764855581185*^9, 3.806764855581185*^9}, {
   3.8067662514444556`*^9, 3.8067662527884216`*^9}, {3.806832604894101*^9, 
   3.8068326118481846`*^9}, {3.8073729437351265`*^9, 3.807372986008688*^9}, {
   3.80737302670437*^9, 3.8073730661730986`*^9}, {3.8073732170595627`*^9, 
   3.8073732182865176`*^9}, {3.807887221131212*^9, 3.8078872230065255`*^9}, 
   3.825256701619412*^9},
 CellLabel->
  "In[187]:=",ExpressionUUID->"731377da-9a28-4166-b87e-1fc4636c09d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsp", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vrtp0", "+", "vsdp0"}], 
     RowBox[{"vadp0", "+", "vttp0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pnp0", "Pcp0"], ")"}], 
     RowBox[{"betap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.805018527670006*^9, 3.8050185566621103`*^9}, {3.805018727285775*^9, 
   3.8050187442272134`*^9}, {3.8050187967043133`*^9, 3.8050187992359776`*^9}, 
   3.805019614619006*^9, 3.8050196452264185`*^9, 3.805019802540661*^9, {
   3.806766253225992*^9, 3.8067662541991515`*^9}, {3.8067691749605126`*^9, 
   3.806769177132744*^9}, {3.807373089848527*^9, 3.8073731369501963`*^9}, {
   3.8073732321713243`*^9, 3.807373235605999*^9}, 3.8078869372751875`*^9, 
   3.8252567042014475`*^9},
 CellLabel->
  "In[188]:=",ExpressionUUID->"62eabe97-1954-43ae-855a-7d2c54b35cbd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pp0", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pcp0", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bsp", " ", 
       SuperscriptBox["Pnp0", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, 3.8050196146346335`*^9, 
   3.8050196452264185`*^9, 3.8050196847698293`*^9, {3.805019802540661*^9, 
   3.8050198551991177`*^9}, {3.805640058914117*^9, 3.805640067666767*^9}, 
   3.806766260935816*^9, {3.806769261515285*^9, 3.8067692861381626`*^9}, {
   3.80737314651264*^9, 3.807373173686798*^9}, {3.807373236300543*^9, 
   3.807373239400957*^9}, {3.807373272524741*^9, 3.8073732726528416`*^9}, 
   3.8252567119695425`*^9},
 CellLabel->
  "In[189]:=",ExpressionUUID->"e6724399-0426-4abd-bb4b-27370550b482"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ku", "=", 
   FractionBox[
    RowBox[{"qttu0", " ", 
     SuperscriptBox["Pu0", 
      RowBox[{
       RowBox[{"-", "etau"}], "-", "betau", " "}]], 
     SuperscriptBox["Pcu0", 
      RowBox[{"betau", "-", "sigmac"}]], 
     SuperscriptBox["pttu0", "sigmac"]}], "btu"]}], ";"}]], "Input",
 CellChangeTimes->{{3.800140454488206*^9, 3.800140523176643*^9}, {
   3.800455058428173*^9, 3.800455063959334*^9}, {3.8006362513154964`*^9, 
   3.800636260384779*^9}, 3.8006363054963803`*^9, 3.800647348889147*^9, 
   3.8006960898303185`*^9, 3.800804256877533*^9, {3.8008043645295997`*^9, 
   3.800804364685875*^9}, {3.8008068728494596`*^9, 3.800806875974489*^9}, {
   3.8016604841908655`*^9, 3.8016604867536297`*^9}, {3.801663391117081*^9, 
   3.801663391882834*^9}, 3.801664413638791*^9, {3.8016647577403903`*^9, 
   3.801664759459405*^9}, {3.8016648404783707`*^9, 3.8016648805396347`*^9}, {
   3.801665135307444*^9, 3.801665211909813*^9}, 3.8016653900835795`*^9, {
   3.8016670898715615`*^9, 3.8016670989043036`*^9}, {3.80168887262052*^9, 
   3.8016888744489493`*^9}, {3.8016889608852425`*^9, 3.801689010426876*^9}, {
   3.8017784454569283`*^9, 3.801778458163327*^9}, 3.801778528743101*^9, {
   3.8017814934521255`*^9, 3.8017814938740683`*^9}, {3.8031140023071547`*^9, 
   3.803114014512789*^9}, {3.8031260626605997`*^9, 3.8031261061075296`*^9}, {
   3.804344640574292*^9, 3.804344672830389*^9}, {3.8048534574220657`*^9, 
   3.8048535141640887`*^9}, {3.804954429923254*^9, 3.804954429923254*^9}, 
   3.8050174498061085`*^9, 3.8050180911664543`*^9, {3.8050196031952763`*^9, 
   3.8050196146346335`*^9}, {3.806764855673539*^9, 3.806764855673539*^9}, {
   3.806766271845762*^9, 3.806766273142846*^9}, {3.806788838484434*^9, 
   3.806788849604492*^9}, {3.8073732905167494`*^9, 3.807373326728939*^9}, {
   3.8078869466207952`*^9, 3.807886950981553*^9}, 3.8252567143653746`*^9},
 CellLabel->
  "In[190]:=",ExpressionUUID->"0f3e7553-f6e2-4c16-ad42-a622b32f2bcb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kp", "=", 
   FractionBox[
    RowBox[{"qttp0", " ", 
     SuperscriptBox["Pp0", 
      RowBox[{
       RowBox[{"-", "etap"}], "-", "betap"}]], 
     SuperscriptBox["Pcp0", 
      RowBox[{"betap", "-", "sigmac"}]], " ", 
     SuperscriptBox["pttp0", "sigmac"]}], "btp"]}], ";"}]], "Input",
 CellChangeTimes->{{3.801689038848219*^9, 3.8016890477090626`*^9}, 
   3.80177853075905*^9, 3.8031139983340187`*^9, {3.8031261513407984`*^9, 
   3.80312624801073*^9}, {3.8031284224239283`*^9, 3.8031284235638275`*^9}, {
   3.804344676926572*^9, 3.8043446965778627`*^9}, {3.80485352319683*^9, 
   3.8048535706159515`*^9}, {3.8049544667270565`*^9, 3.8049544667270565`*^9}, 
   3.8050175026566935`*^9, 3.8050182696893077`*^9, 3.8050199344667687`*^9, 
   3.805019969866063*^9, {3.8067648665516233`*^9, 3.8067648665516233`*^9}, {
   3.806766274283498*^9, 3.806766275580185*^9}, {3.806788858252745*^9, 
   3.8067888731246524`*^9}, {3.806833239257119*^9, 3.806833269833151*^9}, {
   3.807373333689361*^9, 3.8073733526501217`*^9}, {3.8074570940245266`*^9, 
   3.8074570951363907`*^9}, {3.8078869536538916`*^9, 3.8078869594986544`*^9}, 
   3.8252567181913924`*^9},
 CellLabel->
  "In[191]:=",ExpressionUUID->"3ef16ad7-9288-471b-b407-adece8171bc8"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4. New Equilibrium Calculation",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.7954529786642447`*^9}, {
  3.79545386036082*^9, 3.7954538618860044`*^9}, {3.795525436722562*^9, 
  3.795525448873003*^9}, {3.819900451316465*^9, 
  3.819900451678748*^9}},ExpressionUUID->"adefa830-0aad-442a-a63c-\
7faf6a6e3231"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padu", 
       RowBox[{"1", "-", "sigmac"}]], "+", 
      RowBox[{"btu", " ", 
       SuperscriptBox["pttu", 
        RowBox[{"1", "-", "sigmac"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmac"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048537407717743`*^9, 3.804853751697942*^9}, {
   3.804954429923254*^9, 3.804954429938881*^9}, {3.8050196031952763`*^9, 
   3.8050196146346335`*^9}, {3.8050202419412766`*^9, 3.805020254318351*^9}, {
   3.806764855673539*^9, 3.806764855689166*^9}, {3.8067662760490103`*^9, 
   3.806766277137709*^9}, {3.8067889104228306`*^9, 3.8067889156268196`*^9}, {
   3.8073733877004075`*^9, 3.807373413787715*^9}, 3.807886968203288*^9},
 CellLabel->
  "In[192]:=",ExpressionUUID->"ef893d96-bd08-4069-9c34-459925ad7abd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pnu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdu", 
       RowBox[{"1", "-", "sigman"}]], "+", 
      RowBox[{"bru", " ", 
       SuperscriptBox["prtu", 
        RowBox[{"1", "-", "sigman"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigman"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.804853754104593*^9, 
   3.8048537632655916`*^9}, {3.8049544890767255`*^9, 
   3.8049544890767255`*^9}, {3.805019635911148*^9, 3.8050196452420464`*^9}, {
   3.805020269508397*^9, 3.805020277728525*^9}, {3.8067649135109673`*^9, 
   3.8067649135109673`*^9}, {3.806788883376049*^9, 3.806788883454187*^9}, {
   3.80678891895547*^9, 3.8067889336454124`*^9}, {3.8073709493188176`*^9, 
   3.807370949320819*^9}, {3.8073734046205783`*^9, 3.8073734205609875`*^9}},
 CellLabel->
  "In[193]:=",ExpressionUUID->"8ed78591-642f-4073-ae37-f3504a3aa756"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pu", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pcu", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bsu", " ", 
       SuperscriptBox["Pnu", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048536729130955`*^9, 
   3.804853693916567*^9}, 3.805019614650261*^9, 3.8050196452420464`*^9, 
   3.8050196847698293`*^9, {3.805019802540661*^9, 3.805019812682934*^9}, {
   3.8050203129401875`*^9, 3.805020330818774*^9}, {3.8050205921461425`*^9, 
   3.8050205922399073`*^9}, {3.805640322587119*^9, 3.8056403333666506`*^9}, 
   3.806766277340867*^9, {3.806789028285674*^9, 3.806789054157593*^9}, {
   3.8073734299072657`*^9, 3.8073734396308327`*^9}},
 CellLabel->
  "In[194]:=",ExpressionUUID->"fcad075f-b133-4c8a-bbfe-1247200c7621"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcp", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padp", 
       RowBox[{"1", "-", "sigmac"}]], "+", 
      RowBox[{"btp", " ", 
       SuperscriptBox["pttp", 
        RowBox[{"1", "-", "sigmac"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmac"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048537407717743`*^9, 3.804853751697942*^9}, {
   3.804954429923254*^9, 3.804954429938881*^9}, {3.8050196031952763`*^9, 
   3.8050196146346335`*^9}, {3.8050202419412766`*^9, 3.805020254318351*^9}, {
   3.806764855673539*^9, 3.806764855689166*^9}, {3.8067662760490103`*^9, 
   3.806766277137709*^9}, {3.8067889104228306`*^9, 3.8067889156268196`*^9}, {
   3.8073733877004075`*^9, 3.807373413787715*^9}, {3.807373616096217*^9, 
   3.8073736180947685`*^9}, 3.8078869727521725`*^9},
 CellLabel->
  "In[195]:=",ExpressionUUID->"e4f1b596-0573-4ff5-85bd-0349547c3a1b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pnp", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdp", 
       RowBox[{"1", "-", "sigman"}]], "+", 
      RowBox[{"brp", " ", 
       SuperscriptBox["prtp", 
        RowBox[{"1", "-", "sigman"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigman"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.804853754104593*^9, 
   3.8048537632655916`*^9}, {3.8049544890767255`*^9, 
   3.8049544890767255`*^9}, {3.805019635911148*^9, 3.8050196452420464`*^9}, {
   3.805020269508397*^9, 3.805020277728525*^9}, {3.8067649135109673`*^9, 
   3.8067649135109673`*^9}, {3.806788883376049*^9, 3.806788883454187*^9}, {
   3.80678891895547*^9, 3.8067889336454124`*^9}, {3.8073709493188176`*^9, 
   3.807370949320819*^9}, {3.8073734046205783`*^9, 3.8073734205609875`*^9}, {
   3.807373618686228*^9, 3.8073736200342813`*^9}},
 CellLabel->
  "In[196]:=",ExpressionUUID->"f79d4387-0447-4407-8c07-0248d4b385fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pp", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pcp", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bsp", " ", 
       SuperscriptBox["Pnp", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048536729130955`*^9, 
   3.804853693916567*^9}, 3.805019614650261*^9, 3.8050196452420464`*^9, 
   3.8050196847698293`*^9, {3.805019802540661*^9, 3.805019812682934*^9}, {
   3.8050203129401875`*^9, 3.805020330818774*^9}, {3.8050205921461425`*^9, 
   3.8050205922399073`*^9}, {3.805640322587119*^9, 3.8056403333666506`*^9}, 
   3.806766277340867*^9, {3.806789028285674*^9, 3.806789054157593*^9}, {
   3.8073734299072657`*^9, 3.8073734396308327`*^9}, {3.807373620704802*^9, 
   3.8073736238352385`*^9}},
 CellLabel->
  "In[197]:=",ExpressionUUID->"7517f389-6f5d-4907-bf9f-a9ec53179fc7"],

Cell[TextData[StyleBox["Equilibrium equations",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8252567420880613`*^9, 
  3.825256746080194*^9}},ExpressionUUID->"0b09dc1a-4b30-4d5f-9dba-\
ae16cde992b2"],

Cell["\<\
Total supply (landings) of wild caught = exports + consumer demand \
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800413034212*^9}, 3.799855091636346*^9, {
   3.799884003726459*^9, 3.7998840232612796`*^9}, {3.800099320730234*^9, 
   3.800099324730491*^9}, {3.804344834713479*^9, 3.8043448352639103`*^9}, {
   3.806766281090131*^9, 3.8067662858218727`*^9}, 3.807531513926655*^9, {
   3.8254093249961815`*^9, 
   3.8254093256666775`*^9}},ExpressionUUID->"a73e3fe0-db97-486d-b715-\
1d3b31d8449a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E1", "=", 
   RowBox[{
    RowBox[{"qadcap", "-", 
     RowBox[{"aadu", " ", 
      SuperscriptBox["padu", 
       RowBox[{"-", "eadu"}]]}]}], "\[Equal]", 
    RowBox[{"qadue0", "+", 
     RowBox[{"ku", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Pcu", 
       RowBox[{"sigmac", "-", "betau"}]], " ", 
      SuperscriptBox["padu", 
       RowBox[{"-", "sigmac"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.804854416639573*^9, 3.8048544212964177`*^9}, {
   3.8048603517476826`*^9, 3.8048603524352975`*^9}, {3.804954429938881*^9, 
   3.804954429938881*^9}, {3.8049544667270565`*^9, 3.8049544667270565`*^9}, 
   3.8050172287448063`*^9, 3.8050183281629877`*^9, {3.805018387688871*^9, 
   3.8050183990668306`*^9}, 3.805018972205937*^9, 3.805019614650261*^9, 
   3.805019969866063*^9, {3.8050202419412766`*^9, 3.8050202419412766`*^9}, 
   3.805020609852163*^9, {3.806764855689166*^9, 3.8067648665672507`*^9}, {
   3.806766281355798*^9, 3.806766293185562*^9}, {3.806789333051278*^9, 
   3.8067893549231033`*^9}, 3.8073726333945265`*^9, {3.807373653286169*^9, 
   3.807373761956767*^9}, {3.8075314194831514`*^9, 3.807531450067649*^9}, {
   3.8075317629659204`*^9, 3.8075317672491274`*^9}},
 CellLabel->
  "In[198]:=",ExpressionUUID->"7054bfa1-6724-4536-94f8-428722fa9818"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E2", "=", 
   RowBox[{
    RowBox[{"qsdcap", "-", 
     RowBox[{"asdu", " ", 
      SuperscriptBox["psdu", 
       RowBox[{"-", "esdu"}]]}]}], "\[Equal]", 
    RowBox[{"qsdue0", "+", 
     RowBox[{"ku", " ", "bsu", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Pnu", 
       RowBox[{"sigman", "-", "betau"}]], " ", 
      SuperscriptBox["psdu", 
       RowBox[{"-", "sigman"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541303369503`*^9, 3.8048541304619713`*^9}, {
   3.8048542078548927`*^9, 3.8048542473983154`*^9}, {3.8048544408381042`*^9, 
   3.8048544472919245`*^9}, {3.8048546221752834`*^9, 
   3.8048546230035305`*^9}, {3.804860163075424*^9, 3.804860163434861*^9}, {
   3.804860364468531*^9, 3.8048603661250505`*^9}, {3.8048606546180067`*^9, 
   3.8048606554618917`*^9}, {3.8049546267265406`*^9, 3.804954640509137*^9}, 
   3.8050172630966716`*^9, 3.805018360214622*^9, {3.805018443417308*^9, 
   3.8050184579051275`*^9}, 3.8050194297527933`*^9, 3.805019684785465*^9, 
   3.805019812682934*^9, 3.805020008092595*^9, 3.8050201313295197`*^9, {
   3.8050202878564696`*^9, 3.8050202878564696`*^9}, 3.8050206310766573`*^9, {
   3.8050208652351437`*^9, 3.8050208655164404`*^9}, {3.8050209307173986`*^9, 
   3.8050209595502567`*^9}, {3.8067895482004004`*^9, 
   3.8067895601560745`*^9}, {3.807373747038153*^9, 3.807373810593633*^9}, {
   3.8074593545714483`*^9, 3.807459355535203*^9}, {3.8075314264072084`*^9, 
   3.8075314428734465`*^9}, {3.807531769702651*^9, 3.8075317763597383`*^9}},
 CellLabel->
  "In[199]:=",ExpressionUUID->"c2996b52-8c55-4eee-9698-15dc1c36aea2"],

Cell["\<\
Supply of imported unprocessed product = Demand for imported unprocessed \
product\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.7998012380597954`*^9}, {3.804854223408702*^9, 
   3.804854223455584*^9}, {3.80485425494967*^9, 3.8048542550121794`*^9}, {
   3.804854289806265*^9, 3.8048542955259604`*^9}, {3.8048543266944003`*^9, 
   3.804854326803794*^9}, 3.8067662935918775`*^9, {3.8067663997058973`*^9, 
   3.8067664000340776`*^9}},ExpressionUUID->"f2222292-c02a-4dff-bfb0-\
5253e658f6aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E4", "=", 
   RowBox[{
    RowBox[{"qtlu0", "+", 
     RowBox[{"replt", " ", "qtiu0"}]}], "\[Equal]", 
    RowBox[{"ku", "  ", "btu", " ", 
     SuperscriptBox["Pu", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Pcu", 
      RowBox[{"sigmac", "-", "betau"}]], "  ", 
     SuperscriptBox["pttu", 
      RowBox[{"-", "sigmac"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854492241708*^9}, {3.8048545380175877`*^9, 
   3.8048545527071533`*^9}, {3.8048605221100817`*^9, 
   3.8048605232990365`*^9}, {3.8049546267265406`*^9, 3.8049546267265406`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805019670771908*^9, 
   3.805019684785465*^9}, 3.8050198126985607`*^9, 3.8050202964360323`*^9, {
   3.805020977131299*^9, 3.8050209774125957`*^9}, {3.805638042536155*^9, 
   3.8056380426924305`*^9}, {3.8067649535028925`*^9, 
   3.8067649535028925`*^9}, {3.806789674553228*^9, 3.8067897296714444`*^9}, {
   3.807371003076667*^9, 3.8073710030786686`*^9}, 3.8073711919557037`*^9, 
   3.8073717498019867`*^9, 3.8073718921975455`*^9, 3.8073738524011803`*^9, {
   3.807373989043585*^9, 3.8073739896350465`*^9}, {3.80737403297479*^9, 
   3.8073740582114377`*^9}},
 CellLabel->
  "In[200]:=",ExpressionUUID->"d16e2950-660f-43e2-895a-44af17fb0b6a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E5", "=", 
   RowBox[{
    RowBox[{"qrlu0", "+", 
     RowBox[{"replr", " ", "qriu0"}]}], "\[Equal]", 
    RowBox[{"ku", " ", "bru", " ", "bsu", " ", 
     SuperscriptBox["Pu", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Pnu", 
      RowBox[{"sigman", "-", "betau"}]], "  ", 
     SuperscriptBox["prtu", 
      RowBox[{"-", "sigman"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854492241708*^9}, {3.8048545380175877`*^9, 
   3.8048545527071533`*^9}, {3.8048605221100817`*^9, 
   3.8048605232990365`*^9}, {3.8049546267265406`*^9, 3.8049546267265406`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805019670771908*^9, 
   3.805019684785465*^9}, 3.8050198126985607`*^9, 3.8050202964360323`*^9, {
   3.805020977131299*^9, 3.805021024420715*^9}, {3.8056380458491983`*^9, 
   3.805638046021101*^9}, {3.8067649723509226`*^9, 3.8067649723509226`*^9}, {
   3.8067897332190866`*^9, 3.8067897560275936`*^9}, {3.807371026559946*^9, 
   3.8073710265609465`*^9}, 3.807371205212028*^9, 3.807371757886277*^9, 
   3.8073719197619996`*^9, 3.8073738547440047`*^9, {3.807373996487384*^9, 
   3.8073740045806828`*^9}, {3.807374036391451*^9, 3.807374054872837*^9}},
 CellLabel->
  "In[201]:=",ExpressionUUID->"cfe54ccf-0db7-4801-88fa-6007d3fcd471"],

Cell["\<\
Supply of imported processed product = Demand for imported processed product\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.7998012380597954`*^9}, {3.799884418200181*^9, 
   3.799884420684106*^9}, {3.8048542235337224`*^9, 3.8048542235649776`*^9}, {
   3.8048542551059437`*^9, 3.804854255152827*^9}, {3.8048543063260717`*^9, 
   3.804854311392005*^9}, {3.8048546319736*^9, 3.8048546323799095`*^9}, 
   3.806766295873494*^9, {3.806766402784531*^9, 
   3.806766402909552*^9}},ExpressionUUID->"aee4aa60-9cad-4f3f-8312-\
69ed87061370"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E7", "=", 
   RowBox[{
    RowBox[{"qtlp0", "+", 
     RowBox[{"replt", " ", "qtip0"}]}], "\[Equal]", 
    RowBox[{"kp", " ", "btp", " ", 
     SuperscriptBox["Pp", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pcp", 
      RowBox[{"sigmac", "-", "betap"}]], " ", 
     SuperscriptBox["pttp", 
      RowBox[{"-", "sigmac"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
   3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
   3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
   3.8048546364093094`*^9, 3.804854691797214*^9}, {3.804854727667985*^9, 
   3.8048547417515974`*^9}, {3.804860470270588*^9, 3.8048604712707496`*^9}, {
   3.804954640509137*^9, 3.804954640524764*^9}, 3.8050176541599693`*^9, 
   3.8050199537057533`*^9, 3.8050200081082225`*^9, 3.805020131345148*^9, 
   3.8050206707245793`*^9, {3.805021060755541*^9, 3.8050210902671776`*^9}, {
   3.8056380617710304`*^9, 3.8056380622641325`*^9}, {3.806789916393276*^9, 
   3.8067899376337585`*^9}, {3.807371010529467*^9, 3.807371010530468*^9}, 
   3.807371191956704*^9, 3.8073718117011766`*^9, 3.807371901527806*^9, 
   3.8073738616764016`*^9, {3.807374074732298*^9, 3.807374123702425*^9}},
 CellLabel->
  "In[202]:=",ExpressionUUID->"0940c008-f167-45b0-8f67-f75f70a7d4aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E8", "=", 
   RowBox[{
    RowBox[{"qrlp0", "+", 
     RowBox[{"replr", " ", "qrip0"}]}], "\[Equal]", 
    RowBox[{"kp", " ", "brp", " ", "bsp", " ", 
     SuperscriptBox["Pp", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pnp", 
      RowBox[{"sigman", "-", "betap"}]], " ", 
     SuperscriptBox["prtp", 
      RowBox[{"-", "sigman"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
   3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
   3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
   3.8048546364093094`*^9, 3.8048546757308216`*^9}, {3.8049544667426844`*^9, 
   3.8049544667426844`*^9}, 3.805017636828994*^9, 3.8050199344667687`*^9, 
   3.805019969866063*^9, 3.8050206555502205`*^9, {3.8050210534247737`*^9, 
   3.8050210719588156`*^9}, {3.805021114427477*^9, 3.8050211350415163`*^9}, {
   3.8056380697113733`*^9, 3.805638069878157*^9}, {3.806789940916145*^9, 
   3.8067899607220736`*^9}, {3.8068329705184917`*^9, 3.806832979083044*^9}, {
   3.807371042775569*^9, 3.80737104277657*^9}, 3.8073712052140293`*^9, 
   3.8073718208843207`*^9, 3.807371911147298*^9, 3.8073738649549537`*^9, {
   3.8073740804827766`*^9, 3.8073741196162453`*^9}},
 CellLabel->
  "In[203]:=",ExpressionUUID->"4a6d51bc-ab93-4cda-be00-59be19085ebe"],

Cell["\<\
Supply of domestic processed lobster = demand of domestic processed lobster\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800413034212*^9}, 3.799855091636346*^9, {
   3.799884003726459*^9, 3.7998840232612796`*^9}, {3.800099320730234*^9, 
   3.800099324730491*^9}, {3.804344834713479*^9, 3.8043448352639103`*^9}, {
   3.806766281090131*^9, 3.8067662858218727`*^9}, {3.807531537621533*^9, 
   3.8075315492908115`*^9}},ExpressionUUID->"fe5ac143-fd1f-49dd-8606-\
531639c6211f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E9", "=", 
   RowBox[{
    RowBox[{"aadp", " ", 
     SuperscriptBox["padp", "ead"]}], "\[Equal]", " ", 
    RowBox[{"qadpe0", "+", 
     RowBox[{"kp", " ", 
      SuperscriptBox["Pp", 
       RowBox[{"etap", "+", "betap"}]], 
      SuperscriptBox["Pcp", 
       RowBox[{"sigmac", "-", "betap"}]], " ", 
      SuperscriptBox["padp", 
       RowBox[{"-", "sigmac"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.804854416639573*^9, 3.8048544212964177`*^9}, {
   3.8048603517476826`*^9, 3.8048603524352975`*^9}, {3.804954429938881*^9, 
   3.804954429938881*^9}, {3.8049544667270565`*^9, 3.8049544667270565`*^9}, 
   3.8050172287448063`*^9, 3.8050183281629877`*^9, {3.805018387688871*^9, 
   3.8050183990668306`*^9}, 3.805018972205937*^9, 3.805019614650261*^9, 
   3.805019969866063*^9, {3.8050202419412766`*^9, 3.8050202419412766`*^9}, 
   3.805020609852163*^9, {3.806764855689166*^9, 3.8067648665672507`*^9}, {
   3.806766281355798*^9, 3.806766293185562*^9}, {3.806789333051278*^9, 
   3.8067893549231033`*^9}, 3.8073726333945265`*^9, {3.807373653286169*^9, 
   3.807373761956767*^9}, {3.8075314194831514`*^9, 3.807531450067649*^9}, {
   3.807531553023554*^9, 3.8075316237259045`*^9}},
 CellLabel->
  "In[204]:=",ExpressionUUID->"9ffbd96d-803b-44a0-99d8-0c1850ae94f5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E10", "=", 
   RowBox[{
    RowBox[{"asdp", " ", 
     SuperscriptBox["psdp", "esd"]}], "\[Equal]", " ", 
    RowBox[{"qsdpe0", "+", 
     RowBox[{"bsp", " ", "kp", " ", 
      SuperscriptBox["Pp", 
       RowBox[{"etap", "+", "betap"}]], 
      SuperscriptBox["Pnp", 
       RowBox[{"sigman", "-", "betap"}]], " ", 
      SuperscriptBox["psdp", 
       RowBox[{"-", "sigman"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541303369503`*^9, 3.8048541304619713`*^9}, {
   3.8048542078548927`*^9, 3.8048542473983154`*^9}, {3.8048544408381042`*^9, 
   3.8048544472919245`*^9}, {3.8048546221752834`*^9, 
   3.8048546230035305`*^9}, {3.804860163075424*^9, 3.804860163434861*^9}, {
   3.804860364468531*^9, 3.8048603661250505`*^9}, {3.8048606546180067`*^9, 
   3.8048606554618917`*^9}, {3.8049546267265406`*^9, 3.804954640509137*^9}, 
   3.8050172630966716`*^9, 3.805018360214622*^9, {3.805018443417308*^9, 
   3.8050184579051275`*^9}, 3.8050194297527933`*^9, 3.805019684785465*^9, 
   3.805019812682934*^9, 3.805020008092595*^9, 3.8050201313295197`*^9, {
   3.8050202878564696`*^9, 3.8050202878564696`*^9}, 3.8050206310766573`*^9, {
   3.8050208652351437`*^9, 3.8050208655164404`*^9}, {3.8050209307173986`*^9, 
   3.8050209595502567`*^9}, {3.8067895482004004`*^9, 
   3.8067895601560745`*^9}, {3.807373747038153*^9, 3.807373810593633*^9}, {
   3.8074593545714483`*^9, 3.807459355535203*^9}, {3.8075314264072084`*^9, 
   3.8075314428734465`*^9}, {3.8075315567130866`*^9, 3.807531589993263*^9}, {
   3.8075316315092554`*^9, 3.807531639556748*^9}},
 CellLabel->
  "In[205]:=",ExpressionUUID->"0fb150fd-2c3a-41ba-8817-4473beb48449"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "E1", ",", "E2", ",", " ", "E4", ",", " ", "E5", ",", " ", "E7", ",", 
     "E8", ",", "E9", ",", "E10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"padu", ",", "padu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"psdu", ",", "psdu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pttu", ",", "pttu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"prtu", ",", "prtu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"prtp", ",", "prtp0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pttp", ",", "pttp0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"padp", ",", "padp0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"psdp", ",", "psdp0"}], "}"}], ",", 
   RowBox[{"AccuracyGoal", "\[Rule]", "6"}], ",", " ", 
   RowBox[{"PrecisionGoal", "\[Rule]", "6"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799801050741409*^9, 3.7998010802456255`*^9}, {
   3.799801592828159*^9, 3.799801634478999*^9}, {3.7998017203390927`*^9, 
   3.799801763344025*^9}, 3.7998021088038597`*^9, {3.799855159502365*^9, 
   3.799855165706504*^9}, {3.801692496821689*^9, 3.801692518577862*^9}, {
   3.801780123825697*^9, 3.8017801628874054`*^9}, {3.80178020897694*^9, 
   3.8017802303410735`*^9}, {3.804345075920143*^9, 3.8043451100366836`*^9}, {
   3.8048547484844165`*^9, 3.8048549152697835`*^9}, {3.8050178536701374`*^9, 
   3.805017872704455*^9}, {3.8050180911664543`*^9, 3.805018113403982*^9}, {
   3.8050182696893077`*^9, 3.8050182855042944`*^9}, {3.8050202419569035`*^9, 
   3.8050202964360323`*^9}, {3.8050206555502205`*^9, 
   3.8050206707245793`*^9}, {3.8050211495951157`*^9, 
   3.8050212640550547`*^9}, {3.805640520045041*^9, 3.8056405549869733`*^9}, 
   3.8056410453683844`*^9, {3.806766295890339*^9, 3.8067662959059663`*^9}, {
   3.806790033493409*^9, 3.806790075525874*^9}, {3.806790132327119*^9, 
   3.8067902104953566`*^9}, {3.8068345450910096`*^9, 
   3.8068345455442104`*^9}, {3.8068361427784767`*^9, 3.806836163988557*^9}, {
   3.8068362180905004`*^9, 3.806836244028018*^9}, {3.806836474800679*^9, 
   3.8068364886153865`*^9}, 3.807371984345276*^9, {3.807372026249895*^9, 
   3.8073720482860503`*^9}, {3.807372230999284*^9, 3.807372252484008*^9}, {
   3.8073738704001913`*^9, 3.807373958608214*^9}, 3.807374145897703*^9, {
   3.8074535237049417`*^9, 3.807453555850959*^9}, {3.8075316436667967`*^9, 
   3.8075316611899304`*^9}, {3.8075319358123436`*^9, 3.807531938868207*^9}, {
   3.8078869909915686`*^9, 3.807887003045738*^9}},
 CellLabel->
  "In[206]:=",ExpressionUUID->"6340c5ef-1fdf-4a1b-8913-8de97b421861"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"padu", "\[Rule]", "9.435471053962102`"}], ",", 
   RowBox[{"psdu", "\[Rule]", "19.60618618862167`"}], ",", 
   RowBox[{"pttu", "\[Rule]", "22.561991594209896`"}], ",", 
   RowBox[{"prtu", "\[Rule]", "35.77357185141801`"}], ",", 
   RowBox[{"prtp", "\[Rule]", "22.44176457775414`"}], ",", 
   RowBox[{"pttp", "\[Rule]", "32.64257159869641`"}], ",", 
   RowBox[{"padp", "\[Rule]", "43.926967470177466`"}], ",", 
   RowBox[{"psdp", "\[Rule]", "21.56119505892864`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8067906011164465`*^9, 3.8067906285634785`*^9}, 
   3.8068326309942307`*^9, 3.8068329898048162`*^9, 3.806833355120599*^9, 
   3.8068340563226423`*^9, 3.806834363778349*^9, {3.806834552232403*^9, 
   3.8068345690982485`*^9}, 3.80683475689135*^9, 3.806835133896302*^9, 
   3.806835276686602*^9, 3.806835339430457*^9, 3.8068354380532455`*^9, 
   3.8068355638795533`*^9, 3.8068361671453285`*^9, {3.806836222537903*^9, 
   3.806836245075068*^9}, 3.806836451708686*^9, {3.806836481973657*^9, 
   3.806836494676769*^9}, 3.806836811768938*^9, 3.806839110733186*^9, 
   3.806839660216255*^9, {3.807374133917375*^9, 3.807374148284563*^9}, 
   3.8074533666857443`*^9, {3.8074535201481733`*^9, 3.807453556808704*^9}, 
   3.8074562098871536`*^9, 3.8074571011820965`*^9, 3.8074593078810987`*^9, 
   3.8074593613587313`*^9, 3.8074594104589586`*^9, 3.807459643222172*^9, 
   3.8075281619908595`*^9, {3.807531459035243*^9, 3.8075314651299863`*^9}, {
   3.8075316836951776`*^9, 3.807531713606776*^9}, 3.807531779188323*^9, 
   3.8075319796817446`*^9, 3.8075320806442103`*^9, 3.807532148711596*^9, 
   3.8075321822157383`*^9, 3.807532968012939*^9, 3.8075332592408895`*^9, 
   3.8078857252924747`*^9, 3.807887057591963*^9, 3.8078872966640544`*^9, 
   3.807887505354844*^9, 3.807887612550062*^9, 3.807887785273885*^9, 
   3.807888675608638*^9, 3.8100492174637847`*^9, 3.812473125534316*^9, 
   3.8124731968827505`*^9, 3.8128184418141403`*^9, 3.8128186943186483`*^9, 
   3.812818744490694*^9, 3.812966989917389*^9, 3.812967845693839*^9, 
   3.8129679745218544`*^9, 3.8129682053711643`*^9, 3.81296869614845*^9, 
   3.8129689396776304`*^9, 3.8129767316142645`*^9, 3.812976879893673*^9, 
   3.815479720659051*^9, 3.8157758736203175`*^9, 3.815775950154084*^9, 
   3.817018087633877*^9, 3.8188014624767437`*^9, 3.825258169315151*^9, 
   3.8254093561425*^9},
 CellLabel->
  "Out[206]=",ExpressionUUID->"20b6ca24-e4a9-402d-a2f4-ed039c4569f1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"padu1", " ", "=", " ", 
   RowBox[{"padu", "/.", "%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549276482487`*^9}, {3.8050202419725313`*^9, 3.8050202419725313`*^9}, {
  3.8067662959372215`*^9, 3.8067662959372215`*^9}},
 CellLabel->
  "In[207]:=",ExpressionUUID->"946f9cfe-6f47-48dd-8266-de1998056519"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psdu1", " ", "=", " ", 
   RowBox[{"psdu", "/.", "%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549276482487`*^9}, {3.804854975285405*^9, 3.804855007481864*^9}, {
  3.805020287872097*^9, 3.805020287872097*^9}, {3.805021309212026*^9, 
  3.805021316136299*^9}, {3.8067902206374283`*^9, 3.806790221028118*^9}, {
  3.807374216118375*^9, 3.807374243863976*^9}},
 CellLabel->
  "In[208]:=",ExpressionUUID->"ed362b77-6bc1-4448-880e-83a403e1ad8b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pttu1", " ", "=", " ", 
   RowBox[{"pttu", "/.", "%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8073742655968957`*^9, 3.8073742741505566`*^9}, 
   3.807887009173047*^9},
 CellLabel->
  "In[209]:=",ExpressionUUID->"b901077e-ba84-4d1a-bd1b-dfa323d53551"],

Cell[BoxData[
 RowBox[{
  RowBox[{"prtu1", " ", "=", " ", 
   RowBox[{"prtu", "/.", "%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8073742778454313`*^9, 3.8073742845686646`*^9}, 
   3.807887010595169*^9},
 CellLabel->
  "In[210]:=",ExpressionUUID->"5f198fb4-af13-477e-b3e2-2b1ca023ac14"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pttp1", "=", 
   RowBox[{"pttp", "/.", "  ", "%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8073742991229973`*^9, 3.8073743276351943`*^9}, {
  3.8078870151584597`*^9, 3.807887015345992*^9}},
 CellLabel->
  "In[211]:=",ExpressionUUID->"a37949b0-46b4-43d3-acca-4c540695d556"],

Cell[BoxData[
 RowBox[{
  RowBox[{"prtp1", "=", 
   RowBox[{"prtp", "/.", "  ", "%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.807374317683447*^9, 3.80737432981089*^9}, {
  3.8078870170494127`*^9, 3.8078870172213173`*^9}},
 CellLabel->
  "In[212]:=",ExpressionUUID->"4ec415df-f1f6-4235-8f57-f0f55d60a4bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"padp1", "=", 
   RowBox[{"padp", "/.", "  ", "%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8075319423378887`*^9, 3.8075319540299883`*^9}, {
  3.807887018893482*^9, 3.8078870198636103`*^9}},
 CellLabel->
  "In[213]:=",ExpressionUUID->"d1d550e2-8667-4173-a166-eaba82db75e2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psdp1", "=", 
   RowBox[{"psdp", "/.", "  ", "%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8075319574216948`*^9, 3.8075319634323587`*^9}, {
  3.8078870212388487`*^9, 3.8078870244581566`*^9}},
 CellLabel->
  "In[214]:=",ExpressionUUID->"2b2d3001-1e71-440e-8768-e05a22c12b60"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padu1", 
       RowBox[{"1", "-", "sigmac"}]], "+", 
      RowBox[{"btu", " ", 
       SuperscriptBox["pttu1", 
        RowBox[{"1", "-", "sigmac"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmac"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048537407717743`*^9, 3.804853751697942*^9}, {
   3.804954429923254*^9, 3.804954429938881*^9}, {3.8050196031952763`*^9, 
   3.8050196146346335`*^9}, {3.8050202419412766`*^9, 3.805020254318351*^9}, {
   3.806764855673539*^9, 3.806764855689166*^9}, {3.8067662760490103`*^9, 
   3.806766277137709*^9}, {3.8067889104228306`*^9, 3.8067889156268196`*^9}, {
   3.8073733877004075`*^9, 3.807373413787715*^9}, {3.8074554234571695`*^9, 
   3.807455429875166*^9}, 3.8078870288657737`*^9},
 CellLabel->
  "In[215]:=",ExpressionUUID->"a5af71ce-981b-4c9c-8433-55c32cdbb79f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pnu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdu1", 
       RowBox[{"1", "-", "sigman"}]], "+", 
      RowBox[{"bru", " ", 
       SuperscriptBox["prtu1", 
        RowBox[{"1", "-", "sigman"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigman"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.804853754104593*^9, 
   3.8048537632655916`*^9}, {3.8049544890767255`*^9, 
   3.8049544890767255`*^9}, {3.805019635911148*^9, 3.8050196452420464`*^9}, {
   3.805020269508397*^9, 3.805020277728525*^9}, {3.8067649135109673`*^9, 
   3.8067649135109673`*^9}, {3.806788883376049*^9, 3.806788883454187*^9}, {
   3.80678891895547*^9, 3.8067889336454124`*^9}, {3.8073709493188176`*^9, 
   3.807370949320819*^9}, {3.8073734046205783`*^9, 3.8073734205609875`*^9}, {
   3.8074554329375505`*^9, 3.807455440184189*^9}},
 CellLabel->
  "In[216]:=",ExpressionUUID->"68197689-5d5c-453f-8c51-3ecc77e002db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pu1", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pcu1", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bsu", " ", 
       SuperscriptBox["Pnu1", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048536729130955`*^9, 
   3.804853693916567*^9}, 3.805019614650261*^9, 3.8050196452420464`*^9, 
   3.8050196847698293`*^9, {3.805019802540661*^9, 3.805019812682934*^9}, {
   3.8050203129401875`*^9, 3.805020330818774*^9}, {3.8050205921461425`*^9, 
   3.8050205922399073`*^9}, {3.805640322587119*^9, 3.8056403333666506`*^9}, 
   3.806766277340867*^9, {3.806789028285674*^9, 3.806789054157593*^9}, {
   3.8073734299072657`*^9, 3.8073734396308327`*^9}, {3.80745544209468*^9, 
   3.807455446407034*^9}},
 CellLabel->
  "In[217]:=",ExpressionUUID->"f74d1433-2bc8-4050-85e7-d19d899a3992"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcp1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padp1", 
       RowBox[{"1", "-", "sigmac"}]], "+", 
      RowBox[{"btp", " ", 
       SuperscriptBox["pttp1", 
        RowBox[{"1", "-", "sigmac"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmac"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048537407717743`*^9, 3.804853751697942*^9}, {
   3.804954429923254*^9, 3.804954429938881*^9}, {3.8050196031952763`*^9, 
   3.8050196146346335`*^9}, {3.8050202419412766`*^9, 3.805020254318351*^9}, {
   3.806764855673539*^9, 3.806764855689166*^9}, {3.8067662760490103`*^9, 
   3.806766277137709*^9}, {3.8067889104228306`*^9, 3.8067889156268196`*^9}, {
   3.8073733877004075`*^9, 3.807373413787715*^9}, {3.807373616096217*^9, 
   3.8073736180947685`*^9}, {3.8074556677042933`*^9, 3.8074556726371355`*^9}, 
   3.8078870324132633`*^9},
 CellLabel->
  "In[218]:=",ExpressionUUID->"ca7652b4-172e-444c-86c9-c661db0d93a1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pnp1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdp1", 
       RowBox[{"1", "-", "sigman"}]], "+", 
      RowBox[{"brp", " ", 
       SuperscriptBox["prtp1", 
        RowBox[{"1", "-", "sigman"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigman"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.804853754104593*^9, 
   3.8048537632655916`*^9}, {3.8049544890767255`*^9, 
   3.8049544890767255`*^9}, {3.805019635911148*^9, 3.8050196452420464`*^9}, {
   3.805020269508397*^9, 3.805020277728525*^9}, {3.8067649135109673`*^9, 
   3.8067649135109673`*^9}, {3.806788883376049*^9, 3.806788883454187*^9}, {
   3.80678891895547*^9, 3.8067889336454124`*^9}, {3.8073709493188176`*^9, 
   3.807370949320819*^9}, {3.8073734046205783`*^9, 3.8073734205609875`*^9}, {
   3.807373618686228*^9, 3.8073736200342813`*^9}, {3.8074556747147493`*^9, 
   3.8074556779242477`*^9}},
 CellLabel->
  "In[219]:=",ExpressionUUID->"b1575cbc-f7c2-4573-84ee-68dc0f42b469"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pp1", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pcp1", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bsp", " ", 
       SuperscriptBox["Pnp1", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048536729130955`*^9, 
   3.804853693916567*^9}, 3.805019614650261*^9, 3.8050196452420464`*^9, 
   3.8050196847698293`*^9, {3.805019802540661*^9, 3.805019812682934*^9}, {
   3.8050203129401875`*^9, 3.805020330818774*^9}, {3.8050205921461425`*^9, 
   3.8050205922399073`*^9}, {3.805640322587119*^9, 3.8056403333666506`*^9}, 
   3.806766277340867*^9, {3.806789028285674*^9, 3.806789054157593*^9}, {
   3.8073734299072657`*^9, 3.8073734396308327`*^9}, {3.807373620704802*^9, 
   3.8073736238352385`*^9}, {3.8074556817942595`*^9, 3.807455685948492*^9}},
 CellLabel->
  "In[220]:=",ExpressionUUID->"c8f46bfd-2bad-4bc4-979a-89dd6b762369"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qadu1", "=", 
   RowBox[{"qadcap", "-", 
    RowBox[{"aadu", " ", 
     SuperscriptBox["padu1", 
      RowBox[{"-", "eadu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
   3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
   3.804858318066416*^9}, {3.8048583709925175`*^9, 3.8048583807603416`*^9}, 
   3.80501724212201*^9, 3.805018338258299*^9, 3.8050189849580746`*^9, 
   3.805020269539652*^9, {3.805021595591544*^9, 3.805021596091627*^9}, {
   3.8067906511053405`*^9, 3.806790661966323*^9}, 3.8073713156820245`*^9, 
   3.8073723285762434`*^9, 3.807372655520752*^9, {3.8074554588727393`*^9, 
   3.8074554691707544`*^9}},
 CellLabel->
  "In[221]:=",ExpressionUUID->"064cbe9c-6fec-482e-bdd6-f14a7ba69e58"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qsdu1", "=", 
   RowBox[{"qsdcap", "-", 
    RowBox[{"asdu", " ", 
     SuperscriptBox["psdu1", 
      RowBox[{"-", "esdu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
   3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
   3.804858318066416*^9}, {3.8048583709925175`*^9, 3.8048583807603416`*^9}, 
   3.80501724212201*^9, 3.805018338258299*^9, 3.8050189849580746`*^9, 
   3.805020269539652*^9, {3.805021595591544*^9, 3.805021596091627*^9}, {
   3.8067906511053405`*^9, 3.806790661966323*^9}, 3.8073713156820245`*^9, 
   3.8073723285762434`*^9, 3.807372655520752*^9, {3.8074554588727393`*^9, 
   3.80745549469163*^9}},
 CellLabel->
  "In[222]:=",ExpressionUUID->"15a4da0a-d2ac-4b14-b5d8-64edcdd860c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qttu1", " ", "=", " ", 
   RowBox[{"qtlu0", "+", 
    RowBox[{"replt", " ", "qtiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, {3.804858383088846*^9, 3.804858391482087*^9}, 
   3.805017589247558*^9, 3.8050176939254065`*^9, {3.8050216031396575`*^9, 
   3.8050216036397414`*^9}, {3.8056381411939945`*^9, 3.80563814135027*^9}, {
   3.8067906645475845`*^9, 3.80679067256215*^9}, 3.8074554728826427`*^9, {
   3.807455503218255*^9, 3.8074555330614843`*^9}},
 CellLabel->
  "In[223]:=",ExpressionUUID->"e0bd41da-0520-483d-85ad-448b663088ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qrtu1", " ", "=", " ", 
   RowBox[{"qrlu0", "+", 
    RowBox[{"replr", " ", "qriu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, {3.804858383088846*^9, 3.804858391482087*^9}, 
   3.805017589247558*^9, 3.8050176939254065`*^9, {3.8050216031396575`*^9, 
   3.8050216036397414`*^9}, {3.8056381411939945`*^9, 3.80563814135027*^9}, {
   3.8067906645475845`*^9, 3.80679067256215*^9}, 3.8074554728826427`*^9, {
   3.807455503218255*^9, 3.8074555462627606`*^9}},
 CellLabel->
  "In[224]:=",ExpressionUUID->"a1d0f908-d542-43ae-ac90-db795839efa6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qttp1", " ", "=", " ", 
   RowBox[{"qtlp0", "+", 
    RowBox[{"replt", " ", "qtip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, {3.804858383088846*^9, 3.804858391482087*^9}, 
   3.805017589247558*^9, 3.8050176939254065`*^9, {3.8050216031396575`*^9, 
   3.8050216036397414`*^9}, {3.8056381411939945`*^9, 3.80563814135027*^9}, {
   3.8067906645475845`*^9, 3.80679067256215*^9}, 3.8074554728826427`*^9, {
   3.807455503218255*^9, 3.8074555330614843`*^9}, {3.807455592349639*^9, 
   3.8074555963667607`*^9}},
 CellLabel->
  "In[225]:=",ExpressionUUID->"2d739507-8746-442c-8849-97a16bdaccb9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qrtp1", " ", "=", " ", 
   RowBox[{"qrlp0", "+", 
    RowBox[{"replr", " ", "qrip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, {3.804858383088846*^9, 3.804858391482087*^9}, 
   3.805017589247558*^9, 3.8050176939254065`*^9, {3.8050216031396575`*^9, 
   3.8050216036397414`*^9}, {3.8056381411939945`*^9, 3.80563814135027*^9}, {
   3.8067906645475845`*^9, 3.80679067256215*^9}, 3.8074554728826427`*^9, {
   3.807455503218255*^9, 3.8074555462627606`*^9}, {3.8074555967510595`*^9, 
   3.807455598788648*^9}},
 CellLabel->
  "In[226]:=",ExpressionUUID->"209a49c6-79ed-470d-a067-a9b809e10e02"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qadp1", " ", "=", " ", 
   RowBox[{"qadpe0", "+", 
    RowBox[{"kp", " ", 
     SuperscriptBox["Pp1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pcp1", 
      RowBox[{"sigmac", "-", "betap"}]], " ", 
     SuperscriptBox["padp1", 
      RowBox[{"-", "sigmac"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
   3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
   3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
   3.804858331686155*^9, 3.8048583574115205`*^9}, {3.8048583936074276`*^9, 
   3.804858404171567*^9}, {3.804860786055422*^9, 3.8048607864617367`*^9}, {
   3.804954510247425*^9, 3.804954510247425*^9}, 3.805018413272153*^9, 
   3.8050199843542175`*^9, 3.8050201228437223`*^9, 3.8050206231378593`*^9, {
   3.805021615341569*^9, 3.805021615904162*^9}, {3.806790686580677*^9, 
   3.8067907039102373`*^9}, 3.8067907891791697`*^9, {3.8073709592495475`*^9, 
   3.8073709592505484`*^9}, 3.80737248425443*^9, {3.8074555662413125`*^9, 
   3.807455568666201*^9}, {3.8074556216204214`*^9, 3.8074556313229733`*^9}},
 CellLabel->
  "In[227]:=",ExpressionUUID->"fb0677fa-4abb-470e-89b4-ff6f82e5318f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qsdp1", " ", "=", " ", 
   RowBox[{"qsdpe0", "+", 
    RowBox[{"bsp", " ", "kp", " ", 
     SuperscriptBox["Pp1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pnp1", 
      RowBox[{"sigman", "-", "betap"}]], " ", 
     SuperscriptBox["psdp1", 
      RowBox[{"-", "sigman"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
   3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
   3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
   3.804858331686155*^9, 3.8048583574115205`*^9}, {3.8048583936074276`*^9, 
   3.804858404171567*^9}, {3.804860786055422*^9, 3.8048607864617367`*^9}, {
   3.804954510247425*^9, 3.804954510247425*^9}, 3.805018413272153*^9, 
   3.8050199843542175`*^9, 3.8050201228437223`*^9, 3.8050206231378593`*^9, {
   3.805021615341569*^9, 3.805021615904162*^9}, {3.806790686580677*^9, 
   3.8067907039102373`*^9}, 3.8067907891791697`*^9, {3.8073709592495475`*^9, 
   3.8073709592505484`*^9}, 3.80737248425443*^9, {3.807455574348626*^9, 
   3.8074555744557095`*^9}, {3.8074556446753674`*^9, 3.8074556555238094`*^9}},
 CellLabel->
  "In[228]:=",ExpressionUUID->"8c57543b-fa44-4e29-b9c4-d01229df6542"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5. Results",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.7954529786642447`*^9}, {
  3.79545386036082*^9, 3.7954538618860044`*^9}, {3.795525436722562*^9, 
  3.795525448873003*^9}, {3.7998486591642857`*^9, 3.799848659976923*^9}, {
  3.8199004535482035`*^9, 
  3.8199004539735346`*^9}},ExpressionUUID->"d0a2db11-827c-4736-8aa7-\
be8538e4d366"],

Cell[TextData[StyleBox["American Lobster",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, {3.8050217474964285`*^9, 3.805021750496922*^9}, 
   3.805638178490944*^9, 3.8067662960309863`*^9, {3.8067664137719393`*^9, 
   3.806766414193885*^9}, {3.8067909737498302`*^9, 3.8067909803446736`*^9}, {
   3.80745569996941*^9, 3.8074557020570326`*^9}, 
   3.8252579777837453`*^9},ExpressionUUID->"fa466ce1-cea8-4a8d-9b00-\
4b42818ede2f"],

Cell["Percent change in price of unprocessed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}},ExpressionUUID->"37b6f62e-ab42-474a-883b-\
a789278bd2e7"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"padu1", "-", "padu0"}], ")"}], "100"}], "padu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
   3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
   3.8048585992018385`*^9}, {3.8050178536701374`*^9, 3.8050178536701374`*^9}, 
   3.805020241988159*^9, {3.8067662960466137`*^9, 3.8067662960466137`*^9}},
 CellLabel->
  "In[229]:=",ExpressionUUID->"7851d6b9-66dd-4b24-bb64-9b1361450660"],

Cell[BoxData["0.222752710840743`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.804858843696556*^9, 3.8048588867233257`*^9, 
   3.804859663324854*^9, 3.804859749619121*^9, 3.804859963843249*^9, 
   3.804860110717795*^9, 3.804860380033531*^9, 3.8048605369574723`*^9, 
   3.8048606690003757`*^9, 3.8048614895786*^9, 3.8048659499980345`*^9, 
   3.8048662735904975`*^9, 3.8048664443215075`*^9, 3.804867250694828*^9, 
   3.8048811911602716`*^9, 3.8048952696276765`*^9, 3.804896148764747*^9, 
   3.8048969463462353`*^9, 3.8050220289442277`*^9, 3.8050234384041944`*^9, 
   3.8050236804166565`*^9, 3.8050238465394917`*^9, 3.805025220561788*^9, 
   3.805638098243934*^9, 3.8056381939463477`*^9, 3.805638615088058*^9, 
   3.8056408746683674`*^9, 3.8056410602569456`*^9, 3.8056658255455894`*^9, 
   3.806790909288615*^9, 3.8067913679743266`*^9, 3.8068326316818457`*^9, 
   3.8068333557363205`*^9, 3.806834056979002*^9, 3.8068343644586463`*^9, 
   3.8068345698014917`*^9, 3.806834757551732*^9, 3.80683513453703*^9, 
   3.8068354387174635`*^9, 3.8068355645046577`*^9, 3.8068364523193407`*^9, 
   3.806836501039502*^9, 3.8068368123342066`*^9, 3.806839111398734*^9, 
   3.8068396609788523`*^9, 3.807453367179121*^9, 3.807455777603838*^9, 
   3.8074558094798417`*^9, 3.8074560964488583`*^9, 3.8074562102184124`*^9, 
   3.8074571015003653`*^9, 3.807459308196344*^9, 3.807459361676979*^9, 
   3.8074594107682104`*^9, 3.8074596435224047`*^9, 3.8075281622819567`*^9, 
   3.807531482223119*^9, 3.807531979975973*^9, 3.8075320809557343`*^9, 
   3.807532149008519*^9, 3.8075321825392513`*^9, 3.8075329682942495`*^9, 
   3.8075332595534296`*^9, 3.807885725605023*^9, 3.807887057873262*^9, 
   3.8078872968672132`*^9, 3.8078875056205134`*^9, 3.8078876128157315`*^9, 
   3.8078877855239244`*^9, 3.807888675843048*^9, 3.8100492177269893`*^9, 
   3.812473125832548*^9, 3.81247319716296*^9, 3.8128184420943575`*^9, 
   3.8128186945988655`*^9, 3.812818744788926*^9, 3.8129669901986847`*^9, 
   3.8129678460063896`*^9, 3.8129679748656597`*^9, 3.81296820565246*^9, 
   3.81296869652351*^9, 3.8129689399589424`*^9, 3.81297673200494*^9, 
   3.812976880268698*^9, 3.815479720940347*^9, 3.8157758738955326`*^9, 
   3.8157759505524273`*^9, 3.8170180878397636`*^9, 3.818801462686908*^9, 
   3.8252581697895784`*^9, 3.825409356459749*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[229]=",ExpressionUUID->"64b9ea1e-cc81-4f5a-b58e-935209ce71ef"]
}, Open  ]],

Cell["Percent change in quantity of landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.8067662960622416`*^9, {3.806766418665018*^9, 3.8067664189775686`*^9}, 
   3.8067665464737573`*^9},ExpressionUUID->"ff34ab77-1d9f-4ec0-ba1d-\
cae076d2ebb1"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qadu1", "-", "qadu0"}], ")"}], "100"}], "qadu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.805017322701576*^9, 3.805017322701576*^9}, {3.8050217635649242`*^9, 
  3.8050217672842827`*^9}, {3.8067662960622416`*^9, 3.8067662960622416`*^9}},
 CellLabel->
  "In[230]:=",ExpressionUUID->"12284875-4e6e-4aaf-8a4e-b74c3485c4eb"],

Cell[BoxData["1.1112961666491064`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBmKLA0I5qnFvHD0FvKpA9D3RzS9BtE1R1181IB111oJF
HUh/OBHNBaI3TS1VB9FBrd5zPIC0wsQCay8gPe1mUyWIdlBVbAPRJiqL+0B0
dsiVSSC6+RXPVxB9eWuJpDeQrojZZvwdSD8otLsFooMc5H6A6JDbpkI/gPSU
WXPkQbTsEWNTEB1eVbsERJ+xt5whnvzG0ddmr8r29DeOlyRW6ILoJVtdD8Zn
vHHUkLn2AES3Oco8B9GHo094rgDS9VsObwHRC43vHwHRwg+3PwTRlxzE5FcC
6SXrG21B9DONFu61QDpOklcORBeLK5oW575xvPnH/gJz3htHhh9Xb4LotqTf
MUkFbxyVyq6pnSx+4+jfYXNdsuGNY+DJiSuTgTQAMcGqcw==
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[230]=",ExpressionUUID->"48085d6e-e1f2-45aa-ad21-a676e26c621a"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}, {3.8074558417250867`*^9, 
  3.807455841901224*^9}},ExpressionUUID->"5c1d1f1d-b9e6-447b-940b-\
9952b3a28d24"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"padp1", "-", "padp0"}], ")"}], "100"}], "padp0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
   3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
   3.8048585992018385`*^9}, {3.8050178536701374`*^9, 3.8050178536701374`*^9}, 
   3.805020241988159*^9, {3.8067662960466137`*^9, 3.8067662960466137`*^9}, {
   3.807455859509428*^9, 3.807455864264127*^9}},
 CellLabel->
  "In[231]:=",ExpressionUUID->"af4d1872-6df6-4d03-857d-85798ae33095"],

Cell[BoxData["0.24296270051109298`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.804858843696556*^9, 3.8048588867233257`*^9, 
   3.804859663324854*^9, 3.804859749619121*^9, 3.804859963843249*^9, 
   3.804860110717795*^9, 3.804860380033531*^9, 3.8048605369574723`*^9, 
   3.8048606690003757`*^9, 3.8048614895786*^9, 3.8048659499980345`*^9, 
   3.8048662735904975`*^9, 3.8048664443215075`*^9, 3.804867250694828*^9, 
   3.8048811911602716`*^9, 3.8048952696276765`*^9, 3.804896148764747*^9, 
   3.8048969463462353`*^9, 3.8050220289442277`*^9, 3.8050234384041944`*^9, 
   3.8050236804166565`*^9, 3.8050238465394917`*^9, 3.805025220561788*^9, 
   3.805638098243934*^9, 3.8056381939463477`*^9, 3.805638615088058*^9, 
   3.8056408746683674`*^9, 3.8056410602569456`*^9, 3.8056658255455894`*^9, 
   3.806790909288615*^9, 3.8067913679743266`*^9, 3.8068326316818457`*^9, 
   3.8068333557363205`*^9, 3.806834056979002*^9, 3.8068343644586463`*^9, 
   3.8068345698014917`*^9, 3.806834757551732*^9, 3.80683513453703*^9, 
   3.8068354387174635`*^9, 3.8068355645046577`*^9, 3.8068364523193407`*^9, 
   3.806836501039502*^9, 3.8068368123342066`*^9, 3.806839111398734*^9, 
   3.8068396609788523`*^9, 3.807453367179121*^9, 3.807455777603838*^9, 
   3.8074558094798417`*^9, 3.8074560966890445`*^9, 3.8074562104055586`*^9, 
   3.8074571017215166`*^9, 3.807459308446538*^9, 3.807459361856119*^9, 
   3.80745941096537*^9, 3.807459643771599*^9, 3.8075281624350767`*^9, 
   3.8075314847679205`*^9, 3.8075319801771293`*^9, 3.8075320811220684`*^9, 
   3.807532149188239*^9, 3.8075321827233734`*^9, 3.8075329684973917`*^9, 
   3.807533259740961*^9, 3.807885725776925*^9, 3.8078870580295396`*^9, 
   3.807887297007862*^9, 3.807887505761162*^9, 3.807887612987635*^9, 
   3.8078877856958275`*^9, 3.807888675999321*^9, 3.8100492178460817`*^9, 
   3.8124731259906707`*^9, 3.8124731973431344`*^9, 3.8128184422554827`*^9, 
   3.812818694780007*^9, 3.8128187449740906`*^9, 3.8129669903393326`*^9, 
   3.812967846209548*^9, 3.812967975100073*^9, 3.8129682058556175`*^9, 
   3.8129686968517056`*^9, 3.8129689401620836`*^9, 3.8129767322549562`*^9, 
   3.812976880550003*^9, 3.815479721112251*^9, 3.815775874084687*^9, 
   3.8157759508045893`*^9, 3.817018087870788*^9, 3.818801462715931*^9, 
   3.82525816999171*^9, 3.8254093566699142`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[231]=",ExpressionUUID->"318f4e52-6e3d-4cee-bc42-bae70c799ea4"]
}, Open  ]],

Cell["Percent change in quantity of processed production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.8067662960622416`*^9, {3.806766418665018*^9, 3.8067664189775686`*^9}, 
   3.8067665464737573`*^9, {3.807455846371724*^9, 
   3.807455848508397*^9}},ExpressionUUID->"41620eb5-5b08-466c-86cd-\
f380df276f9c"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qadp1", "-", "qadp0"}], ")"}], "100"}], "qadp0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.805017322701576*^9, 3.805017322701576*^9}, {3.8050217635649242`*^9, 
  3.8050217672842827`*^9}, {3.8067662960622416`*^9, 3.8067662960622416`*^9}, {
  3.807455852428909*^9, 3.807455856673219*^9}},
 CellLabel->
  "In[232]:=",ExpressionUUID->"3ff77757-42ce-47c8-bc80-54388deb25b9"],

Cell[BoxData["1.2207309496716454`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.804858843837203*^9, 3.8048588868952274`*^9, 
   3.8048596634655075`*^9, 3.804859749775401*^9, 3.804859963983899*^9, 
   3.804860110889693*^9, 3.804860380189807*^9, 3.8048605370981197`*^9, 
   3.804860669156651*^9, 3.804861489672364*^9, 3.8048659501230545`*^9, 
   3.804866273731145*^9, 3.8048664444309*^9, 3.804867250819849*^9, 
   3.8048811912696643`*^9, 3.804895269705816*^9, 3.80489614887414*^9, 
   3.8048969464556475`*^9, 3.80502202911613*^9, 3.8050234413118887`*^9, 
   3.8050236807292056`*^9, 3.805023846727021*^9, 3.805025220749321*^9, 
   3.8056380984098864`*^9, 3.805638194118269*^9, 3.80563861527559*^9, 
   3.8056408748705235`*^9, 3.8056410606995664`*^9, 3.8056658257487497`*^9, 
   3.806790909523029*^9, 3.806791368193113*^9, 3.8068326318224936`*^9, 
   3.8068333559235096`*^9, 3.806834057166534*^9, 3.8068343646305504`*^9, 
   3.8068345699902678`*^9, 3.806834757660817*^9, 3.806835134708934*^9, 
   3.8068354388581123`*^9, 3.806835564692189*^9, 3.806836452506871*^9, 
   3.806836501242617*^9, 3.8068368125217047`*^9, 3.806839111601902*^9, 
   3.80683966119302*^9, 3.8074533673042192`*^9, 3.8074557777839794`*^9, 
   3.8074558096089425`*^9, 3.807456096787121*^9, 3.807456210500633*^9, 
   3.8074571018166065`*^9, 3.807459308545615*^9, 3.8074593619672065`*^9, 
   3.807459411078452*^9, 3.8074596438666725`*^9, 3.807528162511136*^9, 
   3.807531486080634*^9, 3.807531980261227*^9, 3.807532081221491*^9, 
   3.80753214929132*^9, 3.8075321828264537`*^9, 3.8075329685755296`*^9, 
   3.807533259850354*^9, 3.8078857258550615`*^9, 3.8078870581076775`*^9, 
   3.8078872970703726`*^9, 3.8078875058392997`*^9, 3.8078876130657735`*^9, 
   3.807887785773965*^9, 3.8078886760774574`*^9, 3.810049217916169*^9, 
   3.81247312606673*^9, 3.8124731974241805`*^9, 3.8128184423305416`*^9, 
   3.8128186948650723`*^9, 3.812818745066141*^9, 3.812966990433098*^9, 
   3.8129678463147326`*^9, 3.8129679752095156`*^9, 3.8129682059650106`*^9, 
   3.8129686969923477`*^9, 3.8129689402714767`*^9, 3.812976732395621*^9, 
   3.812976880690643*^9, 3.8154797212372723`*^9, 3.8157758741467285`*^9, 
   3.8157759509246836`*^9, 3.8170180878857994`*^9, 3.8188014627309427`*^9, 
   3.825258170085762*^9, 3.8254093568090324`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[232]=",ExpressionUUID->"e00ead32-9981-4c53-9349-26da3fa3524b"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.805638279440954*^9}, 3.8067664996269903`*^9, {3.825258029251766*^9, 
   3.8252580330367093`*^9}},ExpressionUUID->"66e3d8bf-0da9-4845-95b9-\
8b8bf770b527"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "sigmac"}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"padu1", " ", 
      RowBox[{"(", 
       RowBox[{"qadu1", "-", "qadue0"}], ")"}]}], " ", "-", " ", 
     RowBox[{"padu0", " ", 
      RowBox[{"(", 
       RowBox[{"qadu0", "-", "qadue0"}], ")"}]}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
   3.805638515113145*^9, 3.8056385175665255`*^9}, {3.805641232235357*^9, 
   3.8056412347513914`*^9}, 3.806764855876698*^9, {3.806766296124751*^9, 
   3.806766296124751*^9}, {3.8067909260569143`*^9, 3.806790963434382*^9}, 
   3.8067913896045895`*^9, {3.8074558005797224`*^9, 3.8074558008429966`*^9}, 
   3.8252580257010045`*^9},
 CellLabel->
  "In[233]:=",ExpressionUUID->"f293df65-97a3-435d-a196-54d89d1d73ff"],

Cell[BoxData["2.3973676573159485`*^6"], "Output",
 CellChangeTimes->CompressedData["
1:eJwdylsog3EcxvGJ5BBJYUPEXiOHIo2Ypb8mQxS7EDkULS42h0hIywVyTg4l
hxxyQV71kpILZXlTmjRJw95kuxH9ycSMiN9vF0+fi+8TU99SrvUQiURKmPj2
wnpfTUmERvz3DvITC5Uf4NgV2UFFw5wFHU6rcaDqZJOPE+Q4RyZ65XTWoD87
u3q0LYsV3J0/tqOmqA3fT9CV95XgAss0rB6drXoOZWop0Q0oVHHgM5OhRoc0
kTo0W6zpQWXM4aO7T878ysDLBeIVD3aMa/3QlRNDPOo8KF9Ug96xL4oicE05
2o2ybOIgGli3NYHar4Upt08hH2hOhkFSDPLCYfonKH/Lv0XnjxgXumLNCXaB
dH49GtWpFHJ09bt/HVUt586FNVAS+c4z+42UmBO5FJSVlhjrmiiRVtzdo6VB
cQ9okGAu3ABHHGd7aNfeE48abEYbOmWURm/ijxtVovaESf9t8FUSHoXawpLk
7XpKrNMFZs9mSlK/bTdowPFPdX0rJZ3nFtlpOyW9F/kWSR8lzcLSZgP4D5Tg
Av0=
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[233]=",ExpressionUUID->"3fbffe77-c8aa-45cf-a239-a0dde0fdedac"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.8056382995792217`*^9}, 3.8067665212880273`*^9, {3.806791328885791*^9, 
   3.8067913448405657`*^9}, {3.8252580354195623`*^9, 
   3.825258038702114*^9}},ExpressionUUID->"51e65939-3a6f-4da8-8ee4-\
abe8097d7ac7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "sigmac"}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"padp1", " ", 
      RowBox[{"(", 
       RowBox[{"qadp1", "-", "qadpe0"}], ")"}]}], " ", "-", " ", 
     RowBox[{"padp0", " ", 
      RowBox[{"(", 
       RowBox[{"qadp0", "-", "qadpe0"}], ")"}]}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
   3.805638311659393*^9, 3.805638322630473*^9}, {3.805638433988842*^9, 
   3.8056384793310328`*^9}, {3.805638585596484*^9, 3.8056385956233883`*^9}, {
   3.805641132394824*^9, 3.805641135817252*^9}, {3.806791330555209*^9, 
   3.8067913326024265`*^9}, {3.807455798175852*^9, 3.8074558224750147`*^9}, {
   3.812818426264041*^9, 3.812818454353901*^9}, 3.825258022645629*^9},
 CellLabel->
  "In[234]:=",ExpressionUUID->"85750734-0499-4097-b6f7-113e9003885d"],

Cell[BoxData["793139.6982754071`"], "Output",
 CellChangeTimes->{
  3.8056382863724117`*^9, 3.805638323678563*^9, {3.805638445362606*^9, 
   3.8056384571096716`*^9}, 3.8056386259021473`*^9, 3.805640891530364*^9, 
   3.805641076054661*^9, 3.8056411369424357`*^9, 3.8056658377454967`*^9, 
   3.806791376779174*^9, 3.806832641808526*^9, 3.8068333657176375`*^9, 
   3.806834066886694*^9, 3.806834374371389*^9, 3.8068347665856695`*^9, 
   3.806835144258343*^9, 3.806835448380022*^9, 3.8068355746794853`*^9, 
   3.806836462453657*^9, 3.8068365117599883`*^9, 3.8068368218795953`*^9, 
   3.8068391208524585`*^9, 3.8068396707785215`*^9, 3.8074533741005077`*^9, 
   3.807455778337411*^9, {3.807455809775072*^9, 3.8074558242444005`*^9}, 
   3.807456096982272*^9, 3.80745621068978*^9, 3.8074571020037355`*^9, 
   3.8074593087387657`*^9, 3.8074593621493483`*^9, 3.807459411269622*^9, 
   3.80745964405682*^9, 3.8075281626602774`*^9, 3.807531488815442*^9, 
   3.807531980452343*^9, 3.807532081417821*^9, 3.807532149449119*^9, 
   3.80753218299524*^9, 3.807532968778687*^9, 3.8075332600378857`*^9, 
   3.807885726026963*^9, 3.8078870582483263`*^9, 3.8078872972110214`*^9, 
   3.807887505979948*^9, 3.8078876132220497`*^9, 3.8078877859302397`*^9, 
   3.8078886762438583`*^9, 3.8100492180602474`*^9, 3.8124731262268543`*^9, 
   3.812473197587289*^9, {3.8128184424916677`*^9, 3.8128184552535996`*^9}, 
   3.8128186950342035`*^9, 3.8128187452493343`*^9, 3.812966990667511*^9, 
   3.8129678465221543`*^9, 3.8129679754438787`*^9, 3.812968206152541*^9, 
   3.8129686972580323`*^9, 3.8129689404590073`*^9, 3.8129767326300206`*^9, 
   3.812976880940716*^9, 3.8154797214404306`*^9, 3.8157758744129367`*^9, 
   3.81577595129698*^9, 3.8170180879288864`*^9, 3.8188014627719746`*^9, 
   3.8252581702789035`*^9, 3.825409357038227*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[234]=",ExpressionUUID->"28087d7c-1057-444a-876c-8e7ffa276492"]
}, Open  ]],

Cell[TextData[StyleBox["Spiny Lobster",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, {3.804858674828244*^9, 3.8048586759846716`*^9}, {
   3.805021921987334*^9, 3.8050219236606793`*^9}, {3.805021990843542*^9, 
   3.805021993390811*^9}, {3.8067912830814295`*^9, 3.8067912848213053`*^9}, {
   3.8074557573230515`*^9, 3.8074557624030085`*^9}, 
   3.8252579827245865`*^9},ExpressionUUID->"cfdf10cf-34a8-40d8-b0b1-\
39725aa5bbd3"],

Cell["Percent change in price of unprocessed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}},ExpressionUUID->"87808b10-38b2-412a-a34f-\
6e65d6b3752c"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"psdu1", "-", "psdu0"}], ")"}], "100"}], "psdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
   3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
   3.8048585992018385`*^9}, {3.8048587486137724`*^9, 3.804858750004611*^9}, {
   3.805017872704455*^9, 3.805017872704455*^9}, 3.805020287887725*^9, {
   3.8050220006263056`*^9, 3.8050220011576376`*^9}, {3.8067912937864294`*^9, 
   3.8067912942095757`*^9}},
 CellLabel->
  "In[235]:=",ExpressionUUID->"56d3ee65-2e64-4653-9ce7-3699a45d9e92"],

Cell[BoxData["5.467440147939569`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.804858847139168*^9, 3.804858890192608*^9, 
   3.804859666825571*^9, 3.8048597532291985`*^9, 3.8048599673748865`*^9, 
   3.804860114402596*^9, 3.8048603837216387`*^9, 3.8048605407393417`*^9, 
   3.8048606726728387`*^9, 3.804861492313425*^9, 3.8048659526859646`*^9, 
   3.8048662764034476`*^9, 3.8048664469938164`*^9, 3.8048672534297056`*^9, 
   3.8048811936294165`*^9, 3.804895272018732*^9, 3.8048961514683075`*^9, 
   3.8048969490185413`*^9, 3.805022035836521*^9, 3.8050235258023567`*^9, 
   3.805023689652461*^9, 3.805023853170941*^9, 3.8050252280334463`*^9, 
   3.805638104340911*^9, 3.805638200620223*^9, 3.8056386242595654`*^9, 
   3.8056408884620004`*^9, 3.805641074038709*^9, 3.80566583586731*^9, 
   3.8067913754039445`*^9, 3.8068326401519995`*^9, 3.8068333641592455`*^9, 
   3.806834065323949*^9, 3.806834372830785*^9, 3.8068347650197945`*^9, 
   3.806835142695588*^9, 3.8068354468306274`*^9, 3.8068355730385857`*^9, 
   3.806836460834708*^9, 3.806836510009695*^9, 3.8068368202699614`*^9, 
   3.8068391199303493`*^9, 3.8068396698377714`*^9, 3.807453373406965*^9, 
   3.8074557779400997`*^9, 3.80745609708235*^9, 3.807456210784854*^9, 
   3.8074571020978084`*^9, 3.807459308835842*^9, 3.807459362247426*^9, 
   3.807459411364727*^9, 3.807459644152895*^9, 3.8075281627693377`*^9, 
   3.8075319805344067`*^9, 3.8075320815155287`*^9, 3.807532149542885*^9, 
   3.8075321830733776`*^9, 3.807532968856825*^9, 3.807533260116024*^9, 
   3.8078857261051006`*^9, 3.8078870583420935`*^9, 3.807887297273531*^9, 
   3.8078875060424757`*^9, 3.8078876133001876`*^9, 3.8078877860083776`*^9, 
   3.8078886763219175`*^9, 3.810049218129301*^9, 3.8124731263079185`*^9, 
   3.8124731976723557`*^9, 3.812818442568728*^9, 3.812818695123273*^9, 
   3.8128187453454027`*^9, 3.8129669907612762`*^9, 3.8129678466276045`*^9, 
   3.812967975553316*^9, 3.812968206246306*^9, 3.8129686974299192`*^9, 
   3.8129689405527716`*^9, 3.812976732770691*^9, 3.812976881050082*^9, 
   3.8154797215498457`*^9, 3.8157758744970026`*^9, 3.815775951408082*^9, 
   3.8170180879435616`*^9, 3.818801462785985*^9, 3.825258170383026*^9, 
   3.8254093571543145`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[235]=",ExpressionUUID->"1f1454f7-70d1-4279-95af-998ae60d82a2"]
}, Open  ]],

Cell["Percent change in quantity of landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.8067662962810264`*^9, 3.806766445987071*^9, 
   3.80676654652064*^9},ExpressionUUID->"340dbded-46cb-42bc-b420-\
65dd828b0c5b"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qsdu1", "-", "qsdu0"}], ")"}], "100"}], "qsdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.804858792627643*^9, 3.804858798896052*^9}, {3.8050173592553644`*^9, 
  3.8050173592553644`*^9}, {3.8050219270518637`*^9, 3.8050219271612563`*^9}, {
  3.8050220013295393`*^9, 3.805022001657715*^9}, {3.8067912973038373`*^9, 
  3.8067912980539627`*^9}},
 CellLabel->
  "In[236]:=",ExpressionUUID->"97a2aaff-8b6f-4bc3-b744-39d4f05435f7"],

Cell[BoxData["17.70653460908589`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.8048588472798543`*^9, 3.8048588903332553`*^9, 
   3.8048596669662247`*^9, 3.8048597533854685`*^9, 3.8048599675155373`*^9, 
   3.8048601145432453`*^9, 3.8048603838622866`*^9, 3.8048605408956027`*^9, 
   3.804860672829114*^9, 3.804861492438445*^9, 3.8048659527953568`*^9, 
   3.8048662765128403`*^9, 3.8048664471032095`*^9, 3.804867253539048*^9, 
   3.804881193738809*^9, 3.804895272128127*^9, 3.8048961515777006`*^9, 
   3.8048969491279335`*^9, 3.8050220360396776`*^9, 3.805023529474801*^9, 
   3.805023689902499*^9, 3.805023853342844*^9, 3.805025228267862*^9, 
   3.8056381044928074`*^9, 3.8056382007608705`*^9, 3.805638624431469*^9, 
   3.8056408887682347`*^9, 3.805641074241867*^9, 3.8056658361017256`*^9, 
   3.806791375528965*^9, 3.8068326403864136`*^9, 3.8068333643155212`*^9, 
   3.8068340654958363`*^9, 3.8068343730183163`*^9, 3.8068347651879053`*^9, 
   3.806835142851904*^9, 3.8068354470494146`*^9, 3.806835573226117*^9, 
   3.806836461006612*^9, 3.8068365102441096`*^9, 3.806836820457492*^9, 
   3.8068391201022453`*^9, 3.8068396700679517`*^9, 3.807453373537066*^9, 
   3.807455778024165*^9, 3.8074560971844287`*^9, 3.8074562108789263`*^9, 
   3.807457102192921*^9, 3.8074593089359207`*^9, 3.807459362344502*^9, 
   3.807459411460742*^9, 3.807459644248969*^9, 3.807528162841395*^9, 
   3.8075319806337442`*^9, 3.8075320816055984`*^9, 3.8075321496210227`*^9, 
   3.8075321831737947`*^9, 3.80753296895059*^9, 3.8075332602097898`*^9, 
   3.8078857261832376`*^9, 3.807887058420232*^9, 3.8078872973516693`*^9, 
   3.807887506120597*^9, 3.8078876133939533`*^9, 3.8078877860865154`*^9, 
   3.807888676399977*^9, 3.8100492182033587`*^9, 3.8124731263849773`*^9, 
   3.8124731977554197`*^9, 3.8128184426698074`*^9, 3.8128186952103405`*^9, 
   3.812818745434427*^9, 3.812966990870669*^9, 3.8129678467339573`*^9, 
   3.8129679756782923`*^9, 3.812968206340071*^9, 3.8129686975549536`*^9, 
   3.8129689406465373`*^9, 3.8129767328956904`*^9, 3.8129768811907177`*^9, 
   3.815479721643589*^9, 3.8157758745810685`*^9, 3.815775951523163*^9, 
   3.8170180879595337`*^9, 3.818801462800997*^9, 3.8252581704831085`*^9, 
   3.825409357268384*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[236]=",ExpressionUUID->"22cd31f1-198d-42c2-b3eb-54dedb3f08ea"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 
  3.80485427153401*^9}},ExpressionUUID->"65d42bae-b5c3-4483-b02f-\
77a2a2d19e21"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"psdp1", "-", "psdp0"}], ")"}], "100"}], "psdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
   3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
   3.8048586124851284`*^9}, {3.804858750567197*^9, 3.8048587511610384`*^9}, {
   3.805018163895453*^9, 3.8050181639110804`*^9}, 3.805020631092285*^9, {
   3.805022001845244*^9, 3.805022002157792*^9}, {3.8067913023515496`*^9, 
   3.8067913028985157`*^9}},
 CellLabel->
  "In[237]:=",ExpressionUUID->"ec89fe8d-c64b-4802-9fa0-5fda4fec5080"],

Cell[BoxData["0.33899791714412186`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.804858847436088*^9, 3.8048588904739017`*^9, 
   3.8048596671068783`*^9, 3.804859753526121*^9, 3.804859967671815*^9, 
   3.804860114699522*^9, 3.80486038403419*^9, 3.8048605410518775`*^9, 
   3.8048606730010166`*^9, 3.8048614925478373`*^9, 3.80486595290475*^9, 
   3.804866276622233*^9, 3.8048664472126026`*^9, 3.8048672536484404`*^9, 
   3.8048811938325744`*^9, 3.8048952722375216`*^9, 3.804896151687093*^9, 
   3.8048969492373266`*^9, 3.8050220362115784`*^9, 3.8050235331784983`*^9, 
   3.805023690074402*^9, 3.805023853499117*^9, 3.8050252284397664`*^9, 
   3.80563810466471*^9, 3.805638200932774*^9, 3.80563862465195*^9, 
   3.805640889080476*^9, 3.805641074507535*^9, 3.805665836312825*^9, 
   3.8067913757008705`*^9, 3.806832640573945*^9, 3.806833364487425*^9, 
   3.8068340656521125`*^9, 3.806834373190221*^9, 3.806834765383057*^9, 
   3.806835143023766*^9, 3.8068354472235785`*^9, 3.8068355733980207`*^9, 
   3.8068364611785154`*^9, 3.806836510431641*^9, 3.8068368206293945`*^9, 
   3.806839120284373*^9, 3.8068396702430887`*^9, 3.807453373672172*^9, 
   3.80745577810623*^9, 3.807456097283506*^9, 3.807456210973*^9, 
   3.807457102286955*^9, 3.807459309032997*^9, 3.8074593624435797`*^9, 
   3.8074594115528145`*^9, 3.8074596443450704`*^9, 3.8075281629184546`*^9, 
   3.8075319807058144`*^9, 3.8075320816883698`*^9, 3.8075321497147884`*^9, 
   3.807532183251931*^9, 3.8075329690287275`*^9, 3.807533260319183*^9, 
   3.8078857262613745`*^9, 3.8078870584827423`*^9, 3.80788729741418*^9, 
   3.8078875061831074`*^9, 3.8078876134720917`*^9, 3.807887786164653*^9, 
   3.8078886764662695`*^9, 3.810049218277416*^9, 3.812473126457033*^9, 
   3.8124731978434877`*^9, 3.812818442748869*^9, 3.812818695307416*^9, 
   3.8128187455195055`*^9, 3.812966990980062*^9, 3.8129678468319497`*^9, 
   3.812967975772057*^9, 3.8129682064338365`*^9, 3.8129686977112412`*^9, 
   3.81296894075593*^9, 3.812976733020691*^9, 3.812976881331359*^9, 
   3.8154797217373543`*^9, 3.8157758746671352`*^9, 3.8157759516562567`*^9, 
   3.8170180879755464`*^9, 3.8188014628160086`*^9, 3.8252581705841427`*^9, 
   3.825409357388489*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[237]=",ExpressionUUID->"b173e90c-f10f-44ad-8621-c439f92cfe86"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
   3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
   3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
   3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
   3.804854255481004*^9, 3.8048542778511686`*^9}, 3.806766296296654*^9, 
   3.8067664460027585`*^9},ExpressionUUID->"9d2d41d9-d662-4692-b0f9-\
275af69086a3"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qsdp1", "-", "qsdp0"}], ")"}], "100"}], "qsdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}, {
  3.8048587995680304`*^9, 3.8048588001931267`*^9}, {3.8050174161743164`*^9, 
  3.8050174161743164`*^9}, {3.805021931896407*^9, 3.805021932052683*^9}, {
  3.8050220023296947`*^9, 3.805022002689125*^9}, {3.806791306624547*^9, 
  3.8067913073277874`*^9}},
 CellLabel->
  "In[238]:=",ExpressionUUID->"c68f8a88-0d37-4eca-8a0f-53c6953ed701"],

Cell[BoxData["1.7065205680819477`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.8048588475923624`*^9, 3.8048588906145487`*^9, 
   3.8048596672475457`*^9, 3.8048597536824007`*^9, 3.8048599678124647`*^9, 
   3.8048601148557987`*^9, 3.8048603841904664`*^9, 3.804860541192525*^9, 
   3.804860673141664*^9, 3.80486149265723*^9, 3.804865953014142*^9, 
   3.8048662767316256`*^9, 3.8048664473219957`*^9, 3.804867253757833*^9, 
   3.8048811939419665`*^9, 3.804895272346916*^9, 3.8048961517964897`*^9, 
   3.804896949346719*^9, 3.8050220363991084`*^9, 3.8050235340536337`*^9, 
   3.805023690246303*^9, 3.805023853639764*^9, 3.8050252286272993`*^9, 
   3.805638104820986*^9, 3.805638201089049*^9, 3.8056386248238406`*^9, 
   3.805640889450761*^9, 3.805641074710693*^9, 3.8056658365069833`*^9, 
   3.8067913758415174`*^9, 3.806832640730221*^9, 3.8068333646593285`*^9, 
   3.8068340658240166`*^9, 3.8068343733308687`*^9, 3.806834765550187*^9, 
   3.806835143195668*^9, 3.806835447395483*^9, 3.8068355735699244`*^9, 
   3.806836461350419*^9, 3.8068365106816826`*^9, 3.806836820801302*^9, 
   3.8068391204607935`*^9, 3.806839670420227*^9, 3.8074533738052764`*^9, 
   3.807455778187293*^9, 3.8074560973825827`*^9, 3.80745621108909*^9, 
   3.807457102380028*^9, 3.807459309129072*^9, 3.8074593625396547`*^9, 
   3.807459411647888*^9, 3.807459644445122*^9, 3.807528162995515*^9, 
   3.8075319807788653`*^9, 3.807532081784051*^9, 3.807532149792927*^9, 
   3.8075321833613243`*^9, 3.8075329691224923`*^9, 3.807533260397352*^9, 
   3.807885726339511*^9, 3.8078870585765095`*^9, 3.807887297492318*^9, 
   3.8078875062612457`*^9, 3.807887613550229*^9, 3.807887786258418*^9, 
   3.807888676560033*^9, 3.8100492183504725`*^9, 3.812473126534093*^9, 
   3.812473197949582*^9, 3.812818442825929*^9, 3.8128186953904805`*^9, 
   3.8128187456165686`*^9, 3.8129669910738864`*^9, 3.8129678469334173`*^9, 
   3.812967975897077*^9, 3.8129682065276017`*^9, 3.8129686978846917`*^9, 
   3.8129689408497086`*^9, 3.812976733163761*^9, 3.812976881458441*^9, 
   3.81547972183112*^9, 3.815775874751201*^9, 3.815775951773347*^9, 
   3.8170180879905577`*^9, 3.818801462831021*^9, 3.82525817072427*^9, 
   3.8254093575085726`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[238]=",ExpressionUUID->"c9e95019-e91a-4807-86f6-edd1f5907852"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.805638279440954*^9}, 3.806766499658245*^9, {3.8252580451711473`*^9, 
   3.825258048608818*^9}},ExpressionUUID->"3a1d09b7-e021-4be5-9440-\
183f46789866"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "sigman"}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"psdu1", " ", 
      RowBox[{"(", 
       RowBox[{"qsdu1", "-", "qsdue0"}], ")"}]}], " ", "-", " ", 
     RowBox[{"psdu0", " ", 
      RowBox[{"(", 
       RowBox[{"qsdu0", "-", "qsdue0"}], ")"}]}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
   3.8056384216076107`*^9, 3.8056384298283195`*^9}, {3.805638482271556*^9, 
   3.805638484475052*^9}, {3.8056385728292103`*^9, 3.805638582553885*^9}, {
   3.805641139929985*^9, 3.8056411496359625`*^9}, {3.806791326776063*^9, 
   3.806791349982044*^9}, {3.8068350380292435`*^9, 3.80683506059543*^9}, 
   3.8074558832779293`*^9, {3.8157759295129867`*^9, 3.8157759329856906`*^9}, 
   3.825258014473274*^9},
 CellLabel->
  "In[239]:=",ExpressionUUID->"f13aef5f-971b-4fd5-973c-dd47a644d343"],

Cell[BoxData["891906.6987485467`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwA2KdmLfm66PeOE5r3+i6G0hveyd460HMG0eb+yYMX4H0
hrKNUSB60/2wTSDa5NGxGyB6xt6znN+AtM6Es3ogWvwIkyWI/ryCPR5EG9hd
yAPRUi0n7oLoOYGfH4PonKXbuL4D6boYEa0fQJpN73IeiDaK3CeuEvfGMXGa
h4sqkM7qfREEojWq9HNAdOWd1CoQvUj5/EsQPctm+V81IP00PIRFHUir7Svn
AtFVgRPVQfS7pKQ5HkCa8casSi8gzcBo0waiT8Tv6QPRuXveTQLRE7LVvoLo
39v6Jb2BdELsWePvQPrep5BbIFr9oOEPEG19x0voB5CeJr1FHkRLH/UyBdE2
b6YsAdHHpvrOEE9+4xjXdllle/obx33SB3VBtBdf7MH4DKC79N8/ANGni82e
g+gPd556rgDSEssebgHRaXYMR0G0x6MrD0F0gb+D/EogfcVgni2ILrBdyb0W
SFsuMZID0Rsk7EyLc984+m2KusCc98bxe+qfmyA6T5UhNqngjaMP0221k8Vv
HIsKo65LNrxxXMW6ZWUykAYAKZj9/w==
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[239]=",ExpressionUUID->"6aa8b08c-9568-47f0-a51b-0c06c086e71f"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.8056382995792217`*^9}, 3.8067665212880273`*^9, {3.806791328885791*^9, 
   3.8067913448405657`*^9}, {3.825258050940631*^9, 
   3.8252580541010885`*^9}},ExpressionUUID->"94b7fb62-ff27-41b0-b6cf-\
9ff2d7401e61"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", "sigman"}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"psdp1", " ", 
      RowBox[{"(", 
       RowBox[{"qsdp1", "-", "qsdpe0"}], ")"}]}], " ", "-", " ", 
     RowBox[{"psdp0", " ", 
      RowBox[{"(", 
       RowBox[{"qsdp0", "-", "qsdpe0"}], ")"}]}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
   3.805638311659393*^9, 3.805638322630473*^9}, {3.805638433988842*^9, 
   3.8056384793310328`*^9}, {3.805638585596484*^9, 3.8056385956233883`*^9}, {
   3.805641132394824*^9, 3.805641135817252*^9}, {3.806791330555209*^9, 
   3.8067913326024265`*^9}, 3.8074558870488625`*^9, {3.8128184691694293`*^9, 
   3.8128184799087887`*^9}, 3.8252580118172092`*^9},
 CellLabel->
  "In[240]:=",ExpressionUUID->"c3180513-ab60-4ec9-8f7d-e65b660c3a99"],

Cell[BoxData["33019.88898090545`"], "Output",
 CellChangeTimes->{
  3.8056382863724117`*^9, 3.805638323678563*^9, {3.805638445362606*^9, 
   3.8056384571096716`*^9}, 3.8056386259021473`*^9, 3.805640891530364*^9, 
   3.805641076054661*^9, 3.8056411369424357`*^9, 3.8056658377454967`*^9, 
   3.806791376779174*^9, 3.806832641808526*^9, 3.8068333657176375`*^9, 
   3.806834066886694*^9, 3.806834374371389*^9, 3.8068347665856695`*^9, 
   3.806835144258343*^9, 3.806835448380022*^9, 3.8068355746794853`*^9, 
   3.806836462453657*^9, 3.8068365117599883`*^9, 3.8068368218795953`*^9, 
   3.8068391208524585`*^9, 3.8068396707785215`*^9, 3.8074533741005077`*^9, 
   3.807455778337411*^9, 3.8074558931005745`*^9, 3.8074560976257715`*^9, 
   3.807456211277236*^9, 3.8074571025651712`*^9, 3.8074593093952804`*^9, 
   3.8074593627308216`*^9, 3.807459411837043*^9, 3.8074596446873093`*^9, 
   3.8075281631506357`*^9, 3.8075319809169893`*^9, 3.807532081967193*^9, 
   3.8075321499648304`*^9, 3.80753218354957*^9, 3.8075329692943954`*^9, 
   3.8075332605692244`*^9, 3.807885726480158*^9, 3.8078870587327857`*^9, 
   3.807887297632967*^9, 3.8078875064175215`*^9, 3.8078876137065053`*^9, 
   3.807887786414693*^9, 3.807888676731933*^9, 3.810049218507595*^9, 
   3.812473126687212*^9, 3.8124731981167006`*^9, 3.8128184430010667`*^9, 
   3.812818480819498*^9, 3.8128186955596113`*^9, 3.8128187457857003`*^9, 
   3.8129669912769847`*^9, 3.812967847148864*^9, 3.81296797612613*^9, 
   3.8129682067463875`*^9, 3.812968698150395*^9, 3.8129689410372252`*^9, 
   3.8129767334293995`*^9, 3.8129768817038736`*^9, 3.815479722034279*^9, 
   3.815775875010403*^9, 3.8157759521356297`*^9, 3.8170180880336657`*^9, 
   3.818801462872052*^9, 3.8252581709234242`*^9, 3.825409357773819*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[240]=",ExpressionUUID->"f92124dc-1615-4f37-8fd7-9c6b7b784e58"]
}, Open  ]],

Cell[TextData[StyleBox["True Lobster Imports",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQB2IQfeDUR41u/zeOh9LEDEG0y38FbxB9ou2RL4jOviqR
AaLFtk8B03Imt5pBdAfL+RYQrVSSsw5EJ3x5vhlEP9459TuI/sbD9wtE65vJ
HFsEpHcmh58E0Zsi590G0ZL6s+6D6AkzMj6D6Ern019B9LMY2T8gmuu1+1+w
/Hth9sVAWq/5NJjedv2NkUXEG0cpW1cTEJ025ctPvcg3jjkiX8E055Nnf0E0
f8pzML0qYTm/IZCWfXQSTP9qiFID0XlN9WDadob9nQYg7alSCqZ9/t16AqLb
GnWegmih2UnnHsQA/ekxC0wXhK1yVI1741j01McJRDNNWB8Cok2uBoaC6A+8
U2JBtP/16wkgOq/I8LRkwxvHPpEgMA0AeO64+A==
  "],ExpressionUUID->"0507f61c-2455-4a07-82fc-57ee92df6550"],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
   3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
   3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
   3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
   3.8048542642949595`*^9}, {3.8074559167830076`*^9, 3.807455917914886*^9}, 
   3.8074559890352488`*^9},ExpressionUUID->"37bcdd80-3d78-4036-ac8b-\
572ef657ff1f"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pttu1", "-", "pttu0"}], ")"}], "100"}], "pttu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
   3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
   3.8048586228946285`*^9}, {3.804858751489214*^9, 3.8048587520986824`*^9}, {
   3.805018113403982*^9, 3.8050181134196095`*^9}, 3.80502029645166*^9, {
   3.805022002845399*^9, 3.8050220032048297`*^9}, {3.806791310305574*^9, 
   3.8067913110556993`*^9}, {3.807455920715067*^9, 3.8074559246201086`*^9}, {
   3.8074560128347716`*^9, 3.807456013837553*^9}},
 CellLabel->
  "In[241]:=",ExpressionUUID->"f05c93cc-2e5d-49fa-8d02-82dcf99d9205"],

Cell[BoxData["2.5554395685865137`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.8048588477330093`*^9, 3.8048588907551947`*^9, 
   3.8048596674038343`*^9, 3.804859753823053*^9, 3.8048599679531155`*^9, 
   3.804860114996448*^9, 3.8048603843467426`*^9, 3.8048605413487997`*^9, 
   3.804860673297939*^9, 3.8048614927666225`*^9, 3.8048659531235347`*^9, 
   3.8048662768410177`*^9, 3.804866447431389*^9, 3.804867253867225*^9, 
   3.804881194051359*^9, 3.804895272440683*^9, 3.804896151905878*^9, 
   3.804896949456112*^9, 3.8050220365710096`*^9, 3.8050235376791954`*^9, 
   3.8050236904025784`*^9, 3.8050238537980585`*^9, 3.805025228799204*^9, 
   3.8056381049772606`*^9, 3.805638201323462*^9, 3.8056386249957447`*^9, 
   3.805640889845065*^9, 3.805641074913851*^9, 3.805665836704134*^9, 
   3.8067913759665384`*^9, 3.8068326409021254`*^9, 3.806833364831233*^9, 
   3.8068340659802923`*^9, 3.806834373487193*^9, 3.806834765696938*^9, 
   3.8068351433519435`*^9, 3.8068354475674105`*^9, 3.8068355738043437`*^9, 
   3.8068364615066953`*^9, 3.806836510853586*^9, 3.806836820988827*^9, 
   3.806839121025593*^9, 3.8068396709586487`*^9, 3.8074533742996635`*^9, 
   3.807455778405464*^9, 3.807455942717224*^9, 3.8074560981081743`*^9, 
   3.807456211743613*^9, 3.8074571030865765`*^9, 3.8074593098856616`*^9, 
   3.8074593632151794`*^9, 3.8074594123174086`*^9, 3.8074596451676903`*^9, 
   3.807528163549446*^9, 3.807531981351718*^9, 3.8075320824416285`*^9, 
   3.807532150386774*^9, 3.8075321840029216`*^9, 3.8075329697319784`*^9, 
   3.8075332610224257`*^9, 3.807885726886471*^9, 3.8078870588109245`*^9, 
   3.8078872976954765`*^9, 3.807887506480032*^9, 3.807887613784643*^9, 
   3.807887786508458*^9, 3.80788867681007*^9, 3.8100492185766487`*^9, 
   3.8124731267613173`*^9, 3.8124731981977634`*^9, 3.8128184430801287`*^9, 
   3.8128186956566873`*^9, 3.8128187458697653`*^9, 3.8129669913707495`*^9, 
   3.8129678472334695`*^9, 3.8129679762355227`*^9, 3.8129682068401527`*^9, 
   3.812968698290985*^9, 3.81296894114662*^9, 3.81297673355443*^9, 
   3.8129768818289*^9, 3.8154797221280446`*^9, 3.815775875094469*^9, 
   3.8157759522567387`*^9, 3.8170180880487776`*^9, 3.818801462886063*^9, 
   3.8252581710295057`*^9, 3.825409357897878*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[241]=",ExpressionUUID->"69cebaa9-7e02-41ff-81f6-2f2ee31ad876"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
   3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
   3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
   3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
   3.8048542553403563`*^9, 3.8048542677330275`*^9}, 3.806766296296654*^9, 
   3.8067664460183263`*^9, {3.8074559297400937`*^9, 3.8074559310801344`*^9}, 
   3.8074559915952396`*^9},ExpressionUUID->"681290b6-aebb-43bc-9019-\
980ae0c84e8f"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qttu1", "-", "qttu0"}], ")"}], "100"}], "qttu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.804858800630694*^9, 3.8048588012870445`*^9}, {3.8050174723410645`*^9, 
  3.8050174723410645`*^9}, {3.805021936100234*^9, 3.8050219362096276`*^9}, {
  3.8050220033611035`*^9, 3.8050220037373953`*^9}, {3.8067913141964664`*^9, 
  3.8067913149622197`*^9}, {3.8074559347349825`*^9, 3.8074559386610365`*^9}, {
  3.8074560182599936`*^9, 3.8074560192527704`*^9}},
 CellLabel->
  "In[242]:=",ExpressionUUID->"c7702cb2-a522-48c0-b2bb-4797d8cae5df"],

Cell[BoxData[
 RowBox[{"-", "2.696984603732375`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588478736553`*^9, 3.8048588909114695`*^9, 
   3.8048596675600967`*^9, 3.804859753963705*^9, 3.804859968109393*^9, 
   3.804860115168353*^9, 3.8048603844873915`*^9, 3.8048605415207024`*^9, 
   3.8048606734385867`*^9, 3.8048614928760147`*^9, 3.804865953232927*^9, 
   3.8048662769660378`*^9, 3.8048664475407825`*^9, 3.804867253961108*^9, 
   3.8048811941607513`*^9, 3.804895272550078*^9, 3.8048961520152717`*^9, 
   3.804896949565504*^9, 3.8050220367429113`*^9, 3.8050235381636443`*^9, 
   3.8050236905744786`*^9, 3.8050238539344997`*^9, 3.8050252289867373`*^9, 
   3.8056381051335363`*^9, 3.8056382014953647`*^9, 3.805638625183276*^9, 
   3.805640890159307*^9, 3.8056410751170087`*^9, 3.80566583690129*^9, 
   3.806791376107187*^9, 3.806832641089656*^9, 3.8068333649719067`*^9, 
   3.806834066183451*^9, 3.806834373659048*^9, 3.8068347658688407`*^9, 
   3.806835143570729*^9, 3.8068354477236624`*^9, 3.80683557399187*^9, 
   3.8068364616785994`*^9, 3.8068365110254908`*^9, 3.8068368211763573`*^9, 
   3.806839121186432*^9, 3.8068396711908307`*^9, 3.807453374434769*^9, 
   3.8074557784765196`*^9, 3.807455942862308*^9, 3.8074560982052217`*^9, 
   3.807456211834669*^9, 3.8074571031816797`*^9, 3.8074593099827375`*^9, 
   3.807459363312255*^9, 3.8074594124224896`*^9, 3.807459645260758*^9, 
   3.807528163635315*^9, 3.8075319814454827`*^9, 3.80753208251704*^9, 
   3.807532150480539*^9, 3.807532184088989*^9, 3.8075329698257303`*^9, 
   3.8075332611161914`*^9, 3.807885726965851*^9, 3.807887058889063*^9, 
   3.807887297773615*^9, 3.8078875065581703`*^9, 3.8078876138627815`*^9, 
   3.8078877865865955`*^9, 3.8078886768882065`*^9, 3.8100492186507063`*^9, 
   3.8124731268423324`*^9, 3.812473198280828*^9, 3.812818443162238*^9, 
   3.812818695743826*^9, 3.8128187459528294`*^9, 3.8129669914645147`*^9, 
   3.812967847342862*^9, 3.8129679763292885`*^9, 3.812968206949545*^9, 
   3.8129686984316325`*^9, 3.812968941240384*^9, 3.812976733679452*^9, 
   3.8129768819538865`*^9, 3.815479722237438*^9, 3.8157758751805363`*^9, 
   3.815775952367832*^9, 3.8170180880637994`*^9, 3.8188014629000745`*^9, 
   3.82525817113457*^9, 3.825409358012974*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[242]=",ExpressionUUID->"b2a17040-a38a-4e8b-9c92-5cda13a9e9e9"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
   3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
   3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
   3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
   3.8048542642949595`*^9}, {3.8074559167830076`*^9, 3.807455917914886*^9}, 
   3.8074559940661626`*^9, {3.8074561190214233`*^9, 
   3.807456119169538*^9}},ExpressionUUID->"6815a9ad-d720-4c61-b472-\
0f7b31fdd47b"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pttp1", "-", "pttp0"}], ")"}], "100"}], "pttp0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
   3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
   3.8048586228946285`*^9}, {3.804858751489214*^9, 3.8048587520986824`*^9}, {
   3.805018113403982*^9, 3.8050181134196095`*^9}, 3.80502029645166*^9, {
   3.805022002845399*^9, 3.8050220032048297`*^9}, {3.806791310305574*^9, 
   3.8067913110556993`*^9}, {3.807455920715067*^9, 3.8074559246201086`*^9}, {
   3.8074559607212067`*^9, 3.8074559630460186`*^9}, {3.807456023634179*^9, 
   3.8074560246189437`*^9}},
 CellLabel->
  "In[243]:=",ExpressionUUID->"9c9e149c-c050-4582-90c6-add757a1d276"],

Cell[BoxData["1.5836072369394405`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.8048588477330093`*^9, 3.8048588907551947`*^9, 
   3.8048596674038343`*^9, 3.804859753823053*^9, 3.8048599679531155`*^9, 
   3.804860114996448*^9, 3.8048603843467426`*^9, 3.8048605413487997`*^9, 
   3.804860673297939*^9, 3.8048614927666225`*^9, 3.8048659531235347`*^9, 
   3.8048662768410177`*^9, 3.804866447431389*^9, 3.804867253867225*^9, 
   3.804881194051359*^9, 3.804895272440683*^9, 3.804896151905878*^9, 
   3.804896949456112*^9, 3.8050220365710096`*^9, 3.8050235376791954`*^9, 
   3.8050236904025784`*^9, 3.8050238537980585`*^9, 3.805025228799204*^9, 
   3.8056381049772606`*^9, 3.805638201323462*^9, 3.8056386249957447`*^9, 
   3.805640889845065*^9, 3.805641074913851*^9, 3.805665836704134*^9, 
   3.8067913759665384`*^9, 3.8068326409021254`*^9, 3.806833364831233*^9, 
   3.8068340659802923`*^9, 3.806834373487193*^9, 3.806834765696938*^9, 
   3.8068351433519435`*^9, 3.8068354475674105`*^9, 3.8068355738043437`*^9, 
   3.8068364615066953`*^9, 3.806836510853586*^9, 3.806836820988827*^9, 
   3.806839121025593*^9, 3.8068396709586487`*^9, 3.8074533742996635`*^9, 
   3.807455778405464*^9, 3.807455942717224*^9, 3.8074560983052993`*^9, 
   3.807456211927741*^9, 3.807457103276724*^9, 3.8074593100848165`*^9, 
   3.8074593634053817`*^9, 3.807459412517564*^9, 3.807459645355832*^9, 
   3.8075281637163754`*^9, 3.8075319815079927`*^9, 3.8075320825900383`*^9, 
   3.8075321505600576`*^9, 3.8075321841780586`*^9, 3.807532969919504*^9, 
   3.8075332611943293`*^9, 3.807885727075242*^9, 3.8078870589672017`*^9, 
   3.807887297851753*^9, 3.8078875066363077`*^9, 3.80788761394092*^9, 
   3.807887786664733*^9, 3.807888676966343*^9, 3.810049218724763*^9, 
   3.812473126920413*^9, 3.812473198369897*^9, 3.8128184432412543`*^9, 
   3.812818695829822*^9, 3.8128187460358944`*^9, 3.812966991573908*^9, 
   3.8129678474366283`*^9, 3.8129679764543085`*^9, 3.81296820704331*^9, 
   3.812968698556694*^9, 3.8129689413497767`*^9, 3.8129767338044505`*^9, 
   3.8129768820955324`*^9, 3.8154797223468523`*^9, 3.815775875265603*^9, 
   3.8157759524829273`*^9, 3.8170180880797987`*^9, 3.8188014629150863`*^9, 
   3.8252581712396526`*^9, 3.8254093581250916`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[243]=",ExpressionUUID->"106e5119-5f9c-41be-911c-a2d3458d14a9"]
}, Open  ]],

Cell["Percent change in quantity of processed imports ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
   3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
   3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
   3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
   3.8048542553403563`*^9, 3.8048542677330275`*^9}, 3.806766296296654*^9, 
   3.8067664460183263`*^9, {3.8074559297400937`*^9, 3.8074559310801344`*^9}, 
   3.8074559971385546`*^9, {3.807456117209016*^9, 
   3.807456117386153*^9}},ExpressionUUID->"4364d0a3-d5a4-4220-9619-\
32172f1af36f"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qttp1", "-", "qttp0"}], ")"}], "100"}], "qttp0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.804858800630694*^9, 3.8048588012870445`*^9}, {3.8050174723410645`*^9, 
  3.8050174723410645`*^9}, {3.805021936100234*^9, 3.8050219362096276`*^9}, {
  3.8050220033611035`*^9, 3.8050220037373953`*^9}, {3.8067913141964664`*^9, 
  3.8067913149622197`*^9}, {3.8074559347349825`*^9, 3.807455968519277*^9}, {
  3.807456029473726*^9, 3.807456030605605*^9}},
 CellLabel->
  "In[244]:=",ExpressionUUID->"9dbc6ee4-f141-4896-a063-05a3a8523dba"],

Cell[BoxData[
 RowBox[{"-", "2.7014869054828714`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588478736553`*^9, 3.8048588909114695`*^9, 
   3.8048596675600967`*^9, 3.804859753963705*^9, 3.804859968109393*^9, 
   3.804860115168353*^9, 3.8048603844873915`*^9, 3.8048605415207024`*^9, 
   3.8048606734385867`*^9, 3.8048614928760147`*^9, 3.804865953232927*^9, 
   3.8048662769660378`*^9, 3.8048664475407825`*^9, 3.804867253961108*^9, 
   3.8048811941607513`*^9, 3.804895272550078*^9, 3.8048961520152717`*^9, 
   3.804896949565504*^9, 3.8050220367429113`*^9, 3.8050235381636443`*^9, 
   3.8050236905744786`*^9, 3.8050238539344997`*^9, 3.8050252289867373`*^9, 
   3.8056381051335363`*^9, 3.8056382014953647`*^9, 3.805638625183276*^9, 
   3.805640890159307*^9, 3.8056410751170087`*^9, 3.80566583690129*^9, 
   3.806791376107187*^9, 3.806832641089656*^9, 3.8068333649719067`*^9, 
   3.806834066183451*^9, 3.806834373659048*^9, 3.8068347658688407`*^9, 
   3.806835143570729*^9, 3.8068354477236624`*^9, 3.80683557399187*^9, 
   3.8068364616785994`*^9, 3.8068365110254908`*^9, 3.8068368211763573`*^9, 
   3.806839121186432*^9, 3.8068396711908307`*^9, 3.807453374434769*^9, 
   3.8074557784765196`*^9, 3.807455942862308*^9, 3.8074560984003735`*^9, 
   3.807456212020813*^9, 3.8074571033717976`*^9, 3.8074593101858997`*^9, 
   3.8074593635004187`*^9, 3.8074594126096354`*^9, 3.8074596454709225`*^9, 
   3.807528163814451*^9, 3.8075319816017585`*^9, 3.807532082668173*^9, 
   3.8075321506471252`*^9, 3.8075321842661276`*^9, 3.807532969997634*^9, 
   3.807533261288095*^9, 3.80788572715338*^9, 3.80788705904534*^9, 
   3.807887297929891*^9, 3.807887506714446*^9, 3.807887614019058*^9, 
   3.8078877867428703`*^9, 3.8078886770445023`*^9, 3.8100492188008223`*^9, 
   3.812473127002457*^9, 3.812473198454963*^9, 3.812818443322318*^9, 
   3.812818695914888*^9, 3.8128187461199613`*^9, 3.812966991667673*^9, 
   3.8129678475303936`*^9, 3.812967976579378*^9, 3.8129682071370754`*^9, 
   3.8129686987441893`*^9, 3.8129689414435415`*^9, 3.812976733929463*^9, 
   3.8129768822196293`*^9, 3.8154797224405966`*^9, 3.8157758753526707`*^9, 
   3.8157759525949883`*^9, 3.817018088093809*^9, 3.8188014629301453`*^9, 
   3.8252581713537984`*^9, 3.8254093582401752`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[244]=",ExpressionUUID->"bb7c0595-3e15-4982-b648-d606f84ff6b9"]
}, Open  ]],

Cell[TextData[StyleBox["Rock Lobster Imports",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, {3.804858674828244*^9, 3.8048586759846716`*^9}, {
   3.805021921987334*^9, 3.8050219236606793`*^9}, {3.805021990843542*^9, 
   3.805021993390811*^9}, {3.8067912830814295`*^9, 3.8067912848213053`*^9}, {
   3.8074557573230515`*^9, 3.8074557624030085`*^9}, {3.807455909486329*^9, 
   3.807455914557276*^9}, {3.8074559806267014`*^9, 3.807456006745033*^9}, {
   3.807456040704465*^9, 3.8074560410487328`*^9}, 
   3.8252579965553417`*^9},ExpressionUUID->"bb8a8855-1590-419f-a6a9-\
6e2de8a3b4b4"],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
   3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
   3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
   3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
   3.8048542642949595`*^9}, {3.8074559167830076`*^9, 3.807455917914886*^9}, 
   3.8074559890352488`*^9},ExpressionUUID->"9e2b3065-d9da-493b-afdf-\
4abf852c1892"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"prtu1", "-", "prtu0"}], ")"}], "100"}], "prtu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
   3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
   3.8048586228946285`*^9}, {3.804858751489214*^9, 3.8048587520986824`*^9}, {
   3.805018113403982*^9, 3.8050181134196095`*^9}, 3.80502029645166*^9, {
   3.805022002845399*^9, 3.8050220032048297`*^9}, {3.806791310305574*^9, 
   3.8067913110556993`*^9}, {3.807455920715067*^9, 3.8074559246201086`*^9}, {
   3.8074560128347716`*^9, 3.807456013837553*^9}, {3.807456050052743*^9, 
   3.8074560577507334`*^9}},
 CellLabel->
  "In[245]:=",ExpressionUUID->"5b478f90-972a-45b8-9aa6-9c67d932874c"],

Cell[BoxData["7.669348906011701`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.8048588477330093`*^9, 3.8048588907551947`*^9, 
   3.8048596674038343`*^9, 3.804859753823053*^9, 3.8048599679531155`*^9, 
   3.804860114996448*^9, 3.8048603843467426`*^9, 3.8048605413487997`*^9, 
   3.804860673297939*^9, 3.8048614927666225`*^9, 3.8048659531235347`*^9, 
   3.8048662768410177`*^9, 3.804866447431389*^9, 3.804867253867225*^9, 
   3.804881194051359*^9, 3.804895272440683*^9, 3.804896151905878*^9, 
   3.804896949456112*^9, 3.8050220365710096`*^9, 3.8050235376791954`*^9, 
   3.8050236904025784`*^9, 3.8050238537980585`*^9, 3.805025228799204*^9, 
   3.8056381049772606`*^9, 3.805638201323462*^9, 3.8056386249957447`*^9, 
   3.805640889845065*^9, 3.805641074913851*^9, 3.805665836704134*^9, 
   3.8067913759665384`*^9, 3.8068326409021254`*^9, 3.806833364831233*^9, 
   3.8068340659802923`*^9, 3.806834373487193*^9, 3.806834765696938*^9, 
   3.8068351433519435`*^9, 3.8068354475674105`*^9, 3.8068355738043437`*^9, 
   3.8068364615066953`*^9, 3.806836510853586*^9, 3.806836820988827*^9, 
   3.806839121025593*^9, 3.8068396709586487`*^9, 3.8074533742996635`*^9, 
   3.807455778405464*^9, 3.807455942717224*^9, 3.807456098496448*^9, 
   3.807456212159921*^9, 3.8074571034668713`*^9, 3.807459310290977*^9, 
   3.8074593635964756`*^9, 3.807459412691699*^9, 3.807459645565997*^9, 
   3.8075281638975153`*^9, 3.807531981679897*^9, 3.807532082761938*^9, 
   3.8075321507231874`*^9, 3.8075321843772144`*^9, 3.8075329700913997`*^9, 
   3.8075332613818607`*^9, 3.807885727231518*^9, 3.807887059123479*^9, 
   3.807887298008029*^9, 3.807887506776976*^9, 3.807887614097196*^9, 
   3.8078877868210087`*^9, 3.807888677122616*^9, 3.81004921887488*^9, 
   3.812473127086522*^9, 3.812473198539029*^9, 3.8128184434023805`*^9, 
   3.812818696003969*^9, 3.8128187462030244`*^9, 3.812966991792694*^9, 
   3.81296784762416*^9, 3.8129679766887217`*^9, 3.8129682072464685`*^9, 
   3.8129686989004607`*^9, 3.8129689415373173`*^9, 3.8129767340544834`*^9, 
   3.8129768823437295`*^9, 3.8154797225499897`*^9, 3.8157758754447765`*^9, 
   3.815775952712112*^9, 3.8170180881098223`*^9, 3.818801462944108*^9, 
   3.8252581714528356`*^9, 3.8254093583602395`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[245]=",ExpressionUUID->"b3e8d86c-bcc8-416c-8f18-127cbd35dd0e"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
   3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
   3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
   3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
   3.8048542553403563`*^9, 3.8048542677330275`*^9}, 3.806766296296654*^9, 
   3.8067664460183263`*^9, {3.8074559297400937`*^9, 3.8074559310801344`*^9}, 
   3.8074559915952396`*^9},ExpressionUUID->"1fe024e0-75ce-4e30-8292-\
aadf2be5d1ab"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qrtu1", "-", "qrtu0"}], ")"}], "100"}], "qrtu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.804858800630694*^9, 3.8048588012870445`*^9}, {3.8050174723410645`*^9, 
  3.8050174723410645`*^9}, {3.805021936100234*^9, 3.8050219362096276`*^9}, {
  3.8050220033611035`*^9, 3.8050220037373953`*^9}, {3.8067913141964664`*^9, 
  3.8067913149622197`*^9}, {3.8074559347349825`*^9, 3.8074559386610365`*^9}, {
  3.8074560182599936`*^9, 3.8074560192527704`*^9}, {3.807456063008827*^9, 
  3.8074560675283446`*^9}},
 CellLabel->
  "In[246]:=",ExpressionUUID->"891426fb-e626-4874-862c-c0a08823c846"],

Cell[BoxData[
 RowBox[{"-", "15.262301945611659`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588478736553`*^9, 3.8048588909114695`*^9, 
   3.8048596675600967`*^9, 3.804859753963705*^9, 3.804859968109393*^9, 
   3.804860115168353*^9, 3.8048603844873915`*^9, 3.8048605415207024`*^9, 
   3.8048606734385867`*^9, 3.8048614928760147`*^9, 3.804865953232927*^9, 
   3.8048662769660378`*^9, 3.8048664475407825`*^9, 3.804867253961108*^9, 
   3.8048811941607513`*^9, 3.804895272550078*^9, 3.8048961520152717`*^9, 
   3.804896949565504*^9, 3.8050220367429113`*^9, 3.8050235381636443`*^9, 
   3.8050236905744786`*^9, 3.8050238539344997`*^9, 3.8050252289867373`*^9, 
   3.8056381051335363`*^9, 3.8056382014953647`*^9, 3.805638625183276*^9, 
   3.805640890159307*^9, 3.8056410751170087`*^9, 3.80566583690129*^9, 
   3.806791376107187*^9, 3.806832641089656*^9, 3.8068333649719067`*^9, 
   3.806834066183451*^9, 3.806834373659048*^9, 3.8068347658688407`*^9, 
   3.806835143570729*^9, 3.8068354477236624`*^9, 3.80683557399187*^9, 
   3.8068364616785994`*^9, 3.8068365110254908`*^9, 3.8068368211763573`*^9, 
   3.806839121186432*^9, 3.8068396711908307`*^9, 3.807453374434769*^9, 
   3.8074557784765196`*^9, 3.807455942862308*^9, 3.807456098642561*^9, 
   3.807456212256997*^9, 3.8074571035609446`*^9, 3.807459310481124*^9, 
   3.8074593636925497`*^9, 3.807459412784771*^9, 3.8074596457121115`*^9, 
   3.8075281639815807`*^9, 3.8075319817892904`*^9, 3.8075320828401823`*^9, 
   3.8075321508064175`*^9, 3.807532184467284*^9, 3.8075329701691437`*^9, 
   3.807533261471633*^9, 3.807885727325281*^9, 3.8078870592016172`*^9, 
   3.8078872980705395`*^9, 3.807887506855095*^9, 3.807887614175334*^9, 
   3.8078877868991456`*^9, 3.8078886771851254`*^9, 3.8100492189529405`*^9, 
   3.812473127174591*^9, 3.812473198623094*^9, 3.8128184434864454`*^9, 
   3.812818696090024*^9, 3.8128187462870893`*^9, 3.8129669919020863`*^9, 
   3.8129678477335534`*^9, 3.812967976798136*^9, 3.812968207340234*^9, 
   3.812968699041129*^9, 3.8129689416310716`*^9, 3.8129767341951256`*^9, 
   3.8129768824718227`*^9, 3.815479722643755*^9, 3.815775875539817*^9, 
   3.815775952829195*^9, 3.8170180881248617`*^9, 3.81880146295912*^9, 
   3.825258171555908*^9, 3.825409358487339*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[246]=",ExpressionUUID->"2ff2af79-b691-4ac7-98d5-c30bde319239"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
   3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
   3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
   3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
   3.8048542642949595`*^9}, {3.8074559167830076`*^9, 3.807455917914886*^9}, 
   3.8074559940661626`*^9, {3.807456070340534*^9, 
   3.807456111251377*^9}},ExpressionUUID->"92ff9ffd-9485-48aa-b033-\
70151e92e8c9"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"prtp1", "-", "prtp0"}], ")"}], "100"}], "prtp0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
   3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
   3.8048586228946285`*^9}, {3.804858751489214*^9, 3.8048587520986824`*^9}, {
   3.805018113403982*^9, 3.8050181134196095`*^9}, 3.80502029645166*^9, {
   3.805022002845399*^9, 3.8050220032048297`*^9}, {3.806791310305574*^9, 
   3.8067913110556993`*^9}, {3.807455920715067*^9, 3.8074559246201086`*^9}, {
   3.8074559607212067`*^9, 3.8074559630460186`*^9}, {3.807456023634179*^9, 
   3.8074560246189437`*^9}, {3.8074560744697475`*^9, 3.8074560781716275`*^9}},
 CellLabel->
  "In[247]:=",ExpressionUUID->"4983c830-e754-401c-a38d-fedf7ffeb2ed"],

Cell[BoxData["0.9612363528782824`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.8048588477330093`*^9, 3.8048588907551947`*^9, 
   3.8048596674038343`*^9, 3.804859753823053*^9, 3.8048599679531155`*^9, 
   3.804860114996448*^9, 3.8048603843467426`*^9, 3.8048605413487997`*^9, 
   3.804860673297939*^9, 3.8048614927666225`*^9, 3.8048659531235347`*^9, 
   3.8048662768410177`*^9, 3.804866447431389*^9, 3.804867253867225*^9, 
   3.804881194051359*^9, 3.804895272440683*^9, 3.804896151905878*^9, 
   3.804896949456112*^9, 3.8050220365710096`*^9, 3.8050235376791954`*^9, 
   3.8050236904025784`*^9, 3.8050238537980585`*^9, 3.805025228799204*^9, 
   3.8056381049772606`*^9, 3.805638201323462*^9, 3.8056386249957447`*^9, 
   3.805640889845065*^9, 3.805641074913851*^9, 3.805665836704134*^9, 
   3.8067913759665384`*^9, 3.8068326409021254`*^9, 3.806833364831233*^9, 
   3.8068340659802923`*^9, 3.806834373487193*^9, 3.806834765696938*^9, 
   3.8068351433519435`*^9, 3.8068354475674105`*^9, 3.8068355738043437`*^9, 
   3.8068364615066953`*^9, 3.806836510853586*^9, 3.806836820988827*^9, 
   3.806839121025593*^9, 3.8068396709586487`*^9, 3.8074533742996635`*^9, 
   3.807455778405464*^9, 3.807455942717224*^9, 3.807456098740638*^9, 
   3.8074562123520703`*^9, 3.807457103653016*^9, 3.807459310582203*^9, 
   3.807459363788625*^9, 3.8074594128668346`*^9, 3.8074596458081865`*^9, 
   3.8075281640626435`*^9, 3.807531981868353*^9, 3.807532082927786*^9, 
   3.807532150884555*^9, 3.8075321845543528`*^9, 3.80753297026291*^9, 
   3.8075332615497704`*^9, 3.807885727403418*^9, 3.807887059281003*^9, 
   3.807887298148678*^9, 3.8078875069332323`*^9, 3.8078876142534723`*^9, 
   3.807887786977284*^9, 3.807888677263262*^9, 3.8100492190300007`*^9, 
   3.812473127257655*^9, 3.81247319870816*^9, 3.8128184435895257`*^9, 
   3.812818696174106*^9, 3.81281874637216*^9, 3.812966991995852*^9, 
   3.8129678478346443`*^9, 3.8129679769231343`*^9, 3.8129682074340057`*^9, 
   3.8129686991817627`*^9, 3.812968941740465*^9, 3.812976734320209*^9, 
   3.812976882596938*^9, 3.815479722753148*^9, 3.8157758756338906`*^9, 
   3.815775952950272*^9, 3.8170180881400137`*^9, 3.8188014629741325`*^9, 
   3.825258171659995*^9, 3.825409358609451*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[247]=",ExpressionUUID->"0e05d4e9-ec9e-4a48-8452-9ea53020a490"]
}, Open  ]],

Cell["Percent change in quantity of processed imports ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
   3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
   3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
   3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
   3.8048542553403563`*^9, 3.8048542677330275`*^9}, 3.806766296296654*^9, 
   3.8067664460183263`*^9, {3.8074559297400937`*^9, 3.8074559310801344`*^9}, 
   3.8074559971385546`*^9, {3.807456114362799*^9, 
   3.807456114510914*^9}},ExpressionUUID->"5bc51b94-ca5a-481e-bfb4-\
b6540c350dff"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qrtp1", "-", "qrtp0"}], ")"}], "100"}], "qrtp0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.804858800630694*^9, 3.8048588012870445`*^9}, {3.8050174723410645`*^9, 
  3.8050174723410645`*^9}, {3.805021936100234*^9, 3.8050219362096276`*^9}, {
  3.8050220033611035`*^9, 3.8050220037373953`*^9}, {3.8067913141964664`*^9, 
  3.8067913149622197`*^9}, {3.8074559347349825`*^9, 3.807455968519277*^9}, {
  3.807456029473726*^9, 3.807456030605605*^9}, {3.8074560835578227`*^9, 
  3.80745608865879*^9}},
 CellLabel->
  "In[248]:=",ExpressionUUID->"653ac09f-c710-4609-add1-9a293c68db02"],

Cell[BoxData[
 RowBox[{"-", "8.240593580485784`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588478736553`*^9, 3.8048588909114695`*^9, 
   3.8048596675600967`*^9, 3.804859753963705*^9, 3.804859968109393*^9, 
   3.804860115168353*^9, 3.8048603844873915`*^9, 3.8048605415207024`*^9, 
   3.8048606734385867`*^9, 3.8048614928760147`*^9, 3.804865953232927*^9, 
   3.8048662769660378`*^9, 3.8048664475407825`*^9, 3.804867253961108*^9, 
   3.8048811941607513`*^9, 3.804895272550078*^9, 3.8048961520152717`*^9, 
   3.804896949565504*^9, 3.8050220367429113`*^9, 3.8050235381636443`*^9, 
   3.8050236905744786`*^9, 3.8050238539344997`*^9, 3.8050252289867373`*^9, 
   3.8056381051335363`*^9, 3.8056382014953647`*^9, 3.805638625183276*^9, 
   3.805640890159307*^9, 3.8056410751170087`*^9, 3.80566583690129*^9, 
   3.806791376107187*^9, 3.806832641089656*^9, 3.8068333649719067`*^9, 
   3.806834066183451*^9, 3.806834373659048*^9, 3.8068347658688407`*^9, 
   3.806835143570729*^9, 3.8068354477236624`*^9, 3.80683557399187*^9, 
   3.8068364616785994`*^9, 3.8068365110254908`*^9, 3.8068368211763573`*^9, 
   3.806839121186432*^9, 3.8068396711908307`*^9, 3.807453374434769*^9, 
   3.8074557784765196`*^9, 3.807455942862308*^9, 3.8074560988377123`*^9, 
   3.8074562124441986`*^9, 3.80745710380013*^9, 3.807459310679278*^9, 
   3.807459363884699*^9, 3.807459412961909*^9, 3.8074596459042606`*^9, 
   3.80752816414771*^9, 3.807531981955421*^9, 3.807532083005847*^9, 
   3.807532150980695*^9, 3.8075321846394196`*^9, 3.8075329703566756`*^9, 
   3.8075332616435366`*^9, 3.807885727481556*^9, 3.807887059359142*^9, 
   3.8078872982268157`*^9, 3.8078875070113707`*^9, 3.8078876143316097`*^9, 
   3.807887787055421*^9, 3.8078886773414016`*^9, 3.8100492191100626`*^9, 
   3.8124731273377175`*^9, 3.8124731987952275`*^9, 3.8128184436735964`*^9, 
   3.8128186962551527`*^9, 3.812818746461225*^9, 3.812966992105244*^9, 
   3.8129678479439335`*^9, 3.8129679770325274`*^9, 3.8129682075277643`*^9, 
   3.8129686993224707`*^9, 3.8129689418342295`*^9, 3.812976734460785*^9, 
   3.812976882735057*^9, 3.815479722862542*^9, 3.815775875728965*^9, 
   3.8157759530633574`*^9, 3.8170180881550255`*^9, 3.8188014629881425`*^9, 
   3.825258171800113*^9, 3.8254093587295623`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[248]=",ExpressionUUID->"560cadf6-32f4-439c-85da-cb55d53d0e50"]
}, Open  ]],

Cell[TextData[StyleBox["Price Indexes",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
  3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
  3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
  3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
  3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
  3.8048584943088517`*^9}, {3.804858674828244*^9, 
  3.8048586889112*^9}},ExpressionUUID->"13815c13-7ce0-400f-bac6-d5bef354e17d"],

Cell["Percent change in unprocessed price index", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998489833914266`*^9, 3.79984901086983*^9}, {3.7998491773192368`*^9, 
   3.79984917888201*^9}, {3.7998492779954705`*^9, 3.799849344403957*^9}, {
   3.799855217193923*^9, 3.7998552176158657`*^9}, 3.804345400385578*^9, {
   3.8043488808930616`*^9, 3.8043489145962877`*^9}, {3.8048542237212534`*^9, 
   3.8048542237212534`*^9}, {3.8048542553091016`*^9, 
   3.8048542553091016`*^9}},ExpressionUUID->"8d6f960c-cea6-4ac7-9d42-\
3184797329a6"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Pu1", "-", "Pu0"}], ")"}], "100"}], "Pu0"]], "Input",
 CellChangeTimes->{{3.79984918480492*^9, 3.799849273791636*^9}, {
  3.7998552126150475`*^9, 3.7998552128807173`*^9}, {3.8017816587699327`*^9, 
  3.8017816805942984`*^9}, {3.804345394438952*^9, 3.8043453971470623`*^9}, {
  3.804348884814114*^9, 3.804348889233554*^9}},
 CellLabel->
  "In[249]:=",ExpressionUUID->"4be7ba51-cceb-4e00-9209-e3ee85fa7c30"],

Cell[BoxData["3.214350640726625`"], "Output",
 CellChangeTimes->{
  3.7998492746667833`*^9, 3.7998495923806477`*^9, 3.7998508747820983`*^9, 
   3.7998510932094183`*^9, 3.7998552215383844`*^9, 3.7998552591406136`*^9, 
   3.799856732964707*^9, 3.7998567782777624`*^9, 3.799857195292985*^9, {
   3.79985741126893*^9, 3.799857481157101*^9}, 3.7998575225746374`*^9, {
   3.799857623596133*^9, 3.799857665541498*^9}, 3.7998577599781284`*^9, {
   3.8016608497619348`*^9, 3.801660862874851*^9}, 3.801662764470834*^9, 
   3.8016634678095245`*^9, 3.8016642628400764`*^9, {3.801664312666783*^9, 
   3.8016643351216216`*^9}, 3.801664460338441*^9, {3.8016653833153267`*^9, 
   3.8016653970378222`*^9}, 3.8016654290440674`*^9, {3.801666723097561*^9, 
   3.8016667511780653`*^9}, 3.8016667864140167`*^9, {3.801666960325522*^9, 
   3.8016669841279755`*^9}, 3.801667113594228*^9, 3.8016672275438757`*^9, 
   3.8016673978818293`*^9, 3.8016675839057274`*^9, {3.8016678479599924`*^9, 
   3.8016678631653695`*^9}, 3.8016679342935286`*^9, {3.801668183552487*^9, 
   3.8016682040499134`*^9}, {3.801668269038266*^9, 3.8016682954359474`*^9}, {
   3.801668345072152*^9, 3.801668369796582*^9}, 3.801668420866907*^9, 
   3.8016684524994974`*^9, 3.801668487394171*^9, 3.801668541287839*^9, 
   3.801692587562277*^9, 3.80169264102909*^9, 3.8016927462307262`*^9, 
   3.8016929523093896`*^9, 3.8016932298288126`*^9, 3.801693287020975*^9, 
   3.8016933968966064`*^9, 3.801693489102943*^9, 3.801776983907366*^9, 
   3.8017772015105257`*^9, 3.801777273900032*^9, 3.8017776517080097`*^9, 
   3.8017780057445364`*^9, 3.801778074046605*^9, 3.8017783131783795`*^9, 
   3.8017783439221983`*^9, 3.8017786553876815`*^9, 3.801779138145771*^9, 
   3.8017792488796043`*^9, 3.801779506310661*^9, 3.8017795492418423`*^9, 
   3.8017796217887506`*^9, 3.801779709371714*^9, 3.801779817116694*^9, 
   3.8017798533916473`*^9, 3.801779899000266*^9, {3.8017799405079165`*^9, 
   3.801779967450033*^9}, 3.8017802560183163`*^9, 3.801780306746418*^9, 
   3.801780344211422*^9, {3.8017804439702563`*^9, 3.8017804721700673`*^9}, 
   3.8017805409035826`*^9, 3.8017805802003374`*^9, 3.8017806656129417`*^9, 
   3.8017811762878675`*^9, 3.801781222587922*^9, 3.801781688096794*^9, {
   3.8017819978231897`*^9, 3.801782035287342*^9}, 3.8017820890438232`*^9, {
   3.8017822319383073`*^9, 3.8017822491911564`*^9}, 3.8030750870008593`*^9, 
   3.8030751540073695`*^9, 3.803075259202407*^9, 3.8030754034217415`*^9, 
   3.8030755054493756`*^9, 3.8031139645613594`*^9, 3.803114084480019*^9, 
   3.8031141469538784`*^9, 3.803114191096325*^9, 3.803114297645469*^9, 
   3.803114393611354*^9, 3.8031185696297293`*^9, 3.803118638170224*^9, 
   3.803118702047079*^9, {3.8031187473594465`*^9, 3.803118769043373*^9}, 
   3.80311880845013*^9, 3.8031205934932847`*^9, 3.803120630774397*^9, 
   3.8031244174185233`*^9, 3.8031245169131594`*^9, 3.8031249102831197`*^9, 
   3.803124991509452*^9, 3.803125759075655*^9, 3.803126253346963*^9, 
   3.803128483130848*^9, 3.8031286690979834`*^9, 3.8032924987962933`*^9, 
   3.803303084561537*^9, 3.8033032747697845`*^9, 3.8033104115209475`*^9, 
   3.803312901030964*^9, 3.803313231275567*^9, 3.803391647600006*^9, 
   3.803392062973687*^9, 3.8033921283218317`*^9, 3.803392520065557*^9, 
   3.8033926306852746`*^9, 3.8033944589630575`*^9, 3.8033947991320267`*^9, 
   3.803394914026799*^9, 3.803397326004096*^9, 3.8033974445483875`*^9, 
   3.8033980677407513`*^9, 3.8033984374911313`*^9, 3.803398591318152*^9, 
   3.8035096208316846`*^9, 3.8035103296726255`*^9, 3.803511721217949*^9, 
   3.803512180748121*^9, 3.804345496959716*^9, 3.804345535141422*^9, 
   3.8043455688236265`*^9, 3.8043459771150684`*^9, 3.804346900651185*^9, 
   3.804347743976942*^9, {3.8043478447983723`*^9, 3.8043478587622347`*^9}, 
   3.8043478907551184`*^9, 3.8043479285926*^9, {3.8043482361294065`*^9, 
   3.804348258143536*^9}, 3.804348936898817*^9, 3.804349006147746*^9, 
   3.8043490998016157`*^9, 3.8045199879901805`*^9, 3.804520290649263*^9, 
   3.8045204189345813`*^9, 3.8045205647204466`*^9, 3.804521041946695*^9, 
   3.8045210804643292`*^9, 3.8045211595556393`*^9, 3.8045213929101944`*^9, 
   3.8045214710169363`*^9, 3.8045458082556286`*^9, 3.8045458827903852`*^9, 
   3.804546096639233*^9, 3.8045461955027046`*^9, 3.8045873500938845`*^9, 
   3.804590445246277*^9, 3.80459171067251*^9, 3.8045918182908363`*^9, 
   3.804858848295595*^9, 3.8048588913334084`*^9, 3.8048596680133142`*^9, 
   3.804859754401289*^9, 3.80485996853561*^9, 3.8048601156215563`*^9, 
   3.8048603849562187`*^9, 3.804860542005155*^9, 3.8048606738917837`*^9, 
   3.804861493206768*^9, 3.8048659536079865`*^9, 3.8048662772785873`*^9, 
   3.804866447868962*^9, 3.8048672543047976`*^9, 3.8048811944889293`*^9, 
   3.8048952728938904`*^9, 3.8048961523434486`*^9, 3.804896949893682*^9, 
   3.805022037321126*^9, 3.8050235460867453`*^9, 3.8050236911526933`*^9, 
   3.8050238544790134`*^9, 3.8050252295805902`*^9, 3.805638105696127*^9, 
   3.805638201964205*^9, 3.805638626074051*^9, 3.805640895737607*^9, 
   3.805641078336277*^9, 3.8056658400271454`*^9, 3.806791376951078*^9, 
   3.8068326419804306`*^9, 3.806833365858286*^9, 3.8068340670429707`*^9, 
   3.806834374551753*^9, 3.806834766757572*^9, 3.8068351444302425`*^9, 
   3.806835448536298*^9, 3.806835574905506*^9, 3.8068364626255608`*^9, 
   3.8068365119318924`*^9, 3.8068368220358706`*^9, 3.806839121712882*^9, 
   3.806839671713239*^9, 3.80745337484709*^9, 3.8074557787517347`*^9, 
   3.807456098935789*^9, 3.8074562125372148`*^9, 3.807457103895204*^9, 
   3.8074593107773542`*^9, 3.8074593639797764`*^9, 3.8074594130549927`*^9, 
   3.807459645999335*^9, 3.807528164229126*^9, 3.8075319820337424`*^9, 
   3.807532083087646*^9, 3.8075321510667615`*^9, 3.807532184715479*^9, 
   3.8075329704348345`*^9, 3.8075332617373023`*^9, 3.8078857275753193`*^9, 
   3.8078870594216523`*^9, 3.807887298304954*^9, 3.807887507089509*^9, 
   3.807887614425376*^9, 3.8078877871335583`*^9, 3.8078886774195366`*^9, 
   3.8100492191881227`*^9, 3.812473127420782*^9, 3.812473198876291*^9, 
   3.812818443755655*^9, 3.8128186963522277`*^9, 3.8128187465462914`*^9, 
   3.8129669921990094`*^9, 3.8129678480533266`*^9, 3.8129679771419477`*^9, 
   3.812968207621529*^9, 3.8129686994474325`*^9, 3.8129689419279947`*^9, 
   3.812976734585821*^9, 3.812976882857114*^9, 3.815479722956307*^9, 
   3.815775875819035*^9, 3.8157759531874704`*^9, 3.817018088171038*^9, 
   3.8188014630021534`*^9, 3.8252581719002028`*^9, 3.8254093588706546`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[249]=",ExpressionUUID->"a1ca85f7-e500-4ba2-8c10-cc5dd1672fa3"]
}, Open  ]],

Cell["Percent change in processed price index", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8043489043563223`*^9, 3.80434890819631*^9}, {3.8048542238619013`*^9, 
  3.8048542238619013`*^9}, {3.804854255465377*^9, 
  3.804854255465377*^9}},ExpressionUUID->"c459d460-c983-4424-b98e-\
d057822b1f1b"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Pp1", "-", "Pp0"}], ")"}], "100"}], "Pp0"]], "Input",
 CellLabel->
  "In[250]:=",ExpressionUUID->"ea1630c7-69ec-469b-95ed-58312d9bf06e"],

Cell[BoxData["1.0049763540481238`"], "Output",
 CellChangeTimes->CompressedData["
1:eJwd030s1HEAx/ErabszbMZx8nDm+alHZyrKz5k4RkLJPKw7Vx6PJYpqaNJa
8kdpu6zGWl0Ybm5aYqtDTlxM5iEX56ErD/tZTx5u7dD30x+fvf75/Pt2Euad
Ee9iMBjZZJburlRAIk09GvsYASWl5QlQc+CO6h7Rtj+ZhpIlsQEeM6szqyKq
1RECuG+aHQM9wv8mQkW9WxG0M1kuhT48C6GUGBGZng3tCrmVUMa+8QBmlqub
mokb822+rcRqY60aaoZjp6Bi3TTw0HmaKvLOo2B87u1nsOZcbAv87cz+AHfr
rmng/cfOBtjp1Wd+mNjBDOHCHfumSqi84t/uR0zIap6G7cM7v6BF99BZHrH4
RZxrIHHJlmvMJyq2zArgQY5yAi6o5CtlREF/3MtyIluU9QaOeo4PwXzLjuJb
+IUd72pJoqnBGH4/1GpPGWCH0V4bOZHBH9kPe1KZYV3Eqz+cNXPJNEXPhjLW
idGbyiRov5KhgN/1E59h1dsZ5gZx/L3lUShtZKdBl5IFCRyrmJqBsaNGOmgp
U7E2ibXfgrz0xIEogwTG181au6TSlE1hUqgrMcfqQg4s8q4pgR4NO8vQ6c+X
LTfiRG3FHndislTGgoz1HnfIGb/7JJzYOtNbLCCyosWV0KdXVw3r5ZyHkLty
eh1a2XRyIokOy2tHNomC7TzNf0Oi9DAlRWyhJw7ajThCf9VFHlyl5c+h79MM
qbWIpvzMf7q8vkRTJ3RaX5iuKulOy6CpmG3TeSh7F78IM1OZggbitp/xK9jN
8uiDbV835mH1p8uOjUS+QhkEA09OmrQQg63SHGCArZBXkEtTouCbI0YSmhpe
9NRAxzXjFGE+TWVXzLkNFJAuWGWTnDKaur462ygi/gMwmLEk
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[250]=",ExpressionUUID->"15b8611a-ff47-4eaa-8ae4-d99a0f82211e"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{743, 709},
WindowMargins->{{7, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 1483, 28, 196, "Title",ExpressionUUID->"d2b2e88b-412d-4daf-b693-8efdf54ef634"],
Cell[2066, 52, 4406, 65, 370, "Text",ExpressionUUID->"ded1986f-8993-437c-847e-5eafe9b068cf"],
Cell[6475, 119, 230, 5, 28, "Input",ExpressionUUID->"0c777ea8-191a-4659-be18-f91ea0d0ffda"],
Cell[CellGroupData[{
Cell[6730, 128, 404, 7, 62, "Section",ExpressionUUID->"d71ac8e8-e851-4193-bf90-47327a6dd4ff"],
Cell[CellGroupData[{
Cell[7159, 139, 457, 8, 43, "Subsubsection",ExpressionUUID->"2817593e-79b6-4a56-9a16-b6d64551836b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[7619, 149, 555, 8, 48, "Text",ExpressionUUID->"4e4a0823-4889-4f02-80db-3d69c49e9c7e",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[8177, 159, 879, 13, 34, "Text",ExpressionUUID->"af0bd7ae-da5b-470b-b108-b5d440caf772",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[9059, 174, 632, 11, 44, "Input",ExpressionUUID->"e187ba23-5877-47a9-b403-9771c122b111",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[9694, 187, 239, 4, 34, "Text",ExpressionUUID->"0c683e20-e6b4-4f00-8658-6d7602cddda9",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[9936, 193, 708, 12, 44, "Input",ExpressionUUID->"4e618303-f802-4bb1-a914-80696ff1b87a",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[10681, 210, 400, 7, 43, "Subsubsection",ExpressionUUID->"87c399f4-3e97-4172-85cc-186c7682399f"],
Cell[11084, 219, 554, 8, 30, "Text",ExpressionUUID->"59a61570-26e2-416c-a81b-2cc3ae8dcc26"],
Cell[11641, 229, 164, 3, 34, "Text",ExpressionUUID->"77afa9cd-cc59-4b6e-b428-b5dcf7468315"],
Cell[11808, 234, 1789, 27, 44, "Input",ExpressionUUID->"45be8dc0-b9d4-4d0f-a0da-e6c1cfe04bbc"],
Cell[13600, 263, 813, 12, 34, "Text",ExpressionUUID->"889b1e8d-9dc0-459f-b333-770d3f6645e2"],
Cell[14416, 277, 1601, 24, 44, "Input",ExpressionUUID->"c6d174b2-4072-4602-bf86-ac72813840e5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16054, 306, 600, 9, 43, "Subsubsection",ExpressionUUID->"c8295b7c-4f31-46c4-ab62-b68a3a53efaf"],
Cell[16657, 317, 532, 7, 30, "Text",ExpressionUUID->"c54f1830-a44e-4153-81d6-a7c0c3c7e59d"],
Cell[17192, 326, 800, 12, 34, "Text",ExpressionUUID->"8b8425c4-54a7-4b99-bbae-9361e4edf62b"],
Cell[17995, 340, 1062, 18, 44, "Input",ExpressionUUID->"5076e941-d581-47fe-82e7-6640b4c1f980"],
Cell[19060, 360, 826, 12, 34, "Text",ExpressionUUID->"25d3293f-b9cd-4261-a7f4-b22d3656fd04"],
Cell[19889, 374, 1059, 18, 44, "Input",ExpressionUUID->"2d81b003-4ca7-430a-8b2d-e325db131038"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20985, 397, 617, 9, 43, "Subsubsection",ExpressionUUID->"7c739ecf-54e8-499e-8dc2-9ddbab8adf8c"],
Cell[21605, 408, 847, 12, 48, "Text",ExpressionUUID->"a45e12f9-61ed-46f6-9809-46e910ffef49"],
Cell[22455, 422, 898, 13, 34, "Text",ExpressionUUID->"4565c44d-15af-43c8-941f-ca6c776e2df8"],
Cell[23356, 437, 3459, 49, 44, "Input",ExpressionUUID->"c1974cde-0bee-4337-89d4-4d8be79bede4"],
Cell[26818, 488, 215, 4, 34, "Text",ExpressionUUID->"5b4d84a0-f222-4101-b6c7-5a4ebb8ce1fe"],
Cell[27036, 494, 3431, 49, 44, "Input",ExpressionUUID->"8416828b-6e0d-4043-b421-691ce31c4cb1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30504, 548, 702, 10, 43, "Subsubsection",ExpressionUUID->"f8339f84-e49d-436f-a389-e71673f4d8ce"],
Cell[31209, 560, 598, 9, 30, "Text",ExpressionUUID->"e87dd23c-c367-4ac0-9304-7d5d4a331962"],
Cell[31810, 571, 890, 12, 34, "Text",ExpressionUUID->"484e6aac-9186-4168-9405-72364f09a3f4"],
Cell[32703, 585, 2285, 33, 44, "Input",ExpressionUUID->"0e61cea0-3282-45a7-bd8e-9e8e785d69eb"],
Cell[34991, 620, 159, 3, 34, "Text",ExpressionUUID->"3a3ae47a-4e65-4b69-898b-78063599371a"],
Cell[35153, 625, 2341, 34, 44, "Input",ExpressionUUID->"daaf0596-c33a-4587-81b3-e028c2d51607"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[37543, 665, 445, 7, 62, "Section",ExpressionUUID->"795a1d4e-5478-405a-9590-a6564398b6f1"],
Cell[CellGroupData[{
Cell[38013, 676, 423, 7, 43, "Subsubsection",ExpressionUUID->"fbdce3df-ed6c-496d-bedd-478a269481cc",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[38439, 685, 776, 12, 66, "Text",ExpressionUUID->"39279e1b-8b0e-47a6-b252-e315fc37af3b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[39218, 699, 299, 5, 34, "Text",ExpressionUUID->"0ca75514-fc43-42c2-accb-0e42b6cc7eda",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[39520, 706, 1434, 23, 44, "Input",ExpressionUUID->"400c8e39-93cb-4fef-a9fb-41930d195d3f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[40957, 731, 2010, 32, 47, "Input",ExpressionUUID->"cfe43c25-be78-4227-bac0-674e47880d70",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[42970, 765, 298, 5, 34, "Text",ExpressionUUID->"e1e61a7d-5945-4ec8-812a-eda529f850ba",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[43271, 772, 1402, 23, 44, "Input",ExpressionUUID->"4ecde827-d0a5-44ad-8f2a-1ab84264d7b8",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[44676, 797, 2034, 33, 47, "Input",ExpressionUUID->"fc8eb168-ab40-4abf-a2f7-a6c4a5fe0448",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[46747, 835, 516, 9, 43, "Subsubsection",ExpressionUUID->"58d1864b-63d2-4ac0-9ab7-e1ac53d09b11",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[47266, 846, 1141, 16, 138, "Text",ExpressionUUID->"3f522b1e-d6a8-445d-957f-1f7b7d0f6d7f",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[48410, 864, 252, 4, 34, "Text",ExpressionUUID->"e22b65ca-0d01-4663-9a3d-79b2b10442b4",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[48665, 870, 1588, 25, 44, "Input",ExpressionUUID->"6561412e-06fd-4c57-ae93-47270a6df98e",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[50256, 897, 2064, 33, 47, "Input",ExpressionUUID->"b500756c-56aa-4933-bf28-26ff15c812df",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[52323, 932, 249, 4, 34, "Text",ExpressionUUID->"7d8e623d-6a9d-4b24-8417-56762dbbc581",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[52575, 938, 1508, 25, 44, "Input",ExpressionUUID->"abd93098-806c-4525-be8c-4d88e9e76f05",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}],
Cell[54086, 965, 2089, 33, 47, "Input",ExpressionUUID->"ebcd232e-c795-4bc1-a40e-cba3ff4afb1c",
 CellGroupingRules->{"GroupTogetherGrouping", 10002.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[56212, 1003, 566, 9, 43, "Subsubsection",ExpressionUUID->"9f10f444-ddc7-48bd-88d7-8153ec7e4711",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[56781, 1014, 580, 9, 30, "Text",ExpressionUUID->"7224716d-5dc4-4c93-8771-4160d39caef0",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[57364, 1025, 417, 6, 34, "Text",ExpressionUUID->"31ae3b95-4ea8-419a-bb07-29c5b1772b9d",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[57784, 1033, 1949, 34, 44, "Input",ExpressionUUID->"371d9049-7ce7-40f7-b41b-29c4bc91fb4b",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[59736, 1069, 1761, 29, 47, "Input",ExpressionUUID->"aac04036-7655-40bb-aad7-1dc7991d1003",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[61500, 1100, 263, 4, 34, "Text",ExpressionUUID->"18b427f4-cad5-417f-a746-17a06e3f07a4",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[61766, 1106, 1981, 35, 44, "Input",ExpressionUUID->"e3583c1c-0b7d-498c-9dc9-be43612a7e2d",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[63750, 1143, 1708, 28, 47, "Input",ExpressionUUID->"8abd3c2c-fa5f-4fa9-b775-f67376897e53",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[65461, 1173, 565, 8, 34, "Text",ExpressionUUID->"d9aa3b4d-191b-46e8-b6d9-0c7164d1e004",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[66029, 1183, 1911, 34, 44, "Input",ExpressionUUID->"fc53ee63-8e40-4683-b321-8821e0a01696",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[67943, 1219, 1796, 29, 47, "Input",ExpressionUUID->"a19c8c06-1203-453b-97b9-81d7697dca09",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[69742, 1250, 261, 4, 34, "Text",ExpressionUUID->"5542ff37-707a-4950-9052-2ac9c9c57645",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[70006, 1256, 1865, 33, 44, "Input",ExpressionUUID->"aaf62327-53e1-464d-9269-855cd6a8d47e",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[71874, 1291, 1839, 30, 47, "Input",ExpressionUUID->"830979a0-2024-4f7e-94ef-e6fd5d545f12",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[73716, 1323, 569, 9, 34, "Text",ExpressionUUID->"9d1598b7-ef35-4a1a-bc39-af1981762772",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[74288, 1334, 1789, 33, 44, "Input",ExpressionUUID->"7d33a6af-ed15-4356-8e81-ee1b51ecb618",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[76080, 1369, 1795, 31, 44, "Input",ExpressionUUID->"d335b394-b7ba-460c-8916-2bfed61ddef4",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[77878, 1402, 552, 8, 34, "Text",ExpressionUUID->"4ad3ea4e-94c7-4ae2-a004-83c9bd8ee64d",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[78433, 1412, 1924, 33, 44, "Input",ExpressionUUID->"35bf12f1-9497-43a8-93f9-a343c7e57c0a",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[80360, 1447, 1907, 33, 44, "Input",ExpressionUUID->"5c57897c-e6e0-4547-adec-f264f983fc1c",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[82270, 1482, 473, 7, 34, "Text",ExpressionUUID->"cd6f868f-52a1-4b7d-bdd8-1e0c25075729",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[82746, 1491, 991, 16, 28, "Input",ExpressionUUID->"7642a00a-7e5c-4224-8711-9ffc11e1be68",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[83740, 1509, 889, 15, 28, "Input",ExpressionUUID->"912b37a4-b188-4750-8262-c62c624d05cf",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[84632, 1526, 1038, 17, 28, "Input",ExpressionUUID->"b2292b82-0665-4f04-80e1-a2dee86e9765",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}],
Cell[85673, 1545, 899, 15, 28, "Input",ExpressionUUID->"2f08f5a1-311d-43ce-870b-fb2dfac7f219",
 CellGroupingRules->{"GroupTogetherGrouping", 10003.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[86609, 1565, 606, 9, 43, "Subsubsection",ExpressionUUID->"c77e5d06-f1d8-4350-8e77-87365306630b",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[87218, 1576, 726, 10, 48, "Text",ExpressionUUID->"0919bd74-ac92-4ede-a4ad-3c13fc557bbe",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[87947, 1588, 1122, 19, 44, "Input",ExpressionUUID->"d36c758b-7ed8-4713-92ae-51ee7315a7bf",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[89072, 1609, 1144, 20, 44, "Input",ExpressionUUID->"0e506b29-bfc7-4479-8fc4-8cfa6b23b871",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[90219, 1631, 1217, 21, 44, "Input",ExpressionUUID->"ebbcdefa-e8b4-418d-bbcc-8a1406b8ea24",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}],
Cell[91439, 1654, 954, 17, 44, "Input",ExpressionUUID->"3302594c-3311-486c-975d-02c4f6420f26",
 CellGroupingRules->{"GroupTogetherGrouping", 10004.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[92430, 1676, 600, 9, 43, "Subsubsection",ExpressionUUID->"20494cf4-adab-4dbb-8350-dbdf64a8c10d",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[93033, 1687, 237, 4, 34, "Text",ExpressionUUID->"185ead6d-f6bb-434f-afe3-ef00a1d5122e",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[93273, 1693, 686, 11, 30, "Text",ExpressionUUID->"1f50a929-70ab-44fe-a73d-75504f21a74b",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[93962, 1706, 1637, 26, 44, "Input",ExpressionUUID->"802c6b9b-1962-431d-b17b-a621193520c7",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[95602, 1734, 234, 4, 34, "Text",ExpressionUUID->"07927045-5790-40c2-813e-6a2d1eab9036",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[95839, 1740, 1286, 19, 156, "Text",ExpressionUUID->"3a8f1040-8e3f-4a1f-8d8e-1a3dca91edf6",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}],
Cell[97128, 1761, 1543, 25, 44, "Input",ExpressionUUID->"cb959750-59dd-405b-8ff0-098877582c11",
 CellGroupingRules->{"GroupTogetherGrouping", 10005.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[98708, 1791, 492, 8, 43, "Subsubsection",ExpressionUUID->"0bcfb45d-7762-443a-8819-6c1bda987ce2",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[99203, 1801, 383, 9, 28, "Input",ExpressionUUID->"9bd5a9f7-6a53-4209-b795-7ed16c734d0a",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[99589, 1812, 724, 11, 32, "Output",ExpressionUUID->"23c27096-7d2d-45fd-a7c7-7a704a6fe537",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[100316, 1825, 385, 9, 28, "Input",ExpressionUUID->"d5614ce3-fad6-47e4-88e0-0d4d74431e46",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[100704, 1836, 714, 11, 32, "Output",ExpressionUUID->"d50ee5ff-4fc1-4d3b-8c24-ccd361893c6d",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[101421, 1849, 433, 9, 28, "Input",ExpressionUUID->"2864af37-e549-430c-9e06-d2f8451f20b7",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[101857, 1860, 738, 11, 32, "Output",ExpressionUUID->"4916e431-0e57-4a29-bdb2-27f39bdc82d7",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[102598, 1873, 387, 9, 28, "Input",ExpressionUUID->"0e236d69-eac0-4597-a69b-d2da31542bbd",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}],
Cell[102988, 1884, 744, 11, 32, "Output",ExpressionUUID->"dc132945-2d78-430f-935f-0971f14105e8",
 CellGroupingRules->{"GroupTogetherGrouping", 10006.}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[103781, 1901, 446, 7, 62, "Section",ExpressionUUID->"090a6d96-50fc-4f0a-9c97-b55f50ce848a"],
Cell[104230, 1910, 558, 8, 34, "Text",ExpressionUUID->"7bcc55d1-51bf-4c8b-8d08-10dbd38a5ae0",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[104791, 1920, 1096, 18, 28, "Input",ExpressionUUID->"bcd1b8c2-12df-4a34-b46e-55c2ab4cc24e"],
Cell[105890, 1940, 1159, 18, 28, "Input",ExpressionUUID->"7ba43ca5-42d7-4dd1-9e4d-54130dec78d9"],
Cell[107052, 1960, 1114, 18, 28, "Input",ExpressionUUID->"a670896e-3a79-4021-8343-54a5ece8d061"],
Cell[108169, 1980, 1188, 19, 28, "Input",ExpressionUUID->"e277d6ca-3f55-4be1-9d33-c1ff6a01c5a3"],
Cell[109360, 2001, 1846, 30, 28, "Input",ExpressionUUID->"a3ab304f-2aee-4fbd-bfd7-6f5a12f02f88"],
Cell[111209, 2033, 1498, 26, 28, "Input",ExpressionUUID->"39bf3198-00de-45df-a1be-3f7603e2375e"],
Cell[112710, 2061, 1793, 30, 28, "Input",ExpressionUUID->"452c9f24-2134-4294-98c5-98d220bcf96c"],
Cell[114506, 2093, 1446, 25, 28, "Input",ExpressionUUID->"ebbbcfd0-9681-4755-aac2-3374db013fbe"],
Cell[CellGroupData[{
Cell[115977, 2122, 197, 3, 44, "Subsubsection",ExpressionUUID->"22d0e65b-838e-4777-8c88-7f76411ad0e1"],
Cell[116177, 2127, 1005, 19, 48, "Input",ExpressionUUID->"251b4ab0-22c0-46e3-b8e5-e9aa3e6836c2"],
Cell[117185, 2148, 1859, 30, 28, "Input",ExpressionUUID->"84a21240-2395-4207-a627-0bd1de0b1bd2",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[119047, 2180, 1081, 20, 48, "Input",ExpressionUUID->"ddefb4fb-ed0b-41c9-b34f-815fdb269d09"],
Cell[CellGroupData[{
Cell[120153, 2204, 1959, 31, 28, "Input",ExpressionUUID->"9804a220-ad8a-4ea2-b0a3-d983552dacc8",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[122115, 2237, 1948, 30, 28, "Input",ExpressionUUID->"bc3c59fe-1a5a-4620-b777-5193481a7c20",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[124066, 2269, 1995, 31, 28, "Input",ExpressionUUID->"5f10e891-dfc6-4792-ad06-a5c8539015a5",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[126110, 2306, 199, 3, 44, "Subsubsection",ExpressionUUID->"764cfc7f-4169-418e-9916-e02e7bded345"],
Cell[126312, 2311, 391, 11, 49, "Input",ExpressionUUID->"34c2bdbf-9703-407d-a3dc-bdf6109d5ebe"],
Cell[126706, 2324, 1355, 26, 41, "Input",ExpressionUUID->"9e69d06c-6caf-46db-bda6-a3faf4148c88"],
Cell[128064, 2352, 2866, 44, 49, "Input",ExpressionUUID->"366feb00-9bf5-4990-95a3-a7a110168717"],
Cell[130933, 2398, 1330, 26, 41, "Input",ExpressionUUID->"43a9bcc6-6d6d-4177-a452-ad251c4b00f8"],
Cell[132266, 2426, 1025, 21, 47, "Input",ExpressionUUID->"ead5963f-2b2a-45a5-8c0e-2269dfb14f41"],
Cell[133294, 2449, 1183, 24, 39, "Input",ExpressionUUID->"a8ffdad4-a19d-4acd-9f6d-4ed4d842efd6"],
Cell[134480, 2475, 440, 12, 49, "Input",ExpressionUUID->"36403031-0b54-4e3f-b978-34490e792346"],
Cell[134923, 2489, 1440, 28, 41, "Input",ExpressionUUID->"bfe09279-c02a-4e14-b37a-2ead85213dd7"],
Cell[136366, 2519, 2914, 45, 49, "Input",ExpressionUUID->"c032c0bb-88fc-4890-aaa4-791e8693396f"],
Cell[139283, 2566, 1382, 27, 41, "Input",ExpressionUUID->"731377da-9a28-4166-b87e-1fc4636c09d9"],
Cell[140668, 2595, 1079, 22, 49, "Input",ExpressionUUID->"62eabe97-1954-43ae-855a-7d2c54b35cbd"],
Cell[141750, 2619, 1287, 26, 41, "Input",ExpressionUUID->"e6724399-0426-4abd-bb4b-27370550b482"],
Cell[143040, 2647, 1982, 33, 47, "Input",ExpressionUUID->"0f3e7553-f6e2-4c16-ad42-a622b32f2bcb"],
Cell[145025, 2682, 1262, 24, 50, "Input",ExpressionUUID->"3ef16ad7-9288-471b-b407-adece8171bc8"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[146336, 2712, 509, 8, 62, "Section",ExpressionUUID->"adefa830-0aad-442a-a63c-7faf6a6e3231"],
Cell[146848, 2722, 1272, 25, 41, "Input",ExpressionUUID->"ef893d96-bd08-4069-9c34-459925ad7abd"],
Cell[148123, 2749, 1327, 26, 41, "Input",ExpressionUUID->"8ed78591-642f-4073-ae37-f3504a3aa756"],
Cell[149453, 2777, 1313, 26, 39, "Input",ExpressionUUID->"fcad075f-b133-4c8a-bbfe-1247200c7621"],
Cell[150769, 2805, 1326, 26, 41, "Input",ExpressionUUID->"e4f1b596-0573-4ff5-85bd-0349547c3a1b"],
Cell[152098, 2833, 1379, 27, 41, "Input",ExpressionUUID->"f79d4387-0447-4407-8c07-0248d4b385fa"],
Cell[153480, 2862, 1365, 27, 41, "Input",ExpressionUUID->"7517f389-6f5d-4907-bf9f-a9ec53179fc7"],
Cell[154848, 2891, 206, 4, 34, "Text",ExpressionUUID->"0b09dc1a-4b30-4d5f-9dba-ae16cde992b2"],
Cell[155057, 2897, 574, 10, 34, "Text",ExpressionUUID->"a73e3fe0-db97-486d-b715-1d3b31d8449a"],
Cell[155634, 2909, 1737, 33, 28, "Input",ExpressionUUID->"7054bfa1-6724-4536-94f8-428722fa9818"],
Cell[157374, 2944, 2043, 37, 28, "Input",ExpressionUUID->"c2996b52-8c55-4eee-9698-15dc1c36aea2"],
Cell[159420, 2983, 716, 12, 34, "Text",ExpressionUUID->"f2222292-c02a-4dff-bfb0-5253e658f6aa"],
Cell[160139, 2997, 1627, 31, 28, "Input",ExpressionUUID->"d16e2950-660f-43e2-895a-44af17fb0b6a"],
Cell[161769, 3030, 1629, 30, 28, "Input",ExpressionUUID->"cfe54ccf-0db7-4801-88fa-6007d3fcd471"],
Cell[163401, 3062, 757, 12, 34, "Text",ExpressionUUID->"aee4aa60-9cad-4f3f-8312-69ed87061370"],
Cell[164161, 3076, 1378, 26, 28, "Input",ExpressionUUID->"0940c008-f167-45b0-8f67-f75f70a7d4aa"],
Cell[165542, 3104, 1375, 26, 28, "Input",ExpressionUUID->"4a6d51bc-ab93-4cda-be00-59be19085ebe"],
Cell[166920, 3132, 554, 9, 34, "Text",ExpressionUUID->"fe5ac143-fd1f-49dd-8606-531639c6211f"],
Cell[167477, 3143, 1684, 31, 28, "Input",ExpressionUUID->"9ffbd96d-803b-44a0-99d8-0c1850ae94f5"],
Cell[169164, 3176, 2045, 36, 28, "Input",ExpressionUUID->"0fb150fd-2c3a-41ba-8817-4473beb48449"],
Cell[CellGroupData[{
Cell[171234, 3216, 2580, 49, 67, "Input",ExpressionUUID->"6340c5ef-1fdf-4a1b-8913-8de97b421861"],
Cell[173817, 3267, 2470, 38, 52, "Output",ExpressionUUID->"20b6ca24-e4a9-402d-a2f4-ed039c4569f1"]
}, Open  ]],
Cell[176302, 3308, 469, 9, 28, "Input",ExpressionUUID->"946f9cfe-6f47-48dd-8266-de1998056519"],
Cell[176774, 3319, 608, 11, 28, "Input",ExpressionUUID->"ed362b77-6bc1-4448-880e-83a403e1ad8b"],
Cell[177385, 3332, 290, 7, 28, "Input",ExpressionUUID->"b901077e-ba84-4d1a-bd1b-dfa323d53551"],
Cell[177678, 3341, 291, 7, 28, "Input",ExpressionUUID->"5f198fb4-af13-477e-b3e2-2b1ca023ac14"],
Cell[177972, 3350, 313, 7, 28, "Input",ExpressionUUID->"a37949b0-46b4-43d3-acca-4c540695d556"],
Cell[178288, 3359, 311, 7, 28, "Input",ExpressionUUID->"4ec415df-f1f6-4235-8f57-f0f55d60a4bf"],
Cell[178602, 3368, 315, 7, 28, "Input",ExpressionUUID->"d1d550e2-8667-4173-a166-eaba82db75e2"],
Cell[178920, 3377, 318, 7, 28, "Input",ExpressionUUID->"2b2d3001-1e71-440e-8768-e05a22c12b60"],
Cell[179241, 3386, 1329, 26, 41, "Input",ExpressionUUID->"a5af71ce-981b-4c9c-8433-55c32cdbb79f"],
Cell[180573, 3414, 1382, 27, 41, "Input",ExpressionUUID->"68197689-5d5c-453f-8c51-3ecc77e002db"],
Cell[181958, 3443, 1365, 27, 39, "Input",ExpressionUUID->"f74d1433-2bc8-4050-85e7-d19d899a3992"],
Cell[183326, 3472, 1383, 27, 41, "Input",ExpressionUUID->"ca7652b4-172e-444c-86c9-c661db0d93a1"],
Cell[184712, 3501, 1436, 28, 41, "Input",ExpressionUUID->"b1575cbc-f7c2-4573-84ee-68dc0f42b469"],
Cell[186151, 3531, 1416, 27, 41, "Input",ExpressionUUID->"c8f46bfd-2bad-4bc4-979a-89dd6b762369"],
Cell[187570, 3560, 812, 16, 28, "Input",ExpressionUUID->"064cbe9c-6fec-482e-bdd6-f14a7ba69e58"],
Cell[188385, 3578, 809, 16, 28, "Input",ExpressionUUID->"15a4da0a-d2ac-4b14-b5d8-64edcdd860c7"],
Cell[189197, 3596, 721, 13, 28, "Input",ExpressionUUID->"e0bd41da-0520-483d-85ad-448b663088ea"],
Cell[189921, 3611, 721, 13, 28, "Input",ExpressionUUID->"a1d0f908-d542-43ae-ac90-db795839efa6"],
Cell[190645, 3626, 773, 14, 28, "Input",ExpressionUUID->"2d739507-8746-442c-8849-97a16bdaccb9"],
Cell[191421, 3642, 773, 14, 28, "Input",ExpressionUUID->"209a49c6-79ed-470d-a067-a9b809e10e02"],
Cell[192197, 3658, 1241, 23, 28, "Input",ExpressionUUID->"fb0677fa-4abb-470e-89b4-ff6f82e5318f"],
Cell[193441, 3683, 1253, 23, 28, "Input",ExpressionUUID->"8c57543b-fa44-4e29-b9c4-d01229df6542"]
}, Open  ]],
Cell[CellGroupData[{
Cell[194731, 3711, 544, 9, 62, "Section",ExpressionUUID->"d0a2db11-827c-4736-8aa7-be8538e4d366"],
Cell[195278, 3722, 1183, 17, 34, "Text",ExpressionUUID->"fa466ce1-cea8-4a8d-9b00-4b42818ede2f"],
Cell[196464, 3741, 747, 10, 34, "Text",ExpressionUUID->"37b6f62e-ab42-474a-883b-a789278bd2e7"],
Cell[CellGroupData[{
Cell[197236, 3755, 506, 10, 48, "Input",ExpressionUUID->"7851d6b9-66dd-4b24-bb64-9b1361450660"],
Cell[197745, 3767, 6714, 93, 48, "Output",ExpressionUUID->"64b9ea1e-cc81-4f5a-b58e-935209ce71ef"]
}, Open  ]],
Cell[204474, 3863, 877, 12, 34, "Text",ExpressionUUID->"ff34ab77-1d9f-4ec0-ba1d-cae076d2ebb1"],
Cell[CellGroupData[{
Cell[205376, 3879, 576, 11, 48, "Input",ExpressionUUID->"12284875-4e6e-4aaf-8a4e-b74c3485c4eb"],
Cell[205955, 3892, 625, 12, 48, "Output",ExpressionUUID->"48085d6e-e1f2-45aa-ad21-a676e26c621a"]
}, Open  ]],
Cell[206595, 3907, 796, 11, 34, "Text",ExpressionUUID->"5c1d1f1d-b9e6-447b-940b-9952b3a28d24"],
Cell[CellGroupData[{
Cell[207416, 3922, 556, 11, 48, "Input",ExpressionUUID->"af4d1872-6df6-4d03-857d-85798ae33095"],
Cell[207975, 3935, 6714, 93, 48, "Output",ExpressionUUID->"318f4e52-6e3d-4cee-bc42-bae70c799ea4"]
}, Open  ]],
Cell[214704, 4031, 938, 13, 34, "Text",ExpressionUUID->"41620eb5-5b08-466c-86cd-f380df276f9c"],
Cell[CellGroupData[{
Cell[215667, 4048, 625, 12, 48, "Input",ExpressionUUID->"3ff77757-42ce-47c8-bc80-54388deb25b9"],
Cell[216295, 4062, 6694, 93, 48, "Output",ExpressionUUID->"e00ead32-9981-4c53-9349-26da3fa3524b"]
}, Open  ]],
Cell[223004, 4158, 972, 13, 34, "Text",ExpressionUUID->"66e3d8bf-0da9-4845-95b9-8b8bf770b527"],
Cell[CellGroupData[{
Cell[224001, 4175, 854, 20, 28, "Input",ExpressionUUID->"f293df65-97a3-435d-a196-54d89d1d73ff"],
Cell[224858, 4197, 767, 15, 48, "Output",ExpressionUUID->"3fbffe77-c8aa-45cf-a239-a0dde0fdedac"]
}, Open  ]],
Cell[225640, 4215, 1024, 14, 34, "Text",ExpressionUUID->"51e65939-3a6f-4da8-8ee4-abe8097d7ac7"],
Cell[CellGroupData[{
Cell[226689, 4233, 896, 20, 28, "Input",ExpressionUUID->"85750734-0499-4097-b6f7-113e9003885d"],
Cell[227588, 4255, 1925, 28, 48, "Output",ExpressionUUID->"28087d7c-1057-444a-876c-8e7ffa276492"]
}, Open  ]],
Cell[229528, 4286, 1183, 17, 34, "Text",ExpressionUUID->"cfdf10cf-34a8-40d8-b0b1-39725aa5bbd3"],
Cell[230714, 4305, 747, 10, 34, "Text",ExpressionUUID->"87808b10-38b2-412a-a34f-6e65d6b3752c"],
Cell[CellGroupData[{
Cell[231486, 4319, 608, 12, 48, "Input",ExpressionUUID->"56d3ee65-2e64-4653-9ce7-3699a45d9e92"],
Cell[232097, 4333, 6617, 92, 48, "Output",ExpressionUUID->"1f1454f7-70d1-4279-95af-998ae60d82a2"]
}, Open  ]],
Cell[238729, 4428, 848, 12, 34, "Text",ExpressionUUID->"340dbded-46cb-42bc-b420-65dd828b0c5b"],
Cell[CellGroupData[{
Cell[239602, 4444, 680, 13, 48, "Input",ExpressionUUID->"97a2aaff-8b6f-4bc3-b744-39d4f05435f7"],
Cell[240285, 4459, 6622, 92, 48, "Output",ExpressionUUID->"22cd31f1-198d-42c2-b3eb-54dedb3f08ea"]
}, Open  ]],
Cell[246922, 4554, 800, 11, 34, "Text",ExpressionUUID->"65d42bae-b5c3-4483-b02f-77a2a2d19e21"],
Cell[CellGroupData[{
Cell[247747, 4569, 607, 12, 48, "Input",ExpressionUUID->"ec89fe8d-c64b-4802-9fa0-5fda4fec5080"],
Cell[248357, 4583, 6610, 92, 48, "Output",ExpressionUUID->"b173e90c-f10f-44ad-8621-c439f92cfe86"]
}, Open  ]],
Cell[254982, 4678, 903, 12, 34, "Text",ExpressionUUID->"9d2d41d9-d662-4692-b0f9-275af69086a3"],
Cell[CellGroupData[{
Cell[255910, 4694, 685, 13, 48, "Input",ExpressionUUID->"c68f8a88-0d37-4eca-8a0f-53c6953ed701"],
Cell[256598, 4709, 6598, 92, 48, "Output",ExpressionUUID->"c9e95019-e91a-4807-86f6-edd1f5907852"]
}, Open  ]],
Cell[263211, 4804, 970, 13, 34, "Text",ExpressionUUID->"3a1d09b7-e021-4be5-9440-183f46789866"],
Cell[CellGroupData[{
Cell[264206, 4821, 929, 21, 28, "Input",ExpressionUUID->"f13aef5f-971b-4fd5-973c-dd47a644d343"],
Cell[265138, 4844, 791, 15, 81, "Output",ExpressionUUID->"6aa8b08c-9568-47f0-a51b-0c06c086e71f"]
}, Open  ]],
Cell[265944, 4862, 1024, 14, 34, "Text",ExpressionUUID->"94b7fb62-ff27-41b0-b6cf-9ff2d7401e61"],
Cell[CellGroupData[{
Cell[266993, 4880, 878, 20, 28, "Input",ExpressionUUID->"c3180513-ab60-4ec9-8f7d-e65b660c3a99"],
Cell[267874, 4902, 1873, 27, 48, "Output",ExpressionUUID->"f92124dc-1615-4f37-8fd7-9c6b7b784e58"]
}, Open  ]],
Cell[269762, 4932, 582, 10, 34, "Text",ExpressionUUID->"0507f61c-2455-4a07-82fc-57ee92df6550"],
Cell[270347, 4944, 874, 12, 34, "Text",ExpressionUUID->"37bcdd80-3d78-4036-ac8b-572ef657ff1f"],
Cell[CellGroupData[{
Cell[271246, 4960, 712, 13, 47, "Input",ExpressionUUID->"f05c93cc-2e5d-49fa-8d02-82dcf99d9205"],
Cell[271961, 4975, 6628, 92, 48, "Output",ExpressionUUID->"69cebaa9-7e02-41ff-81f6-2f2ee31ad876"]
}, Open  ]],
Cell[278604, 5070, 971, 13, 34, "Text",ExpressionUUID->"681290b6-aebb-43bc-9019-980ae0c84e8f"],
Cell[CellGroupData[{
Cell[279600, 5087, 792, 14, 47, "Input",ExpressionUUID->"c7702cb2-a522-48c0-b2bb-4797d8cae5df"],
Cell[280395, 5103, 6645, 93, 48, "Output",ExpressionUUID->"b2a17040-a38a-4e8b-9c92-5cda13a9e9e9"]
}, Open  ]],
Cell[287055, 5199, 924, 13, 34, "Text",ExpressionUUID->"6815a9ad-d720-4c61-b472-0f7b31fdd47b"],
Cell[CellGroupData[{
Cell[288004, 5216, 766, 14, 47, "Input",ExpressionUUID->"9c9e149c-c050-4582-90c6-add757a1d276"],
Cell[288773, 5232, 6627, 92, 48, "Output",ExpressionUUID->"106e5119-5f9c-41be-911c-a2d3458d14a9"]
}, Open  ]],
Cell[295415, 5327, 1020, 14, 34, "Text",ExpressionUUID->"4364d0a3-d5a4-4220-9619-32172f1af36f"],
Cell[CellGroupData[{
Cell[296460, 5345, 786, 14, 47, "Input",ExpressionUUID->"9dbc6ee4-f141-4896-a063-05a3a8523dba"],
Cell[297249, 5361, 6652, 93, 48, "Output",ExpressionUUID->"bb7c0595-3e15-4982-b648-d606f84ff6b9"]
}, Open  ]],
Cell[303916, 5457, 1340, 19, 34, "Text",ExpressionUUID->"bb8a8855-1590-419f-a6a9-6e2de8a3b4b4"],
Cell[305259, 5478, 874, 12, 34, "Text",ExpressionUUID->"9e2b3065-d9da-493b-afdf-4abf852c1892"],
Cell[CellGroupData[{
Cell[306158, 5494, 764, 14, 47, "Input",ExpressionUUID->"5b478f90-972a-45b8-9aa6-9c67d932874c"],
Cell[306925, 5510, 6620, 92, 48, "Output",ExpressionUUID->"b3e8d86c-bcc8-416c-8f18-127cbd35dd0e"]
}, Open  ]],
Cell[313560, 5605, 971, 13, 34, "Text",ExpressionUUID->"1fe024e0-75ce-4e30-8292-aadf2be5d1ab"],
Cell[CellGroupData[{
Cell[314556, 5622, 843, 15, 47, "Input",ExpressionUUID->"891426fb-e626-4874-862c-c0a08823c846"],
Cell[315402, 5639, 6647, 93, 48, "Output",ExpressionUUID->"2ff2af79-b691-4ac7-98d5-c30bde319239"]
}, Open  ]],
Cell[322064, 5735, 922, 13, 34, "Text",ExpressionUUID->"92ff9ffd-9485-48aa-b033-70151e92e8c9"],
Cell[CellGroupData[{
Cell[323011, 5752, 816, 14, 47, "Input",ExpressionUUID->"4983c830-e754-401c-a38d-fedf7ffeb2ed"],
Cell[323830, 5768, 6612, 92, 48, "Output",ExpressionUUID->"0e05d4e9-ec9e-4a48-8452-9ea53020a490"]
}, Open  ]],
Cell[330457, 5863, 1020, 14, 34, "Text",ExpressionUUID->"5bc51b94-ca5a-481e-bfb4-b6540c350dff"],
Cell[CellGroupData[{
Cell[331502, 5881, 836, 15, 47, "Input",ExpressionUUID->"653ac09f-c710-4609-add1-9a293c68db02"],
Cell[332341, 5898, 6651, 93, 48, "Output",ExpressionUUID->"560cadf6-32f4-439c-85da-cb55d53d0e50"]
}, Open  ]],
Cell[339007, 5994, 936, 13, 34, "Text",ExpressionUUID->"13815c13-7ce0-400f-bac6-d5bef354e17d"],
Cell[339946, 6009, 1021, 14, 34, "Text",ExpressionUUID->"8d6f960c-cea6-4ac7-9d42-3184797329a6"],
Cell[CellGroupData[{
Cell[340992, 6027, 473, 10, 44, "Input",ExpressionUUID->"4be7ba51-cceb-4e00-9209-e3ee85fa7c30"],
Cell[341468, 6039, 6593, 91, 48, "Output",ExpressionUUID->"a1ca85f7-e500-4ba2-8c10-cc5dd1672fa3"]
}, Open  ]],
Cell[348076, 6133, 774, 11, 34, "Text",ExpressionUUID->"c459d460-c983-4424-b98e-d057822b1f1b"],
Cell[CellGroupData[{
Cell[348875, 6148, 205, 6, 47, "Input",ExpressionUUID->"ea1630c7-69ec-469b-95ed-58312d9bf06e"],
Cell[349083, 6156, 1113, 20, 48, "Output",ExpressionUUID->"15b8611a-ff47-4eaa-8ae4-d99a0f82211e"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

