(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    928647,      15990]
NotebookOptionsPosition[    868025,      15207]
NotebookOutlinePosition[    868366,      15222]
CellTagsIndexPosition[    868323,      15219]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["IUU Fishing: Economic Effects of IUU Imports on U.S. Commercial \
Fishers\n",
  FontSize->36],
 StyleBox["Species: Atlantic salmon, chinook salmon, chum salmon, coho \
salmon, pink salmon, sockeye salmon",
  FontSize->24],
 StyleBox["\n",
  FontSize->18],
 StyleBox["Model Release",
  FontSize->18,
  FontSlant->"Italic"]
}], "Title",
 CellChangeTimes->{{3.7159437701501894`*^9, 3.715943776742571*^9}, {
   3.7160177883406353`*^9, 3.716017799612287*^9}, {3.716044926298222*^9, 
   3.7160449278653135`*^9}, {3.7167127367223215`*^9, 3.716712737322365*^9}, {
   3.716716446852584*^9, 3.716716448548705*^9}, {3.717141741657609*^9, 
   3.717141743761731*^9}, {3.717937945363772*^9, 3.7179379529402757`*^9}, {
   3.7185331704286838`*^9, 3.7185331826684923`*^9}, {3.7185539001319838`*^9, 
   3.7185539082355175`*^9}, {3.7847892842210164`*^9, 
   3.7847892988406277`*^9}, {3.787835927539494*^9, 3.7878359285709715`*^9}, {
   3.7879338873743715`*^9, 3.7879338874784536`*^9}, {3.791201099377099*^9, 
   3.7912011013376207`*^9}, 3.7954520024204845`*^9, {3.798810740721634*^9, 
   3.798810744523918*^9}, {3.799789945142694*^9, 3.7997899492227287`*^9}, {
   3.7998541778687954`*^9, 3.7998541814351215`*^9}, {3.8016687240812187`*^9, 
   3.8016687246281986`*^9}, {3.8017788040189447`*^9, 
   3.8017788092541156`*^9}, {3.819664877798711*^9, 3.819664951849766*^9}, {
   3.8199010796026187`*^9, 3.8199010810067167`*^9}, {3.8249771280972795`*^9, 
   3.824977134543296*^9}, {3.8252737056085243`*^9, 
   3.8252737197895765`*^9}},ExpressionUUID->"859cf04b-9ead-4320-a51d-\
805da0a25176"],

Cell[TextData[{
 StyleBox["Read Me :",
  FontWeight->"Bold"],
 "\nThis model accompanies the USITC report, ",
 StyleBox["Seafood Obtained via Illegal, Unreported, and Unregulated Fishing: \
U.S. Imports and Economic Impact on U.S. Commercial Fisheries",
  FontSlant->"Italic"],
 ", Inv. 332-575. The report includes a quantitative analysis of the economic \
impact of IUU imports on U.S. commercial fishers and U.S. commercial fishing \
production, trade, and prices. Economic effects are modeled by species, with \
each species-level model customized to fit the unique features of the U.S. \
domestic industry. Consumers of seafood products choose between domestic \
marine-capture sources, imports, and in some models, domestic aquaculture \
products. Imports include both legal and IUU sources that enter the U.S. at \
the same price, so consumers cannot distinguish an IUU from non-IUU product. \
2018 data is used to establish an initial equilibrium with imports of IUU \
products included in the baseline. The model then removes the IUU imports, as \
estimated in chapter 3, and solves for a new equilibrium absent those \
products. \n\nIn the salmon model, there are domestic and imported  varieties \
of atlantic, chinook, chum, coho, pink, and sockeye salmon species. The model \
includes cross-species substitution, so relative price changes in one species \
affects the other species. Landings of some of the domestic varieties are \
potentially constrained by low supply elasticities to capture their \
endangered species status. There are two markets modeled: unprocessed and \
processed products. Landings  flow to three destinations: the unprocessed \
market, the processed market, or are exported outside the country. The price \
of the processed product is a constant markup over the price of the \
unprocessed product, so increases in domestic prices of landed fish affect \
the price of processing. Initial consumption of unprocessed products, before \
the policy change was implemented, was calculated as a residual using 2018 \
conversion factors.\n\nData inputs in the simulation are in the BLUE-shaded \
cells (with sources for the input data listed in the cell above). Outputs are \
in the GREEN-shaded cells. The white cells are intermediate calculations. \n\n\
Note: p_xDU is the price of the unprocessed product sold to consumers. q_xDU \
is the quantity of landings, not the unprocessed quantity sold to U.S. \
consumers. The unprocessed quantity sold to U.S. consumers must exclude \
exports and processed product * conversion rate."
}], "Text",
 CellChangeTimes->{{3.8151793544957237`*^9, 3.8151793654382553`*^9}, {
   3.815180147319877*^9, 3.8151801612046986`*^9}, 3.8193117353392124`*^9, {
   3.819364667233782*^9, 3.819364673128374*^9}, {3.819364986036234*^9, 
   3.81936502379967*^9}, {3.8193652789237294`*^9, 3.819365313721591*^9}, {
   3.819365363147914*^9, 3.819365382037648*^9}, {3.8193654602015305`*^9, 
   3.8193655738330727`*^9}, {3.819365634647441*^9, 3.8193657347144046`*^9}, {
   3.8193659700247307`*^9, 3.819365970554162*^9}, 3.8193660018247957`*^9, {
   3.819366258029726*^9, 3.819366301792824*^9}, {3.819366347287284*^9, 
   3.819366415704628*^9}, {3.8193664545638943`*^9, 3.819366511109967*^9}, {
   3.819366610713606*^9, 3.8193669391806083`*^9}, {3.8193669763456044`*^9, 
   3.8193670889590435`*^9}, {3.819367863082618*^9, 3.8193678631977077`*^9}, {
   3.819400007994233*^9, 3.819400030667904*^9}, {3.819400277598463*^9, 
   3.8194002936449785`*^9}, {3.8194011542913923`*^9, 
   3.8194012480694838`*^9}, {3.8194013222643557`*^9, 
   3.8194013264886327`*^9}, {3.8194013868456955`*^9, 
   3.8194013890784397`*^9}, {3.819401463985852*^9, 3.819401508238408*^9}, {
   3.8194019318657284`*^9, 3.8194019329005365`*^9}, {3.819665080356598*^9, 
   3.8196650954828777`*^9}, {3.8196652430795116`*^9, 3.819665263767852*^9}, {
   3.8196694045310993`*^9, 3.819669946270366*^9}, {3.819669976834861*^9, 
   3.8196705383246193`*^9}, {3.819670606948246*^9, 3.819670798460183*^9}, {
   3.819670860785177*^9, 3.8196709679574733`*^9}, {3.8196710056524982`*^9, 
   3.819671491943797*^9}, 3.819671563400182*^9, {3.819672484886944*^9, 
   3.8196724859338183`*^9}, {3.8199011533041058`*^9, 
   3.8199012321717076`*^9}, {3.8199021437167053`*^9, 3.819902144786538*^9}, {
   3.819904727337638*^9, 3.8199047710337067`*^9}, {3.820012303009897*^9, 
   3.820012307046046*^9}, {3.820012457109111*^9, 3.820012461730715*^9}, {
   3.821228471311254*^9, 3.821228478115568*^9}, {3.821228583604739*^9, 
   3.8212286069008274`*^9}, {3.821254034767659*^9, 3.8212540557230434`*^9}, {
   3.8212540945664053`*^9, 3.8212541288301916`*^9}, {3.821254184887725*^9, 
   3.8212542155085*^9}, {3.8249772744922485`*^9, 3.824977299960084*^9}, {
   3.824977554120001*^9, 3.8249776832165327`*^9}, {3.8249777599192657`*^9, 
   3.824977766653509*^9}, {3.82507490832841*^9, 3.825074908517795*^9}, 
   3.8250749591061897`*^9, {3.8250758189670277`*^9, 3.8250758195591617`*^9}, {
   3.8252737421440673`*^9, 3.825273870534485*^9}, {3.825413275791944*^9, 
   3.8254132762653093`*^9}, {3.8254138013838444`*^9, 3.825413801784217*^9}},
 FontSize->12,
 Background->GrayLevel[
  0.85],ExpressionUUID->"63cc22a9-a49e-4abf-8469-ccecf697abef"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ClearAll", "[", "f", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.791207469588732*^9, 3.7912074737709374`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"0c777ea8-191a-4659-be18-f91ea0d0ffda"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1. Model Parameters",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.795452962713849*^9}, {
  3.8196715794204283`*^9, 
  3.8196715805723763`*^9}},ExpressionUUID->"fae1ca55-f007-437e-ac6e-\
09bb4f78b71c"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.1 Within-Species Elasticity of Substitution", \
"Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.819814333471882*^9, 3.8198143380684657`*^9}, 
   3.825091280816696*^9, {3.825273895919343*^9, 3.8252738984303055`*^9}, 
   3.825283933963739*^9},ExpressionUUID->"5e9f2ce4-0508-477e-8e97-\
bfee64ddaa0b"],

Cell[TextData[StyleBox["Source: USITC\[CloseCurlyQuote]s econometric \
estimation using the trade cost method in Riker (2020). More information can \
be found in the technical appendix (appendix I). ",
 FontSize->12]], "Text",
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, 3.819672507377739*^9, 3.8252839339647446`*^9},
 FontSlant->"Italic",ExpressionUUID->"1cc24e23-68c9-4c30-b4bc-07547c48adec"],

Cell[TextData[{
 StyleBox["Unprocessed Atlantic salmon:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of unprocessed atlantic salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, 
   3.8252839339647446`*^9},ExpressionUUID->"984d5b54-7d64-4b24-8c95-\
9ec097a13014"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmaau", " ", "=", "5.1416"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.804851225082076*^9}, 3.8048805400169473`*^9, {3.804954566685294*^9, 
   3.8049545899388914`*^9}, {3.8067649349636374`*^9, 3.8067649359481773`*^9}, 
   3.8067650722056513`*^9, {3.8068333277966285`*^9, 3.8068333395239587`*^9}, {
   3.8068334144752445`*^9, 3.8068334171880493`*^9}, 3.8068362638450627`*^9, {
   3.812927570066881*^9, 3.8129275985210238`*^9}, 3.8129276833660574`*^9, 
   3.8129280689507203`*^9, 3.812928459305541*^9, {3.825273907435346*^9, 
   3.825273918912325*^9}, 3.825274170154846*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[2]:=",ExpressionUUID->"8ce1a048-b83e-4f20-84d6-e5ec15b6f8ef"],

Cell[TextData[{
 StyleBox["Unprocessed chinook salmon:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of unprocessed chinook salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.825274125209691*^9}, {
   3.8252741667461796`*^9, 3.825274167467745*^9}, 
   3.8252839339647446`*^9},ExpressionUUID->"e17014d0-d7b4-41e4-bbc8-\
7a7418311a44"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sigmacu", " ", "=", "4.0159"}], " ", ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.8048512302547855`*^9}, 3.804881140319895*^9, {3.8049546169116735`*^9, 
   3.804954630601733*^9}, 3.80495466178432*^9, {3.8067649534872656`*^9, 
   3.806764961394831*^9}, 3.806765053717871*^9, 3.806836269580391*^9, {
   3.8124689531576242`*^9, 3.812468956750429*^9}, {3.812802281304373*^9, 
   3.812802285705798*^9}, 3.81292756531118*^9, {3.8129276143743634`*^9, 
   3.8129276596566057`*^9}, 3.81292807670776*^9, 3.8129284624259715`*^9, {
   3.825273922100819*^9, 3.8252739223990526`*^9}, 3.8252741724176135`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[3]:=",ExpressionUUID->"055efbdb-f3e0-4860-881d-c7aa622d1cfb"],

Cell[TextData[{
 StyleBox["Unprocessed chum salmon:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of unprocessed chum salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741299814215`*^9}, {
   3.825274162211631*^9, 3.825274164010041*^9}, 
   3.8252839339647446`*^9},ExpressionUUID->"8c61d351-d9e2-4fba-ab89-\
0060bb890ca8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sigmahu", " ", "=", "4.0159"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.8048512302547855`*^9}, 3.804881140319895*^9, {3.8049546169116735`*^9, 
   3.804954630601733*^9}, {3.80495466178432*^9, 3.804954682787569*^9}, 
   3.8049547511373854`*^9, {3.806764972319667*^9, 3.8067649800091085`*^9}, 
   3.8067650559994965`*^9, 3.806836273190363*^9, 3.812468962611009*^9, 
   3.812802293326731*^9, 3.812927668323352*^9, 3.8129280785992317`*^9, 
   3.812928464542622*^9, 3.8252739259798536`*^9, 3.8252741749936295`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[4]:=",ExpressionUUID->"736de165-bccb-4534-80f2-371fc7549bff"],

Cell[TextData[{
 StyleBox["Unprocessed coho salmon:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of unprocessed coho salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741588099704`*^9}, 
   3.8252839339647446`*^9},ExpressionUUID->"146e6a6e-dd90-4a0a-ba2f-\
6b9711acc0f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmaou", " ", "=", "4.0159"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.804851215720364*^9}, {3.804868607217617*^9, 3.8048686106688566`*^9}, 
   3.8049544891235495`*^9, {3.8049545291611643`*^9, 3.804954545944648*^9}, {
   3.8067649134953394`*^9, 3.8067649306940565`*^9}, 3.8067650581092243`*^9, 
   3.8068362765346694`*^9, 3.8124689644124203`*^9, 3.812802297140701*^9, 
   3.8129276707342243`*^9, 3.8129280803505955`*^9, 3.812928466197908*^9, 
   3.8252739295986843`*^9, 3.8252741772413893`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[5]:=",ExpressionUUID->"68e3b805-5eb8-437a-a7f8-432c5dc38fa6"],

Cell[TextData[{
 StyleBox["Unprocessed pink salmon:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of unprocessed pink salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, {
   3.8252741397330494`*^9, 3.825274155058035*^9}, 
   3.8252839339647446`*^9},ExpressionUUID->"82f60873-0d07-4667-8aa5-\
970e73bfbf1b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sigmapu", " ", "=", "4.0159"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, 3.8048512034675865`*^9, {
   3.8048685945427647`*^9, 3.804868597324478*^9}, {3.804954434205166*^9, 
   3.8049544511156607`*^9}, {3.804954523810551*^9, 3.804954527582795*^9}, 
   3.8067648554092817`*^9, {3.806764925207309*^9, 3.80676492564853*^9}, 
   3.8067650601876965`*^9, 3.8068362802364197`*^9, 3.8124689660466943`*^9, 
   3.8128022994935284`*^9, 3.812927672811845*^9, 3.8129280816906366`*^9, 
   3.8129284676730547`*^9, 3.825273934330387*^9, {3.8252741793260403`*^9, 
   3.825274179568215*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[6]:=",ExpressionUUID->"0d44e1c6-e9d4-484e-888a-97e11d7e3438"],

Cell[TextData[{
 StyleBox["Unprocessed sockeye salmon:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of unprocessed sockeye salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, {
   3.8252741433008423`*^9, 3.825274151133966*^9}, 
   3.8252839339647446`*^9},ExpressionUUID->"df48dec8-a94e-449a-800b-\
b121ab20ce80"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sigmasu", " ", "=", "4.0159"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.8048512302547855`*^9}, 3.804881140319895*^9, {3.8049546169116735`*^9, 
   3.804954630601733*^9}, {3.80495466178432*^9, 3.8049547375584216`*^9}, 
   3.8056388361404037`*^9, {3.80676498619818*^9, 3.8067649935587797`*^9}, 
   3.8067650620942593`*^9, 3.806836283662056*^9, {3.8124689705472126`*^9, 
   3.812468974090982*^9}, 3.812802302565922*^9, 3.8129276749785285`*^9, 
   3.8129280833048973`*^9, 3.812928469426422*^9, 3.8252739383195086`*^9, 
   3.8252741472939606`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[7]:=",ExpressionUUID->"5fa0e8dd-4806-45d0-b98b-4ec2bc340d09"],

Cell[TextData[{
 StyleBox["Processed chinook salmon:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of processed chinook salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.825274125209691*^9}, {
   3.8252741667461796`*^9, 3.825274201136078*^9}, 
   3.825283933965747*^9},ExpressionUUID->"eff427f1-f6ab-421c-9430-\
5e9eaa7b3495"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sigmacp", " ", "=", "4.0159"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.8048512302547855`*^9}, 3.804881140319895*^9, {3.8049546169116735`*^9, 
   3.804954630601733*^9}, 3.80495466178432*^9, {3.8067649534872656`*^9, 
   3.806764961394831*^9}, 3.806765053717871*^9, 3.8067651041293926`*^9, 
   3.8068362868032064`*^9, 3.8124689913394346`*^9, 3.8128023426391096`*^9, 
   3.8129276912441893`*^9, 3.8129280710853853`*^9, 3.8129281012438583`*^9, 
   3.8129284722235956`*^9, 3.8252739505600805`*^9, 3.8252742094385424`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[8]:=",ExpressionUUID->"766ef20f-c865-472e-bc31-e106c6106cf4"],

Cell[TextData[{
 StyleBox["Processed chum salmon:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of processed chum salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741299814215`*^9}, {
   3.825274162211631*^9, 3.825274164010041*^9}, {3.825274214338352*^9, 
   3.825274218307439*^9}, 
   3.825283933965747*^9},ExpressionUUID->"33f04322-948b-41d9-8bd5-\
6a5283201ac3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmahp", " ", "=", "4.0159"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.8048512302547855`*^9}, 3.804881140319895*^9, {3.8049546169116735`*^9, 
   3.804954630601733*^9}, {3.80495466178432*^9, 3.804954682787569*^9}, 
   3.8049547511373854`*^9, {3.806764972319667*^9, 3.8067649800091085`*^9}, 
   3.8067650559994965`*^9, 3.806765104582591*^9, 3.8068362900224876`*^9, 
   3.8124689934660864`*^9, {3.8128023446076455`*^9, 3.812802344989942*^9}, 
   3.8129276935880103`*^9, 3.8129280853424797`*^9, 3.812928474055024*^9, 
   3.8252739538246336`*^9, 3.825274237256174*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[9]:=",ExpressionUUID->"0a22d713-413c-4a7f-a36c-b4c35ca6976f"],

Cell[TextData[{
 StyleBox["Processed coho salmon:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of processed coho salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741588099704`*^9}, {
   3.8252742252258177`*^9, 3.825274232194237*^9}, 
   3.825283933965747*^9},ExpressionUUID->"4dc55192-c670-4fc5-b72a-\
5f6cac310279"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sigmaop", " ", "=", "4.0159"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.804851215720364*^9}, {3.804868607217617*^9, 3.8048686106688566`*^9}, 
   3.8049544891235495`*^9, {3.8049545291611643`*^9, 3.804954545944648*^9}, {
   3.8067649134953394`*^9, 3.8067649306940565`*^9}, 3.8067650581092243`*^9, 
   3.806765108708255*^9, 3.8068362937887383`*^9, 3.812468995739853*^9, 
   3.8128023489990635`*^9, {3.812927696485267*^9, 3.8129276968585577`*^9}, 
   3.812928086820628*^9, 3.8129284753640413`*^9, 3.8252739578097515`*^9, 
   3.825274234940418*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[10]:=",ExpressionUUID->"63e07d97-a9e9-4202-8f45-003b041f85f6"],

Cell[TextData[{
 StyleBox["Processed pink salmon:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of processed pink salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, {
   3.8252741397330494`*^9, 3.825274155058035*^9}, {3.8252742513151655`*^9, 
   3.8252742549418697`*^9}, 
   3.825283933965747*^9},ExpressionUUID->"8f3aa904-cf29-4c64-83f9-\
8766573942e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmapp", " ", "=", "4.0159"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, 3.8048512034675865`*^9, {
   3.8048685945427647`*^9, 3.804868597324478*^9}, {3.804954434205166*^9, 
   3.8049544511156607`*^9}, {3.804954523810551*^9, 3.804954527582795*^9}, 
   3.8067648554092817`*^9, {3.806764925207309*^9, 3.80676492564853*^9}, 
   3.8067650601876965`*^9, 3.8067651093958645`*^9, 3.806836297070535*^9, 
   3.812468997040864*^9, {3.812802351086685*^9, 3.8128023514879966`*^9}, 
   3.812927699354501*^9, 3.8129280880105577`*^9, 3.81292847649592*^9, 
   3.825273963040841*^9, 3.8252742460319986`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[11]:=",ExpressionUUID->"8fc80ee2-6195-4576-8637-013ee963321d"],

Cell[TextData[{
 StyleBox["Processed sockeye salmon:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of processed sockeye salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, {
   3.8252741433008423`*^9, 3.825274151133966*^9}, {3.8252742617828703`*^9, 
   3.825274265416499*^9}, 
   3.825283933965747*^9},ExpressionUUID->"db0a87a9-5362-4c57-aa6f-\
217ca86abc00"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmasp", " ", "=", "4.0159"}], " ", ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.8048512302547855`*^9}, 3.804881140319895*^9, {3.8049546169116735`*^9, 
   3.804954630601733*^9}, {3.80495466178432*^9, 3.8049547375584216`*^9}, 
   3.8056388361404037`*^9, {3.80676498619818*^9, 3.8067649935587797`*^9}, 
   3.8067650620942593`*^9, 3.8067651109117336`*^9, 3.806836300289508*^9, 
   3.81246899864511*^9, 3.812802354188101*^9, 3.812927701698324*^9, {
   3.8129280909548464`*^9, 3.8129280940852847`*^9}, {3.8129284791539917`*^9, 
   3.812928481004434*^9}, {3.8252739666416607`*^9, 3.825273966903865*^9}, 
   3.825274249385609*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[12]:=",ExpressionUUID->"8604bae3-115b-49d5-9188-1cc3cda84174"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.2 Cross-Species Elasticity of Substitution", \
"Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, 3.8196725148810096`*^9, {
   3.8198143408736553`*^9, 3.819814345001872*^9}, 
   3.825283933965747*^9},ExpressionUUID->"b7af82b0-2be1-478f-8538-\
b8dbf8fc18a3"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate and Interviews with \
Industry Participants.",
 FontSize->12]], "Text",
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725148810096`*^9, 3.820012465372556*^9, {3.8200125245600863`*^9, 
   3.8200125375572243`*^9}, 3.8252839339667053`*^9},
 FontSlant->"Italic",ExpressionUUID->"842f053b-01ed-4a0d-8c05-eac6c3d988fb"],

Cell[TextData[{
 StyleBox["Unprocessed:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across unprocessed products",
  FontSize->14]
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, {3.819672030964613*^9, 3.8196720315651684`*^9}, {
   3.819672128429147*^9, 3.819672157389882*^9}, 3.8196725148810096`*^9, {
   3.8198159557829914`*^9, 3.819815955882069*^9}, {3.824978024405224*^9, 
   3.824978028343289*^9}, 
   3.8252839339667053`*^9},ExpressionUUID->"e9e13dfc-4438-4f78-9413-\
80c7121887df"],

Cell[BoxData[
 RowBox[{
  RowBox[{"betau", "=", "3.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.7997907022612257`*^9, 
   3.799790709387388*^9}, 3.7997908508541403`*^9, {3.8016879044513836`*^9, 
   3.801687907933004*^9}, {3.80434351778264*^9, 3.804343518580264*^9}, {
   3.804345558282427*^9, 3.8043455585966744`*^9}, {3.804346895174925*^9, 
   3.8043468962187347`*^9}, 3.804586879762295*^9, 3.8048512543836975`*^9, {
   3.804851294142619*^9, 3.8048513020969067`*^9}, {3.8048596891343603`*^9, 
   3.8048596894469223`*^9}, {3.804866261943138*^9, 3.804866262021276*^9}, {
   3.8129756645879774`*^9, 3.81297566507374*^9}, {3.812976065003236*^9, 
   3.812976065347055*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[13]:=",ExpressionUUID->"45be8dc0-b9d4-4d0f-a0da-e6c1cfe04bbc"],

Cell[TextData[{
 StyleBox["Processed:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across processed products",
  FontSize->14]
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, {3.819671893067898*^9, 3.819671897578418*^9}, {
   3.8196720341255374`*^9, 3.8196720347751384`*^9}, {3.8196721610431147`*^9, 
   3.8196721644200883`*^9}, 3.8196725148810096`*^9, {3.8198159580197334`*^9, 
   3.81981595815784*^9}, {3.8249780325525694`*^9, 3.8249780336674385`*^9}, 
   3.8252839339667053`*^9},ExpressionUUID->"fed937c8-b7fe-4979-80a5-\
64730cf0d225"],

Cell[BoxData[
 RowBox[{
  RowBox[{"betap", "=", "3.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.7997907022612257`*^9, 
   3.799790709387388*^9}, 3.7997908508541403`*^9, {3.8016879044513836`*^9, 
   3.801687907933004*^9}, {3.80434351778264*^9, 3.804343518580264*^9}, {
   3.804345558282427*^9, 3.8043455585966744`*^9}, {3.804346895174925*^9, 
   3.8043468962187347`*^9}, 3.804586879762295*^9, 3.8048512543836975`*^9, {
   3.8048512977994776`*^9, 3.8048513053474474`*^9}, {3.8048596921193275`*^9, 
   3.8048596924318895`*^9}, {3.812975668068129*^9, 3.812975668579527*^9}, {
   3.812976067972455*^9, 3.812976068316268*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[14]:=",ExpressionUUID->"c6d174b2-4072-4602-bf86-ac72813840e5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.3 Industry Price Elasticity of Demand", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, 3.8196725271002216`*^9, {3.819814291546197*^9, 
   3.819814297331707*^9}, {3.8198143479321556`*^9, 3.8198143530561504`*^9}, 
   3.8252839339667053`*^9},ExpressionUUID->"41c9e23b-2568-4dea-8856-\
6974855a912e"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate.",
 FontSize->12]], "Text",
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725271002216`*^9, 3.820012468652115*^9, {3.8200125463901167`*^9, 
   3.8200125607253003`*^9}, 3.8252839339667053`*^9},
 FontSlant->"Italic",ExpressionUUID->"b87fff88-b17b-4707-8439-863bb154da77"],

Cell[TextData[StyleBox["Unprocessed",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.8016643815964966`*^9, 3.80166438203933*^9}, {
   3.8031104952208443`*^9, 3.8031105339530745`*^9}, {3.803118428298416*^9, 
   3.8031184400395803`*^9}, 3.8033028142898912`*^9, {3.80571075980079*^9, 
   3.8057107601133404`*^9}, {3.8196721218802958`*^9, 
   3.8196721245096445`*^9}, {3.8196721773104386`*^9, 3.8196721827752504`*^9}, 
   3.8196725271002216`*^9, 
   3.8252839339667053`*^9},ExpressionUUID->"1c8b2880-5c23-43bc-bda6-\
8096ea7097e7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"etau", "=", " ", 
   RowBox[{"-", "1.0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, 
   3.8016643791586046`*^9, {3.801780399382991*^9, 3.8017804002581425`*^9}, 
   3.803110491929274*^9, {3.819672112733116*^9, 3.819672113234567*^9}, 
   3.819672527101222*^9, 3.8252839339677377`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[15]:=",ExpressionUUID->"06b1b446-6d5d-48a9-a8b1-e6b7ad803bd2"],

Cell[TextData[StyleBox["Processed",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.8016643815964966`*^9, 
   3.8016643912751904`*^9}, {3.8031105485584755`*^9, 
   3.8031105510724382`*^9}, {3.805710761160388*^9, 3.805710761519824*^9}, {
   3.819672173174797*^9, 3.8196721856998253`*^9}, 3.819672527101222*^9, 
   3.8252839339677377`*^9},ExpressionUUID->"4cd24a48-b529-412b-81d7-\
203f199acd7b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"etap", "=", " ", 
   RowBox[{"-", "1.0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016643791586046`*^9, 3.801664387008879*^9}, {3.80178040319617*^9, 
   3.801780404211971*^9}, {3.819672116662634*^9, 3.819672117252161*^9}, 
   3.819672527101222*^9, 3.8252839339687376`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[16]:=",ExpressionUUID->"adbd9106-dcde-48fa-9f82-5f26883c8abe"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.4 Illegal Imports Replacement Rates", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, {3.81967219811668*^9, 3.819672213143815*^9}, 
   3.819672537084565*^9, {3.819814300125886*^9, 3.8198143058253307`*^9}, {
   3.8198143561535683`*^9, 3.8198143611354523`*^9}, 
   3.8252839339687376`*^9},ExpressionUUID->"95d6f91a-87fd-4972-af18-\
f5878e9f1034"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate.  Further discussion on \
qualitative factors and rate determination can be found in appendix I of the \
USITC\[CloseCurlyQuote]s report.",
 FontSize->12]], "Text",
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196723427492237`*^9, 3.8196725370855665`*^9, {3.819815993710532*^9, 
   3.819815996531728*^9}, {3.8198381383987584`*^9, 3.819838144753663*^9}, {
   3.8198382402870555`*^9, 3.8198383754614663`*^9}, 3.8200124721278267`*^9, {
   3.820012579354833*^9, 3.8200125899691114`*^9}, 3.8252839339687376`*^9},
 FontSlant->"Italic",ExpressionUUID->"9154bae9-d984-49b3-95f6-67334e99da3c"],

Cell[TextData[{
 StyleBox["Atlantic salmon: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of atlantic salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}, {3.8252743225014563`*^9, 3.8252743303151894`*^9}, 
   3.8252839339687376`*^9},ExpressionUUID->"faed53d2-b1b4-4933-ad9a-\
44bfedb31820"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"repla", " ", "=", " ", "0.3"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662885297171*^9}, {3.8016683902542915`*^9, 
   3.801668392194314*^9}, {3.801668476343513*^9, 3.8016684764529057`*^9}, {
   3.8016685159337964`*^9, 3.801668531426852*^9}, 3.801692415143248*^9, {
   3.8016926196184893`*^9, 3.801692619774764*^9}, {3.801780289233728*^9, 
   3.8017802906278515`*^9}, 3.8033028464480004`*^9, 3.8033032141861067`*^9, {
   3.80339474346602*^9, 3.803394743762943*^9}, {3.8033948509102745`*^9, 
   3.80339485100404*^9}, 3.803397269400152*^9, 3.804343569032516*^9, {
   3.8043441779843903`*^9, 3.8043441785348186`*^9}, {3.804345528212033*^9, 
   3.8043455283191147`*^9}, {3.8043482483389072`*^9, 3.804348250335457*^9}, {
   3.804348999502578*^9, 3.8043489995996523`*^9}, {3.8043490925820007`*^9, 
   3.8043490927291145`*^9}, {3.80451933962536*^9, 3.804519339859774*^9}, {
   3.8045205567782145`*^9, 3.804520557247041*^9}, {3.804521073038145*^9, 
   3.8045210732569275`*^9}, {3.804521152663441*^9, 3.804521152757205*^9}, {
   3.804521464187267*^9, 3.8045214643279123`*^9}, {3.804545874319066*^9, 
   3.8045458744753385`*^9}, {3.8045460890897703`*^9, 
   3.8045460891835356`*^9}, {3.804546190142262*^9, 3.804546190595456*^9}, {
   3.8045868865938334`*^9, 3.8045868868282475`*^9}, {3.8045916336063304`*^9, 
   3.8045916336844664`*^9}, {3.804591811382941*^9, 3.804591811507962*^9}, 
   3.8048513408389482`*^9, {3.804858869583768*^9, 3.8048588697400417`*^9}, {
   3.8048672372703323`*^9, 3.8048672375047445`*^9}, 3.8048969343130455`*^9, {
   3.805017086905365*^9, 3.805017089015106*^9}, {3.805637808410037*^9, 
   3.8056378090038867`*^9}, {3.8056379076532135`*^9, 3.805637931934962*^9}, 
   3.8056379957718706`*^9, 3.806765178486972*^9, {3.806765213084243*^9, 
   3.806765213240518*^9}, {3.8068350921074057`*^9, 3.806835100030402*^9}, {
   3.80683530117915*^9, 3.806835301366681*^9}, {3.8068354114521313`*^9, 
   3.806835412044735*^9}, {3.8068355239091153`*^9, 3.8068355244248266`*^9}, {
   3.8068365357213297`*^9, 3.806836535861978*^9}, 3.8068390799604735`*^9, 
   3.8068396303511086`*^9, {3.807650396298931*^9, 3.8076504016906395`*^9}, {
   3.807650930223965*^9, 3.8076509303489857`*^9}, {3.807651361300071*^9, 
   3.807651361440719*^9}, {3.810037571730356*^9, 3.8100375718274317`*^9}, 
   3.825274293539071*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[17]:=",ExpressionUUID->"e71883ba-93a1-4219-bd68-67879f88fe63"],

Cell[TextData[{
 StyleBox["Chinook salmon: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of chinook salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}, {3.8252743225014563`*^9, 3.8252743449991045`*^9}, {
   3.825274378771273*^9, 3.825274380207303*^9}, 
   3.8252839339697375`*^9},ExpressionUUID->"a78f82bd-044c-47ec-8070-\
7fb0ac92002c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"replc", " ", "=", "0.3"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662885297171*^9}, {3.8016683902542915`*^9, 
   3.801668392194314*^9}, {3.801668476343513*^9, 3.8016684764529057`*^9}, {
   3.8016685159337964`*^9, 3.801668531426852*^9}, 3.801692415143248*^9, {
   3.8016926196184893`*^9, 3.801692619774764*^9}, {3.801780289233728*^9, 
   3.8017802906278515`*^9}, 3.8033028464480004`*^9, 3.8033032141861067`*^9, {
   3.80339474346602*^9, 3.803394743762943*^9}, {3.8033948509102745`*^9, 
   3.80339485100404*^9}, 3.803397269400152*^9, 3.804343569032516*^9, {
   3.8043441779843903`*^9, 3.8043441785348186`*^9}, {3.804345528212033*^9, 
   3.8043455283191147`*^9}, {3.8043482483389072`*^9, 3.804348250335457*^9}, {
   3.804348999502578*^9, 3.8043489995996523`*^9}, {3.8043490925820007`*^9, 
   3.8043490927291145`*^9}, {3.80451933962536*^9, 3.804519339859774*^9}, {
   3.8045205567782145`*^9, 3.804520557247041*^9}, {3.804521073038145*^9, 
   3.8045210732569275`*^9}, {3.804521152663441*^9, 3.804521152757205*^9}, {
   3.804521464187267*^9, 3.8045214643279123`*^9}, {3.804545874319066*^9, 
   3.8045458744753385`*^9}, {3.8045460890897703`*^9, 
   3.8045460891835356`*^9}, {3.804546190142262*^9, 3.804546190595456*^9}, {
   3.8045868865938334`*^9, 3.8045868868282475`*^9}, {3.8045916336063304`*^9, 
   3.8045916336844664`*^9}, {3.804591811382941*^9, 3.804591811507962*^9}, 
   3.8048513408389482`*^9, {3.804858869583768*^9, 3.8048588697400417`*^9}, {
   3.8048672372703323`*^9, 3.8048672375047445`*^9}, 3.8048969343130455`*^9, {
   3.805017086905365*^9, 3.805017089015106*^9}, {3.805637808410037*^9, 
   3.8056378090038867`*^9}, {3.805637839479997*^9, 3.8056378395425076`*^9}, {
   3.805637928829769*^9, 3.805637935794962*^9}, {3.80563799728349*^9, 
   3.8056380004551644`*^9}, {3.8067652166977167`*^9, 3.806765217041522*^9}, {
   3.80683510250356*^9, 3.8068351050467615`*^9}, {3.806835304038997*^9, 
   3.806835304210901*^9}, 3.8068354156513195`*^9, 3.806835530958029*^9, {
   3.8068365390968943`*^9, 3.8068365393781915`*^9}, 3.806839083130948*^9, 
   3.806839633895392*^9, {3.807650404112913*^9, 3.8076504042081175`*^9}, {
   3.8076509324587107`*^9, 3.8076509325837317`*^9}, {3.8076513636442127`*^9, 
   3.807651363784861*^9}, {3.8100375746646338`*^9, 3.810037574761709*^9}, 
   3.825274296807455*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[18]:=",ExpressionUUID->"3570a921-8175-4c5b-ac71-ad5fa82485de"],

Cell[TextData[{
 StyleBox["Chum salmon: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of chum salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}, {3.8252743225014563`*^9, 3.8252743755578337`*^9}, 
   3.8252839339697375`*^9},ExpressionUUID->"2afef52f-60fe-4a17-8f37-\
a8537e5a5833"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"replh", " ", "=", "0.3"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662885297171*^9}, {3.8016683902542915`*^9, 
   3.801668392194314*^9}, {3.801668476343513*^9, 3.8016684764529057`*^9}, {
   3.8016685159337964`*^9, 3.801668531426852*^9}, 3.801692415143248*^9, {
   3.8016926196184893`*^9, 3.801692619774764*^9}, {3.801780289233728*^9, 
   3.8017802906278515`*^9}, 3.8033028464480004`*^9, 3.8033032141861067`*^9, {
   3.80339474346602*^9, 3.803394743762943*^9}, {3.8033948509102745`*^9, 
   3.80339485100404*^9}, 3.803397269400152*^9, 3.804343569032516*^9, {
   3.8043441779843903`*^9, 3.8043441785348186`*^9}, {3.804345528212033*^9, 
   3.8043455283191147`*^9}, {3.8043482483389072`*^9, 3.804348250335457*^9}, {
   3.804348999502578*^9, 3.8043489995996523`*^9}, {3.8043490925820007`*^9, 
   3.8043490927291145`*^9}, {3.80451933962536*^9, 3.804519339859774*^9}, {
   3.8045205567782145`*^9, 3.804520557247041*^9}, {3.804521073038145*^9, 
   3.8045210732569275`*^9}, {3.804521152663441*^9, 3.804521152757205*^9}, {
   3.804521464187267*^9, 3.8045214643279123`*^9}, {3.804545874319066*^9, 
   3.8045458744753385`*^9}, {3.8045460890897703`*^9, 
   3.8045460891835356`*^9}, {3.804546190142262*^9, 3.804546190595456*^9}, {
   3.8045868865938334`*^9, 3.8045868868282475`*^9}, {3.8045916336063304`*^9, 
   3.8045916336844664`*^9}, {3.804591811382941*^9, 3.804591811507962*^9}, 
   3.8048513408389482`*^9, {3.804858869583768*^9, 3.8048588697400417`*^9}, {
   3.8048672372703323`*^9, 3.8048672375047445`*^9}, 3.8048969343130455`*^9, {
   3.805017086905365*^9, 3.805017089015106*^9}, {3.805637808410037*^9, 
   3.8056378090038867`*^9}, {3.805637843341254*^9, 3.8056378458573027`*^9}, 
   3.8056379494388447`*^9, 3.8056380018847294`*^9, {3.806765220245162*^9, 
   3.8067652204639473`*^9}, 3.806835111157448*^9, 3.806835309447442*^9, 
   3.8068354174984727`*^9, 3.8068355355212865`*^9, 3.8068365442259912`*^9, 
   3.8068390876214557`*^9, 3.806839636779994*^9, {3.807650406333473*^9, 
   3.8076504064428663`*^9}, {3.807650934349653*^9, 3.8076509344590454`*^9}, {
   3.8076513660875263`*^9, 3.807651366228174*^9}, {3.810037576870345*^9, 
   3.81003757713455*^9}, 3.8252742998186617`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[19]:=",ExpressionUUID->"8084d100-1196-49fa-a6db-fe6657cbfd2a"],

Cell[TextData[{
 StyleBox["Coho salmon: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of coho salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}, {3.8252743225014563`*^9, 3.8252743716249313`*^9}, 
   3.8252839339697375`*^9},ExpressionUUID->"f95e3d40-404c-4bdd-acaf-\
3e0d8fa31c45"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"replo", " ", "=", "0.3"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662885297171*^9}, {3.8016683902542915`*^9, 
   3.801668392194314*^9}, {3.801668476343513*^9, 3.8016684764529057`*^9}, {
   3.8016685159337964`*^9, 3.801668531426852*^9}, 3.801692415143248*^9, {
   3.8016926196184893`*^9, 3.801692619774764*^9}, {3.801780289233728*^9, 
   3.8017802906278515`*^9}, 3.8033028464480004`*^9, 3.8033032141861067`*^9, {
   3.80339474346602*^9, 3.803394743762943*^9}, {3.8033948509102745`*^9, 
   3.80339485100404*^9}, 3.803397269400152*^9, 3.804343569032516*^9, {
   3.8043441779843903`*^9, 3.8043441785348186`*^9}, {3.804345528212033*^9, 
   3.8043455283191147`*^9}, {3.8043482483389072`*^9, 3.804348250335457*^9}, {
   3.804348999502578*^9, 3.8043489995996523`*^9}, {3.8043490925820007`*^9, 
   3.8043490927291145`*^9}, {3.80451933962536*^9, 3.804519339859774*^9}, {
   3.8045205567782145`*^9, 3.804520557247041*^9}, {3.804521073038145*^9, 
   3.8045210732569275`*^9}, {3.804521152663441*^9, 3.804521152757205*^9}, {
   3.804521464187267*^9, 3.8045214643279123`*^9}, {3.804545874319066*^9, 
   3.8045458744753385`*^9}, {3.8045460890897703`*^9, 
   3.8045460891835356`*^9}, {3.804546190142262*^9, 3.804546190595456*^9}, {
   3.8045868865938334`*^9, 3.8045868868282475`*^9}, {3.8045916336063304`*^9, 
   3.8045916336844664`*^9}, {3.804591811382941*^9, 3.804591811507962*^9}, 
   3.8048513408389482`*^9, {3.804858869583768*^9, 3.8048588697400417`*^9}, {
   3.8048672372703323`*^9, 3.8048672375047445`*^9}, 3.8048969343130455`*^9, {
   3.805017086905365*^9, 3.805017089015106*^9}, {3.805637808410037*^9, 
   3.8056378090038867`*^9}, {3.80563784962342*^9, 3.805637850060994*^9}, {
   3.8056379572848544`*^9, 3.805637967093734*^9}, 3.8056380038482428`*^9, 
   3.8067651675468597`*^9, {3.8067652233706646`*^9, 3.80676522358945*^9}, 
   3.806835112673317*^9, 3.806835311760007*^9, 3.806835419104725*^9, 
   3.806835539339687*^9, 3.806836545726241*^9, 3.8068390894028497`*^9, 
   3.8068396390947533`*^9, {3.8076504084584374`*^9, 3.807650408599086*^9}, {
   3.807650936540043*^9, 3.8076509366806912`*^9}, {3.807651368228509*^9, 
   3.807651368369157*^9}, {3.8100375795774465`*^9, 3.810037579744576*^9}, {
   3.825274302466603*^9, 3.8252743026307707`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[20]:=",ExpressionUUID->"c1974cde-0bee-4337-89d4-4d8be79bede4"],

Cell[TextData[{
 StyleBox["Pink salmon: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of pink salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}, {3.8252743225014563`*^9, 3.8252743674568014`*^9}, 
   3.8252839339697375`*^9},ExpressionUUID->"f1a5b7b7-f382-43e1-a711-\
1236b62de146"],

Cell[BoxData[
 RowBox[{
  RowBox[{"replp", " ", "=", "0.3"}], " ", ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662888928058*^9}, {3.8016683952885675`*^9, 
   3.8016683957417665`*^9}, {3.801668478875883*^9, 3.801668478985276*^9}, {
   3.8016685230652122`*^9, 3.8016685337553577`*^9}, 3.8016924179886847`*^9, {
   3.801692616946184*^9, 3.8016926170868325`*^9}, {3.801780293582797*^9, 
   3.8017802946923575`*^9}, 3.8033028505850444`*^9, {3.8033032081382475`*^9, 
   3.8033032184211392`*^9}, 3.80339474828187*^9, {3.803394853256654*^9, 
   3.8033948533973007`*^9}, 3.8033972714877625`*^9, {3.8043435722129936`*^9, 
   3.8043435734429483`*^9}, {3.8043441746958294`*^9, 
   3.8043441752562647`*^9}, {3.8043455309101295`*^9, 3.804345531017213*^9}, {
   3.80434825300554*^9, 3.8043482532307134`*^9}, {3.8043490017373157`*^9, 
   3.8043490018544083`*^9}, {3.8043490949148126`*^9, 
   3.8043490950228963`*^9}, {3.804519342578964*^9, 3.80451934279775*^9}, {
   3.804520559891337*^9, 3.80452056018826*^9}, {3.804521075397897*^9, 
   3.804521075741864*^9}, {3.804521154945324*^9, 3.804521155070345*^9}, {
   3.8045214667892885`*^9, 3.804521466896373*^9}, {3.804545877273263*^9, 
   3.804545877492049*^9}, {3.8045460915435076`*^9, 3.804546091652898*^9}, {
   3.8045461863758335`*^9, 3.8045461875168595`*^9}, {3.8045868894228296`*^9, 
   3.804586889625988*^9}, {3.8045916357474985`*^9, 3.804591635841265*^9}, {
   3.8045918139304185`*^9, 3.804591814102498*^9}, 3.8048513430267563`*^9, {
   3.804858875065585*^9, 3.804858875190604*^9}, {3.804867240348963*^9, 
   3.8048672406146297`*^9}, 3.804896936438388*^9, {3.805017091984372*^9, 
   3.805017093687793*^9}, {3.805637855297874*^9, 3.805637855782327*^9}, {
   3.805637981691862*^9, 3.8056380055232553`*^9}, 3.8067651703906827`*^9, {
   3.8067652262617545`*^9, 3.80676522654305*^9}, 3.806835114407971*^9, 
   3.8068353134634132`*^9, 3.806835420761252*^9, 3.806835542934036*^9, 
   3.806836548351675*^9, 3.806839091274314*^9, 3.806839641073295*^9, {
   3.807650410833828*^9, 3.807650410974477*^9}, {3.807650940681354*^9, 
   3.807650940853258*^9}, {3.807651370667987*^9, 3.807651370793008*^9}, {
   3.810037582324579*^9, 3.8100375824817*^9}, 3.8252743060382423`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[21]:=",ExpressionUUID->"8416828b-6e0d-4043-b421-691ce31c4cb1"],

Cell[TextData[{
 StyleBox["Sockeye salmon: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of sockeye salmon"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}, {3.8252743225014563`*^9, 3.825274362599167*^9}, 
   3.8252839339697375`*^9},ExpressionUUID->"23007b82-697c-4d8e-b7be-\
e0fc0f90657b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"repls", " ", "=", "0.3"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662888928058*^9}, {3.8016683952885675`*^9, 
   3.8016683957417665`*^9}, {3.801668478875883*^9, 3.801668478985276*^9}, {
   3.8016685230652122`*^9, 3.8016685337553577`*^9}, 3.8016924179886847`*^9, {
   3.801692616946184*^9, 3.8016926170868325`*^9}, {3.801780293582797*^9, 
   3.8017802946923575`*^9}, 3.8033028505850444`*^9, {3.8033032081382475`*^9, 
   3.8033032184211392`*^9}, 3.80339474828187*^9, {3.803394853256654*^9, 
   3.8033948533973007`*^9}, 3.8033972714877625`*^9, {3.8043435722129936`*^9, 
   3.8043435734429483`*^9}, {3.8043441746958294`*^9, 
   3.8043441752562647`*^9}, {3.8043455309101295`*^9, 3.804345531017213*^9}, {
   3.80434825300554*^9, 3.8043482532307134`*^9}, {3.8043490017373157`*^9, 
   3.8043490018544083`*^9}, {3.8043490949148126`*^9, 
   3.8043490950228963`*^9}, {3.804519342578964*^9, 3.80451934279775*^9}, {
   3.804520559891337*^9, 3.80452056018826*^9}, {3.804521075397897*^9, 
   3.804521075741864*^9}, {3.804521154945324*^9, 3.804521155070345*^9}, {
   3.8045214667892885`*^9, 3.804521466896373*^9}, {3.804545877273263*^9, 
   3.804545877492049*^9}, {3.8045460915435076`*^9, 3.804546091652898*^9}, {
   3.8045461863758335`*^9, 3.8045461875168595`*^9}, {3.8045868894228296`*^9, 
   3.804586889625988*^9}, {3.8045916357474985`*^9, 3.804591635841265*^9}, {
   3.8045918139304185`*^9, 3.804591814102498*^9}, 3.8048513430267563`*^9, {
   3.804858875065585*^9, 3.804858875190604*^9}, {3.804867240348963*^9, 
   3.8048672406146297`*^9}, 3.804896936438388*^9, {3.805017091984372*^9, 
   3.805017093687793*^9}, {3.805637855297874*^9, 3.8056378641787643`*^9}, {
   3.805637992675209*^9, 3.805638007096881*^9}, 3.8067651878486977`*^9, {
   3.8067652292934923`*^9, 3.8067652301061225`*^9}, 3.8068351161123276`*^9, 
   3.806835315195705*^9, 3.806835422107489*^9, 3.8068355468139415`*^9, 
   3.8068365500394573`*^9, 3.806839094581896*^9, 3.8068396437303743`*^9, {
   3.807650413052949*^9, 3.8076504132248526`*^9}, {3.807650943384931*^9, 
   3.8076509434943247`*^9}, {3.807651372949619*^9, 3.8076513730277567`*^9}, {
   3.810037584854542*^9, 3.8100375850116634`*^9}, 3.825274308961441*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[22]:=",ExpressionUUID->"917179e3-d8df-4f69-a8d3-384801ef2ab8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.5 Price Elasticity of Supply", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, {3.81967219811668*^9, 3.819672213143815*^9}, {
   3.819672363407755*^9, 3.819672372555518*^9}, 3.8196725593450384`*^9, {
   3.8198143101346893`*^9, 3.8198143131120086`*^9}, {3.8198143634432487`*^9, 
   3.8198143660582876`*^9}, 
   3.8252839339697375`*^9},ExpressionUUID->"60d1625c-38c8-4333-b500-\
d6f0248de0dc"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate and Interviews with \
Industry Participants.",
 FontSize->12]], "Text",
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725593450384`*^9, 3.8200124748939843`*^9, {3.8200126204719076`*^9, 
   3.820012620846199*^9}, 3.8252839339707084`*^9},
 FontSlant->"Italic",ExpressionUUID->"c218cfaf-f121-46c8-84af-6b36366766ed"],

Cell[TextData[StyleBox["U.S. production of Atlantic salmon",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.8249805094257298`*^9, 3.8249805103694663`*^9}, {
   3.8252743961392064`*^9, 3.825274409012866*^9}, 
   3.8252839339707084`*^9},ExpressionUUID->"e99c9f51-317a-47f6-99b0-\
d273b0ef4e49"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eau", " ", "=", "5.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, 3.8048513547315273`*^9, {
   3.8048597028089485`*^9, 3.8048597031058826`*^9}, 3.8050172286041574`*^9, {
   3.806765235780514*^9, 3.806765235889906*^9}, {3.810037587906911*^9, 
   3.8100375899544992`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[23]:=",ExpressionUUID->"0e61cea0-3282-45a7-bd8e-9e8e785d69eb"],

Cell[TextData[StyleBox["U.S. landings of chinook salmon",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.8249805094257298`*^9, 3.8249805103694663`*^9}, {
   3.8252743961392064`*^9, 3.8252744205365267`*^9}, 
   3.8252839339707084`*^9},ExpressionUUID->"4f913130-b827-4a8a-9386-\
ea8cf55ed4a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ecd", " ", "=", "2.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8048513547315273`*^9, 
   3.804851365641842*^9}, {3.8048597057626595`*^9, 3.804859706091468*^9}, 
   3.8050172421063824`*^9, {3.8067652386447334`*^9, 3.8067652387541256`*^9}, {
   3.8100375927016315`*^9, 3.8100375927606773`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[24]:=",ExpressionUUID->"daaf0596-c33a-4587-81b3-e028c2d51607"],

Cell[TextData[StyleBox["U.S. landings of chum salmon",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.8249805094257298`*^9, 3.8249805103694663`*^9}, {
   3.8252743961392064`*^9, 3.8252744303479114`*^9}, 
   3.8252839339707084`*^9},ExpressionUUID->"7f94b918-9475-41a9-affc-\
4976377ce143"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ehd", " ", "=", "2.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8048513547315273`*^9, 
   3.8048513680171757`*^9}, {3.804859708529451*^9, 3.8048597088263845`*^9}, {
   3.806765241630703*^9, 3.806765241927625*^9}, {3.810037595448764*^9, 
   3.8100375955568476`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[25]:=",ExpressionUUID->"61c0c99e-cd47-4677-a666-19e1cd12c8f5"],

Cell[TextData[StyleBox["U.S. landings of coho salmon",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.8249805094257298`*^9, 3.8249805103694663`*^9}, {
   3.8252743961392064`*^9, 3.825274438668157*^9}, 
   3.8252839339707084`*^9},ExpressionUUID->"ad365565-264d-4c4f-a2c6-\
1799b8ac85b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eod", " ", "=", "2.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8048513547315273`*^9, 
   3.8048513702674923`*^9}, {3.804859712264567*^9, 3.8048597125615005`*^9}, 
   3.8050172630810432`*^9, {3.8067652445221033`*^9, 3.8067652448971643`*^9}, {
   3.8100375981268425`*^9, 3.810037598264949*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[26]:=",ExpressionUUID->"c77200e6-564e-48a4-9d46-75e553d26040"],

Cell[TextData[StyleBox["U.S. landings of pink salmon",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.8249805094257298`*^9, 3.8249805103694663`*^9}, {
   3.8252743961392064`*^9, 3.825274409012866*^9}, {3.8252744435438614`*^9, 
   3.825274446754245*^9}, 
   3.8252839339707084`*^9},ExpressionUUID->"90aec3ec-d5be-42a8-b149-\
46cf7864dc69"],

Cell[BoxData[
 RowBox[{
  RowBox[{"epd", " ", "=", "5.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8048513547315273`*^9, 
   3.8048513702674923`*^9}, {3.804859712264567*^9, 3.8048597125615005`*^9}, {
   3.8050172630810432`*^9, 3.805017275067389*^9}, {3.806765247101954*^9, 
   3.8067652473207393`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[27]:=",ExpressionUUID->"91ca236f-1de5-4270-b969-bd269e28ac56"],

Cell[TextData[StyleBox["U.S. landings of sockeye salmon",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.8249805094257298`*^9, 3.8249805103694663`*^9}, {
   3.8252743961392064`*^9, 3.825274409012866*^9}, {3.8252744519762154`*^9, 
   3.8252744546001487`*^9}, 
   3.8252839339707084`*^9},ExpressionUUID->"7d438e40-58be-4399-a644-\
a94a399fb0d8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"esd", " ", "=", "2.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8048513547315273`*^9, 
   3.8048513702674923`*^9}, {3.804859712264567*^9, 3.8048597125615005`*^9}, {
   3.8050172630810432`*^9, 3.8050172793315725`*^9}, {3.806765249883895*^9, 
   3.806765249993287*^9}, {3.810037600814928*^9, 3.8100376015334854`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[28]:=",ExpressionUUID->"3e57279e-e33a-4cae-870a-123d34efdc5f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.6 Conversion Factors", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, {3.81967219811668*^9, 3.819672213143815*^9}, {
   3.819672363407755*^9, 3.819672372555518*^9}, {3.8196724504932003`*^9, 
   3.8196724570907135`*^9}, 3.8196725668572683`*^9, {3.819814317458398*^9, 
   3.8198143176155205`*^9}, {3.819814368847461*^9, 3.819814369193731*^9}, {
   3.8199024597734833`*^9, 3.819902461929121*^9}, 
   3.8252839339717245`*^9},ExpressionUUID->"cecbba16-d571-4f97-aaa1-\
2afca9e7ab68"],

Cell[TextData[StyleBox["Source: Conversion factors were obtained from NOAA \
Fisheries",
 FontSize->12]], "Text",
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725593450384`*^9, 3.8198384238111687`*^9, {3.819839089463401*^9, 
   3.8198391080298843`*^9}, {3.8198393115996747`*^9, 3.819839330504422*^9}, 
   3.8252839339717245`*^9},
 FontSlant->"Italic",ExpressionUUID->"50805045-734f-43fa-a736-3bf97da70c58"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cr", " ", "=", " ", "1.52"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8045456043635373`*^9, 
   3.804545605751848*^9}, {3.804851384410106*^9, 3.8048514151977367`*^9}, {
   3.804859716468526*^9, 3.8048597167967157`*^9}, {3.804859952266411*^9, 
   3.8048599526102223`*^9}, 3.804881198177019*^9, {3.8050171468444257`*^9, 
   3.8050171533454947`*^9}, 3.8056457937164583`*^9, {3.806765277725256*^9, 
   3.806765291681635*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[29]:=",ExpressionUUID->"53379da6-b7f9-4200-b622-21275c340c98"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2. Data Inputs",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.795452962713849*^9}, {
  3.8196715794204283`*^9, 3.8196715805723763`*^9}, {3.819672652231064*^9, 
  3.819672658049889*^9}},ExpressionUUID->"42640f35-dcc0-471f-8c42-\
243e4168908f"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.1 U.S. Landings Quantities and Prices", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672709332239*^9}, 
   3.819814602882104*^9, 3.8249807397550435`*^9, 
   3.8252839339717245`*^9},ExpressionUUID->"f4fd8f61-0f63-41cb-a668-\
bbd4ef6d9901"],

Cell[TextData[StyleBox["Source: National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries).\
\[NonBreakingSpace]Fisheries of the United States 2018. Current Fishery \
Statistics No. 2018. U.S. Department of Commerce. Silver Spring MD:\
\[NonBreakingSpace]NOAA,\[NonBreakingSpace]February 2020. \
https://www.fisheries.noaa.gov/resource/document/fisheries-united-states-2018-\
report.\[NonBreakingSpace]",
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, 
   3.819814602882104*^9, {3.8198155788251867`*^9, 3.8198155811910124`*^9}, 
   3.8249807397550435`*^9, 3.8252839339717245`*^9},
 FontSize->12,ExpressionUUID->"539de5b1-ab7d-4914-adc5-12aa73a8f409"],

Cell[TextData[StyleBox["Chinook ",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.7997922037144547`*^9, 
   3.799792207899268*^9}, {3.805710690264936*^9, 3.8057106905149765`*^9}, {
   3.819814387925336*^9, 3.819814398951932*^9}, 3.819814602882104*^9, {
   3.8249806046378546`*^9, 3.824980605591595*^9}, 3.8249807397550435`*^9, {
   3.8252745578085766`*^9, 3.825274562513236*^9}, 
   3.8252839339717245`*^9},ExpressionUUID->"60181d41-91aa-4d8f-85e3-\
df4f6b94fedb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qcdu0", " ", "=", "3281000.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.8048514568888445`*^9, {
   3.804859007321229*^9, 3.804859009274654*^9}, 3.8050173371426563`*^9, {
   3.805022177647732*^9, 3.8050221804450397`*^9}, {3.8067653602003455`*^9, 
   3.806765360340994*^9}, {3.8067654321826496`*^9, 3.806765433604763*^9}, {
   3.806831973009885*^9, 3.806831975213378*^9}, {3.806834150905658*^9, 
   3.8068341516085234`*^9}, {3.825274586464492*^9, 3.825274587014894*^9}, 
   3.825282791794056*^9, 3.825283933972732*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[30]:=",ExpressionUUID->"4ecde827-d0a5-44ad-8f2a-1ab84264d7b8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pcdu0", " ", "=", "11.7482"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.8048516736382985`*^9}, {3.8048592982724123`*^9, 
   3.80485930216366*^9}, 3.8050178642343397`*^9, {3.8050225293919544`*^9, 
   3.8050225352691364`*^9}, 3.8067666040100727`*^9, {3.806766772356678*^9, 
   3.806766773700653*^9}, 3.8068363234964*^9, {3.816947657772827*^9, 
   3.816947712469644*^9}, {3.8169480669777985`*^9, 3.8169480692187767`*^9}, {
   3.8252745904995904`*^9, 3.8252745929014025`*^9}, 3.825282791794056*^9, 
   3.825283933972732*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[31]:=",ExpressionUUID->"fc8eb168-ab40-4abf-a2f7-a6c4a5fe0448"],

Cell[TextData[StyleBox["Chum",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.7997922037144547`*^9, 
   3.799792207899268*^9}, {3.805710690264936*^9, 3.8057106905149765`*^9}, {
   3.819814387925336*^9, 3.819814398951932*^9}, 3.819814602882104*^9, {
   3.8249806046378546`*^9, 3.824980605591595*^9}, 3.8249807397550435`*^9, {
   3.8252745578085766`*^9, 3.825274562513236*^9}, {3.8252745995754986`*^9, 
   3.82527460004188*^9}, 
   3.825283933972732*^9},ExpressionUUID->"f3cc00d0-bddc-4634-a1bf-\
24b3f621029a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhdu0", " ", "=", "62944000.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.8048514589516478`*^9, {
   3.8048590130252295`*^9, 3.804859016210842*^9}, {3.805022188118102*^9, 
   3.805022192057477*^9}, {3.8067653630914536`*^9, 3.806765374877102*^9}, {
   3.8067654409983096`*^9, 3.8067654435924873`*^9}, {3.80683197869833*^9, 
   3.8068319804798775`*^9}, {3.8068341555441885`*^9, 
   3.8068341560006456`*^9}, {3.8252746032363043`*^9, 3.8252746040018835`*^9}, 
   3.825282791794056*^9, 3.825283933973711*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[32]:=",ExpressionUUID->"6682d775-94cf-4a53-8c9a-592c4584bd42"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"phdu0", " ", "=", "1.7379"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.8048516760920506`*^9}, {3.804859306715953*^9, 
   3.804859310810358*^9}, {3.8050225406447134`*^9, 3.8050225457625327`*^9}, {
   3.806766736341509*^9, 3.8067667367165713`*^9}, {3.8067667820154457`*^9, 
   3.806766782437388*^9}, 3.8068363282940702`*^9, {3.8169479567556615`*^9, 
   3.81694801044468*^9}, {3.8252746122361956`*^9, 3.825274615508688*^9}, 
   3.8252827917950153`*^9, 3.825283933973711*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[33]:=",ExpressionUUID->"f3e5d568-3d3d-4b18-837d-13bce03e24d6"],

Cell[TextData[StyleBox["Coho",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.7997922037144547`*^9, 
   3.799792207899268*^9}, {3.805710690264936*^9, 3.8057106905149765`*^9}, {
   3.819814387925336*^9, 3.819814398951932*^9}, 3.819814602882104*^9, {
   3.8249806046378546`*^9, 3.824980605591595*^9}, 3.8249807397550435`*^9, {
   3.8252745578085766`*^9, 3.825274562513236*^9}, {3.8252745995754986`*^9, 
   3.82527462330665*^9}, 
   3.825283933973711*^9},ExpressionUUID->"3b24adc2-24ff-40aa-b60d-\
0dfc8d6c04d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qodu0", " ", "=", "13104000.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.804851461217606*^9, {
   3.8048590263373966`*^9, 3.8048590278376274`*^9}, 3.80501735923965*^9, {
   3.805022199245713*^9, 3.805022203090089*^9}, {3.8067653684373026`*^9, 
   3.806765377377513*^9}, {3.806765449482295*^9, 3.806765452031381*^9}, {
   3.806831983042804*^9, 3.8068319851694245`*^9}, {3.8068341596891637`*^9, 
   3.8068341600912056`*^9}, {3.825274626599163*^9, 3.825274626810354*^9}, 
   3.8252827917950153`*^9, 3.825283933974738*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[34]:=",ExpressionUUID->"aba9680d-c0d7-4bcf-aed7-0787606061b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"podu0", " ", "=", "2.8403"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.804851678024618*^9}, {3.804859329331564*^9, 
   3.8048593352231383`*^9}, {3.804859838203453*^9, 3.804859839094244*^9}, 
   3.805017872688827*^9, {3.8050225519510365`*^9, 3.8050225559089317`*^9}, {
   3.8067667391388454`*^9, 3.8067667394201427`*^9}, {3.8067667914706063`*^9, 
   3.8067667920488276`*^9}, 3.8068363339055953`*^9, {3.825274711446453*^9, 
   3.825274713667183*^9}, 3.8252827917950153`*^9, 3.825283933974738*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[35]:=",ExpressionUUID->"a81323c0-f581-4d29-94ee-cd5c44c14b81"],

Cell[TextData[StyleBox["Sockeye",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.7997922037144547`*^9, 
   3.799792207899268*^9}, {3.805710690264936*^9, 3.8057106905149765`*^9}, {
   3.819814387925336*^9, 3.819814398951932*^9}, 3.819814602882104*^9, {
   3.8249806046378546`*^9, 3.824980605591595*^9}, 3.8249807397550435`*^9, {
   3.8252745578085766`*^9, 3.825274562513236*^9}, {3.8252745995754986`*^9, 
   3.82527462330665*^9}, {3.8252746639948626`*^9, 3.825274665265853*^9}, 
   3.825283933974738*^9},ExpressionUUID->"b21e1c34-a206-4e4a-b34c-\
7976f272bbd5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdu0", " ", "=", "120339000.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.804851461217606*^9, {
   3.8048590263373966`*^9, 3.8048590278376274`*^9}, {3.80501735923965*^9, 
   3.8050173703386555`*^9}, {3.8050222214856396`*^9, 3.805022223720377*^9}, {
   3.806765384707364*^9, 3.8067653848011293`*^9}, {3.806765464690223*^9, 
   3.806765467284401*^9}, {3.806831993951889*^9, 3.8068319968119383`*^9}, {
   3.8068341672806573`*^9, 3.806834167580118*^9}, {3.825274741437603*^9, 
   3.8252747415517063`*^9}, 3.8252827917959924`*^9, 3.8252839339757137`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[36]:=",ExpressionUUID->"c3fb319a-7734-4450-9427-c60dc29e2cdb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"psdu0", " ", "=", "2.9210"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.804851678024618*^9}, {3.804859329331564*^9, 
   3.8048593352231383`*^9}, {3.804859838203453*^9, 3.804859839094244*^9}, {
   3.805017872688827*^9, 3.805017884237563*^9}, {3.805018062809467*^9, 
   3.805018065512958*^9}, {3.805022569645549*^9, 3.8050225746075516`*^9}, {
   3.8067667440081806`*^9, 3.806766744414499*^9}, {3.806766807758768*^9, 
   3.806766808180714*^9}, {3.8068363432683983`*^9, 3.806836343377792*^9}, {
   3.825274761035693*^9, 3.8252747627199917`*^9}, 3.8252827917959924`*^9, 
   3.8252839339757137`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[37]:=",ExpressionUUID->"977552a6-aaf5-4f0f-b57e-a052f10a9db2"],

Cell[TextData[StyleBox["Pink",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.7997922037144547`*^9, 
   3.799792207899268*^9}, {3.805710690264936*^9, 3.8057106905149765`*^9}, {
   3.819814387925336*^9, 3.819814398951932*^9}, 3.819814602882104*^9, {
   3.8249806046378546`*^9, 3.824980605591595*^9}, 3.8249807397550435`*^9, {
   3.8252745578085766`*^9, 3.825274562513236*^9}, {3.8252745995754986`*^9, 
   3.82527462330665*^9}, {3.825274668170102*^9, 3.825274668558381*^9}, 
   3.8252839339757137`*^9},ExpressionUUID->"d56df26b-671f-4f02-b25c-\
d14637634741"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qpdu0", " ", "=", "61590000.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.804851461217606*^9, {
   3.8048590263373966`*^9, 3.8048590278376274`*^9}, {3.80501735923965*^9, 
   3.805017366961873*^9}, {3.8050222146072206`*^9, 3.805022216810708*^9}, {
   3.8067653820350466`*^9, 3.8067653821756945`*^9}, {3.806765457203483*^9, 
   3.806765460579043*^9}, {3.806831988123044*^9, 3.806831991607874*^9}, {
   3.8068341635085025`*^9, 3.8068341639005423`*^9}, {3.8252746444628277`*^9, 
   3.8252746458018885`*^9}, 3.8252827917959924`*^9, 3.8252839339757137`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[38]:=",ExpressionUUID->"1f90fa36-e1a2-4518-ba97-444f0e6e14ef"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ppdu0", " ", "=", "0.9970"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.804851678024618*^9}, {3.804859329331564*^9, 
   3.8048593352231383`*^9}, {3.804859838203453*^9, 3.804859839094244*^9}, {
   3.805017872688827*^9, 3.80501788154963*^9}, {3.805022560685978*^9, 
   3.805022565829212*^9}, {3.806766741409026*^9, 3.806766741659068*^9}, {
   3.8067668001937246`*^9, 3.8067668007094355`*^9}, 3.806836338531248*^9, {
   3.8252747507027245`*^9, 3.8252747540583196`*^9}, 3.825282791796998*^9, 
   3.825283933976774*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[39]:=",ExpressionUUID->"39683c2b-cd55-4bab-afc2-f50ad5743fba"],

Cell[TextData[StyleBox["Atlantic",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.7997922037144547`*^9, 
   3.799792207899268*^9}, {3.805710690264936*^9, 3.8057106905149765`*^9}, {
   3.819814387925336*^9, 3.819814398951932*^9}, 3.819814602882104*^9, {
   3.8249806046378546`*^9, 3.824980605591595*^9}, 3.8249807397550435`*^9, {
   3.8252745578085766`*^9, 3.825274562513236*^9}, {3.8252745995754986`*^9, 
   3.82527462330665*^9}, {3.8252746607383647`*^9, 3.8252746616450567`*^9}, 
   3.825283933976774*^9},ExpressionUUID->"3b502147-1b24-4336-86aa-\
e76f3083ec61"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadu0", " ", "=", "18003000.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.8048514547791586`*^9, {
   3.804858998862688*^9, 3.8048590002413826`*^9}, 3.8050173226703215`*^9, {
   3.8050221654427185`*^9, 3.8050221715374117`*^9}, 3.8067653569966908`*^9, {
   3.806765406997158*^9, 3.8067654255226603`*^9}, {3.8068319989216657`*^9, 
   3.8068320015627327`*^9}, {3.806834147404319*^9, 3.80683414798254*^9}, {
   3.8252747676037655`*^9, 3.8252747676878614`*^9}, 3.825282791796998*^9, 
   3.825283933976774*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[40]:=",ExpressionUUID->"400c8e39-93cb-4fef-a9fb-41930d195d3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"padu0", " ", "=", "4.4179"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, 
   3.8048516657287436`*^9, {3.804859289924417*^9, 3.804859293881085*^9}, 
   3.8050178536388817`*^9, {3.8050225182495184`*^9, 3.8050225241723566`*^9}, 
   3.8067662214541273`*^9, {3.806766763184125*^9, 3.8067667642114534`*^9}, 
   3.8068363150159225`*^9, {3.825274769814509*^9, 3.8252747745761557`*^9}, 
   3.825282791796998*^9, 3.825283933977741*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[41]:=",ExpressionUUID->"cfe43c25-be78-4227-bac0-674e47880d70"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.2 U.S. Processing Production Quantities and \
Prices", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672733348008*^9}, {
   3.8196727961837325`*^9, 3.8196728038250227`*^9}, 3.819814751753172*^9, 
   3.8249808810930777`*^9, 
   3.825283933977741*^9},ExpressionUUID->"1435c260-9585-4f19-9653-\
05d7d7af47d6"],

Cell[TextData[StyleBox["Sources:\n National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries).\
\[NonBreakingSpace]Fisheries of the United States 2018. Current Fishery \
Statistics No. 2018. U.S. Department of Commerce. Silver Spring MD:\
\[NonBreakingSpace]NOAA,\[NonBreakingSpace]February 2020. \
https://www.fisheries.noaa.gov/resource/document/fisheries-united-states-2018-\
report.\[NonBreakingSpace] \n\nNational Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries). NOAA \
Processed Products database. Accessed September 1, \
2020.https://www.fisheries.noaa.gov/foss/f?p=215:3:5412288074334::NO:::",
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, {
   3.819814602882104*^9, 3.819814670599902*^9}, {3.8198147375350885`*^9, 
   3.819814751753172*^9}, {3.8198155956591797`*^9, 3.8198155972494073`*^9}, 
   3.8249808810930777`*^9, 3.825283933977741*^9, 3.8254134777046957`*^9},
 FontSize->12,ExpressionUUID->"53a3216b-4452-4e14-bf79-1b874933f265"],

Cell[TextData[StyleBox["Processed Chinook",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9, {3.824980768462393*^9, 3.824980769184957*^9}, 
   3.8249808810930777`*^9, {3.8252748152865276`*^9, 3.825274816511503*^9}, 
   3.825283933977741*^9},ExpressionUUID->"0108ff7c-6b7d-467d-9429-\
f60e5ce3f0a6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qcdp0", " ", "=", "347907.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.804851484318285*^9, {3.8048590605689173`*^9, 3.8048590667730417`*^9}, 
   3.8050173975775113`*^9, 3.805022232784355*^9, 3.8050224930197735`*^9, {
   3.8050232180903654`*^9, 3.805023241085371*^9}, {3.805023632655447*^9, 
   3.8050236356424956`*^9}, 3.8056458386741605`*^9, {3.805645871183111*^9, 
   3.8056458757007465`*^9}, {3.8067656082497215`*^9, 3.806765608366813*^9}, {
   3.8067656810295963`*^9, 3.806765683116229*^9}, {3.806834183944996*^9, 
   3.8068341845202856`*^9}, {3.8252748427807302`*^9, 3.825274844365986*^9}, 
   3.8252827802257833`*^9, 3.8252839339787464`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[42]:=",ExpressionUUID->"6561412e-06fd-4c57-ae93-47270a6df98e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pcdp0", " ", "=", "31.9409"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.804343942476156*^9, 3.804343949889929*^9}, {
   3.8045210306472683`*^9, 3.8045210368829145`*^9}, {3.804587081702225*^9, 
   3.8045870826558285`*^9}, {3.804851759302089*^9, 3.8048517613180237`*^9}, 
   3.804865883950451*^9, 3.805018154986638*^9, 3.805022789736844*^9, {
   3.8050232745594635`*^9, 3.805023293624789*^9}, {3.80566562639616*^9, 
   3.8056656278964133`*^9}, {3.8067672129167376`*^9, 3.8067672310607324`*^9}, 
   3.8068363801311255`*^9, {3.825274884951248*^9, 3.825274887522236*^9}, 
   3.8252827802257833`*^9, 3.8252839339787464`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[43]:=",ExpressionUUID->"09c8ff30-42fd-4efc-951c-d2cfbedd4dcc"],

Cell[TextData[StyleBox["Processed Chum",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9, {3.824980768462393*^9, 3.824980769184957*^9}, 
   3.8249808810930777`*^9, {3.8252748152865276`*^9, 3.825274829646615*^9}, 
   3.8252839339787464`*^9},ExpressionUUID->"804d554e-5318-41d2-8646-\
4e9771c33e7b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhdp0", " ", "=", "5872041.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.804851485974779*^9, {3.8048590710549765`*^9, 3.804859073899182*^9}, 
   3.80502223606614*^9, 3.805022494144955*^9, {3.8050232199500046`*^9, 
   3.8050232477426076`*^9}, 3.805645842097738*^9, {3.805645882358735*^9, 
   3.8056458856249104`*^9}, {3.8067656106425915`*^9, 
   3.8067656109668427`*^9}, {3.8067656880200605`*^9, 3.806765692106251*^9}, {
   3.8068341871273413`*^9, 3.806834187454748*^9}, 3.8252748477195377`*^9, 
   3.8252827802268124`*^9, 3.825283933979728*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[44]:=",ExpressionUUID->"abd93098-806c-4525-be8c-4d88e9e76f05"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"phdp0", " ", "=", "7.7801"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.804343942476156*^9, 3.804343949889929*^9}, {
   3.8045210306472683`*^9, 3.8045210368829145`*^9}, {3.804587081702225*^9, 
   3.8045870826558285`*^9}, 3.8048517637402706`*^9, 3.804865889483494*^9, 
   3.8050227919715805`*^9, {3.8050232755596113`*^9, 3.805023302613583*^9}, {
   3.8056656376059666`*^9, 3.8056656387233295`*^9}, {3.806767215589059*^9, 
   3.8067672158703537`*^9}, {3.8067672992669935`*^9, 3.8067673000948343`*^9}, 
   3.806836384704795*^9, 3.8252748910769715`*^9, 3.8252827802268124`*^9, 
   3.825283933979728*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[45]:=",ExpressionUUID->"c11b0971-44f2-457e-a56f-d2e8e07d9df7"],

Cell[TextData[StyleBox["Processed Coho",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9, {3.824980768462393*^9, 3.824980769184957*^9}, 
   3.8249808810930777`*^9, {3.8252748152865276`*^9, 3.8252748330842533`*^9}, 
   3.825283933979728*^9},ExpressionUUID->"bac80548-6326-4b09-91b4-\
3a8babe0fce9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qodp0", " ", "=", "4061329.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.8048514880219545`*^9, {3.8048590780406504`*^9, 3.8048590807442083`*^9}, 
   3.8050174161586895`*^9, 3.805022239350669*^9, 3.8050224952701406`*^9, 
   3.8050232217002525`*^9, {3.8050232521651382`*^9, 3.805023254618627*^9}, 
   3.805645845237493*^9, {3.805645891750942*^9, 3.8056458939388103`*^9}, {
   3.806765613970192*^9, 3.806765614304453*^9}, {3.806765697167205*^9, 
   3.8067656991857843`*^9}, {3.8068341903402767`*^9, 3.8068341906735373`*^9}, 
   3.8252748487113094`*^9, 3.8252827802268124`*^9, 3.8252839339807167`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[46]:=",ExpressionUUID->"99c6e44e-061a-4ff5-961c-12a04ff14f1d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"podp0", " ", "=", "6.8543"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.804343942476156*^9, 3.804343949889929*^9}, {
   3.8045210306472683`*^9, 3.8045210368829145`*^9}, {3.804587081702225*^9, 
   3.8045870826558285`*^9}, 3.804851766084381*^9, 3.804865895093766*^9, 
   3.805018163879826*^9, 3.8050227942063227`*^9, 3.805023277466144*^9, {
   3.805023307715171*^9, 3.8050233123404217`*^9}, {3.8056656472163677`*^9, 
   3.8056656478883595`*^9}, {3.8067672181205177`*^9, 3.806767218354932*^9}, {
   3.806767307144223*^9, 3.8067673078318343`*^9}, 3.8068363887992234`*^9, 
   3.825274892268894*^9, 3.8252827802277985`*^9, 3.8252839339807167`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[47]:=",ExpressionUUID->"b2da8702-0316-46b8-9356-5aa032c6c832"],

Cell[TextData[StyleBox["Processed Pink",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9, {3.824980768462393*^9, 3.824980769184957*^9}, 
   3.8249808810930777`*^9, {3.8252748152865276`*^9, 3.825274836920266*^9}, 
   3.8252839339807167`*^9},ExpressionUUID->"a950b809-90de-46b4-ae9e-\
fe691d7f9539"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qpdp0", " ", "=", "19944643.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.8048514880219545`*^9, {3.8048590780406504`*^9, 3.8048590807442083`*^9}, {
   3.8050174161586895`*^9, 3.8050174244881883`*^9}, 3.8050222430108185`*^9, 
   3.8050224962546763`*^9, 3.805023223403619*^9, {3.8050232587911205`*^9, 
   3.8050232611677017`*^9}, 3.8056458488251038`*^9, {3.805645899512662*^9, 
   3.80564590198705*^9}, {3.8067656166873145`*^9, 3.8067656169335055`*^9}, {
   3.8067657044308825`*^9, 3.8067657081718035`*^9}, {3.8068341934130583`*^9, 
   3.8068341937563252`*^9}, 3.825274849935289*^9, 3.8252827802277985`*^9, 
   3.825283933981739*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[48]:=",ExpressionUUID->"afc8f065-ee22-4e37-948b-934b709956c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ppdp0", " ", "=", "4.8824"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.804343942476156*^9, 3.804343949889929*^9}, {
   3.8045210306472683`*^9, 3.8045210368829145`*^9}, {3.804587081702225*^9, 
   3.8045870826558285`*^9}, 3.804851766084381*^9, 3.804865895093766*^9, {
   3.805018163879826*^9, 3.8050181722248125`*^9}, 3.805022796644215*^9, 
   3.8050232786225653`*^9, {3.8050233174491405`*^9, 3.8050233230437202`*^9}, {
   3.805665655545946*^9, 3.8056656574837837`*^9}, {3.806767220839722*^9, 
   3.8067672210272536`*^9}, {3.8067673161481905`*^9, 3.8067673166170187`*^9}, 
   3.8068363930811825`*^9, 3.8252748935618877`*^9, 3.8252827802277985`*^9, 
   3.825283933981739*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[49]:=",ExpressionUUID->"bffbf241-e5a3-4e32-be55-4013deb3732d"],

Cell[TextData[StyleBox["Processed Sockeye",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9, {3.824980768462393*^9, 3.824980769184957*^9}, 
   3.8249808810930777`*^9, {3.8252748152865276`*^9, 3.8252748403649297`*^9}, 
   3.825283933981739*^9},ExpressionUUID->"053b0852-bae3-47e1-b57a-\
18605fe9d787"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdp0", " ", "=", "27432877.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.8048514880219545`*^9, {3.8048590780406504`*^9, 3.8048590807442083`*^9}, {
   3.8050174161586895`*^9, 3.805017426879205*^9}, 3.8050222461675797`*^9, 
   3.8050224971767*^9, 3.805023225716447*^9, {3.8050236382210197`*^9, 
   3.8050236393305664`*^9}, 3.8056458523944626`*^9, 3.805645906628456*^9, {
   3.80564596119252*^9, 3.805646008123979*^9}, {3.8056460581507945`*^9, 
   3.805646059976446*^9}, {3.8067656193954306`*^9, 3.806765619896823*^9}, {
   3.806765713410902*^9, 3.806765716659439*^9}, {3.80683419596237*^9, 
   3.8068341962864428`*^9}, 3.8252748512873087`*^9, 3.825282780228798*^9, 
   3.8252839339827414`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[50]:=",ExpressionUUID->"e1ddfe9a-548c-4dc9-bd0f-2b29fc1ca0ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"psdp0", " ", "=", "13.9313"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.804343942476156*^9, 3.804343949889929*^9}, {
   3.8045210306472683`*^9, 3.8045210368829145`*^9}, {3.804587081702225*^9, 
   3.8045870826558285`*^9}, 3.804851766084381*^9, 3.804865895093766*^9, {
   3.805018163879826*^9, 3.8050181759909954`*^9}, {3.8050230081841908`*^9, 
   3.8050230092155676`*^9}, 3.805023279888378*^9, {3.805665665469347*^9, 
   3.805665666078829*^9}, {3.806767223090582*^9, 3.8067672232624846`*^9}, {
   3.8067673235413556`*^9, 3.806767324057067*^9}, 3.8068363978479424`*^9, 
   3.825274894721821*^9, 3.825282780228798*^9, 3.8252839339827414`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[51]:=",ExpressionUUID->"ecb360a1-d972-4160-8e9f-525353ea954d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.3 Import Quantities and Prices", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672733348008*^9}, {
   3.819672809477676*^9, 3.8196728096938534`*^9}, 3.8198152044580364`*^9, 
   3.8249830230169973`*^9, 3.8252827698425417`*^9, 
   3.8252828702591667`*^9},ExpressionUUID->"246296ea-0732-4b24-b603-\
873edc8eb9ee"],

Cell[TextData[StyleBox["Source: IUU Estimate Database as described in Chapter \
3 of the report. ",
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, 
   3.819814602882104*^9, {3.8198147741606445`*^9, 3.8198147935287457`*^9}, 
   3.8198152044580364`*^9, 3.820012478192554*^9, {3.8208559831037273`*^9, 
   3.8208560402321887`*^9}, 3.824980895304139*^9, 3.8249830230169973`*^9, 
   3.825282769843543*^9, 3.825282870260154*^9},
 FontSize->12,ExpressionUUID->"a9da071a-83af-494b-aca2-ab2517e0dd64"],

Cell[TextData[StyleBox["Chinook",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.82498135149479*^9, 3.824981353015973*^9}, 3.8249814426737957`*^9, 
   3.8249830230169973`*^9, {3.8252749315381975`*^9, 3.8252749323147917`*^9}, 
   3.825282769843543*^9, 
   3.825282870260154*^9},ExpressionUUID->"5eeb56a2-8276-438b-b8fc-\
a60517a10f9e"],

Cell["Total unprocessed imports", "Text",
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814453368645`*^9, 3.8249814468960824`*^9}, 
   3.8249830230169973`*^9, 3.825282769843543*^9, 
   3.825282870260154*^9},ExpressionUUID->"8e7aaf54-40c3-4c06-968a-\
bf000fc3683c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qctu0", " ", "=", 
    StyleBox["3647588",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.8048515018675895`*^9, {
   3.8048590980585527`*^9, 3.8048591016372504`*^9}, 3.8050174603390923`*^9, {
   3.80502226377987*^9, 3.8050222653269944`*^9}, {3.805646157032232*^9, 
   3.8056461604749346`*^9}, {3.8067657317442274`*^9, 
   3.8067657318322954`*^9}, {3.806765766461358*^9, 3.8067657694647017`*^9}, {
   3.806834210652813*^9, 3.8068342110336113`*^9}, 3.812469167787505*^9, {
   3.8169473314512663`*^9, 3.816947336860225*^9}, {3.816947459752178*^9, 
   3.816947469479126*^9}, {3.8187708385577135`*^9, 3.818770857099124*^9}, {
   3.8252749364359894`*^9, 3.8252749455570197`*^9}, 3.82528183290397*^9, 
   3.825282769843543*^9, 3.825282870260154*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[52]:=",ExpressionUUID->"4f31d8a3-142a-4e41-9984-1a88a6f968f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pctu0", " ", "=", "14.2695"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851741390031*^9, {3.8048593749382596`*^9, 
   3.8048593807364388`*^9}, 3.805018101074109*^9, {3.8050226014569044`*^9, 
   3.805022607145331*^9}, {3.805665532444476*^9, 3.805665533897846*^9}, {
   3.806767006601321*^9, 3.806767032956781*^9}, {3.8068363530181923`*^9, 
   3.8068363530963306`*^9}, {3.812469441990613*^9, 3.8124694438220415`*^9}, {
   3.8169477302709055`*^9, 3.8169477641592307`*^9}, {3.8169480242948914`*^9, 
   3.8169480281301546`*^9}, {3.8187737704402328`*^9, 3.818773802143873*^9}, {
   3.825274973390465*^9, 3.8252749873222456`*^9}, {3.825281843078816*^9, 
   3.8252818458459496`*^9}, 3.8252827698445077`*^9, 3.825282870261176*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[53]:=",ExpressionUUID->"3ff847f8-e519-4d22-a466-267ec672c9ff"],

Cell["Total processed imports", "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, {3.799791442102678*^9, 
   3.7997914423839736`*^9}, {3.804343678512698*^9, 3.804343679783687*^9}, {
   3.804520355853136*^9, 3.804520357118967*^9}, {3.8067655896682005`*^9, 
   3.806765590004464*^9}, {3.8252818965370393`*^9, 3.8252818985916305`*^9}, 
   3.8252827698445077`*^9, 
   3.825282870261176*^9},ExpressionUUID->"2bd48578-c6de-4693-a8fb-\
1fc636f0d55d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qctp0", " ", "=", 
    StyleBox["590030",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.804851519404023*^9, {3.8048591560917697`*^9, 
   3.8048591592391844`*^9}, 3.805017512752103*^9, {3.805022335809778*^9, 
   3.805022340044843*^9}, {3.805646222735584*^9, 3.805646229362497*^9}, {
   3.806765983884262*^9, 3.8067660164356985`*^9}, {3.8068342313117266`*^9, 
   3.8068342321236324`*^9}, 3.8124692199210033`*^9, {3.816947502981413*^9, 
   3.816947515167225*^9}, {3.816947556615327*^9, 3.81694756608064*^9}, {
   3.8187709567337356`*^9, 3.818770962845518*^9}, {3.8252819855386724`*^9, 
   3.825282008877705*^9}, 3.8252827698445077`*^9, 3.825282870261176*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[54]:=",ExpressionUUID->"29350a81-3a4a-4b4b-a909-8f3dc67795fb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pctp0", " ", "=", "15.9467"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.8048517788079557`*^9, {
   3.8048594276529274`*^9, 3.8048594301064444`*^9}, {3.8048594705997667`*^9, 
   3.8048594745222692`*^9}, {3.804865909505168*^9, 3.8048659121618433`*^9}, 
   3.805018278393769*^9, {3.8050230298017282`*^9, 3.805023034771118*^9}, {
   3.805665725529579*^9, 3.80566572662352*^9}, {3.806767347850252*^9, 
   3.806767348022156*^9}, {3.806767383083065*^9, 3.806767383473755*^9}, 
   3.8068364121921844`*^9, {3.812469530668912*^9, 3.812469534911228*^9}, {
   3.816948036792426*^9, 3.8169480432006254`*^9}, {3.818775681104037*^9, 
   3.818775710818504*^9}, {3.825282331722091*^9, 3.8252823478286505`*^9}, 
   3.8252827698455343`*^9, 3.825282870261176*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[55]:=",ExpressionUUID->"6af3a0db-6bd1-4bd8-b13c-06058f2aad81"],

Cell["Illegal imports", "Text",
 CellChangeTimes->{{3.825282376883334*^9, 3.8252823851637506`*^9}, 
   3.8252827698455343`*^9, 
   3.8252828702621574`*^9},ExpressionUUID->"b7ca48c0-5cea-419f-9ae5-\
3c8d750f0bd6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qciu0", " ", "=", 
    StyleBox["298564",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.8048515390631647`*^9, {3.8048592061610203`*^9, 
   3.804859208024148*^9}, 3.805017589247558*^9, {3.80502240255534*^9, 
   3.8050224042587395`*^9}, {3.805646316597954*^9, 3.8056463194890537`*^9}, {
   3.8067660761633725`*^9, 3.8067660919732633`*^9}, {3.8068342571956067`*^9, 
   3.8068342575488825`*^9}, 3.812469273415142*^9, 3.8124693068020773`*^9, {
   3.8169475787237163`*^9, 3.816947597482301*^9}, {3.818773459609539*^9, 
   3.818773468481477*^9}, {3.825282388812597*^9, 3.8252824304772763`*^9}, 
   3.8252827698455343`*^9, 3.8252828702621574`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[56]:=",ExpressionUUID->"49bbfc31-81e6-46c1-a11b-7bf50613d980"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qcip0", " ", "=", 
    StyleBox["55985",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515567692885`*^9, {3.8048592431706595`*^9, 3.8048592455772943`*^9}, 
   3.805017646330557*^9, {3.8050224491983905`*^9, 3.8050224526520786`*^9}, {
   3.805646368460105*^9, 3.8056463708980045`*^9}, {3.8067661353180637`*^9, 
   3.8067661741122646`*^9}, {3.806834276701655*^9, 3.8068342769985795`*^9}, 
   3.8124693595591908`*^9, {3.8169476162261643`*^9, 3.816947633485589*^9}, {
   3.8187736121361976`*^9, 3.8187736172992105`*^9}, {3.8252823913866453`*^9, 
   3.825282402025955*^9}, 3.8252824354861856`*^9, 3.8252827698455343`*^9, 
   3.8252828702621574`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[57]:=",ExpressionUUID->"21327809-8401-4b20-ae5b-310e4df12604"],

Cell[TextData[StyleBox["Chum",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.82498135149479*^9, 3.824981353015973*^9}, 3.8249814426737957`*^9, 
   3.8249830230169973`*^9, {3.8252749315381975`*^9, 3.8252749323147917`*^9}, {
   3.8252750007295275`*^9, 3.825275001157875*^9}, 3.825282769846526*^9, 
   3.8252828702621574`*^9},ExpressionUUID->"2f760a0f-826a-4c23-88e8-\
6b62d2ba5e8c"],

Cell["Total unprocessed imports", "Text",
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814453368645`*^9, 3.8249814468960824`*^9}, 
   3.8249830230169973`*^9, 3.825282769846526*^9, 
   3.825282870263138*^9},ExpressionUUID->"cdd433f1-1d34-4033-b965-\
883a6fae43a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhtu0", " ", "=", 
    StyleBox["944068",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.804851503993678*^9, {
   3.804859106546692*^9, 3.8048591085313845`*^9}, {3.8050222716874075`*^9, 
   3.805022273656476*^9}, {3.805646165378788*^9, 3.8056461681735787`*^9}, {
   3.806765734353266*^9, 3.80676573467852*^9}, {3.8067657747128024`*^9, 
   3.806765777184737*^9}, {3.806834213469077*^9, 3.8068342138221197`*^9}, 
   3.812469174687865*^9, {3.8169473402432814`*^9, 3.8169473447702208`*^9}, {
   3.8169478407960663`*^9, 3.816947843527382*^9}, {3.8187708694086914`*^9, 
   3.8187708713371897`*^9}, {3.825275009501313*^9, 3.8252750122684746`*^9}, 
   3.8252818341859584`*^9, 3.825282769846526*^9, 3.825282870263138*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[58]:=",ExpressionUUID->"8ccfd944-c19b-49ca-bd97-ae7982c4c14d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"phtu0", " ", "=", "4.27613"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851745095583*^9, {3.8048593855964956`*^9, 
   3.804859389253332*^9}, {3.8050226314772887`*^9, 3.8050226372125945`*^9}, {
   3.8056655461121254`*^9, 3.805665546643465*^9}, {3.8067670093986626`*^9, 
   3.8067670096330748`*^9}, {3.806767040552326*^9, 3.8067670409117618`*^9}, 
   3.806836359151471*^9, {3.812469450193019*^9, 3.812469452653942*^9}, {
   3.816948077903352*^9, 3.816948087197053*^9}, {3.818775400519577*^9, 
   3.8187754062400227`*^9}, {3.825275019050683*^9, 3.825275033929155*^9}, 
   3.825281849904079*^9, 3.825282769846526*^9, 3.825282870263138*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[59]:=",ExpressionUUID->"8b465579-3011-4468-9c89-a2f6795256be"],

Cell["Total processed imports", "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, {3.799791442102678*^9, 
   3.7997914423839736`*^9}, {3.804343678512698*^9, 3.804343679783687*^9}, {
   3.804520355853136*^9, 3.804520357118967*^9}, {3.8067655896682005`*^9, 
   3.806765590004464*^9}, {3.8252818965370393`*^9, 3.8252818985916305`*^9}, 
   3.825282769846526*^9, 
   3.825282870263138*^9},ExpressionUUID->"3ab41c4f-4d22-4e73-8a63-\
6f31352d4bfc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhtp0", " ", "=", 
    StyleBox["11082850",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.8048515215605907`*^9, {3.804859164699379*^9, 
   3.804859168700019*^9}, {3.805022345295699*^9, 3.8050223485306015`*^9}, {
   3.805646237247239*^9, 3.805646241247918*^9}, {3.8067659865233235`*^9, 
   3.806765986798539*^9}, {3.8067660218509293`*^9, 3.806766024242801*^9}, {
   3.8068342344068737`*^9, 3.80683423477538*^9}, 3.81246922667525*^9, {
   3.8169478646893826`*^9, 3.816947881189335*^9}, {3.8187709701632338`*^9, 
   3.81877097330169*^9}, 3.8252819737586*^9, 3.825282009739359*^9, 
   3.825282769847536*^9, 3.8252828702641907`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[60]:=",ExpressionUUID->"e01165ce-f1d5-466c-bd97-2cfeb5fb52a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"phtp0", " ", "=", "7.53876"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.804851781495868*^9, {
   3.8048594347165575`*^9, 3.8048594421552544`*^9}, {3.8048594788678904`*^9, 
   3.804859482930971*^9}, {3.8048659166313086`*^9, 3.8048659239918613`*^9}, {
   3.805023039568612*^9, 3.805023045366234*^9}, {3.805665734128354*^9, 
   3.805665735003507*^9}, {3.80676735048802*^9, 3.806767350768963*^9}, {
   3.8067673915389433`*^9, 3.8067673924297132`*^9}, 3.8068364181930695`*^9, {
   3.812469539002427*^9, 3.8124695435409718`*^9}, {3.816948105325485*^9, 
   3.8169481155197945`*^9}, {3.818775737298416*^9, 3.818775747822731*^9}, {
   3.825282263030592*^9, 3.825282281671133*^9}, 3.825282769847536*^9, 
   3.8252828702641907`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[61]:=",ExpressionUUID->"cf846bbd-4358-4ded-a3bd-51431faf16f0"],

Cell["Illegal imports", "Text",
 CellChangeTimes->{{3.825282464780998*^9, 3.8252824671819572`*^9}, 
   3.825282769847536*^9, 
   3.8252828702641907`*^9},ExpressionUUID->"a3bad53e-8398-4804-bd2d-\
a6381cb1ab7e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhiu0", " ", "=", 
    StyleBox["38923",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.804851541954215*^9, {3.804859212477992*^9, 
   3.804859214822117*^9}, {3.805022408853236*^9, 3.805022410087814*^9}, {
   3.8056463242097116`*^9, 3.8056463265851*^9}, {3.806766078300044*^9, 
   3.8067660972286577`*^9}, {3.806834260247501*^9, 3.806834260560051*^9}, 
   3.8124692794408236`*^9, 3.812469313862563*^9, {3.816947895843892*^9, 
   3.8169479177201157`*^9}, {3.8187734880767775`*^9, 
   3.8187734915064435`*^9}, {3.825282471631671*^9, 3.825282490644307*^9}, 
   3.825282769847536*^9, 3.8252828702641907`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[62]:=",ExpressionUUID->"adf09bb8-ba09-42d4-8fa1-3851ed8f03f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhip0", " ", "=", 
    StyleBox["213194",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.80485155892587*^9, {3.8048592504999576`*^9, 3.8048592528905926`*^9}, {
   3.805022457746656*^9, 3.8050224597157245`*^9}, {3.805646375867463*^9, 
   3.8056463782597036`*^9}, {3.8067661382556486`*^9, 3.806766138536944*^9}, 
   3.8067661706117015`*^9, {3.806834279624014*^9, 3.8068342799678197`*^9}, 
   3.812469365821087*^9, {3.8169479305681095`*^9, 3.816947941858949*^9}, {
   3.818773630878764*^9, 3.8187736330534544`*^9}, {3.82528247459111*^9, 
   3.825282491288859*^9}, 3.8252827698485513`*^9, 3.8252828702651367`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[63]:=",ExpressionUUID->"eecac173-9bd3-4c06-b1be-e9c182499ee0"],

Cell[TextData[StyleBox["Coho",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.82498135149479*^9, 3.824981353015973*^9}, 3.8249814426737957`*^9, 
   3.8249830230169973`*^9, {3.8252749315381975`*^9, 3.8252749323147917`*^9}, {
   3.8252750007295275`*^9, 3.825275001157875*^9}, {3.825275062218993*^9, 
   3.825275062702361*^9}, 3.8252827698485513`*^9, 
   3.8252828702651367`*^9},ExpressionUUID->"1bc0f1be-bf75-4682-932b-\
da72338a3e6e"],

Cell["Total unprocessed imports", "Text",
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814453368645`*^9, 3.8249814468960824`*^9}, 
   3.8249830230169973`*^9, 3.8252827698485513`*^9, 
   3.8252828702651367`*^9},ExpressionUUID->"19cd8008-9b3e-4577-b387-\
59d517eea78a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qotu0", " ", "=", "469052"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.804851506634692*^9, {
   3.8048591212377567`*^9, 3.8048591249079113`*^9}, 3.8050174723254375`*^9, {
   3.8050222788917065`*^9, 3.805022281860938*^9}, {3.8056461739322014`*^9, 
   3.805646177617194*^9}, {3.806765736972315*^9, 3.806765737208499*^9}, {
   3.806765782146613*^9, 3.8067657845484924`*^9}, {3.8068342168185606`*^9, 
   3.8068342172224846`*^9}, 3.812469181097844*^9, {3.8169473480149593`*^9, 
   3.8169473624618444`*^9}, {3.8169483421495304`*^9, 
   3.8169483443308525`*^9}, {3.8187708787499514`*^9, 3.818770892466612*^9}, {
   3.825275038770895*^9, 3.82527504872654*^9}, 3.825281835273797*^9, 
   3.8252827698485513`*^9, 3.8252828702651367`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[64]:=",ExpressionUUID->"371d9049-7ce7-40f7-b41b-29c4bc91fb4b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"potu0", " ", "=", "10.337"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851748049161*^9, {3.8048593936292486`*^9, 
   3.804859397458267*^9}, 3.805018113388355*^9, {3.8050226422134104`*^9, 
   3.8050226466203794`*^9}, {3.8056655591158066`*^9, 3.805665559787795*^9}, {
   3.806767012086607*^9, 3.8067670122741385`*^9}, {3.8067670493522654`*^9, 
   3.8067670500398808`*^9}, 3.80683636360534*^9, {3.8124694591330085`*^9, 
   3.812469463376323*^9}, {3.8169484616034117`*^9, 3.8169484960811043`*^9}, {
   3.8187754354407177`*^9, 3.8187754559416513`*^9}, {3.825275073842947*^9, 
   3.8252750834985037`*^9}, 3.825281851545353*^9, 3.8252827698495255`*^9, 
   3.8252828702661495`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[65]:=",ExpressionUUID->"aac04036-7655-40bb-aad7-1dc7991d1003"],

Cell["Total processed imports", "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, {3.799791442102678*^9, 
   3.7997914423839736`*^9}, {3.804343678512698*^9, 3.804343679783687*^9}, {
   3.804520355853136*^9, 3.804520357118967*^9}, {3.8067655896682005`*^9, 
   3.806765590004464*^9}, {3.8252818965370393`*^9, 3.8252818985916305`*^9}, 
   3.8252827698495255`*^9, 
   3.8252828702661495`*^9},ExpressionUUID->"68f85e6b-0349-4de7-8ccf-\
73e47fdd4326"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qotp0", " ", "=", 
    StyleBox["5218760",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.804851523748412*^9, {3.8048591766858854`*^9, 
   3.80485918053025*^9}, 3.805017523488247*^9, {3.8050223529375687`*^9, 
   3.8050223554223504`*^9}, {3.80564624818703*^9, 3.805646251328046*^9}, {
   3.806765989152381*^9, 3.8067659894366035`*^9}, {3.806766029787133*^9, 
   3.8067660338633165`*^9}, {3.806834237283357*^9, 3.806834237650164*^9}, 
   3.812469233311405*^9, {3.816948168404991*^9, 3.816948190904329*^9}, {
   3.81694835969514*^9, 3.8169483665703635`*^9}, {3.8187709835717173`*^9, 
   3.8187709921684394`*^9}, {3.8252819488073463`*^9, 3.825281962724095*^9}, 
   3.8252820112575064`*^9, 3.8252827698495255`*^9, 3.8252828702661495`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[66]:=",ExpressionUUID->"fc53ee63-8e40-4683-b321-8821e0a01696"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"potp0", " ", "=", "9.88819"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.804851783996252*^9, {
   3.8048594463590517`*^9, 3.8048594494689245`*^9}, {3.804859487327943*^9, 
   3.8048594931426477`*^9}, {3.8048659293832474`*^9, 3.8048659328369255`*^9}, 
   3.8050182854886165`*^9, {3.8050230503825045`*^9, 3.8050230545861716`*^9}, {
   3.805665743000533*^9, 3.8056657436142235`*^9}, {3.806767353506043*^9, 
   3.806767353709202*^9}, {3.8067673997591276`*^9, 3.8067674007891197`*^9}, 
   3.806836421326826*^9, {3.8124695478613462`*^9, 3.8124695530894346`*^9}, {
   3.8169485157949095`*^9, 3.8169485497772355`*^9}, {3.8187757663843904`*^9, 
   3.818775792753215*^9}, {3.8252822336816683`*^9, 3.8252822471532288`*^9}, 
   3.8252827698495255`*^9, 3.8252828702661495`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[67]:=",ExpressionUUID->"a19c8c06-1203-453b-97b9-81d7697dca09"],

Cell["Illegal imports", "Text",
 CellChangeTimes->{{3.825282513926466*^9, 3.8252825157909536`*^9}, 
   3.8252827698495255`*^9, 
   3.825282870267167*^9},ExpressionUUID->"bf9eb003-68a1-40ef-9c11-\
7e27d96cb08b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qoiu0", " ", "=", 
    StyleBox["18758",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.804851544345194*^9, {3.804859222792143*^9, 
   3.8048592281838903`*^9}, 3.805017601499572*^9, {3.805022415979398*^9, 
   3.805022417932844*^9}, {3.8056463334000163`*^9, 3.8056463354941115`*^9}, {
   3.8067660804267025`*^9, 3.8067661036161985`*^9}, {3.806834263250675*^9, 
   3.806834263573552*^9}, 3.8124693215925674`*^9, {3.8169482048564653`*^9, 
   3.8169482138214626`*^9}, {3.8169484031037216`*^9, 3.81694840722655*^9}, {
   3.8187735126518774`*^9, 3.8187735173605375`*^9}, {3.8252825199593506`*^9, 
   3.8252825287195177`*^9}, {3.8252825626722155`*^9, 3.825282563628978*^9}, 
   3.825282769850531*^9, 3.825282870267167*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[68]:=",ExpressionUUID->"7d33a6af-ed15-4356-8e81-ee1b51ecb618"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qoip0", " ", "=", 
    StyleBox["385118",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515613793716`*^9, {3.804859261769577*^9, 3.8048592662859316`*^9}, 
   3.8050176541599693`*^9, {3.8050224656385655`*^9, 3.8050224672325726`*^9}, {
   3.805646383822101*^9, 3.80564638584033*^9}, {3.806766140787306*^9, 
   3.806766141021719*^9}, {3.806766186631192*^9, 3.8067661887721605`*^9}, {
   3.8068342829952335`*^9, 3.806834283323414*^9}, 3.8124693721820555`*^9, {
   3.81694841969215*^9, 3.8169484426030345`*^9}, {3.818773656860958*^9, 
   3.818773664283727*^9}, {3.8252825337576094`*^9, 3.8252825685239353`*^9}, 
   3.825282769850531*^9, 3.825282870267167*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[69]:=",ExpressionUUID->"35bf12f1-9497-43a8-93f9-a343c7e57c0a"],

Cell[TextData[StyleBox["Pink",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.82498135149479*^9, 3.824981353015973*^9}, 3.8249814426737957`*^9, 
   3.8249830230169973`*^9, {3.8252749315381975`*^9, 3.8252749323147917`*^9}, {
   3.8252750007295275`*^9, 3.825275001157875*^9}, {3.825275062218993*^9, 
   3.825275062702361*^9}, {3.825275098741331*^9, 3.825275099096661*^9}, 
   3.825282769850531*^9, 
   3.825282870268159*^9},ExpressionUUID->"f13bd789-56a5-4027-a64b-\
1f93cd848a5b"],

Cell["Total unprocessed imports", "Text",
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814453368645`*^9, 3.8249814468960824`*^9}, 
   3.8249830230169973`*^9, 3.825282769850531*^9, 
   3.825282870268159*^9},ExpressionUUID->"d36e7e58-d2e2-4fbf-affd-\
1ae4c276f542"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qptu0", " ", "=", 
    StyleBox["2269827",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.804851506634692*^9, {
   3.8048591212377567`*^9, 3.8048591249079113`*^9}, {3.8050174723254375`*^9, 
   3.8050174834066176`*^9}, {3.8050222868930087`*^9, 3.805022290552119*^9}, {
   3.8056461840458636`*^9, 3.80564618843721*^9}, 3.806765527700594*^9, {
   3.8067657419251842`*^9, 3.806765742161369*^9}, {3.8067657893142157`*^9, 
   3.8067657927508984`*^9}, 3.806832190116372*^9, {3.8068342206466613`*^9, 
   3.8068342210808277`*^9}, 3.812469189556415*^9, {3.8169473537005997`*^9, 
   3.816947359384075*^9}, {3.8169486000454216`*^9, 3.8169486031057463`*^9}, {
   3.818770911539436*^9, 3.8187709156636405`*^9}, {3.8252751071268654`*^9, 
   3.825275107951562*^9}, 3.825281836681883*^9, 3.82528276985155*^9, 
   3.825282870268159*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[70]:=",ExpressionUUID->"e3583c1c-0b7d-498c-9dc9-be43612a7e2d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pptu0", " ", "=", "5.69769"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851748049161*^9, {3.8048593936292486`*^9, 
   3.804859397458267*^9}, {3.805018113388355*^9, 3.805018121905187*^9}, {
   3.8050226512323885`*^9, 3.8050226559050236`*^9}, {3.8067670145770597`*^9, 
   3.8067670148131976`*^9}, {3.806767058151041*^9, 3.80676705874489*^9}, 
   3.806836367480982*^9, {3.8124694688706164`*^9, 3.812469471134383*^9}, {
   3.816948734299847*^9, 3.816948750268694*^9}, {3.818775481743705*^9, 
   3.8187754950240264`*^9}, {3.8252751222236347`*^9, 3.825275136237539*^9}, 
   3.8252818531946163`*^9, 3.82528276985155*^9, 3.825282870268159*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[71]:=",ExpressionUUID->"166a8e37-7c0b-44ee-ae6b-4d2b15981d20"],

Cell["Total processed imports", "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, {3.799791442102678*^9, 
   3.7997914423839736`*^9}, {3.804343678512698*^9, 3.804343679783687*^9}, {
   3.804520355853136*^9, 3.804520357118967*^9}, {3.8067655896682005`*^9, 
   3.806765590004464*^9}, {3.8252818965370393`*^9, 3.8252818985916305`*^9}, 
   3.82528276985155*^9, 
   3.825282870268159*^9},ExpressionUUID->"ac13854e-8673-4092-ac2c-\
66542f673fb3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qptp0", " ", "=", 
    StyleBox["17731074",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.804851523748412*^9, {3.8048591766858854`*^9, 
   3.80485918053025*^9}, {3.805017523488247*^9, 3.8050175307081823`*^9}, {
   3.8050223611106586`*^9, 3.8050223632985163`*^9}, {3.805646256795086*^9, 
   3.805646259346697*^9}, {3.806765991810455*^9, 3.8067659920466394`*^9}, {
   3.806766038914263*^9, 3.8067660420557213`*^9}, {3.8068342402673197`*^9, 
   3.8068342406715107`*^9}, 3.812469239544247*^9, {3.816948618500699*^9, 
   3.8169486377509737`*^9}, {3.8187711086845226`*^9, 3.818771110533968*^9}, 
   3.8252819409613276`*^9, 3.825282016858824*^9, 3.82528276985155*^9, 
   3.8252828702691593`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[72]:=",ExpressionUUID->"aaf62327-53e1-464d-9269-855cd6a8d47e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pptp0", " ", "=", "6.62678"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.804851783996252*^9, {
   3.8048594463590517`*^9, 3.8048594494689245`*^9}, {3.804859487327943*^9, 
   3.8048594931426477`*^9}, {3.8048659293832474`*^9, 
   3.8048659328369255`*^9}, {3.8050182854886165`*^9, 
   3.8050182941251855`*^9}, {3.805023059946237*^9, 3.8050230631497755`*^9}, {
   3.8056657522159815`*^9, 3.805665753372402*^9}, {3.806767356208233*^9, 
   3.806767356459547*^9}, {3.8067674115529585`*^9, 3.80676741200616*^9}, 
   3.806836426140125*^9, {3.812469560524246*^9, 3.812469565604212*^9}, {
   3.816948763902401*^9, 3.816948774167634*^9}, {3.8187758197320986`*^9, 
   3.8187758346857977`*^9}, {3.825282201967987*^9, 3.825282219421564*^9}, 
   3.825282769852564*^9, 3.8252828702691593`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[73]:=",ExpressionUUID->"830979a0-2024-4f7e-94ef-e6fd5d545f12"],

Cell["Illegal imports", "Text",
 CellChangeTimes->{{3.8252826021151404`*^9, 3.825282603798519*^9}, 
   3.825282769852564*^9, 
   3.8252828702691593`*^9},ExpressionUUID->"250d6782-febc-4d59-9ef9-\
18f77ed030ef"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qpiu0", " ", "=", 
    StyleBox["330333",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.804851544345194*^9, {3.804859222792143*^9, 
   3.8048592281838903`*^9}, {3.805017601499572*^9, 3.8050176145309644`*^9}, {
   3.8050224245056534`*^9, 3.80502242658412*^9}, {3.805646340307399*^9, 
   3.8056463430450153`*^9}, {3.806766083173852*^9, 3.8067661197165565`*^9}, {
   3.806834266754854*^9, 3.8068342670986605`*^9}, 3.8124693298629923`*^9, {
   3.8169486677396064`*^9, 3.8169486805902205`*^9}, {3.818773537524209*^9, 
   3.8187735402363167`*^9}, {3.8252826077497063`*^9, 3.8252826251117287`*^9}, 
   3.825282769852564*^9, 3.8252828702691593`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[74]:=",ExpressionUUID->"d335b394-b7ba-460c-8916-2bfed61ddef4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qpip0", " ", "=", 
    StyleBox["818928",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515613793716`*^9, {3.804859261769577*^9, 3.8048592662859316`*^9}, {
   3.8050176541599693`*^9, 3.8050176622706776`*^9}, {3.8050224736086135`*^9, 
   3.805022474483754*^9}, {3.806766143475238*^9, 3.806766143709651*^9}, {
   3.8067661948056383`*^9, 3.806766198119275*^9}, {3.8068342856717997`*^9, 
   3.806834285984372*^9}, 3.81246938197871*^9, {3.8169486953289957`*^9, 
   3.8169487160936847`*^9}, {3.8187736809396725`*^9, 
   3.8187736854842043`*^9}, {3.825282610574008*^9, 3.825282625721238*^9}, 
   3.825282769852564*^9, 3.825282870270173*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[75]:=",ExpressionUUID->"5c57897c-e6e0-4547-adec-f264f983fc1c"],

Cell[TextData[StyleBox["Sockeye",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.82498135149479*^9, 3.824981353015973*^9}, 3.8249814426737957`*^9, 
   3.8249830230169973`*^9, {3.8252749315381975`*^9, 3.8252749323147917`*^9}, {
   3.8252750007295275`*^9, 3.825275001157875*^9}, {3.825275062218993*^9, 
   3.825275062702361*^9}, {3.825275098741331*^9, 3.825275099096661*^9}, {
   3.8252751453206186`*^9, 3.825275146186306*^9}, 3.8252827698535233`*^9, 
   3.825282870270173*^9},ExpressionUUID->"11f1841d-c81d-474a-b0c1-\
4e2613574733"],

Cell["Total unprocessed imports", "Text",
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814453368645`*^9, 3.8249814468960824`*^9}, 
   3.8249830230169973`*^9, 3.8252827698535233`*^9, 
   3.825282870270173*^9},ExpressionUUID->"01d4ba99-9c2b-4fc4-b629-\
0f08936288b9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qstu0", " ", "=", 
    StyleBox["4236885",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.804851506634692*^9, {
   3.8048591212377567`*^9, 3.8048591249079113`*^9}, {3.8050174723254375`*^9, 
   3.805017486142664*^9}, {3.805022295146616*^9, 3.8050222988034616`*^9}, {
   3.8056461958459024`*^9, 3.8056461989581876`*^9}, {3.806765744623289*^9, 
   3.8067657447904196`*^9}, {3.80676579762471*^9, 3.806765800430902*^9}, {
   3.806834223994567*^9, 3.8068342243456955`*^9}, 3.8124691988996735`*^9, {
   3.8169473654320316`*^9, 3.816947368589053*^9}, {3.816948858925507*^9, 
   3.81694886456421*^9}, {3.8187709274498444`*^9, 3.8187709276980386`*^9}, 
   3.8252751511021247`*^9, 3.8252818384442415`*^9, 3.8252827698535233`*^9, 
   3.825282870270173*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[76]:=",ExpressionUUID->"9e84867b-f9b9-42cf-9eed-4e824f4a1706"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pstu0", " ", "=", "8.7212"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851748049161*^9, {3.8048593936292486`*^9, 
   3.804859397458267*^9}, {3.805018113388355*^9, 3.805018124311778*^9}, {
   3.805022660421383*^9, 3.8050226647658396`*^9}, {3.806767017775159*^9, 
   3.806767017868924*^9}, {3.80676706849166*^9, 3.8067670695074544`*^9}, {
   3.8068363737957015`*^9, 3.806836373998861*^9}, {3.8124694767978125`*^9, 
   3.812469480006319*^9}, {3.8169489933019056`*^9, 3.81694900643476*^9}, {
   3.8187755092951183`*^9, 3.818775543022419*^9}, {3.825281736874095*^9, 
   3.8252817590400443`*^9}, 3.8252818550260286`*^9, 3.8252827698535233`*^9, 
   3.8252828702711678`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[77]:=",ExpressionUUID->"98eaeb8e-715e-43ab-ab2b-514540ca6fbe"],

Cell["Total processed imports", "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, {3.799791442102678*^9, 
   3.7997914423839736`*^9}, {3.804343678512698*^9, 3.804343679783687*^9}, {
   3.804520355853136*^9, 3.804520357118967*^9}, {3.8067655896682005`*^9, 
   3.806765590004464*^9}, {3.8252818965370393`*^9, 3.8252818985916305`*^9}, 
   3.8252827698535233`*^9, 
   3.8252828702711678`*^9},ExpressionUUID->"e594c0aa-de19-4692-af73-\
236d36ff1386"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qstp0", " ", "=", 
    StyleBox["19781556",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.804851523748412*^9, {3.8048591766858854`*^9, 
   3.80485918053025*^9}, {3.805017523488247*^9, 3.805017533396126*^9}, {
   3.805022368064474*^9, 3.8050223716740403`*^9}, {3.805646264750458*^9, 
   3.8056462705795403`*^9}, {3.806765995621436*^9, 3.8067659956994963`*^9}, {
   3.8067660481404757`*^9, 3.806766051517112*^9}, {3.806834243456468*^9, 
   3.806834243823779*^9}, 3.8124692463085012`*^9, {3.8169488768433332`*^9, 
   3.8169488888034515`*^9}, {3.8187711251503944`*^9, 3.8187711284819984`*^9}, 
   3.8252819316181116`*^9, 3.825282018693268*^9, 3.8252827698545194`*^9, 
   3.8252828702711678`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[78]:=",ExpressionUUID->"d0c9dc2b-643a-4c85-b86d-881765c9c441"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pstp0", " ", "=", "6.96608"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.804851783996252*^9, {
   3.8048594463590517`*^9, 3.8048594494689245`*^9}, {3.804859487327943*^9, 
   3.8048594931426477`*^9}, {3.8048659293832474`*^9, 
   3.8048659328369255`*^9}, {3.8050182854886165`*^9, 
   3.8050182968443565`*^9}, {3.8050230672908416`*^9, 3.805023070853801*^9}, {
   3.8067673589755907`*^9, 3.806767359100611*^9}, {3.8067674189461336`*^9, 
   3.806767420606447*^9}, 3.806836432579631*^9, {3.812469571256632*^9, 
   3.8124695757451377`*^9}, {3.8169490231682224`*^9, 3.816949034023912*^9}, {
   3.8187758538718143`*^9, 3.8187758744409075`*^9}, {3.8252821670847545`*^9, 
   3.825282189095909*^9}, 3.8252827698545194`*^9, 3.8252828702711678`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[79]:=",ExpressionUUID->"97a149fc-08a4-4fe9-88c3-c69289bd6ca6"],

Cell["Illegal imports", "Text",
 CellChangeTimes->{{3.8252826431021786`*^9, 3.825282644759501*^9}, 
   3.8252827698545194`*^9, 
   3.825282870272152*^9},ExpressionUUID->"a7964455-aa60-47f3-89b1-\
2bc13a62ab52"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsiu0", 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox["=",
     FontColor->GrayLevel[0]], 
    StyleBox["560874",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.804851544345194*^9, {3.804859222792143*^9, 
   3.8048592281838903`*^9}, {3.805017601499572*^9, 3.8050176172501593`*^9}, {
   3.805022431367359*^9, 3.805022433055135*^9}, {3.805646347764537*^9, 
   3.805646349983653*^9}, {3.80676608578785*^9, 3.8067660858972435`*^9}, {
   3.8067661239724894`*^9, 3.8067661255821233`*^9}, {3.806834270153313*^9, 
   3.8068342704658656`*^9}, 3.8124693401320105`*^9, {3.816948914990698*^9, 
   3.816948937349654*^9}, {3.818773556077628*^9, 3.8187735658472214`*^9}, {
   3.825282648547546*^9, 3.825282665014784*^9}, 3.825282769855549*^9, 
   3.825282870272152*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[80]:=",ExpressionUUID->"43dbadf4-e672-4f76-9011-c2105e6d5cee"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsip0", " ", "=", 
    StyleBox["3655213",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515613793716`*^9, {3.804859261769577*^9, 3.8048592662859316`*^9}, {
   3.8050176541599693`*^9, 3.805017664872533*^9}, {3.8050224793751793`*^9, 
   3.805022481297365*^9}, {3.8067661458506203`*^9, 3.8067661459756403`*^9}, {
   3.8067662020417805`*^9, 3.806766204042102*^9}, {3.8068342889113684`*^9, 
   3.80683428928201*^9}, 3.8124693911648912`*^9, {3.816948962151836*^9, 
   3.8169489748437805`*^9}, {3.8187737107668643`*^9, 3.818773714071424*^9}, {
   3.8252826512657366`*^9, 3.8252826662177796`*^9}, 3.825282769855549*^9, 
   3.825282870272152*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[81]:=",ExpressionUUID->"deeacab3-4398-4bbd-8b8a-420ec18f72de"],

Cell[TextData[StyleBox["Atlantic",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.82498135149479*^9, 3.824981353015973*^9}, 3.8249814426737957`*^9, 
   3.8249830230169973`*^9, {3.8252749315381975`*^9, 3.8252749323147917`*^9}, {
   3.8252750007295275`*^9, 3.825275001157875*^9}, {3.825275062218993*^9, 
   3.825275062702361*^9}, {3.825275098741331*^9, 3.825275099096661*^9}, {
   3.8252751453206186`*^9, 3.825275146186306*^9}, {3.8252817275410147`*^9, 
   3.8252817308334756`*^9}, 3.825282769855549*^9, 
   3.825282870272152*^9},ExpressionUUID->"48d7b07e-5cca-4391-ad57-\
42870fd6ee17"],

Cell["Total unprocessed imports", "Text",
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814453368645`*^9, 3.8249814468960824`*^9}, 
   3.8249830230169973`*^9, 3.825282769855549*^9, 
   3.8252828702731714`*^9},ExpressionUUID->"37201b6d-f3ef-4a7f-9a30-\
f982e4510a3c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qatu0", " ", "=", 
    StyleBox["126811751",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.8048514991738663`*^9, {
   3.8048590916512775`*^9, 3.8048590942923245`*^9}, 3.805017449790481*^9, {
   3.8050222550283995`*^9, 3.805022258888447*^9}, {3.8056461502065105`*^9, 
   3.8056461519460487`*^9}, {3.8067657285347185`*^9, 3.806765761154212*^9}, {
   3.8068342075320053`*^9, 3.806834208397287*^9}, 3.812469206265395*^9, {
   3.816947371608656*^9, 3.8169473771270866`*^9}, {3.8169490709687085`*^9, 
   3.81694907924179*^9}, {3.8187709441338863`*^9, 3.8187709448774695`*^9}, {
   3.8252817670521894`*^9, 3.825281777521262*^9}, 3.825281839986431*^9, 
   3.825282769856518*^9, 3.8252828702731714`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[82]:=",ExpressionUUID->"ae10a51e-203c-49fc-b34c-3bab85f2f593"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"patu0", " ", "=", "8.33607"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851738717746*^9, {3.8048593644040937`*^9, 
   3.804859369373639*^9}, 3.8050180911508274`*^9, {3.805022589673736*^9, 
   3.8050225937212696`*^9}, {3.8056655234742956`*^9, 3.8056655242087946`*^9}, 
   3.8067662223788753`*^9, {3.8067669909098706`*^9, 3.806766992247259*^9}, 
   3.8068363477510805`*^9, {3.812469487608261*^9, 3.81246949020729*^9}, {
   3.816949210501066*^9, 3.8169492437932725`*^9}, {3.8187755598925304`*^9, 
   3.8187755725293517`*^9}, {3.825281788751927*^9, 3.8252818019771214`*^9}, 
   3.8252818560087867`*^9, 3.825282769856518*^9, 3.8252828702731714`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[83]:=",ExpressionUUID->"bbe25b2d-bbf5-45c8-98c1-b268a76c3c79"],

Cell["Total processed imports", "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, {3.799791442102678*^9, 
   3.7997914423839736`*^9}, {3.804343678512698*^9, 3.804343679783687*^9}, {
   3.804520355853136*^9, 3.804520357118967*^9}, {3.8067655896682005`*^9, 
   3.806765590004464*^9}, {3.8252818965370393`*^9, 3.8252818985916305`*^9}, 
   3.825282769856518*^9, 
   3.8252828702731714`*^9},ExpressionUUID->"d9aa3b4d-191b-46e8-b6d9-\
0c7164d1e004"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qatp0", " ", "=", 
    StyleBox["210415300",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.8048515168380613`*^9, {3.8048591480713325`*^9, 
   3.804859151134322*^9}, 3.805017502641066*^9, {3.8050223114300685`*^9, 
   3.805022316447248*^9}, {3.8056462154235764`*^9, 3.8056462194300847`*^9}, {
   3.8067659808418837`*^9, 3.806766008381403*^9}, {3.8068342277030306`*^9, 
   3.8068342281874866`*^9}, 3.8124692529942784`*^9, {3.8169491001274304`*^9, 
   3.8169491208671017`*^9}, {3.8187711435357704`*^9, 
   3.8187711490330653`*^9}, {3.8252819075935807`*^9, 3.8252819185160007`*^9}, 
   3.8252820208519225`*^9, 3.825282769856518*^9, 3.8252828702741547`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[84]:=",ExpressionUUID->"9485f714-e9cc-42a5-989a-eec3da2d3d9d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"patp0", " ", "=", "12.026"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.8048517763987885`*^9, {
   3.8048594197297783`*^9, 3.80485942321471*^9}, {3.804859460017418*^9, 
   3.804859464424373*^9}, {3.804865902826519*^9, 3.80486590501756*^9}, 
   3.8050182696736803`*^9, {3.805023020546306*^9, 3.8050230248593616`*^9}, {
   3.805665716479865*^9, 3.805665716933069*^9}, 3.806766223472801*^9, {
   3.806767374985757*^9, 3.8067673756577444`*^9}, {3.8068364035799217`*^9, 
   3.806836405939692*^9}, {3.8124695792508802`*^9, 3.8124695841537085`*^9}, {
   3.816949259423521*^9, 3.8169492907155747`*^9}, {3.8187759027370496`*^9, 
   3.818775918782604*^9}, {3.8252821185342894`*^9, 3.825282150204671*^9}, 
   3.8252827698575425`*^9, 3.8252828702741547`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[85]:=",ExpressionUUID->"780be44e-d362-41c6-bc75-eb26841e8c10"],

Cell["Illegal imports", "Text",
 CellChangeTimes->{{3.825282734952757*^9, 3.825282736544054*^9}, 
   3.8252827698575425`*^9, 
   3.8252828702741547`*^9},ExpressionUUID->"b0ccb7c1-d819-4a7e-876e-\
fe7e5bf532db"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qaiu0", " ", "=", 
    StyleBox["15108631",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.8048515369847345`*^9, {3.804859197487756*^9, 
   3.8048592001756873`*^9}, 3.8050175725603075`*^9, {3.8050223915991592`*^9, 
   3.805022394208959*^9}, {3.8056463094236813`*^9, 3.80564631193972*^9}, {
   3.80676606997954*^9, 3.80676607336619*^9}, {3.8068342487964683`*^9, 
   3.806834249157549*^9}, {3.8124692680980115`*^9, 3.812469293539775*^9}, {
   3.8169491372557354`*^9, 3.8169491653515244`*^9}, {3.818773584764924*^9, 
   3.8187735942853236`*^9}, {3.825282701464074*^9, 3.825282713705796*^9}, 
   3.8252827698575425`*^9, 3.8252828702741547`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[86]:=",ExpressionUUID->"ef17bc6d-a4c5-40a9-85a0-e1e90d4683ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qaip0", " ", "=", "25053337"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515541907682`*^9, {3.8048592345130177`*^9, 3.804859239029372*^9}, 
   3.805017636828994*^9, {3.8050224411970854`*^9, 3.805022443760002*^9}, {
   3.805646360660723*^9, 3.8056463640519037`*^9}, {3.806766132458228*^9, 
   3.806766181207155*^9}, {3.8068342735698805`*^9, 3.80683427388243*^9}, 
   3.8124693992391977`*^9, {3.816949177394046*^9, 3.816949192914052*^9}, {
   3.8187737337276993`*^9, 3.818773742311371*^9}, {3.8252827151109056`*^9, 
   3.825282730917507*^9}, 3.8252827698575425`*^9, 3.8252828702751675`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[87]:=",ExpressionUUID->"5869e936-4b85-417d-9535-9acd134d3627"],

Cell["Calculation of legal imports", "Text",
 CellChangeTimes->{{3.799061046869288*^9, 3.799061055183115*^9}, {
   3.799791360292451*^9, 3.7997914000229187`*^9}, {3.799791698056525*^9, 
   3.7997916983378224`*^9}, {3.7997917503203683`*^9, 3.799791755353649*^9}, {
   3.800692812549324*^9, 3.800692822846528*^9}, 3.8252820426997757`*^9, 
   3.8252827698585396`*^9, 
   3.8252828702751675`*^9},ExpressionUUID->"cd6f868f-52a1-4b7d-bdd8-\
1e0c25075729"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qalu0", " ", "=", " ", 
   RowBox[{"qatu0", "-", "qaiu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516193628035`*^9}, 
   3.8050174498061085`*^9, 3.8050175725603075`*^9, 3.805017684173834*^9, {
   3.806766217014309*^9, 3.806766218031702*^9}, 3.8252820447363935`*^9, 
   3.8252827698585396`*^9, 3.8252828702751675`*^9},
 CellLabel->"In[88]:=",ExpressionUUID->"411685ec-4e7e-4e82-ae79-6c9d904a1b83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qalp0", " ", "=", " ", 
   RowBox[{"qatp0", "-", "qaip0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516228761787`*^9}, 3.805017502641066*^9, 3.805017636828994*^9, {
   3.8050177316792107`*^9, 3.8050177321949186`*^9}, {3.8067662186099195`*^9, 
   3.806766219344413*^9}, 3.8252820455139704`*^9, 3.8252827698585396`*^9, 
   3.8252828702751675`*^9},
 CellLabel->"In[89]:=",ExpressionUUID->"34e10a13-0897-4126-a042-cb29ac11441b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qclu0", " ", "=", " ", 
   RowBox[{"qctu0", "-", "qciu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516271213703`*^9}, 
   3.8050174603547196`*^9, 3.805017589247558*^9, 3.8050176968766108`*^9, {
   3.806766593806302*^9, 3.8067665946198115`*^9}, 3.8252820463916025`*^9, 
   3.8252827698585396`*^9, 3.825282870276148*^9},
 CellLabel->"In[90]:=",ExpressionUUID->"6db908f8-9ec3-41b6-8085-74a4b5f16e26"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qclp0", " ", "=", " ", 
   RowBox[{"qctp0", "-", "qcip0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516321373944`*^9}, 3.805017512752103*^9, 3.805017646330557*^9, {
   3.8050177436811852`*^9, 3.8050177437905784`*^9}, {3.806766595072915*^9, 
   3.8067665957761555`*^9}, 3.8252820473473625`*^9, 3.8252827698595176`*^9, 
   3.825282870276148*^9},
 CellLabel->"In[91]:=",ExpressionUUID->"47372b87-46e4-4e84-abb6-b4b18d167dd3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qhlu0", " ", "=", " ", 
   RowBox[{"qhtu0", "-", "qhiu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516376071844`*^9}, {
   3.806766624204184*^9, 3.8067666300019217`*^9}, 3.8252820483721275`*^9, 
   3.8252827698595176`*^9, 3.825282870276148*^9},
 CellLabel->"In[92]:=",ExpressionUUID->"5cef1721-b569-43ee-b7b4-73bb1e65ec8f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qhlp0", " ", "=", " ", 
   RowBox[{"qhtp0", "-", "qhip0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516080308895`*^9}, {3.804851639935667*^9, 3.8048516418820176`*^9}, {
   3.8067666401468067`*^9, 3.8067666444073915`*^9}, 3.825282049149751*^9, 
   3.8252827698595176`*^9, 3.825282870277191*^9},
 CellLabel->"In[93]:=",ExpressionUUID->"72241c77-9f0f-489b-8a81-f6b0d3b357f1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qolu0", " ", "=", " ", 
   RowBox[{"qotu0", "-", "qoiu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516110447454`*^9}, {
   3.804851645028388*^9, 3.8048516486545525`*^9}, 3.8050174723254375`*^9, 
   3.805017601499572*^9, 3.805017705706191*^9, {3.8067666475387836`*^9, 
   3.8067666523377275`*^9}, 3.8252820500214276`*^9, 3.825282769860554*^9, 
   3.825282870277191*^9},
 CellLabel->"In[94]:=",ExpressionUUID->"7642a00a-7e5c-4224-8711-9ffc11e1be68"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qolp0", " ", "=", " ", 
   RowBox[{"qotp0", "-", "qoip0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516144799304`*^9}, {3.8048516517171288`*^9, 3.804851653045458*^9}, 
   3.805017523503875*^9, 3.8050176541599693`*^9, {3.8050177690133715`*^9, 
   3.80501776909151*^9}, {3.80676665546325*^9, 3.806766660471738*^9}, 
   3.8252820516947126`*^9, 3.825282769860554*^9, 3.825282870277191*^9},
 CellLabel->"In[95]:=",ExpressionUUID->"912b37a4-b188-4750-8262-c62c624d05cf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qplu0", " ", "=", " ", 
   RowBox[{"qptu0", "-", "qpiu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516110447454`*^9}, {
   3.804851645028388*^9, 3.8048516486545525`*^9}, 3.8050174723254375`*^9, 
   3.805017601499572*^9, 3.805017705706191*^9, {3.805017779297551*^9, 
   3.8050177851734924`*^9}, {3.806766664377368*^9, 3.806766668653369*^9}, 
   3.825282052624403*^9, 3.825282769860554*^9, 3.825282870278169*^9},
 CellLabel->"In[96]:=",ExpressionUUID->"b2292b82-0665-4f04-80e1-a2dee86e9765"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qplp0", " ", "=", " ", 
   RowBox[{"qptp0", "-", "qpip0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516144799304`*^9}, {3.8048516517171288`*^9, 3.804851653045458*^9}, 
   3.805017523503875*^9, 3.8050176541599693`*^9, {3.8050177690133715`*^9, 
   3.805017793223928*^9}, {3.806766671622616*^9, 3.8067666779986753`*^9}, 
   3.8252820535161233`*^9, 3.825282769860554*^9, 3.825282870278169*^9},
 CellLabel->"In[97]:=",ExpressionUUID->"2f08f5a1-311d-43ce-870b-fb2dfac7f219"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qslu0", " ", "=", " ", 
   RowBox[{"qstu0", "-", "qsiu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516110447454`*^9}, {
   3.804851645028388*^9, 3.8048516486545525`*^9}, 3.8050174723254375`*^9, 
   3.805017601499572*^9, 3.805017705706191*^9, {3.8050177978316727`*^9, 
   3.8050178023792987`*^9}, {3.806766682922386*^9, 3.806766689126542*^9}, 
   3.8252820552424517`*^9, 3.82528276986152*^9, 3.825282870278169*^9},
 CellLabel->"In[98]:=",ExpressionUUID->"b10de096-9726-4741-8e0d-30b85301d56f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qslp0", " ", "=", " ", 
   RowBox[{"qstp0", "-", "qsip0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516144799304`*^9}, {3.8048516517171288`*^9, 3.804851653045458*^9}, 
   3.805017523503875*^9, 3.8050176541599693`*^9, {3.8050177690133715`*^9, 
   3.80501776909151*^9}, {3.8050178052247257`*^9, 3.8050178102724323`*^9}, {
   3.8067666922713327`*^9, 3.806766697960101*^9}, 3.8252820563152704`*^9, 
   3.82528276986152*^9, 3.825282870278169*^9},
 CellLabel->"In[99]:=",ExpressionUUID->"fc71cdd8-ff97-488c-8f54-4ec2ef85e7be"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.4 Export Quantities", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672744603273*^9}, {
   3.8196728121258554`*^9, 3.8196728122829847`*^9}, {3.819815211108224*^9, 
   3.8198152128205585`*^9}, 3.81981526037964*^9, 3.825007774600871*^9, 
   3.8252828702791944`*^9},ExpressionUUID->"e6348688-762b-443a-892a-\
529db277f3c6"],

Cell[TextData[StyleBox["Source:National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries). NOAA US \
Trade in Fishery Products database. Accessed September 1, 2020. \
https://foss.nmfs.noaa.gov/apexfoss/f?p=215:2:14884747663545::NO",
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, 
   3.819814602882104*^9, {3.8198147741606445`*^9, 3.8198147935287457`*^9}, {
   3.819815219280593*^9, 3.81981526037964*^9}, {3.819815772355571*^9, 
   3.8198157737996855`*^9}, 3.825007774600871*^9, 3.8252828702791944`*^9},
 FontSize->12,ExpressionUUID->"454c406c-2e9f-4bb5-aae3-13295ab94eff"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadue0", " ", "=", "8033812.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.8048518506428456`*^9}, 3.805018387688871*^9, {
   3.805023130413168*^9, 3.8050231336479807`*^9}, 3.8067662301460323`*^9, {
   3.806767656937772*^9, 3.8067676608067927`*^9}, {3.806834315302986*^9, 
   3.806834315662419*^9}, {3.8252828110463552`*^9, 3.825282811937111*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[100]:=",ExpressionUUID->"d36c758b-7ed8-4713-92ae-51ee7315a7bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qcdue0", " ", "=", "2707550.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.8048518633108516`*^9}, {3.804859565020601*^9, 
   3.8048595675211444`*^9}, 3.8050184291651025`*^9, 3.805018466468952*^9, {
   3.8050231373516073`*^9, 3.805023140305151*^9}, {3.806767607638239*^9, 
   3.8067676077953825`*^9}, {3.806767668703966*^9, 3.806767672090616*^9}, {
   3.806834318489034*^9, 3.8068343188244753`*^9}, 3.825282815699027*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[101]:=",ExpressionUUID->"ebbcdefa-e8b4-418d-bbcc-8a1406b8ea24"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qcdpe0", " ", "=", "  ", "131378.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.804851865652524*^9}, {
   3.8048595759473476`*^9, 3.8048595789792566`*^9}, 3.8050184188980236`*^9, 
   3.805018469422534*^9, {3.806767612029669*^9, 3.80676761210773*^9}, {
   3.8067676834935265`*^9, 3.8067676858163443`*^9}, {3.8068343214811664`*^9, 
   3.8068343218562264`*^9}, 3.8252828164276543`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[102]:=",ExpressionUUID->"3302594c-3311-486c-975d-02c4f6420f26"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhdue0", " ", "=", "36963258.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.804851867681604*^9}, {3.8048595877155313`*^9, 
   3.804859590950609*^9}, 3.8050184722360744`*^9, {3.805023149337344*^9, 
   3.805023152290888*^9}, {3.806767614815849*^9, 3.80676761511108*^9}, {
   3.8067676985082636`*^9, 3.8067677012944436`*^9}, {3.80683432451292*^9, 
   3.8068343248410997`*^9}, 3.8252828171001863`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[103]:=",ExpressionUUID->"1673fb4d-d680-490d-a146-b94de2c1ce9e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qhdpe0", " ", "=", "  ", "2471392.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.8048518697629004`*^9}, {
   3.8048595996715755`*^9, 3.804859601859536*^9}, 3.805018474955246*^9, {
   3.8067676178682337`*^9, 3.806767618271547*^9}, {3.806767708767285*^9, 
   3.8067677119287524`*^9}, {3.8068343281541476`*^9, 3.8068343285135827`*^9}, 
   3.825282817849766*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[104]:=",ExpressionUUID->"6a1cb2bd-9ccd-4c6e-a7ca-0c0cc8e3fd86"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qodue0", " ", "=", "5980213.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.804851871981992*^9}, {3.804859615581441*^9, 
   3.804859619692989*^9}, 3.805018443417308*^9, 3.8050184782526307`*^9, {
   3.805023157744404*^9, 3.8050231603693323`*^9}, {3.8067676209406357`*^9, 
   3.8067676211467967`*^9}, {3.8067677244235168`*^9, 3.806767727091604*^9}, {
   3.8068343307327037`*^9, 3.8068343319360304`*^9}, 3.825282818739462*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[105]:=",ExpressionUUID->"778b1d34-2b16-4641-afe4-958ffaa66eba"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qodpe0", " ", "=", "  ", "1533655.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.8048518740604353`*^9}, {
   3.8048596312446957`*^9, 3.8048596325730925`*^9}, {3.8050184579051275`*^9, 
   3.8050184808624096`*^9}, {3.806767624337293*^9, 3.806767624849691*^9}, {
   3.8067677375878105`*^9, 3.806767740728263*^9}, {3.8068343346077957`*^9, 
   3.8068343349403543`*^9}, 3.825282819512092*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[106]:=",ExpressionUUID->"17bf2afb-74a4-4899-a403-1ee2cb2495d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qpdue0", " ", "=", "30000412.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.804851871981992*^9}, {3.804859615581441*^9, 
   3.804859619692989*^9}, 3.805018443417308*^9, {3.8050184782526307`*^9, 
   3.8050184905223784`*^9}, {3.805023165776619*^9, 3.8050231684957542`*^9}, 
   3.8050238288230305`*^9, {3.8067676282663617`*^9, 3.806767628561593*^9}, {
   3.8067677521111593`*^9, 3.80676775527063*^9}, {3.80683433752181*^9, 
   3.8068343378768854`*^9}, 3.8252828208231034`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[107]:=",ExpressionUUID->"7f003a9b-1f8b-4d9e-a4a9-1aca2619de06"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qpdpe0", " ", "=", "  ", "16530654.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.8048518740604353`*^9}, {
   3.8048596312446957`*^9, 3.8048596325730925`*^9}, {3.8050184579051275`*^9, 
   3.805018494757408*^9}, {3.806767631161628*^9, 3.8067676314358406`*^9}, {
   3.8067677648911514`*^9, 3.806767767894495*^9}, {3.8068343409590635`*^9, 
   3.8068343413028708`*^9}, {3.816948836428999*^9, 3.816948837645254*^9}, 
   3.825282821772854*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[108]:=",ExpressionUUID->"37bb7d17-06ad-414f-a3a0-68314fec7d91"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdue0", " ", "=", "40802050.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.804851871981992*^9}, {3.804859615581441*^9, 
   3.804859619692989*^9}, 3.805018443417308*^9, {3.8050184782526307`*^9, 
   3.805018498367342*^9}, 3.8050231725588303`*^9, {3.8067676343801394`*^9, 
   3.8067676346263323`*^9}, {3.806767777695158*^9, 3.8067677808266015`*^9}, {
   3.806834343978668*^9, 3.8068343443463693`*^9}, 3.8252828226705675`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[109]:=",ExpressionUUID->"e1812860-5f1c-4169-94a1-19394261051f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdpe0", " ", "=", "  ", "20008192.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.8048518740604353`*^9}, {
   3.8048596312446957`*^9, 3.8048596325730925`*^9}, {3.8050184579051275`*^9, 
   3.8050185027117643`*^9}, {3.806767637236376*^9, 3.806767637599659*^9}, {
   3.806767787344696*^9, 3.806767790347046*^9}, {3.806834347100793*^9, 
   3.8068343473977175`*^9}, 3.8252828234961905`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[110]:=",ExpressionUUID->"afaa7c76-91eb-4a00-b049-87075744925a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.5 Catch Limits", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672709332239*^9}, {
   3.819672747951029*^9, 3.819672752938134*^9}, {3.819672814932173*^9, 
   3.8196728150802965`*^9}, 3.8198153194016666`*^9, 3.8250241781979237`*^9, 
   3.8252829616523466`*^9, 
   3.825283063327988*^9},ExpressionUUID->"5a9ca741-86a3-462d-a8a9-\
6fee3c9310a0"],

Cell[TextData[StyleBox["No aggregate ACL available, inserted arbitrarily high \
limit so it doesn\[CloseCurlyQuote]t affect calculation. ",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934406567`*^9, 3.8250232599285984`*^9, 3.8250234385889854`*^9, {
   3.8250235568550773`*^9, 3.825023721715456*^9}, {3.8250241515651827`*^9, 
   3.825024178198924*^9}, 3.8252829616523466`*^9, 
   3.825283063327988*^9},ExpressionUUID->"c0266644-bc10-4206-b984-\
978ef0416051"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qadcap", " ", "=", "400000000.00"}], ";", " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.804851796545054*^9, 
   3.8048952007649207`*^9, {3.804895250483545*^9, 3.8048952544374237`*^9}, {
   3.8050183281629877`*^9, 3.805018342993407*^9}, {3.805023083589896*^9, 
   3.8050230976888266`*^9}, {3.805665773734192*^9, 3.80566577395298*^9}, 
   3.8067662239728813`*^9, {3.806834296407627*^9, 3.8068342968474436`*^9}, {
   3.814174256645563*^9, 3.8141742595679245`*^9}, {3.8252829426613398`*^9, 
   3.825282961653345*^9}, 3.825283063327988*^9, {3.825413501750223*^9, 
   3.8254135026248617`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[111]:=",ExpressionUUID->"802c6b9b-1962-431d-b17b-a621193520c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcdcap", " ", "=", "400000000.00"}], ";", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.8048517992485948`*^9, {
   3.8048952270850687`*^9, 3.8048952446230383`*^9}, {3.805018338242672*^9, 
   3.8050183454469113`*^9}, 3.8050231013143167`*^9, {3.8056657763909063`*^9, 
   3.805665776531555*^9}, {3.8067675511110563`*^9, 3.8067675512481637`*^9}, {
   3.8068342994728765`*^9, 3.8068342998323116`*^9}, 3.8141742688975906`*^9, {
   3.825282944691992*^9, 3.825282961653345*^9}, 3.8252830633290005`*^9, 
   3.8254135063257294`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[112]:=",ExpressionUUID->"cb959750-59dd-405b-8ff0-098877582c11"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qhdcap", " ", "=", "400000000.00"}], ";", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.8048518024053288`*^9, 
   3.8048952209520655`*^9, 3.8048952578286753`*^9, {3.805023085762065*^9, 
   3.8050231025488586`*^9}, {3.805665779407057*^9, 3.8056657795320787`*^9}, {
   3.80676755527631*^9, 3.806767555551525*^9}, {3.8068343022858467`*^9, 
   3.806834302629654*^9}, {3.814174271835574*^9, 3.8141742723512864`*^9}, {
   3.8252829463943243`*^9, 3.8252829616543636`*^9}, 3.8252830633290005`*^9, 
   3.8254135076967773`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[113]:=",ExpressionUUID->"63bde8db-8dca-4231-b99b-9dc06652c0ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qodcap", " ", "=", "400000000.00"}], ";", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.804851805171688*^9, {
   3.8048961193381124`*^9, 3.804896138325565*^9}, {3.8050183495569224`*^9, 
   3.8050183601989946`*^9}, {3.8050230886843357`*^9, 
   3.8050231036583843`*^9}, {3.8056657816756353`*^9, 3.805665781800657*^9}, {
   3.8067675583186903`*^9, 3.8067675585548754`*^9}, {3.8068343059114466`*^9, 
   3.806834306239627*^9}, 3.8141742747266793`*^9, {3.825282948723135*^9, 
   3.8252829616543636`*^9}, 3.8252830633290005`*^9, 3.825413509128887*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[114]:=",ExpressionUUID->"fc85e40d-813d-4459-9fa3-8bef78a8fce4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qpdcap", " ", "=", "400000000.00"}], ";", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.804851805171688*^9, {
   3.8048961193381124`*^9, 3.804896138325565*^9}, {3.8050183495569224`*^9, 
   3.8050183601989946`*^9}, {3.805019563577289*^9, 3.805019563702309*^9}, {
   3.8050230912784367`*^9, 3.805023104830418*^9}, {3.805665784176071*^9, 
   3.805665784316721*^9}, {3.80676756115491*^9, 3.806767561390093*^9}, {
   3.8068343088057985`*^9, 3.8068343091964874`*^9}, 3.814174277711546*^9, {
   3.82528295027037*^9, 3.8252829616543636`*^9}, 3.8252830633290005`*^9, 
   3.825413510195737*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[115]:=",ExpressionUUID->"422e32a6-79a0-4a83-9eca-a130a7bfd0fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qsdcap", " ", "=", "400000000.00"}], ";", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.804851805171688*^9, {
   3.8048961193381124`*^9, 3.804896138325565*^9}, {3.8050183495569224`*^9, 
   3.8050183601989946`*^9}, {3.8050195666402893`*^9, 3.805019566843447*^9}, {
   3.8050230933255887`*^9, 3.805023105830553*^9}, {3.805665786724717*^9, 
   3.8056657868341284`*^9}, {3.806767565536332*^9, 3.8067675660767546`*^9}, {
   3.8068343119922433`*^9, 3.806834312320423*^9}, 3.8141742799306636`*^9, {
   3.825282952034745*^9, 3.8252829616553636`*^9}, 3.8252830633299837`*^9, 
   3.8254135114927273`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[116]:=",ExpressionUUID->"8a6ec7a1-47a4-4e5f-837b-ec8dc5daca28"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.6 Import Market Share Statistics", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8199018381766195`*^9, 3.8199018609792204`*^9}, 
   3.819901901056156*^9, 3.8199024672872863`*^9, 3.825024287532875*^9, 
   3.8252830633299837`*^9},ExpressionUUID->"19d1fea4-b481-466d-b51c-\
306eaf6e60b0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qatu0", "/", 
   RowBox[{"(", 
    RowBox[{"qatu0", "+", "qadu0", "-", "qadue0"}], " ", ")"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.818953024907323*^9, 3.8189530373429193`*^9}},
 CellLabel->
  "In[117]:=",ExpressionUUID->"d71e9edd-cd25-47c5-a8ba-562ba90ec246"],

Cell[BoxData["0.9271156633893265`"], "Output",
 CellChangeTimes->{{3.8189530475394964`*^9, 3.8189530634850035`*^9}, 
   3.8200583259797688`*^9, 3.820058357945856*^9, 3.820358843738633*^9, 
   3.825282755012702*^9, 3.8252830447535143`*^9, 3.8252832814436445`*^9, 
   3.825284012338648*^9, 3.8254135287552633`*^9},
 CellLabel->
  "Out[117]=",ExpressionUUID->"1295d508-425f-4567-9db6-16e338dd3dcf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qctu0", "/", 
   RowBox[{"(", 
    RowBox[{"qctu0", "+", "qcdu0", "-", "qcdue0", " ", "-", " ", 
     RowBox[{"cr", " ", "qcdp0"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.810597155119048*^9, 3.810597365066209*^9}, {
  3.812670843854066*^9, 3.812670916882797*^9}, {3.812671106902447*^9, 
  3.812671111883337*^9}},
 CellLabel->
  "In[118]:=",ExpressionUUID->"b5257770-7669-43d7-9c1a-bdb826fb06f2"],

Cell[BoxData["0.9879120508159625`"], "Output",
 CellChangeTimes->{{3.8105971652300406`*^9, 3.810597365972604*^9}, 
   3.812469626521818*^9, 3.812469895809269*^9, {3.8126708662434587`*^9, 
   3.8126708895355625`*^9}, 3.8126709298398623`*^9, 3.8126711660826797`*^9, 
   3.812671223683113*^9, 3.812801907573492*^9, 3.812802309819569*^9, 
   3.8128023609703817`*^9, 3.812927710356062*^9, 3.812928109014907*^9, 
   3.8129284894099765`*^9, 3.8129756757630606`*^9, 3.812976077079729*^9, 
   3.8154770189297113`*^9, 3.815774985074869*^9, 3.8169493260738125`*^9, 
   3.8187759429124823`*^9, {3.8189530477827015`*^9, 3.8189530636861844`*^9}, 
   3.8200583261368923`*^9, 3.820058358105982*^9, 3.8203588438977585`*^9, 
   3.825282755164812*^9, 3.8252830451347723`*^9, 3.825283281669838*^9, 
   3.82528401256182*^9, 3.825413529021454*^9},
 CellLabel->
  "Out[118]=",ExpressionUUID->"6404d630-3d63-42b4-b4d1-cce9bcb0461e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qctp0", "/", 
   RowBox[{"(", 
    RowBox[{"qctp0", "+", "qcdp0", "-", "qcdpe0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.810597155119048*^9, 3.810597365066209*^9}, {
  3.812670843854066*^9, 3.812670857097354*^9}, {3.812670920033244*^9, 
  3.812670925797722*^9}},
 CellLabel->
  "In[119]:=",ExpressionUUID->"4f9f1654-1aad-48c8-b656-5d405430fe68"],

Cell[BoxData["0.7315397881618083`"], "Output",
 CellChangeTimes->{{3.8105971652300406`*^9, 3.810597365972604*^9}, 
   3.812469626521818*^9, 3.812469895809269*^9, 3.8126708662434587`*^9, 
   3.812670927624141*^9, 3.8126712238422365`*^9, 3.8128019077336164`*^9, 
   3.8128023099987082`*^9, 3.812802361144517*^9, 3.812927710548211*^9, 
   3.8129281092050557`*^9, 3.8129284896051283`*^9, 3.812975676023899*^9, 
   3.812976077345398*^9, 3.815477019179753*^9, 3.8157749852980433`*^9, 
   3.816949326085822*^9, 3.818775942924491*^9, {3.818953047979873*^9, 
   3.8189530638723383`*^9}, 3.8200583262209587`*^9, 3.8200583582761154`*^9, 
   3.8203588443030806`*^9, 3.82528275535597*^9, 3.825283045362958*^9, 
   3.8252832817959433`*^9, 3.8252840128120203`*^9, 3.825413529281598*^9},
 CellLabel->
  "Out[119]=",ExpressionUUID->"a69bec5a-7be7-44ef-afc6-12c978718eec"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qhtu0", "/", 
   RowBox[{"(", 
    RowBox[{"qhtu0", "+", "qhdu0", "-", "qhdue0", " ", "-", " ", 
     RowBox[{"cr", " ", "qhdp0"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.810597155119048*^9, 3.810597365066209*^9}, {
  3.812670843854066*^9, 3.8126708881805*^9}, {3.8126709514126205`*^9, 
  3.8126709583820343`*^9}, {3.812671118766714*^9, 3.8126711274605093`*^9}},
 CellLabel->
  "In[120]:=",ExpressionUUID->"c748519c-6bfb-4c72-9cdc-8bc25b257406"],

Cell[BoxData["0.05245023957499236`"], "Output",
 CellChangeTimes->{{3.8105971652300406`*^9, 3.810597365972604*^9}, 
   3.812469626521818*^9, 3.812469895809269*^9, {3.8126708662434587`*^9, 
   3.8126708895355625`*^9}, 3.8126709721327167`*^9, 3.8126711681002593`*^9, 
   3.812671224004363*^9, 3.812801907816681*^9, 3.8128023101768465`*^9, 
   3.812802361307644*^9, 3.8129277107413616`*^9, 3.8129281093901997`*^9, 
   3.812928489790273*^9, 3.8129756762490735`*^9, 3.812976077583172*^9, 
   3.8154770194297943`*^9, 3.81577498540613*^9, 3.816949326098839*^9, 
   3.818775942937501*^9, {3.8189530481690316`*^9, 3.81895306398846*^9}, 
   3.8200583263930936`*^9, 3.82005835835818*^9, 3.8203588444481945`*^9, 
   3.825282755589151*^9, 3.8252830456021166`*^9, 3.8252832820150957`*^9, 
   3.8252840130872393`*^9, 3.8254135295067735`*^9},
 CellLabel->
  "Out[120]=",ExpressionUUID->"997f95e6-6f37-4820-ba66-1e936d96aac6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qhtp0", "/", 
   RowBox[{"(", 
    RowBox[{"qhtp0", "+", "qhdp0", "-", "qhdpe0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.810597155119048*^9, 3.810597365066209*^9}, {
  3.812670843854066*^9, 3.812670857097354*^9}, {3.812670962656355*^9, 
  3.8126709694786544`*^9}},
 CellLabel->
  "In[121]:=",ExpressionUUID->"9145fced-15b2-47bc-8826-d99470fda361"],

Cell[BoxData["0.7652052863745149`"], "Output",
 CellChangeTimes->{{3.8105971652300406`*^9, 3.810597365972604*^9}, 
   3.812469626521818*^9, 3.812469895809269*^9, 3.8126708662434587`*^9, 
   3.8126709743094077`*^9, 3.8126712241544795`*^9, 3.812801907964796*^9, 
   3.8128023103439765`*^9, 3.812802361473773*^9, 3.8129277109455204`*^9, 
   3.8129281095733423`*^9, 3.8129284899814234`*^9, 3.8129756764772816`*^9, 
   3.812976077864502*^9, 3.8154770196642084`*^9, 3.815774985620305*^9, 
   3.81694932611091*^9, 3.818775942950512*^9, {3.8189530483762116`*^9, 
   3.818953064189601*^9}, 3.8200583265572443`*^9, 3.8200583585042944`*^9, 
   3.8203588445973125`*^9, 3.825282755825345*^9, 3.825283045832303*^9, 
   3.8252832822803*^9, 3.825284013333427*^9, 3.825413529743971*^9},
 CellLabel->
  "Out[121]=",ExpressionUUID->"db83d8c7-ac3f-4d9e-ab76-71b5f583ec87"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qotu0", "/", 
   RowBox[{"(", 
    RowBox[{"qotu0", "+", "qodu0", "-", "qodue0", " ", "-", " ", 
     RowBox[{"cr", " ", "qodp0"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.810597155119048*^9, 3.810597365066209*^9}, {
  3.812670843854066*^9, 3.8126708881805*^9}, {3.81267099014571*^9, 
  3.81267099826902*^9}, {3.81267113309291*^9, 3.812671140427635*^9}, {
  3.820358493836504*^9, 3.820358495677938*^9}},
 CellLabel->
  "In[122]:=",ExpressionUUID->"da31f88c-ffc5-4b6b-99e0-2f2b3b053f93"],

Cell[BoxData["0.3304069799238799`"], "Output",
 CellChangeTimes->{{3.8105971652300406`*^9, 3.810597365972604*^9}, 
   3.812469626521818*^9, 3.812469895809269*^9, {3.8126708662434587`*^9, 
   3.8126708895355625`*^9}, {3.8126710006188455`*^9, 3.8126710134097815`*^9}, 
   3.8126711700207577`*^9, 3.8126712243006105`*^9, 3.812801908179963*^9, 
   3.8128023105051017`*^9, 3.8128023616409025`*^9, 3.812927711139671*^9, 
   3.8129281097554836`*^9, 3.812928490166568*^9, 3.8129756766984234`*^9, 
   3.812976078145775*^9, 3.81547701991425*^9, 3.8157749858374667`*^9, 
   3.816949326124033*^9, 3.818775942963522*^9, {3.818953048573383*^9, 
   3.8189530643027587`*^9}, 3.8200583267053385`*^9, 3.820058358594365*^9, 
   3.820358844744429*^9, 3.8252827560495243`*^9, 3.825283046064496*^9, 
   3.825283282505528*^9, 3.8252840135856667`*^9, 3.825413530044219*^9},
 CellLabel->
  "Out[122]=",ExpressionUUID->"3a7f4c9d-ec0a-4f04-ba0a-747355298c26"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qotp0", "/", 
   RowBox[{"(", 
    RowBox[{"qotp0", "+", "qodp0", "-", "qodpe0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.810597155119048*^9, 3.810597365066209*^9}, {
  3.812670843854066*^9, 3.812670857097354*^9}, {3.8126710029076233`*^9, 
  3.8126710096708775`*^9}},
 CellLabel->
  "In[123]:=",ExpressionUUID->"7bfcd954-2105-4eee-ada3-e486fd33ff54"],

Cell[BoxData["0.6736983752782248`"], "Output",
 CellChangeTimes->{{3.8105971652300406`*^9, 3.810597365972604*^9}, 
   3.812469626521818*^9, 3.812469895809269*^9, 3.8126708662434587`*^9, 
   3.8126710115263186`*^9, 3.8126712244457073`*^9, 3.812801908329079*^9, 
   3.812802310675234*^9, 3.8128023618090334`*^9, 3.8129277113908663`*^9, 
   3.8129281099316206`*^9, 3.8129284903677797`*^9, 3.8129756769185944`*^9, 
   3.812976078411414*^9, 3.8154770201486645`*^9, 3.815774986029617*^9, 
   3.8169493261370444`*^9, 3.8187759429755316`*^9, {3.818953048756538*^9, 
   3.8189530644828854`*^9}, 3.8200583268544555`*^9, 3.820058358739479*^9, 
   3.8203588448955483`*^9, 3.8252827562776995`*^9, 3.8252830463327017`*^9, 
   3.825283282727662*^9, 3.825284013830834*^9, 3.825413530300407*^9},
 CellLabel->
  "Out[123]=",ExpressionUUID->"ef170ac2-50a6-48aa-92e6-3721a69c34c5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qptu0", "/", 
   RowBox[{"(", 
    RowBox[{"qptu0", "+", "qpdu0", "-", "qpdue0", " ", "-", " ", 
     RowBox[{"cr", " ", "qpdp0"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.810597155119048*^9, 3.810597365066209*^9}, {
  3.812670843854066*^9, 3.8126708881805*^9}, {3.812671028743694*^9, 
  3.812671035782161*^9}, {3.8126711433128943`*^9, 3.812671147320021*^9}},
 CellLabel->
  "In[124]:=",ExpressionUUID->"64f21cd7-4bc8-4331-a623-54225eba06cc"],

Cell[BoxData["0.6405503255761912`"], "Output",
 CellChangeTimes->{{3.8105971652300406`*^9, 3.810597365972604*^9}, 
   3.812469626521818*^9, 3.812469895809269*^9, {3.8126708662434587`*^9, 
   3.8126708895355625`*^9}, 3.8126710516775093`*^9, 3.812671171940256*^9, 
   3.8126712246068335`*^9, 3.8128019084761934`*^9, 3.8128023108473673`*^9, 
   3.812802361995178*^9, 3.8129277116070337`*^9, 3.812928110144786*^9, 
   3.8129284905689096`*^9, 3.812975677160531*^9, 3.8129760786615057`*^9, 
   3.8154770204143333`*^9, 3.8157749862267694`*^9, 3.8169493261541157`*^9, 
   3.8187759429885416`*^9, {3.818953048974716*^9, 3.8189530645879974`*^9}, 
   3.8200583270035725`*^9, 3.8200583588315644`*^9, 3.8203588450556755`*^9, 
   3.825282756543995*^9, 3.8252830465869436`*^9, 3.825283283030907*^9, 
   3.8252840141140604`*^9, 3.825413530528611*^9},
 CellLabel->
  "Out[124]=",ExpressionUUID->"5ce24511-676e-4eef-8bf9-c86c0fa69beb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qptp0", "/", 
   RowBox[{"(", 
    RowBox[{"qptp0", "+", "qpdp0", "-", "qpdpe0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.810597155119048*^9, 3.810597365066209*^9}, {
  3.812670843854066*^9, 3.812670857097354*^9}, {3.8126710385493107`*^9, 
  3.812671046062147*^9}},
 CellLabel->
  "In[125]:=",ExpressionUUID->"80efdd6a-883c-466c-8dc3-9bef8f7e6a27"],

Cell[BoxData["0.8385443921354123`"], "Output",
 CellChangeTimes->{{3.8105971652300406`*^9, 3.810597365972604*^9}, 
   3.812469626521818*^9, 3.812469895809269*^9, 3.8126708662434587`*^9, 
   3.8126710482138186`*^9, 3.8126712247539487`*^9, 3.8128019086243086`*^9, 
   3.812802311011495*^9, 3.8128023621753187`*^9, 3.8129277118061895`*^9, 
   3.812928110325927*^9, 3.812928490763034*^9, 3.8129756773719387`*^9, 
   3.8129760789271283`*^9, 3.815477020680002*^9, 3.8157749864529457`*^9, 
   3.8169493261700697`*^9, 3.8187759430006003`*^9, {3.818953049168871*^9, 
   3.8189530647620883`*^9}, 3.820058327155692*^9, 3.8200583589816694`*^9, 
   3.8203588452038035`*^9, 3.8252827567670946`*^9, 3.825283046840108*^9, 
   3.8252832833681974`*^9, 3.825284014356264*^9, 3.8254135307778006`*^9},
 CellLabel->
  "Out[125]=",ExpressionUUID->"056be80f-4262-40ec-86cd-54162f79675c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qstu0", "/", 
   RowBox[{"(", 
    RowBox[{"qstu0", "+", "qsdu0", "-", "qsdue0", "-", 
     RowBox[{"cr", " ", "qsdp0"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.810597155119048*^9, 3.810597365066209*^9}, {
  3.812670843854066*^9, 3.8126708881805*^9}, {3.8126711519686565`*^9, 
  3.8126711591552725`*^9}},
 CellLabel->
  "In[126]:=",ExpressionUUID->"d3b97b9f-e211-491f-b3e8-ade2b1540012"],

Cell[BoxData["0.10069633282920863`"], "Output",
 CellChangeTimes->{{3.8105971652300406`*^9, 3.810597365972604*^9}, 
   3.812469626521818*^9, 3.812469895809269*^9, {3.8126708662434587`*^9, 
   3.8126708895355625`*^9}, {3.8126711623897977`*^9, 3.812671173910798*^9}, 
   3.8126712248980618`*^9, 3.812801908773425*^9, 3.812802311179628*^9, 
   3.812802362341447*^9, 3.812927712001342*^9, 3.812928110504065*^9, 
   3.8129284909531813`*^9, 3.812975677606352*^9, 3.812976079192792*^9, 
   3.8154770209267855`*^9, 3.8157749866871634`*^9, 3.8169493261820793`*^9, 
   3.8187759430115595`*^9, {3.8189530493560452`*^9, 3.8189530648771887`*^9}, 
   3.8200583273048086`*^9, 3.82005835907174*^9, 3.8203588453639193`*^9, 
   3.8252827570192986`*^9, 3.8252830470892973`*^9, 3.825283283681396*^9, 
   3.8252840145894213`*^9, 3.825413531368232*^9},
 CellLabel->
  "Out[126]=",ExpressionUUID->"1062b641-54c1-42e3-8b55-761d743992c7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qstp0", "/", 
   RowBox[{"(", 
    RowBox[{"qstp0", "+", "qsdp0", "-", "qsdpe0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.810597155119048*^9, 3.810597365066209*^9}, {
  3.812670843854066*^9, 3.812670857097354*^9}},
 CellLabel->
  "In[127]:=",ExpressionUUID->"383526ba-b438-46d4-8677-896d5f8d4c05"],

Cell[BoxData["0.7270962570683689`"], "Output",
 CellChangeTimes->{{3.8105971652300406`*^9, 3.810597365972604*^9}, 
   3.812469626521818*^9, 3.812469895809269*^9, 3.8126708662434587`*^9, 
   3.812671225052182*^9, 3.812801908927546*^9, 3.8128023113467555`*^9, 
   3.8128023625075765`*^9, 3.812927712232523*^9, 3.812928110676199*^9, 
   3.812928491147332*^9, 3.8129756778095093`*^9, 3.8129760794584665`*^9, 
   3.8154770211612115`*^9, 3.8157749869203186`*^9, 3.816949326194088*^9, 
   3.818775943022568*^9, {3.818953049560212*^9, 3.8189530650603385`*^9}, 
   3.820058327473942*^9, 3.8200583592158527`*^9, 3.820358845510035*^9, 
   3.8252827572574854`*^9, 3.825283047385507*^9, 3.8252832839416046`*^9, 
   3.825284014837589*^9, 3.825413531589423*^9},
 CellLabel->
  "Out[127]=",ExpressionUUID->"c24718aa-806f-443d-abe0-5e1991a48452"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3. Calibration",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.7954529786642447`*^9}, {
  3.79545386036082*^9, 3.7954538618860044`*^9}, {3.819900448697421*^9, 
  3.8199004491007357`*^9}},ExpressionUUID->"0211a225-8a35-4582-b9ef-\
4f2047c88c34"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vatu0", "=", 
   RowBox[{"qatu0", " ", "patu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.8048519125993204`*^9, 3.804851917644553*^9}, 
   3.8050174498061085`*^9, 3.8050180911508274`*^9, 3.805018527654379*^9, {
   3.806766231877928*^9, 3.806766232893716*^9}},
 CellLabel->
  "In[128]:=",ExpressionUUID->"9d5a52cf-3316-4cb2-80ab-9c9bede1d617"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vatp0", "=", 
   RowBox[{"qatp0", " ", "patp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519143027067`*^9, 3.804851921426384*^9}, 3.805017502641066*^9, 
   3.8050182696736803`*^9, 3.805018537499652*^9, {3.806766233362541*^9, 
   3.806766234022113*^9}},
 CellLabel->
  "In[129]:=",ExpressionUUID->"563be225-6049-49ee-806a-d676b042abd2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vctu0", "=", 
   RowBox[{"qctu0", " ", "pctu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851926580485*^9, 3.8048519296747103`*^9}, 
   3.8050174603547196`*^9, 3.805018101074109*^9, 3.8050185566621103`*^9, {
   3.8067680042442317`*^9, 3.806768006696144*^9}},
 CellLabel->
  "In[130]:=",ExpressionUUID->"586a9c09-4290-443b-bf7d-c0d9a9d73e0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vctp0", "=", 
   RowBox[{"qctp0", " ", "pctp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519311436853`*^9, 3.804851933990306*^9}, 3.805017512752103*^9, 
   3.805018278393769*^9, 3.805018548673256*^9, {3.806768007129483*^9, 
   3.8067680078870764`*^9}},
 CellLabel->
  "In[131]:=",ExpressionUUID->"64e92a99-a9c8-424b-ad08-340b3749b512"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vhtu0", "=", 
   RowBox[{"qhtu0", " ", "phtu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851936162515*^9, 3.8048519393476534`*^9}, {
   3.8067680317167034`*^9, 3.806768032532342*^9}},
 CellLabel->
  "In[132]:=",ExpressionUUID->"d41b583f-dae0-48e9-b4c3-be318f3fd670"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vhtp0", "=", 
   RowBox[{"qhtp0", " ", "phtp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519407330923`*^9, 3.8048519441135435`*^9}, {3.806768032926649*^9, 
   3.806768033644206*^9}},
 CellLabel->
  "In[133]:=",ExpressionUUID->"4ff425df-281f-4ea5-98ba-80b9dac98a0d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"votu0", "=", 
   RowBox[{"qotu0", " ", "potu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851948303916*^9, 3.804851950926388*^9}, 
   3.8050174723410645`*^9, 3.805018113403982*^9, 3.8050185702579627`*^9, {
   3.806768085830998*^9, 3.8067680867547207`*^9}},
 CellLabel->
  "In[134]:=",ExpressionUUID->"bcd1b8c2-12df-4a34-b46e-55c2ab4cc24e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"votp0", "=", 
   RowBox[{"qotp0", " ", "potp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519523417597`*^9, 3.804851955436349*^9}, 3.805017523503875*^9, 
   3.8050182854886165`*^9, 3.805018578479169*^9, {3.806768087287137*^9, 
   3.806768088596162*^9}},
 CellLabel->
  "In[135]:=",ExpressionUUID->"7ba43ca5-42d7-4dd1-9e4d-54130dec78d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vptu0", "=", 
   RowBox[{"qptu0", " ", "pptu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851948303916*^9, 3.804851950926388*^9}, 
   3.8050174723410645`*^9, 3.805018113403982*^9, {3.8050185702579627`*^9, 
   3.8050186149235363`*^9}, {3.806768108614807*^9, 3.806768109548538*^9}},
 CellLabel->
  "In[136]:=",ExpressionUUID->"a670896e-3a79-4021-8343-54a5ece8d061"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vptp0", "=", 
   RowBox[{"qptp0", " ", "pptp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519523417597`*^9, 3.804851955436349*^9}, 3.805017523503875*^9, 
   3.8050182854886165`*^9, {3.805018578479169*^9, 3.8050186102353115`*^9}, {
   3.806768109952854*^9, 3.8067681108585615`*^9}},
 CellLabel->
  "In[137]:=",ExpressionUUID->"e277d6ca-3f55-4be1-9d33-c1ff6a01c5a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vstu0", "=", 
   RowBox[{"qstu0", " ", "pstu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851948303916*^9, 3.804851950926388*^9}, 
   3.8050174723410645`*^9, 3.805018113403982*^9, {3.8050185702579627`*^9, 
   3.805018604889504*^9}, {3.8067681435000734`*^9, 3.806768144266674*^9}},
 CellLabel->
  "In[138]:=",ExpressionUUID->"d10dcd0c-1bec-4815-805a-88cd35a2b449"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vstp0", "=", 
   RowBox[{"qstp0", " ", "pstp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519523417597`*^9, 3.804851955436349*^9}, 3.805017523503875*^9, 
   3.8050182854886165`*^9, {3.805018578479169*^9, 3.8050185989979677`*^9}, {
   3.80676814467099*^9, 3.806768145635745*^9}},
 CellLabel->
  "In[139]:=",ExpressionUUID->"53646c65-6bf2-44ab-80e9-9a7f3d2e9934"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vadu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qadu0", "-", "qadue0"}], ")"}], " ", "padu0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.8048519638260803`*^9, 3.8048519716484485`*^9}, {
   3.8048598918387938`*^9, 3.804859912733159*^9}, {3.804860064780347*^9, 
   3.804860071891223*^9}, 3.8048664223456783`*^9, 3.805017322685949*^9, 
   3.80501738938866*^9, 3.8050178536388817`*^9, 3.805018387688871*^9, 
   3.805018727270131*^9, {3.805025120899139*^9, 3.8050251367937717`*^9}, 
   3.8050252580605593`*^9, 3.805665863356492*^9, {3.806766234381547*^9, 
   3.8067662361710587`*^9}, {3.806768033988475*^9, 3.806768062827016*^9}, 
   3.806832458677179*^9},
 CellLabel->
  "In[140]:=",ExpressionUUID->"a3ab304f-2aee-4fbd-bfd7-6f5a12f02f88"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vcdu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qcdu0", "-", "qcdue0", "-", 
      RowBox[{"cr", " ", "qcdp0"}]}], " ", ")"}], " ", "pcdu0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.8048519828841496`*^9, 3.804851990206542*^9}, {
   3.8048598935265956`*^9, 3.8048599148897953`*^9}, {3.8048600789598665`*^9, 
   3.804860083476311*^9}, 3.804866425674345*^9, 3.805017337158284*^9, 
   3.8050173975775113`*^9, 3.8050178642343397`*^9, 3.8050184291651025`*^9, {
   3.8050187442272134`*^9, 3.8050187632601604`*^9}, {3.805025141075765*^9, 
   3.805025155558032*^9}, 3.8050252619518375`*^9, 3.8056658649505205`*^9, {
   3.806768011018526*^9, 3.8067680130270915`*^9}, 3.806832460927555*^9},
 CellLabel->
  "In[141]:=",ExpressionUUID->"719d6bd9-ab83-433d-bc57-a6b508965f6b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vcdp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qcdp0", "-", "qcdpe0"}], ")"}], " ", "pcdp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.804851992378751*^9, 3.8048520018629837`*^9}, 3.8050173975775113`*^9, 
   3.805018154986638*^9, 3.805018413272153*^9, 3.805018840007553*^9, 
   3.8056658858328915`*^9, {3.8067680136976166`*^9, 3.8067680148084855`*^9}, 
   3.8068324753295574`*^9},
 CellLabel->
  "In[142]:=",ExpressionUUID->"ca4a1562-a6dc-469b-905d-0d39aef96b5a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vhdu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qhdu0", "-", "qhdue0", "-", 
      RowBox[{"cr", " ", "qhdp0"}]}], " ", ")"}], " ", "phdu0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.804852007460396*^9, 3.804852013220827*^9}, {
   3.80485989505812*^9, 3.8048599170464315`*^9}, {3.8048600866018105`*^9, 
   3.8048600916988807`*^9}, 3.8048664286460667`*^9, {3.805025158428979*^9, 
   3.8050251700740337`*^9}, 3.8050252659837627`*^9, 3.805665866717702*^9, {
   3.806768169470299*^9, 3.8067681793849936`*^9}, 3.806832477910413*^9},
 CellLabel->
  "In[143]:=",ExpressionUUID->"12c30e9d-754a-45e0-8c39-1b72a9f6c4ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vhdp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qhdp0", "-", "qhdpe0"}], ")"}], " ", "phdp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.8048520162475986`*^9, 3.8048520205763884`*^9}, 3.8056658839419365`*^9, {
   3.806768187430237*^9, 3.8067681953163567`*^9}, 3.8068324950517974`*^9},
 CellLabel->
  "In[144]:=",ExpressionUUID->"288ea92c-c9be-4ba0-82d7-1acdbbeb49ee"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vodu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qodu0", "-", "qodue0", "-", 
      RowBox[{"cr", " ", "qodp0"}]}], " ", ")"}], " ", "podu0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.804852022920974*^9, 3.804852030499457*^9}, {
   3.804859896652155*^9, 3.804859921734771*^9}, {3.8048600950900917`*^9, 
   3.8048600972310853`*^9}, 3.804866433404766*^9, 3.80501735923965*^9, 
   3.8050174161586895`*^9, 3.805017872688827*^9, 3.805018443417308*^9, 
   3.805018858088605*^9, {3.8050251727620006`*^9, 3.8050251792318745`*^9}, 
   3.8050252695468607`*^9, 3.805665869264631*^9, {3.8067680898481407`*^9, 
   3.806768092150937*^9}, 3.806832501224698*^9},
 CellLabel->
  "In[145]:=",ExpressionUUID->"b2ccd627-d7eb-4881-8b69-b0a9aa854d3c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vodp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qodp0", "-", "qodpe0"}], ")"}], " ", "podp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.8048520323591175`*^9, 3.804852037110026*^9}, 3.8050174161743164`*^9, 
   3.805018163879826*^9, 3.8050184579051275`*^9, 3.805018865715522*^9, 
   3.805665881923529*^9, {3.8067680927904377`*^9, 3.8067680955275793`*^9}, 
   3.8068325056160574`*^9},
 CellLabel->
  "In[146]:=",ExpressionUUID->"07cb80e4-b70d-4a54-9c85-400d2cb9ea9b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vpdu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qpdu0", "-", "qpdue0", "-", 
      RowBox[{"cr", " ", "qpdp0"}]}], " ", ")"}], " ", "ppdu0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.804852022920974*^9, 3.804852030499457*^9}, {
   3.804859896652155*^9, 3.804859921734771*^9}, {3.8048600950900917`*^9, 
   3.8048600972310853`*^9}, 3.804866433404766*^9, 3.80501735923965*^9, 
   3.8050174161586895`*^9, 3.805017872688827*^9, 3.805018443417308*^9, {
   3.805018858088605*^9, 3.80501889274378*^9}, {3.805023754012517*^9, 
   3.8050237635049405`*^9}, 3.8050250545222626`*^9, {3.8050251892456903`*^9, 
   3.8050251953572793`*^9}, {3.8050252724379697`*^9, 3.805025272875543*^9}, 
   3.8056658711243305`*^9, {3.806768111666189*^9, 3.8067681133685207`*^9}, 
   3.8068325114295235`*^9},
 CellLabel->
  "In[147]:=",ExpressionUUID->"c58f1e24-fc21-48b5-a52b-8ef5b76fd29a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vpdp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qpdp0", "-", "qpdpe0"}], ")"}], " ", "ppdp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.8048520323591175`*^9, 3.804852037110026*^9}, 3.8050174161743164`*^9, 
   3.805018163879826*^9, 3.8050184579051275`*^9, 3.805018865715522*^9, {
   3.805018895994308*^9, 3.8050189056064577`*^9}, 3.805665879876297*^9, {
   3.806768113822876*^9, 3.806768116164709*^9}, 3.8068325156815367`*^9},
 CellLabel->
  "In[148]:=",ExpressionUUID->"58ea194b-8382-4059-9a56-4bd3f7863104"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vsdu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qsdu0", "-", "qsdue0", "-", 
      RowBox[{"cr", " ", "qsdp0"}]}], " ", ")"}], " ", "psdu0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.804852022920974*^9, 3.804852030499457*^9}, {
   3.804859896652155*^9, 3.804859921734771*^9}, {3.8048600950900917`*^9, 
   3.8048600972310853`*^9}, 3.804866433404766*^9, 3.80501735923965*^9, 
   3.8050174161586895`*^9, 3.805017872688827*^9, 3.805018443417308*^9, 
   3.805018858088605*^9, {3.8050189086090927`*^9, 3.8050189207964573`*^9}, {
   3.805025198060874*^9, 3.805025202280357*^9}, 3.8050252760635777`*^9, 
   3.805665872969016*^9, {3.80676822628439*^9, 3.8067682281548424`*^9}, 
   3.806832524401739*^9},
 CellLabel->
  "In[149]:=",ExpressionUUID->"452c9f24-2134-4294-98c5-98d220bcf96c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vsdp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qsdp0", "-", "qsdpe0"}], ")"}], " ", "psdp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.8048520323591175`*^9, 3.804852037110026*^9}, 3.8050174161743164`*^9, 
   3.805018163879826*^9, 3.8050184579051275`*^9, 3.805018865715522*^9, {
   3.805018922906186*^9, 3.80501893122008*^9}, 3.8056658784229183`*^9, {
   3.806768228648225*^9, 3.806768230547699*^9}, 3.80683252666142*^9},
 CellLabel->
  "In[150]:=",ExpressionUUID->"ebbbcfd0-9681-4755-aac2-3374db013fbe"],

Cell[CellGroupData[{

Cell["3.1 Supply Parameters", "Subsubsection",
 CellChangeTimes->{{3.819902497376732*^9, 3.819902510893259*^9}, 
   3.8250246051964817`*^9},
 CellLabel->
  "In[207]:=",ExpressionUUID->"eaf6ed4f-37fe-45de-a9ec-4e216ee77481"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eauu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"eau", " ", 
     FractionBox["qadu0", 
      RowBox[{"(", 
       RowBox[{"qadcap", "-", "qadu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.804852083303175*^9, 3.804852090898363*^9}, {
   3.805017228666668*^9, 3.805017228666668*^9}, {3.805017322685949*^9, 
   3.805017322685949*^9}, 3.8050183281629877`*^9, {3.8067662415466795`*^9, 
   3.8067662448054667`*^9}, 3.8252831500858784`*^9},
 CellLabel->
  "In[151]:=",ExpressionUUID->"251b4ab0-22c0-46e3-b8e5-e9aa3e6836c2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aadu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qadcap", "-", "qadu0"}], ")"}], " ", 
    SuperscriptBox["padu0", "eauu"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048520933987694`*^9, 
   3.804852099759162*^9}, 3.805017228682296*^9, 3.805017322685949*^9, 
   3.8050178536388817`*^9, 3.8050183281629877`*^9, 3.805018972205937*^9, {
   3.806766245508704*^9, 3.806766247493399*^9}, 3.8252831513548784`*^9, 
   3.8252839339827414`*^9},
 CellLabel->
  "In[152]:=",ExpressionUUID->"84a21240-2395-4207-a627-0bd1de0b1bd2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ecdu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"ecd", " ", 
     FractionBox["qcdu0", 
      RowBox[{"(", 
       RowBox[{"qcdcap", "-", "qcdu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.8048521093589597`*^9, 3.804852115828997*^9}, {
   3.80501724212201*^9, 3.80501724212201*^9}, {3.805017337158284*^9, 
   3.805017337158284*^9}, 3.805018338242672*^9, {3.8067684152658606`*^9, 
   3.8067684169223766`*^9}, 3.8252831520033693`*^9},
 CellLabel->
  "In[153]:=",ExpressionUUID->"ddefb4fb-ed0b-41c9-b34f-815fdb269d09"],

Cell[BoxData[
 RowBox[{
  RowBox[{"acdu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qcdcap", "-", "qcdu0"}], ")"}], " ", 
    SuperscriptBox["pcdu0", "ecdu"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521184231625`*^9, 
   3.8048521249554644`*^9}, 3.80501724212201*^9, 3.805017337158284*^9, 
   3.8050178642343397`*^9, 3.805018338258299*^9, 3.8050189849580746`*^9, {
   3.8067684173599467`*^9, 3.806768419188366*^9}, 3.8252831528330564`*^9, 
   3.8252839339837737`*^9},
 CellLabel->
  "In[154]:=",ExpressionUUID->"9804a220-ad8a-4ea2-b0a3-d983552dacc8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ehdu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"ehd", " ", 
     FractionBox["qhdu0", 
      RowBox[{"(", 
       RowBox[{"qhdcap", "-", "qhdu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.8048521327848425`*^9, 3.8048521396333513`*^9}, {
   3.806768475094221*^9, 3.806768484170909*^9}, 3.8252831536296597`*^9},
 CellLabel->
  "In[155]:=",ExpressionUUID->"f305acde-6487-41d5-8850-a22925249eb5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ahdu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qhdcap", "-", "qhdu0"}], ")"}], " ", 
    SuperscriptBox["phdu0", "ehdu"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521436041384`*^9, 
   3.8048521498553686`*^9}, {3.806768490297201*^9, 3.806768501376392*^9}, 
   3.8252831558684025`*^9, 3.8252839339837737`*^9},
 CellLabel->
  "In[156]:=",ExpressionUUID->"f5232fbe-62d7-4e00-986d-f2c32840b136"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eodu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"eod", " ", 
     FractionBox["qodu0", 
      RowBox[{"(", 
       RowBox[{"qodcap", "-", "qodu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.8048521589190774`*^9, 3.804852165998335*^9}, {
   3.8050172630810432`*^9, 3.8050172630810432`*^9}, {3.80501735923965*^9, 
   3.8050173592553644`*^9}, 3.8050183601989946`*^9, {3.8067685142546587`*^9, 
   3.8067685162862353`*^9}, 3.825283156904234*^9},
 CellLabel->
  "In[157]:=",ExpressionUUID->"ac224861-1ffc-4908-a6d4-f00c1b91f388"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aodu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qodcap", "-", "qodu0"}], ")"}], " ", 
    SuperscriptBox["podu0", "eodu"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521687650814`*^9, 
   3.8048521751254616`*^9}, 3.8050172630966716`*^9, 3.8050173592553644`*^9, 
   3.805017872688827*^9, 3.8050183601989946`*^9, 3.8050194297527933`*^9, {
   3.8067685168262153`*^9, 3.806768519732933*^9}, 3.825283174768227*^9, 
   3.8252839339837737`*^9},
 CellLabel->
  "In[158]:=",ExpressionUUID->"22c1ee31-aa92-4f38-bac8-c199f7968ae9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"epdu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"epd", " ", 
     FractionBox["qpdu0", 
      RowBox[{"(", 
       RowBox[{"qpdcap", "-", "qpdu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.8048521589190774`*^9, 3.804852165998335*^9}, {
   3.8050172630810432`*^9, 3.8050172630810432`*^9}, {3.80501735923965*^9, 
   3.8050173592553644`*^9}, 3.8050183601989946`*^9, {3.8050194862238812`*^9, 
   3.805019495709798*^9}, {3.806768530781646*^9, 3.8067685327194567`*^9}, 
   3.8252831762663527`*^9},
 CellLabel->
  "In[159]:=",ExpressionUUID->"2c6e2342-421a-4708-b8b8-5c667135aa12"],

Cell[BoxData[
 RowBox[{
  RowBox[{"apdu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qpdcap", "-", "qpdu0"}], ")"}], " ", 
    SuperscriptBox["ppdu0", "epdu"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521687650814`*^9, 
   3.8048521751254616`*^9}, 3.8050172630966716`*^9, 3.8050173592553644`*^9, 
   3.805017872688827*^9, 3.8050183601989946`*^9, 3.8050194297527933`*^9, {
   3.8050195018045397`*^9, 3.8050195102746644`*^9}, {3.806768540877019*^9, 
   3.8067685439863863`*^9}, 3.82528317781357*^9, 3.8252839339847393`*^9},
 CellLabel->
  "In[160]:=",ExpressionUUID->"e4a181ee-069f-4237-bdb1-e29ece128f2d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"esdu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"esd", " ", 
     FractionBox["qsdu0", 
      RowBox[{"(", 
       RowBox[{"qsdcap", "-", "qsdu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.8048521589190774`*^9, 3.804852165998335*^9}, {
   3.8050172630810432`*^9, 3.8050172630810432`*^9}, {3.80501735923965*^9, 
   3.8050173592553644`*^9}, 3.8050183601989946`*^9, {3.8050195139940205`*^9, 
   3.8050195356237755`*^9}, {3.8067685986132984`*^9, 3.8067686091462393`*^9}, 
   3.8252831792236614`*^9},
 CellLabel->
  "In[161]:=",ExpressionUUID->"745d2426-5f4e-4ea4-8d95-2cd7241500ec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"asdu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qsdcap", "-", "qsdu0"}], ")"}], " ", 
    SuperscriptBox["psdu0", "esdu"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521687650814`*^9, 
   3.8048521751254616`*^9}, 3.8050172630966716`*^9, 3.8050173592553644`*^9, 
   3.805017872688827*^9, 3.8050183601989946`*^9, 3.8050194297527933`*^9, {
   3.8050195390618343`*^9, 3.805019548651763*^9}, {3.806768614868563*^9, 
   3.8067686225948825`*^9}, 3.825283180660788*^9, 3.8252839339847393`*^9},
 CellLabel->
  "In[162]:=",ExpressionUUID->"94b6edbf-8c1e-4ac1-9ae1-85e6f5b9f009"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2 Demand Parameters", "Subsubsection",
 CellChangeTimes->{{3.819902497376732*^9, 3.819902510893259*^9}, 
   3.8250246051964817`*^9, {3.825283986924929*^9, 
   3.825283990682822*^9}},ExpressionUUID->"12bc2ed7-48ae-40fa-b416-\
727b1343aa1b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"batu", " ", "=", 
   RowBox[{
    FractionBox["vatu0", "vadu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["patu0", "padu0"], ")"}], 
     RowBox[{"sigmaau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852908773026*^9}, 
   3.804954429860744*^9, 3.8050178536388817`*^9, 3.8050180911508274`*^9, 
   3.805018527670006*^9, 3.805018727270131*^9, 3.8050196031952763`*^9, 
   3.806764855581185*^9, {3.806766248790482*^9, 3.8067662507126665`*^9}, {
   3.8068325963302846`*^9, 3.8068325967991133`*^9}, 3.825283187844451*^9},
 CellLabel->
  "In[163]:=",ExpressionUUID->"1bd69a31-8d5e-4be7-ac7b-526a6a7dc4b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pau0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padu0", 
       RowBox[{"1", "-", "sigmaau"}]], "+", 
      RowBox[{"batu", " ", 
       SuperscriptBox["patu0", 
        RowBox[{"1", "-", "sigmaau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8049544298763714`*^9, 3.8049544298763714`*^9}, 
   3.8050178536545095`*^9, 3.8050180911664543`*^9, {3.8050196031952763`*^9, 
   3.805019614619006*^9}, {3.806764855581185*^9, 3.806764855581185*^9}, {
   3.8067662514444556`*^9, 3.8067662527884216`*^9}, {3.806832604894101*^9, 
   3.8068326118481846`*^9}, 3.8252831894897456`*^9},
 CellLabel->
  "In[164]:=",ExpressionUUID->"bfe09279-c02a-4e14-b37a-2ead85213dd7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bctu", " ", "=", 
   RowBox[{
    FractionBox["vctu0", "vcdu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pctu0", "pcdu0"], ")"}], 
     RowBox[{"sigmacu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.8048529305003295`*^9}, 
   3.80495448906104*^9, 3.805017864249967*^9, 3.805018101074109*^9, 
   3.8050185566621103`*^9, 3.8050187442272134`*^9, {3.80501878270205*^9, 
   3.8050187879997787`*^9}, 3.805019635911148*^9, 3.8067649134953394`*^9, {
   3.8067686547422457`*^9, 3.8067686658736267`*^9}, 3.825283191025895*^9},
 CellLabel->
  "In[165]:=",ExpressionUUID->"d2ca5df3-78b6-49e1-b854-f20b9894de8a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pcdu0", 
       RowBox[{"1", "-", "sigmacu"}]], "+", 
      RowBox[{"bctu", " ", 
       SuperscriptBox["pctu0", 
        RowBox[{"1", "-", "sigmacu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmacu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.80495448906104*^9, 
   3.8049544890767255`*^9}, 3.805017864249967*^9, 3.8050181010897365`*^9, {
   3.805019635911148*^9, 3.8050196452264185`*^9}, {3.8067649134953394`*^9, 
   3.8067649134953394`*^9}, {3.8067686701144753`*^9, 3.806768684740861*^9}, 
   3.8252831929153795`*^9},
 CellLabel->
  "In[166]:=",ExpressionUUID->"e9996e19-c9e2-4bad-80d6-e5d1f107f50b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bhtu", " ", "=", 
   RowBox[{
    FractionBox["vhtu0", "vhdu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["phtu0", "phdu0"], ")"}], 
     RowBox[{"sigmahu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.8067686919298267`*^9, 3.806768704523485*^9}, 3.8252831943364897`*^9},
 CellLabel->
  "In[167]:=",ExpressionUUID->"385ca98f-830d-4059-a353-b4dd92eaff40"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Phu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["phdu0", 
       RowBox[{"1", "-", "sigmahu"}]], "+", 
      RowBox[{"bhtu", " ", 
       SuperscriptBox["phtu0", 
        RowBox[{"1", "-", "sigmahu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmahu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.806768708542983*^9, 
   3.806768726695898*^9}, 3.8252831967703924`*^9},
 CellLabel->
  "In[168]:=",ExpressionUUID->"11633740-7877-4529-9267-5101c3b28f3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"botu", " ", "=", 
   RowBox[{
    FractionBox["votu0", "vodu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["potu0", "podu0"], ")"}], 
     RowBox[{"sigmaou", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.804853007174381*^9, 3.8048530190200768`*^9}, 3.8049546266952868`*^9, 
   3.805017872688827*^9, 3.805018113403982*^9, 3.8050185702579627`*^9, 
   3.805018858088605*^9, 3.80501967075628*^9, 3.8067649534872656`*^9, {
   3.8067687332482185`*^9, 3.8067687399228725`*^9}, {3.8067689945577307`*^9, 
   3.80676899928259*^9}, 3.825283198199539*^9},
 CellLabel->
  "In[169]:=",ExpressionUUID->"387dcf33-3dbb-4670-99ab-85ffff228603"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pou0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["podu0", 
       RowBox[{"1", "-", "sigmaou"}]], "+", 
      RowBox[{"botu", " ", 
       SuperscriptBox["potu0", 
        RowBox[{"1", "-", "sigmaou"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaou"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8049546267109137`*^9, 3.8049546267109137`*^9}, 
   3.805017872688827*^9, 3.805018113403982*^9, {3.80501967075628*^9, 
   3.8050196847698293`*^9}, {3.8067649534872656`*^9, 
   3.8067649535028925`*^9}, {3.8067690060333624`*^9, 3.806769022754347*^9}, 
   3.825283199635665*^9},
 CellLabel->
  "In[170]:=",ExpressionUUID->"764696a7-2ccb-4e84-8698-455b1318fc9e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bptu", " ", "=", 
   RowBox[{
    FractionBox["vptu0", "vpdu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pptu0", "ppdu0"], ")"}], 
     RowBox[{"sigmapu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.804853007174381*^9, 3.8048530190200768`*^9}, 3.8049546266952868`*^9, 
   3.805017872688827*^9, 3.805018113403982*^9, 3.8050185702579627`*^9, 
   3.805018858088605*^9, 3.80501967075628*^9, {3.805019702949969*^9, 
   3.8050197141705465`*^9}, 3.806764972319667*^9, {3.8067690287539835`*^9, 
   3.806769043475799*^9}, 3.825283201433042*^9},
 CellLabel->
  "In[171]:=",ExpressionUUID->"7e8bc4a9-59b5-4213-a12b-64692d4817e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ppu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["ppdu0", 
       RowBox[{"1", "-", "sigmapu"}]], "+", 
      RowBox[{"bptu", " ", 
       SuperscriptBox["pptu0", 
        RowBox[{"1", "-", "sigmapu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmapu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8049546267109137`*^9, 3.8049546267109137`*^9}, 
   3.805017872688827*^9, 3.805018113403982*^9, {3.80501967075628*^9, 
   3.8050196847698293`*^9}, {3.8050197183743553`*^9, 3.805019732064079*^9}, {
   3.806764972335295*^9, 3.806764972335295*^9}, {3.806769055938671*^9, 
   3.8067690823818517`*^9}, 3.825283203731886*^9},
 CellLabel->
  "In[172]:=",ExpressionUUID->"6881808e-6ee8-4fbf-a097-67964535b9e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bstu", " ", "=", 
   RowBox[{
    FractionBox["vstu0", "vsdu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pstu0", "psdu0"], ")"}], 
     RowBox[{"sigmasu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.804853007174381*^9, 3.8048530190200768`*^9}, 3.8049546266952868`*^9, 
   3.805017872688827*^9, 3.805018113403982*^9, 3.8050185702579627`*^9, 
   3.805018858088605*^9, 3.80501967075628*^9, {3.8050197383932323`*^9, 
   3.805019751506009*^9}, {3.8067691190868845`*^9, 3.80676912874527*^9}, 
   3.8252832051529756`*^9},
 CellLabel->
  "In[173]:=",ExpressionUUID->"973e0b37-8182-4fda-9e0f-5a79f4428a28"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdu0", 
       RowBox[{"1", "-", "sigmasu"}]], "+", 
      RowBox[{"bstu", " ", 
       SuperscriptBox["pstu0", 
        RowBox[{"1", "-", "sigmasu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8049546267109137`*^9, 3.8049546267109137`*^9}, 
   3.805017872688827*^9, 3.805018113403982*^9, {3.80501967075628*^9, 
   3.8050196847698293`*^9}, {3.8050197560536213`*^9, 
   3.8050197733327894`*^9}, {3.8067691335898237`*^9, 3.806769151865198*^9}, 
   3.825283206793265*^9},
 CellLabel->
  "In[174]:=",ExpressionUUID->"47fa4eb1-e757-4dc0-863e-a3881a527a94"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bcu", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vcdu0", "+", "vctu0"}], 
     RowBox[{"vadu0", "+", "vatu0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pcu0", "Pau0"], ")"}], 
     RowBox[{"betau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.805018527670006*^9, 3.8050185566621103`*^9}, {3.805018727285775*^9, 
   3.8050187442272134`*^9}, {3.8050187967043133`*^9, 3.8050187992359776`*^9}, 
   3.805019614619006*^9, 3.8050196452264185`*^9, 3.805019802540661*^9, {
   3.806766253225992*^9, 3.8067662541991515`*^9}, {3.8067691749605126`*^9, 
   3.806769177132744*^9}, 3.8252832128650064`*^9},
 CellLabel->
  "In[175]:=",ExpressionUUID->"62eabe97-1954-43ae-855a-7d2c54b35cbd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bhu", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vhdu0", "+", "vhtu0"}], 
     RowBox[{"vadu0", "+", "vatu0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Phu0", "Pau0"], ")"}], 
     RowBox[{"betau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.804853293988452*^9}, 
   3.805018527670006*^9, 3.805018727285775*^9, 3.8050196146346335`*^9, {
   3.8067662546367216`*^9, 3.806766255433725*^9}, {3.8067691856497593`*^9, 
   3.806769196556162*^9}, 3.825283214455228*^9},
 CellLabel->
  "In[176]:=",ExpressionUUID->"4d9b0a1f-c966-472a-b552-6af5401f68b8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bou", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vodu0", "+", "votu0"}], 
     RowBox[{"vadu0", "+", "vatu0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pou0", "Pau0"], ")"}], 
     RowBox[{"betau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.8048532815960116`*^9, 3.8048533048189335`*^9}, 3.8050185276856337`*^9, 
   3.8050185702579627`*^9, 3.805018727285775*^9, 3.805018858088605*^9, 
   3.8050196146346335`*^9, 3.8050196847698293`*^9, 3.805019812682934*^9, {
   3.806766255855667*^9, 3.806766256637043*^9}, {3.806769207836508*^9, 
   3.806769217980049*^9}, 3.8252832161375685`*^9},
 CellLabel->
  "In[177]:=",ExpressionUUID->"47587f17-c0fe-4f2d-a12a-ff180e9cd8e7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bpu", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vpdu0", "+", "vptu0"}], 
     RowBox[{"vadu0", "+", "vatu0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Ppu0", "Pau0"], ")"}], 
     RowBox[{"betau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.8048532815960116`*^9, 3.8048533048189335`*^9}, 3.8050185276856337`*^9, 
   3.8050185702579627`*^9, 3.805018727285775*^9, 3.805018858088605*^9, 
   3.8050196146346335`*^9, 3.8050196847698293`*^9, 3.805019812682934*^9, {
   3.8050198659677114`*^9, 3.8050198748597784`*^9}, {3.8067662570589857`*^9, 
   3.8067662578247337`*^9}, {3.8067692247142153`*^9, 3.80676923643801*^9}, 
   3.825283309265413*^9},
 CellLabel->
  "In[178]:=",ExpressionUUID->"2bd131a2-c9c0-49aa-a8ac-c0ffda5dda8c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsu", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vsdu0", "+", "vstu0"}], 
     RowBox[{"vadu0", "+", "vatu0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Psu0", "Pau0"], ")"}], 
     RowBox[{"betau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.8048532815960116`*^9, 3.8048533048189335`*^9}, 3.8050185276856337`*^9, 
   3.8050185702579627`*^9, 3.805018727285775*^9, 3.805018858088605*^9, 
   3.8050196146346335`*^9, 3.8050196847698293`*^9, 3.805019812682934*^9, {
   3.8050198805950856`*^9, 3.8050198891156464`*^9}, {3.8067662582154217`*^9, 
   3.8067662589414196`*^9}, {3.8067692391658087`*^9, 3.8067692458387566`*^9}, 
   3.8252832187455835`*^9},
 CellLabel->
  "In[179]:=",ExpressionUUID->"f941036b-720f-480c-b55f-675c0c274d1d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pu0", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pau0", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bcu", " ", 
       SuperscriptBox["Pcu0", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bhu", " ", 
       SuperscriptBox["Phu0", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bou", " ", 
       SuperscriptBox["Pou0", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bpu", " ", 
       SuperscriptBox["Ppu0", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bsu", " ", 
       SuperscriptBox["Psu0", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, 3.8050196146346335`*^9, 
   3.8050196452264185`*^9, 3.8050196847698293`*^9, {3.805019802540661*^9, 
   3.8050198551991177`*^9}, {3.805640058914117*^9, 3.805640067666767*^9}, 
   3.806766260935816*^9, {3.806769261515285*^9, 3.8067692861381626`*^9}, 
   3.825283220449937*^9},
 CellLabel->
  "In[180]:=",ExpressionUUID->"e6724399-0426-4abd-bb4b-27370550b482"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bctp", " ", "=", 
   RowBox[{
    FractionBox["vctp0", "vcdp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pctp0", "pcdp0"], ")"}], 
     RowBox[{"sigmacp", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.8048529305003295`*^9}, {
   3.8048533881740723`*^9, 3.804853389939992*^9}, 3.8049545102161703`*^9, 
   3.805018154986638*^9, 3.805018278393769*^9, 3.8050185486888833`*^9, 
   3.805018840007553*^9, 3.80501994403093*^9, {3.806769322339163*^9, 
   3.806769359874774*^9}, 3.825283226465662*^9},
 CellLabel->
  "In[181]:=",ExpressionUUID->"29fbc036-d510-40fe-8daf-9600259594f0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcp0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pcdp0", 
       RowBox[{"1", "-", "sigmacp"}]], "+", 
      RowBox[{"bctp", " ", 
       SuperscriptBox["pctp0", 
        RowBox[{"1", "-", "sigmacp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmacp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.8048533906588616`*^9, 
   3.804853392674816*^9}, {3.8049545102317977`*^9, 3.8049545102317977`*^9}, 
   3.805018154986638*^9, 3.805018278409396*^9, 3.805019944046558*^9, 
   3.8050199843385897`*^9, {3.8067693647688365`*^9, 3.806769378036579*^9}, 
   3.825283228822526*^9},
 CellLabel->
  "In[182]:=",ExpressionUUID->"d597280d-cf66-4efd-a4df-e8e3cfc822e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bhtp", " ", "=", 
   RowBox[{
    FractionBox["vhtp0", "vhdp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["phtp0", "phdp0"], ")"}], 
     RowBox[{"sigmahp", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.8048533930967607`*^9, 3.804853394675149*^9}, {3.8067693831887975`*^9, 
   3.806769396151554*^9}, 3.8252832302096057`*^9},
 CellLabel->
  "In[183]:=",ExpressionUUID->"046a6855-34da-4a95-a501-75e89b292345"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Php0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["phdp0", 
       RowBox[{"1", "-", "sigmahp"}]], "+", 
      RowBox[{"bhtp", " ", 
       SuperscriptBox["phtp0", 
        RowBox[{"1", "-", "sigmahp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmahp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048533952064857`*^9, 
   3.8048533971443033`*^9}, {3.8067693998755674`*^9, 3.8067694140293064`*^9}, 
   3.8252832321360884`*^9},
 CellLabel->
  "In[184]:=",ExpressionUUID->"d22c127a-b4b1-4a89-8bd5-9291c05be00a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"botp", " ", "=", 
   RowBox[{
    FractionBox["votp0", "vodp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["potp0", "podp0"], ")"}], 
     RowBox[{"sigmaop", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.804853007174381*^9, 3.8048530190200768`*^9}, {3.8048533974568553`*^9, 
   3.804853398894594*^9}, 3.8049546404935093`*^9, 3.805018163895453*^9, 
   3.8050182854886165`*^9, 3.805018578494796*^9, 3.805018865715522*^9, 
   3.8050199536901255`*^9, {3.8067694181393623`*^9, 3.8067694294786577`*^9}, 
   3.8252832335982094`*^9},
 CellLabel->
  "In[185]:=",ExpressionUUID->"93b2d3b9-f4dc-4bec-b540-3dc836afe09b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pop0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["podp0", 
       RowBox[{"1", "-", "sigmaop"}]], "+", 
      RowBox[{"botp", " ", 
       SuperscriptBox["potp0", 
        RowBox[{"1", "-", "sigmaop"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaop"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.804954640509137*^9, 3.804954640509137*^9}, 3.805018163895453*^9, 
   3.8050182855042944`*^9, 3.8050199537057533`*^9, 3.805020008092595*^9, {
   3.8067694342680693`*^9, 3.8067694520294504`*^9}, 3.825283235551758*^9},
 CellLabel->
  "In[186]:=",ExpressionUUID->"ad032d2a-ff52-44d7-8d69-ecdf737d464c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bptp", " ", "=", 
   RowBox[{
    FractionBox["vptp0", "vpdp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pptp0", "ppdp0"], ")"}], 
     RowBox[{"sigmapp", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.804853007174381*^9, 3.8048530190200768`*^9}, {3.8048533974568553`*^9, 
   3.804853398894594*^9}, 3.8049546404935093`*^9, 3.805018163895453*^9, 
   3.8050182854886165`*^9, 3.805018578494796*^9, 3.805018865715522*^9, 
   3.8050199536901255`*^9, {3.8050200349746237`*^9, 3.8050200456795435`*^9}, {
   3.806788489450205*^9, 3.806788507219159*^9}, 3.8252832374061885`*^9},
 CellLabel->
  "In[187]:=",ExpressionUUID->"d89a45b1-455b-4c84-bfb2-4d419410a0cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ppp0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["ppdp0", 
       RowBox[{"1", "-", "sigmapp"}]], "+", 
      RowBox[{"bptp", " ", 
       SuperscriptBox["pptp0", 
        RowBox[{"1", "-", "sigmapp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmapp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.804954640509137*^9, 3.804954640509137*^9}, 3.805018163895453*^9, 
   3.8050182855042944`*^9, 3.8050199537057533`*^9, 3.805020008092595*^9, {
   3.8050200498208623`*^9, 3.805020066793394*^9}, {3.806788510548123*^9, 
   3.80678853343295*^9}, 3.82528323903049*^9},
 CellLabel->
  "In[188]:=",ExpressionUUID->"e0dfef6b-9095-46bd-b1db-493e8ded06e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bstp", " ", "=", 
   RowBox[{
    FractionBox["vstp0", "vsdp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pstp0", "psdp0"], ")"}], 
     RowBox[{"sigmasp", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.804853007174381*^9, 3.8048530190200768`*^9}, {3.8048533974568553`*^9, 
   3.804853398894594*^9}, 3.8049546404935093`*^9, 3.805018163895453*^9, 
   3.8050182854886165`*^9, 3.805018578494796*^9, 3.805018865715522*^9, 
   3.8050199536901255`*^9, {3.805020071591073*^9, 3.805020083710909*^9}, {
   3.80678857066184*^9, 3.806788582747246*^9}, 3.8252832407888384`*^9},
 CellLabel->
  "In[189]:=",ExpressionUUID->"251ab582-9b64-4b8f-8f2a-b01aa1edb46b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psp0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdp0", 
       RowBox[{"1", "-", "sigmasp"}]], "+", 
      RowBox[{"bstp", " ", 
       SuperscriptBox["pstp0", 
        RowBox[{"1", "-", "sigmasp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.804954640509137*^9, 3.804954640509137*^9}, 3.805018163895453*^9, 
   3.8050182855042944`*^9, 3.8050199537057533`*^9, 3.805020008092595*^9, {
   3.805020086773922*^9, 3.8050201036517515`*^9}, {3.8067885862368155`*^9, 
   3.8067886019587965`*^9}, 3.8252832423810773`*^9},
 CellLabel->
  "In[190]:=",ExpressionUUID->"10c092d2-c064-4dbd-b087-f6d73fab8a94"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bhp", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vhdp0", "+", "vhtp0"}], 
     RowBox[{"vcdp0", "+", "vctp0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Php0", "Pcp0"], ")"}], 
     RowBox[{"betap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.804853425853657*^9, 3.804853428010266*^9}, {3.805018537499652*^9, 
   3.8050185486888833`*^9}, 3.8050187353507767`*^9, 3.805018840007553*^9, {
   3.8050199698348083`*^9, 3.8050199843385897`*^9}, 3.8050201228280954`*^9, {
   3.806766264903937*^9, 3.8067662653727627`*^9}, {3.8067886157315135`*^9, 
   3.806788620952303*^9}, {3.8067886661007924`*^9, 3.8067886971324315`*^9}, 
   3.8252832482526903`*^9},
 CellLabel->
  "In[191]:=",ExpressionUUID->"8305e50c-adba-4ce2-96df-65790eba427b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bop", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vodp0", "+", "votp0"}], 
     RowBox[{"vcdp0", "+", "vctp0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pop0", "Pcp0"], ")"}], 
     RowBox[{"betap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.804853293988452*^9}, {
   3.8048534284009533`*^9, 3.80485342996371*^9}, 3.805018537515279*^9, 
   3.8050187353507767`*^9, 3.8050199698348083`*^9, {3.806766265607175*^9, 
   3.806766266107256*^9}, {3.8067886285580482`*^9, 3.806788632642768*^9}, {
   3.806788669929533*^9, 3.8067886701170635`*^9}, {3.806788701148525*^9, 
   3.80678870775383*^9}, {3.8252832496688056`*^9, 3.8252832590351105`*^9}},
 CellLabel->
  "In[192]:=",ExpressionUUID->"54f686b0-44db-4784-8a4e-7cfac2c72f32"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bpp", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vpdp0", "+", "vptp0"}], 
     RowBox[{"vcdp0", "+", "vctp0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Ppp0", "Pcp0"], ")"}], 
     RowBox[{"betap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.8048532815960116`*^9, 3.8048533048189335`*^9}, {3.804853430260635*^9, 
   3.8048534318233943`*^9}, 3.805018537515279*^9, 3.805018578494796*^9, 
   3.8050187353507767`*^9, 3.805018865715522*^9, 3.8050199698348083`*^9, 
   3.805020008092595*^9, 3.8050201313295197`*^9, {3.806766266341668*^9, 
   3.806766266794866*^9}, {3.806788636596547*^9, 3.8067886418318014`*^9}, {
   3.8067886746593146`*^9, 3.80678867594077*^9}, {3.806788711348181*^9, 
   3.8067887171303916`*^9}, 3.825283260561307*^9},
 CellLabel->
  "In[193]:=",ExpressionUUID->"abbcb4b4-51f3-478d-a36c-47dc2ecc337b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsp", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vsdp0", "+", "vstp0"}], 
     RowBox[{"vcdp0", "+", "vctp0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Psp0", "Pcp0"], ")"}], 
     RowBox[{"betap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.8048532815960116`*^9, 3.8048533048189335`*^9}, {3.804853430260635*^9, 
   3.8048534318233943`*^9}, 3.805018537515279*^9, 3.805018578494796*^9, 
   3.8050187353507767`*^9, 3.805018865715522*^9, 3.8050199698348083`*^9, 
   3.805020008092595*^9, 3.8050201313295197`*^9, {3.8050201748795977`*^9, 
   3.805020183272869*^9}, {3.8067662670449066`*^9, 3.806766267263692*^9}, {
   3.806788643925888*^9, 3.8067886479577866`*^9}, {3.806788684461233*^9, 
   3.806788684617508*^9}, {3.8067887214747763`*^9, 3.8067887268037863`*^9}, 
   3.8252832622976613`*^9},
 CellLabel->
  "In[194]:=",ExpressionUUID->"d45e55d8-cf88-4b9a-97a8-b5feb88adfba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bap", "=", 
   RowBox[{
    FractionBox["vatp0", 
     RowBox[{"vcdp0", "+", "vctp0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["patp0", "Pcp0"], ")"}], 
     RowBox[{"betap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8067887691816397`*^9, 3.8067887906740427`*^9}, 
   3.8252832637337847`*^9},
 CellLabel->
  "In[195]:=",ExpressionUUID->"13662bd9-e26a-4f27-9881-ab00ec57da1f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pp0", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pcp0", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bhp", " ", 
       SuperscriptBox["Php0", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bop", " ", 
       SuperscriptBox["Pop0", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bpp", " ", 
       SuperscriptBox["Ppp0", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bsp", " ", 
       SuperscriptBox["Psp0", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bap", " ", 
       SuperscriptBox["patp0", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048534322140846`*^9, 
   3.8048534358553085`*^9}, {3.805019969866063*^9, 3.805020008092595*^9}, {
   3.8050201228437223`*^9, 3.8050201668938847`*^9}, {3.8056401304009275`*^9, 
   3.805640139998988*^9}, 3.8067662692672224`*^9, 3.806769344950416*^9, {
   3.8067887364777555`*^9, 3.806788756551898*^9}, {3.8067887989410534`*^9, 
   3.806788803488679*^9}, {3.8067892960281935`*^9, 3.806789299669428*^9}, 
   3.825283265706366*^9},
 CellLabel->
  "In[196]:=",ExpressionUUID->"a4a909b7-206c-40c9-bf6f-7340e63204b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ku", "=", 
   FractionBox[
    RowBox[{"qatu0", " ", 
     SuperscriptBox["Pu0", 
      RowBox[{
       RowBox[{"-", "etau"}], "-", "betau", " "}]], 
     SuperscriptBox["Pau0", 
      RowBox[{"betau", "-", "sigmaau"}]], 
     SuperscriptBox["patu0", "sigmaau"]}], "batu"]}], ";"}]], "Input",
 CellChangeTimes->{{3.800140454488206*^9, 3.800140523176643*^9}, {
   3.800455058428173*^9, 3.800455063959334*^9}, {3.8006362513154964`*^9, 
   3.800636260384779*^9}, 3.8006363054963803`*^9, 3.800647348889147*^9, 
   3.8006960898303185`*^9, 3.800804256877533*^9, {3.8008043645295997`*^9, 
   3.800804364685875*^9}, {3.8008068728494596`*^9, 3.800806875974489*^9}, {
   3.8016604841908655`*^9, 3.8016604867536297`*^9}, {3.801663391117081*^9, 
   3.801663391882834*^9}, 3.801664413638791*^9, {3.8016647577403903`*^9, 
   3.801664759459405*^9}, {3.8016648404783707`*^9, 3.8016648805396347`*^9}, {
   3.801665135307444*^9, 3.801665211909813*^9}, 3.8016653900835795`*^9, {
   3.8016670898715615`*^9, 3.8016670989043036`*^9}, {3.80168887262052*^9, 
   3.8016888744489493`*^9}, {3.8016889608852425`*^9, 3.801689010426876*^9}, {
   3.8017784454569283`*^9, 3.801778458163327*^9}, 3.801778528743101*^9, {
   3.8017814934521255`*^9, 3.8017814938740683`*^9}, {3.8031140023071547`*^9, 
   3.803114014512789*^9}, {3.8031260626605997`*^9, 3.8031261061075296`*^9}, {
   3.804344640574292*^9, 3.804344672830389*^9}, {3.8048534574220657`*^9, 
   3.8048535141640887`*^9}, {3.804954429923254*^9, 3.804954429923254*^9}, 
   3.8050174498061085`*^9, 3.8050180911664543`*^9, {3.8050196031952763`*^9, 
   3.8050196146346335`*^9}, {3.806764855673539*^9, 3.806764855673539*^9}, {
   3.806766271845762*^9, 3.806766273142846*^9}, {3.806788838484434*^9, 
   3.806788849604492*^9}, 3.8252832727629013`*^9},
 CellLabel->
  "In[197]:=",ExpressionUUID->"0f3e7553-f6e2-4c16-ad42-a622b32f2bcb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kp", "=", 
   FractionBox[
    RowBox[{"qatp0", " ", 
     SuperscriptBox["Pp0", 
      RowBox[{
       RowBox[{"-", "etap"}], "-", "betap"}]], " ", 
     SuperscriptBox["patp0", "betap"]}], "bap"]}], ";"}]], "Input",
 CellChangeTimes->{{3.801689038848219*^9, 3.8016890477090626`*^9}, 
   3.80177853075905*^9, 3.8031139983340187`*^9, {3.8031261513407984`*^9, 
   3.80312624801073*^9}, {3.8031284224239283`*^9, 3.8031284235638275`*^9}, {
   3.804344676926572*^9, 3.8043446965778627`*^9}, {3.80485352319683*^9, 
   3.8048535706159515`*^9}, {3.8049544667270565`*^9, 3.8049544667270565`*^9}, 
   3.8050175026566935`*^9, 3.8050182696893077`*^9, 3.8050199344667687`*^9, 
   3.805019969866063*^9, {3.8067648665516233`*^9, 3.8067648665516233`*^9}, {
   3.806766274283498*^9, 3.806766275580185*^9}, {3.806788858252745*^9, 
   3.8067888731246524`*^9}, {3.806833239257119*^9, 3.806833269833151*^9}, 
   3.825283274337109*^9},
 CellLabel->
  "In[198]:=",ExpressionUUID->"3ef16ad7-9288-471b-b407-adece8171bc8"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4. New Equilibrium Calculation",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.7954529786642447`*^9}, {
  3.79545386036082*^9, 3.7954538618860044`*^9}, {3.795525436722562*^9, 
  3.795525448873003*^9}, {3.819900451316465*^9, 
  3.819900451678748*^9}},ExpressionUUID->"a7cca8e1-1791-4b70-9a68-\
3ca375af4ec2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pau", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padu", 
       RowBox[{"1", "-", "sigmaau"}]], "+", 
      RowBox[{"batu", " ", 
       SuperscriptBox["patu", 
        RowBox[{"1", "-", "sigmaau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048537407717743`*^9, 3.804853751697942*^9}, {
   3.804954429923254*^9, 3.804954429938881*^9}, {3.8050196031952763`*^9, 
   3.8050196146346335`*^9}, {3.8050202419412766`*^9, 3.805020254318351*^9}, {
   3.806764855673539*^9, 3.806764855689166*^9}, {3.8067662760490103`*^9, 
   3.806766277137709*^9}, {3.8067889104228306`*^9, 3.8067889156268196`*^9}},
 CellLabel->
  "In[199]:=",ExpressionUUID->"ef893d96-bd08-4069-9c34-459925ad7abd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pcdu", 
       RowBox[{"1", "-", "sigmacu"}]], "+", 
      RowBox[{"bctu", " ", 
       SuperscriptBox["pctu", 
        RowBox[{"1", "-", "sigmacu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmacu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.804853754104593*^9, 
   3.8048537632655916`*^9}, {3.8049544890767255`*^9, 
   3.8049544890767255`*^9}, {3.805019635911148*^9, 3.8050196452420464`*^9}, {
   3.805020269508397*^9, 3.805020277728525*^9}, {3.8067649135109673`*^9, 
   3.8067649135109673`*^9}, {3.806788883376049*^9, 3.806788883454187*^9}, {
   3.80678891895547*^9, 3.8067889336454124`*^9}},
 CellLabel->
  "In[200]:=",ExpressionUUID->"8ed78591-642f-4073-ae37-f3504a3aa756"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Phu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["phdu", 
       RowBox[{"1", "-", "sigmahu"}]], "+", 
      RowBox[{"bhtu", " ", 
       SuperscriptBox["phtu", 
        RowBox[{"1", "-", "sigmahu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmahu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048537655159597`*^9, 
   3.8048537724008365`*^9}, {3.806788889080122*^9, 3.80678888922077*^9}, {
   3.806788937349157*^9, 3.8067889502175436`*^9}},
 CellLabel->
  "In[201]:=",ExpressionUUID->"ce99f432-061e-4019-ad09-c149f12ad464"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pou", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["podu", 
       RowBox[{"1", "-", "sigmaou"}]], "+", 
      RowBox[{"botu", " ", 
       SuperscriptBox["potu", 
        RowBox[{"1", "-", "sigmaou"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaou"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}, {
   3.8049546267109137`*^9, 3.8049546267265406`*^9}, {3.80501967075628*^9, 
   3.8050196847698293`*^9}, {3.8050202878564696`*^9, 
   3.8050202964360323`*^9}, {3.8067649535028925`*^9, 
   3.8067649535028925`*^9}, {3.806788892064996*^9, 3.8067888925650797`*^9}, {
   3.806788956132414*^9, 3.806788981895514*^9}},
 CellLabel->
  "In[202]:=",ExpressionUUID->"885540a3-c558-4d46-8645-7a9b84d95c48"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ppu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["ppdu", 
       RowBox[{"1", "-", "sigmapu"}]], "+", 
      RowBox[{"bptu", " ", 
       SuperscriptBox["pptu", 
        RowBox[{"1", "-", "sigmapu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmapu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}, {
   3.8049546267109137`*^9, 3.8049546267265406`*^9}, {3.80501967075628*^9, 
   3.8050196847698293`*^9}, {3.8050202878564696`*^9, 
   3.8050202964360323`*^9}, {3.8050203416174593`*^9, 
   3.8050203570617857`*^9}, {3.806764972335295*^9, 3.806764972335295*^9}, {
   3.806788895558351*^9, 3.8067888957303176`*^9}, {3.8067889886037445`*^9, 
   3.806789004827945*^9}},
 CellLabel->
  "In[203]:=",ExpressionUUID->"26e7f073-06b1-4e5a-8eff-d9badcd29a3b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdu", 
       RowBox[{"1", "-", "sigmasu"}]], "+", 
      RowBox[{"bstu", " ", 
       SuperscriptBox["pstu", 
        RowBox[{"1", "-", "sigmasu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}, {
   3.8049546267109137`*^9, 3.8049546267265406`*^9}, {3.80501967075628*^9, 
   3.8050196847698293`*^9}, {3.8050202878564696`*^9, 
   3.8050202964360323`*^9}, {3.805020361828209*^9, 3.805020377674616*^9}, {
   3.806788898527591*^9, 3.806788898636985*^9}, {3.8067890084241467`*^9, 
   3.806789022894151*^9}},
 CellLabel->
  "In[204]:=",ExpressionUUID->"46b47e41-b29a-438d-a4f1-ca328fe5a8e2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pu", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pau", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bcu", " ", 
       SuperscriptBox["Pcu", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bhu", " ", 
       SuperscriptBox["Phu", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bou", " ", 
       SuperscriptBox["Pou", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bpu", " ", 
       SuperscriptBox["Ppu", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bsu", " ", 
       SuperscriptBox["Psu", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048536729130955`*^9, 
   3.804853693916567*^9}, 3.805019614650261*^9, 3.8050196452420464`*^9, 
   3.8050196847698293`*^9, {3.805019802540661*^9, 3.805019812682934*^9}, {
   3.8050203129401875`*^9, 3.805020330818774*^9}, {3.8050205921461425`*^9, 
   3.8050205922399073`*^9}, {3.805640322587119*^9, 3.8056403333666506`*^9}, 
   3.806766277340867*^9, {3.806789028285674*^9, 3.806789054157593*^9}},
 CellLabel->
  "In[205]:=",ExpressionUUID->"fcad075f-b133-4c8a-bbfe-1247200c7621"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcdp", "=", 
   FractionBox[
    RowBox[{"pcdu", " ", "pcdp0"}], "pcdu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031106027958107`*^9, 3.8031106200452766`*^9}, 
   3.8031139807171125`*^9, {3.8048538603016443`*^9, 3.8048538983265047`*^9}, 
   3.805017864249967*^9, 3.805018154986638*^9, {3.8050202419412766`*^9, 
   3.805020269508397*^9}, {3.8050206098365355`*^9, 3.8050206231222305`*^9}, {
   3.8067662792304564`*^9, 3.8067662794492416`*^9}, {3.806789067834445*^9, 
   3.806789090820309*^9}},
 CellLabel->
  "In[206]:=",ExpressionUUID->"23f8d671-37dc-4151-9949-66fd776c3fb2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"phdp", "=", 
   FractionBox[
    RowBox[{"phdu", " ", "phdp0"}], "phdu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031106027958107`*^9, 3.8031106200452766`*^9}, 
   3.8031139807171125`*^9, {3.8048538603016443`*^9, 3.804853907051484*^9}, {
   3.8067890935707693`*^9, 3.8067890987747583`*^9}},
 CellLabel->
  "In[207]:=",ExpressionUUID->"2a61f943-defe-466e-9826-0ea9a239ab59"],

Cell[BoxData[
 RowBox[{
  RowBox[{"podp", "=", 
   FractionBox[
    RowBox[{"podu", " ", "podp0"}], "podu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031106027958107`*^9, 3.8031106200452766`*^9}, 
   3.8031139807171125`*^9, {3.8048538603016443`*^9, 3.804853877601373*^9}, {
   3.804853909817563*^9, 3.8048539155841417`*^9}, 3.805017872704455*^9, 
   3.805018163895453*^9, 3.8050202878564696`*^9, 3.8050206310766573`*^9, {
   3.806789101165783*^9, 3.8067891081582403`*^9}},
 CellLabel->
  "In[208]:=",ExpressionUUID->"3a2e6051-8d58-45c7-9742-83a507bdd9ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ppdp", "=", 
   FractionBox[
    RowBox[{"ppdu", " ", "ppdp0"}], "ppdu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031106027958107`*^9, 3.8031106200452766`*^9}, 
   3.8031139807171125`*^9, {3.8048538603016443`*^9, 3.804853877601373*^9}, {
   3.804853909817563*^9, 3.8048539155841417`*^9}, 3.805017872704455*^9, 
   3.805018163895453*^9, 3.8050202878564696`*^9, 3.8050206310766573`*^9, {
   3.805020694025097*^9, 3.8050207030278025`*^9}, {3.806789111472597*^9, 
   3.8067891167703543`*^9}},
 CellLabel->
  "In[209]:=",ExpressionUUID->"e1f04e98-a3b4-4090-b339-40efac64b9ef"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psdp", "=", 
   FractionBox[
    RowBox[{"psdu", " ", "psdp0"}], "psdu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031106027958107`*^9, 3.8031106200452766`*^9}, 
   3.8031139807171125`*^9, {3.8048538603016443`*^9, 3.804853877601373*^9}, {
   3.804853909817563*^9, 3.8048539155841417`*^9}, 3.805017872704455*^9, 
   3.805018163895453*^9, 3.8050202878564696`*^9, 3.8050206310766573`*^9, {
   3.8050207067627883`*^9, 3.8050207138108144`*^9}, {3.8067891193026257`*^9, 
   3.8067891326642237`*^9}},
 CellLabel->
  "In[210]:=",ExpressionUUID->"d9bd73b9-ccb4-4725-a60e-aba4d548a5c0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcp", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pcdp", 
       RowBox[{"1", "-", "sigmacp"}]], "+", 
      RowBox[{"bctp", " ", 
       SuperscriptBox["pctp", 
        RowBox[{"1", "-", "sigmacp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmacp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.8048533906588616`*^9, 
   3.804853392674816*^9}, {3.8048538223073983`*^9, 3.8048538261666756`*^9}, 
   3.8048540893066835`*^9, {3.8049545102317977`*^9, 3.8049545102317977`*^9}, 
   3.805019944046558*^9, 3.8050199843385897`*^9, 3.8050206231222305`*^9, 
   3.8050206633483715`*^9, {3.806789149496649*^9, 3.8067891591403112`*^9}},
 CellLabel->
  "In[211]:=",ExpressionUUID->"a48f174d-0b4e-4016-89cb-12950409eed7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Php", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["phdp", 
       RowBox[{"1", "-", "sigmahp"}]], "+", 
      RowBox[{"bhtp", " ", 
       SuperscriptBox["phtp", 
        RowBox[{"1", "-", "sigmahp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmahp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048533952064857`*^9, 
   3.8048533971443033`*^9}, {3.8048538294184713`*^9, 3.8048538335596733`*^9}, 
   3.8048540912601304`*^9, {3.806789169711401*^9, 3.8067891798382025`*^9}},
 CellLabel->
  "In[212]:=",ExpressionUUID->"d25cd3d4-d9b3-4009-ac7e-4fadd097d429"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pop", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["podp", 
       RowBox[{"1", "-", "sigmaop"}]], "+", 
      RowBox[{"botp", " ", 
       SuperscriptBox["potp", 
        RowBox[{"1", "-", "sigmaop"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaop"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.8048538356537657`*^9, 3.804853840279529*^9}, 3.804854093104184*^9, {
   3.804954640509137*^9, 3.804954640509137*^9}, 3.8050199537057533`*^9, 
   3.805020008092595*^9, 3.8050206310766573`*^9, 3.8050206707245793`*^9, {
   3.806789191404808*^9, 3.8067892010204115`*^9}},
 CellLabel->
  "In[213]:=",ExpressionUUID->"32ef4bb7-8042-4bd0-bd2d-98b82f2e0275"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ppp", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["ppdp", 
       RowBox[{"1", "-", "sigmapp"}]], "+", 
      RowBox[{"bptp", " ", 
       SuperscriptBox["pptp", 
        RowBox[{"1", "-", "sigmapp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmapp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.8048538356537657`*^9, 3.804853840279529*^9}, 3.804854093104184*^9, {
   3.804954640509137*^9, 3.804954640509137*^9}, 3.8050199537057533`*^9, 
   3.805020008092595*^9, 3.8050206310766573`*^9, 3.8050206707245793`*^9, {
   3.805020734720484*^9, 3.8050207497491813`*^9}, {3.806789219191902*^9, 
   3.8067892242095633`*^9}},
 CellLabel->
  "In[214]:=",ExpressionUUID->"08466a49-25b4-495a-aed9-6e7b567f6770"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psp", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdp", 
       RowBox[{"1", "-", "sigmasp"}]], "+", 
      RowBox[{"bstp", " ", 
       SuperscriptBox["pstp", 
        RowBox[{"1", "-", "sigmasp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.8048538356537657`*^9, 3.804853840279529*^9}, 3.804854093104184*^9, {
   3.804954640509137*^9, 3.804954640509137*^9}, 3.8050199537057533`*^9, 
   3.805020008092595*^9, 3.8050206310766573`*^9, 3.8050206707245793`*^9, {
   3.8050207543196583`*^9, 3.8050207705410624`*^9}, {3.8067892409166594`*^9, 
   3.806789245214246*^9}},
 CellLabel->
  "In[215]:=",ExpressionUUID->"4534289d-cc08-4831-a2b9-f2744c2fce2a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pp", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pcp", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bhp", " ", 
       SuperscriptBox["Php", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bop", " ", 
       SuperscriptBox["Pop", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bpp", " ", 
       SuperscriptBox["Ppp", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bsp", " ", 
       SuperscriptBox["Psp", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bap", " ", 
       SuperscriptBox["patp", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048534322140846`*^9, 
   3.8048534358553085`*^9}, {3.8048536992339973`*^9, 3.8048537091388454`*^9}, 
   3.8048540746935024`*^9, {3.805019969866063*^9, 3.805020008092595*^9}, {
   3.8050201228437223`*^9, 3.8050201313295197`*^9}, {3.805020781011525*^9, 
   3.805020802171235*^9}, {3.805640379370714*^9, 3.805640384222707*^9}, 
   3.806766280808835*^9, {3.8067892637478743`*^9, 3.8067893109837904`*^9}},
 CellLabel->
  "In[216]:=",ExpressionUUID->"f0685b32-fed0-4748-827d-4b13ae9f2b4c"],

Cell[TextData[StyleBox["Equilibrium equations",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.825283347660452*^9, 
  3.825283351345337*^9}},ExpressionUUID->"f53d5384-df04-49e5-9c59-\
86eacf427b49"],

Cell["\<\
Total supply (landings) = exports + consumer demand for whole fish + consumer \
demand for processed fish\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800413034212*^9}, 3.799855091636346*^9, {
   3.799884003726459*^9, 3.7998840232612796`*^9}, {3.800099320730234*^9, 
   3.800099324730491*^9}, {3.804344834713479*^9, 3.8043448352639103`*^9}, {
   3.806766281090131*^9, 3.8067662858218727`*^9}, 
   3.8252833613121777`*^9},ExpressionUUID->"a73e3fe0-db97-486d-b715-\
1d3b31d8449a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E1", "=", 
   RowBox[{
    RowBox[{"qadcap", "-", 
     RowBox[{"aadu", " ", 
      SuperscriptBox["padu", 
       RowBox[{"-", "eauu"}]]}]}], "\[Equal]", 
    RowBox[{"qadue0", "+", 
     RowBox[{"ku", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Pau", 
       RowBox[{"sigmaau", "-", "betau"}]], " ", 
      SuperscriptBox["padu", 
       RowBox[{"-", "sigmaau"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.804854416639573*^9, 3.8048544212964177`*^9}, {
   3.8048603517476826`*^9, 3.8048603524352975`*^9}, {3.804954429938881*^9, 
   3.804954429938881*^9}, {3.8049544667270565`*^9, 3.8049544667270565`*^9}, 
   3.8050172287448063`*^9, 3.8050183281629877`*^9, {3.805018387688871*^9, 
   3.8050183990668306`*^9}, 3.805018972205937*^9, 3.805019614650261*^9, 
   3.805019969866063*^9, {3.8050202419412766`*^9, 3.8050202419412766`*^9}, 
   3.805020609852163*^9, {3.806764855689166*^9, 3.8067648665672507`*^9}, {
   3.806766281355798*^9, 3.806766293185562*^9}, {3.806789333051278*^9, 
   3.8067893549231033`*^9}},
 CellLabel->
  "In[217]:=",ExpressionUUID->"7054bfa1-6724-4536-94f8-428722fa9818"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E2", "=", 
   RowBox[{
    RowBox[{"qcdcap", "-", 
     RowBox[{"acdu", " ", 
      SuperscriptBox["pcdu", 
       RowBox[{"-", "ecdu"}]]}]}], "\[Equal]", 
    RowBox[{"qcdue0", "+", 
     RowBox[{"cr", " ", "qcdpe0"}], "+", 
     RowBox[{"ku", " ", "bcu", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Pcu", 
       RowBox[{"sigmacu", "-", "betau"}]], " ", 
      SuperscriptBox["pcdu", 
       RowBox[{"-", "sigmacu"}]]}], "+", 
     RowBox[{"cr", " ", "kp", " ", 
      SuperscriptBox["Pp", 
       RowBox[{"etap", "+", "betap"}]], 
      SuperscriptBox["Pcp", 
       RowBox[{"sigmacp", "-", "betap"}]], " ", 
      SuperscriptBox["pcdp", 
       RowBox[{"-", "sigmacp"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541255705385`*^9, 3.8048541651264515`*^9}, {
   3.8048544272849865`*^9, 3.8048544302820015`*^9}, {3.8048546142370343`*^9, 
   3.804854615080909*^9}, {3.8048603568579025`*^9, 3.804860357420493*^9}, {
   3.8048606311455*^9, 3.804860631911248*^9}, {3.8049544890767255`*^9, 
   3.804954510247425*^9}, 3.80501724212201*^9, 3.805018338258299*^9, {
   3.805018413272153*^9, 3.8050184291651025`*^9}, 3.8050189849580746`*^9, 
   3.8050196452420464`*^9, 3.805019802540661*^9, 3.8050199843542175`*^9, 
   3.8050201228437223`*^9, {3.805020269508397*^9, 3.805020269508397*^9}, 
   3.8050206231222305`*^9, {3.8067649135109673`*^9, 3.8067649135109673`*^9}, {
   3.806789368175403*^9, 3.806789406129859*^9}, {3.8067895737676497`*^9, 
   3.806789580020321*^9}},
 CellLabel->
  "In[218]:=",ExpressionUUID->"8d9a5d54-6195-4864-9379-ebaa47dda552"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E3", "=", 
   RowBox[{
    RowBox[{"qhdcap", "-", 
     RowBox[{"ahdu", " ", 
      SuperscriptBox["phdu", 
       RowBox[{"-", "ehdu"}]]}]}], "\[Equal]", 
    RowBox[{"qhdue0", "+", 
     RowBox[{"cr", " ", "qhdpe0"}], "+", 
     RowBox[{"ku", " ", "bhu", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Phu", 
       RowBox[{"sigmahu", "-", "betau"}]], " ", 
      SuperscriptBox["phdu", 
       RowBox[{"-", "sigmahu"}]]}], "+", 
     RowBox[{"cr", " ", "bhp", " ", "kp", " ", 
      SuperscriptBox["Pp", 
       RowBox[{"etap", "+", "betap"}]], 
      SuperscriptBox["Php", 
       RowBox[{"sigmahp", "-", "betap"}]], " ", 
      SuperscriptBox["phdp", 
       RowBox[{"-", "sigmahp"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541278209124`*^9, 3.804854127961561*^9}, {
   3.804854173974129*^9, 3.8048542013069344`*^9}, {3.8048544347821636`*^9, 
   3.804854437822094*^9}, {3.8048546184876595`*^9, 3.804854619268606*^9}, {
   3.804860360530382*^9, 3.804860361030465*^9}, {3.8048606435537367`*^9, 
   3.8048606448664465`*^9}, {3.806789412974747*^9, 3.8067894579128532`*^9}},
 CellLabel->
  "In[219]:=",ExpressionUUID->"b0114ba0-c557-4d16-ae5b-21ff20f003b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E4", "=", 
   RowBox[{
    RowBox[{"qodcap", "-", 
     RowBox[{"aodu", " ", 
      SuperscriptBox["podu", 
       RowBox[{"-", "eodu"}]]}]}], "\[Equal]", 
    RowBox[{"qodue0", "+", 
     RowBox[{"cr", " ", "qodpe0"}], "+", 
     RowBox[{"ku", " ", "bou", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Pou", 
       RowBox[{"sigmaou", "-", "betau"}]], " ", 
      SuperscriptBox["podu", 
       RowBox[{"-", "sigmaou"}]]}], "+", 
     RowBox[{"cr", " ", "bop", " ", "kp", " ", 
      SuperscriptBox["Pp", 
       RowBox[{"etap", "+", "betap"}]], 
      SuperscriptBox["Pop", 
       RowBox[{"sigmaop", "-", "betap"}]], " ", 
      SuperscriptBox["podp", 
       RowBox[{"-", "sigmaop"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541303369503`*^9, 3.8048541304619713`*^9}, {
   3.8048542078548927`*^9, 3.8048542473983154`*^9}, {3.8048544408381042`*^9, 
   3.8048544472919245`*^9}, {3.8048546221752834`*^9, 
   3.8048546230035305`*^9}, {3.804860163075424*^9, 3.804860163434861*^9}, {
   3.804860364468531*^9, 3.8048603661250505`*^9}, {3.8048606546180067`*^9, 
   3.8048606554618917`*^9}, {3.8049546267265406`*^9, 3.804954640509137*^9}, 
   3.8050172630966716`*^9, 3.805018360214622*^9, {3.805018443417308*^9, 
   3.8050184579051275`*^9}, 3.8050194297527933`*^9, 3.805019684785465*^9, 
   3.805019812682934*^9, 3.805020008092595*^9, 3.8050201313295197`*^9, {
   3.8050202878564696`*^9, 3.8050202878564696`*^9}, 3.8050206310766573`*^9, {
   3.8067649535028925`*^9, 3.8067649535028925`*^9}, {3.806789468853359*^9, 
   3.80678949682239*^9}, {3.8068328434463844`*^9, 3.8068328552295294`*^9}},
 CellLabel->
  "In[220]:=",ExpressionUUID->"b96827f8-268f-402a-b86f-72a53198ccf1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E5", "=", 
   RowBox[{
    RowBox[{"qpdcap", "-", 
     RowBox[{"apdu", " ", 
      SuperscriptBox["ppdu", 
       RowBox[{"-", "epdu"}]]}]}], "\[Equal]", 
    RowBox[{"qpdue0", "+", 
     RowBox[{"cr", " ", "qpdpe0"}], "+", 
     RowBox[{"ku", " ", "bpu", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Ppu", 
       RowBox[{"sigmapu", "-", "betau"}]], " ", 
      SuperscriptBox["ppdu", 
       RowBox[{"-", "sigmapu"}]]}], "+", 
     RowBox[{"cr", " ", "bpp", " ", "kp", " ", 
      SuperscriptBox["Pp", 
       RowBox[{"etap", "+", "betap"}]], 
      SuperscriptBox["Ppp", 
       RowBox[{"sigmapp", "-", "betap"}]], " ", 
      SuperscriptBox["ppdp", 
       RowBox[{"-", "sigmapp"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541303369503`*^9, 3.8048541304619713`*^9}, {
   3.8048542078548927`*^9, 3.8048542473983154`*^9}, {3.8048544408381042`*^9, 
   3.8048544472919245`*^9}, {3.8048546221752834`*^9, 
   3.8048546230035305`*^9}, {3.804860163075424*^9, 3.804860163434861*^9}, {
   3.804860364468531*^9, 3.8048603661250505`*^9}, {3.8048606546180067`*^9, 
   3.8048606554618917`*^9}, {3.8049546267265406`*^9, 3.804954640509137*^9}, 
   3.8050172630966716`*^9, 3.805018360214622*^9, {3.805018443417308*^9, 
   3.8050184579051275`*^9}, 3.8050194297527933`*^9, 3.805019684785465*^9, 
   3.805019812682934*^9, 3.805020008092595*^9, 3.8050201313295197`*^9, {
   3.8050202878564696`*^9, 3.8050202878564696`*^9}, 3.8050206310766573`*^9, {
   3.805020861123869*^9, 3.805020912948207*^9}, {3.806764972335295*^9, 
   3.806764972335295*^9}, {3.806789509372573*^9, 3.8067895360890055`*^9}},
 CellLabel->
  "In[221]:=",ExpressionUUID->"0968519c-053b-4dae-becf-1dda4af898b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E6", "=", 
   RowBox[{
    RowBox[{"qsdcap", "-", 
     RowBox[{"asdu", " ", 
      SuperscriptBox["psdu", 
       RowBox[{"-", "esdu"}]]}]}], "\[Equal]", 
    RowBox[{"qsdue0", "+", 
     RowBox[{"cr", " ", "qsdpe0"}], "+", 
     RowBox[{"ku", " ", "bsu", " ", 
      SuperscriptBox["Pu", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Psu", 
       RowBox[{"sigmasu", "-", "betau"}]], " ", 
      SuperscriptBox["psdu", 
       RowBox[{"-", "sigmasu"}]]}], "+", 
     RowBox[{"cr", " ", "bsp", " ", "kp", " ", 
      SuperscriptBox["Pp", 
       RowBox[{"etap", "+", "betap"}]], 
      SuperscriptBox["Psp", 
       RowBox[{"sigmasp", "-", "betap"}]], " ", 
      SuperscriptBox["psdp", 
       RowBox[{"-", "sigmasp"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541303369503`*^9, 3.8048541304619713`*^9}, {
   3.8048542078548927`*^9, 3.8048542473983154`*^9}, {3.8048544408381042`*^9, 
   3.8048544472919245`*^9}, {3.8048546221752834`*^9, 
   3.8048546230035305`*^9}, {3.804860163075424*^9, 3.804860163434861*^9}, {
   3.804860364468531*^9, 3.8048603661250505`*^9}, {3.8048606546180067`*^9, 
   3.8048606554618917`*^9}, {3.8049546267265406`*^9, 3.804954640509137*^9}, 
   3.8050172630966716`*^9, 3.805018360214622*^9, {3.805018443417308*^9, 
   3.8050184579051275`*^9}, 3.8050194297527933`*^9, 3.805019684785465*^9, 
   3.805019812682934*^9, 3.805020008092595*^9, 3.8050201313295197`*^9, {
   3.8050202878564696`*^9, 3.8050202878564696`*^9}, 3.8050206310766573`*^9, {
   3.8050208652351437`*^9, 3.8050208655164404`*^9}, {3.8050209307173986`*^9, 
   3.8050209595502567`*^9}, {3.8067895482004004`*^9, 3.8067895601560745`*^9}},
 CellLabel->
  "In[222]:=",ExpressionUUID->"c2996b52-8c55-4eee-9698-15dc1c36aea2"],

Cell["\<\
Supply of imported unprocessed product = Demand for imported unprocessed \
product\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.7998012380597954`*^9}, {3.804854223408702*^9, 
   3.804854223455584*^9}, {3.80485425494967*^9, 3.8048542550121794`*^9}, {
   3.804854289806265*^9, 3.8048542955259604`*^9}, {3.8048543266944003`*^9, 
   3.804854326803794*^9}, 3.8067662935918775`*^9, {3.8067663997058973`*^9, 
   3.8067664000340776`*^9}},ExpressionUUID->"f2222292-c02a-4dff-bfb0-\
5253e658f6aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E7", "=", 
   RowBox[{
    RowBox[{"qalu0", "+", 
     RowBox[{"repla", " ", "qaiu0"}]}], "\[Equal]", 
    RowBox[{"ku", " ", "batu", " ", 
     SuperscriptBox["Pu", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Pau", 
      RowBox[{"sigmaau", "-", "betau"}]], "  ", 
     SuperscriptBox["patu", 
      RowBox[{"-", "sigmaau"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854469219143*^9}, {3.8049544299545083`*^9, 
   3.8049544299545083`*^9}, 3.8050175725759478`*^9, 3.8050176841894617`*^9, {
   3.805019603210904*^9, 3.805019614650261*^9}, 3.805020254318351*^9, {
   3.8050209691455855`*^9, 3.805020969286234*^9}, {3.8056380321600294`*^9, 
   3.8056380324725823`*^9}, {3.8067648557204213`*^9, 
   3.8067648557204213`*^9}, {3.806766293795035*^9, 3.8067662948108234`*^9}, {
   3.806789615684561*^9, 3.8067896217947903`*^9}, {3.8067906145288486`*^9, 
   3.8067906150758142`*^9}},
 CellLabel->
  "In[223]:=",ExpressionUUID->"791f993f-332f-45c9-b74d-5610bfc47b08"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E8", "=", 
   RowBox[{
    RowBox[{"qclu0", "+", 
     RowBox[{"replc", " ", "qciu0"}]}], "\[Equal]", 
    RowBox[{"ku", " ", "bctu", " ", "bcu", " ", 
     SuperscriptBox["Pu", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Pcu", 
      RowBox[{"sigmacu", "-", "betau"}]], "  ", 
     SuperscriptBox["pctu", 
      RowBox[{"-", "sigmacu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.8048545129788523`*^9}, {3.804860514608667*^9, 
   3.8048605154838066`*^9}, {3.8049544890767255`*^9, 3.8049544890767255`*^9}, 
   3.805017589247558*^9, 3.8050176968766108`*^9, {3.805019635926775*^9, 
   3.8050196452420464`*^9}, 3.805019802540661*^9, 3.805020277728525*^9, {
   3.8050209719898124`*^9, 3.805020972114833*^9}, {3.805638036066558*^9, 
   3.805638036240765*^9}, {3.8067649135109673`*^9, 3.8067649135109673`*^9}, {
   3.8067896328863115`*^9, 3.806789650336342*^9}},
 CellLabel->
  "In[224]:=",ExpressionUUID->"e0970f00-5295-4a08-929a-eb9fdaf290f2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E9", "=", 
   RowBox[{
    RowBox[{"qhlu0", "+", 
     RowBox[{"replh", " ", "qhiu0"}]}], "\[Equal]", 
    RowBox[{"ku", " ", "bhtu", " ", "bhu", " ", 
     SuperscriptBox["Pu", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Phu", 
      RowBox[{"sigmahu", "-", "betau"}]], "  ", 
     SuperscriptBox["phtu", 
      RowBox[{"-", "sigmahu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854535651602*^9}, {3.804860518781827*^9, 
   3.8048605197034464`*^9}, {3.805020974568369*^9, 3.8050209747090178`*^9}, {
   3.8056380391773567`*^9, 3.805638039489907*^9}, {3.806789652752277*^9, 
   3.806789671005782*^9}},
 CellLabel->
  "In[225]:=",ExpressionUUID->"ff7b668f-42fc-496d-9711-68ef3214bd65"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E10", "=", 
   RowBox[{
    RowBox[{"qolu0", "+", 
     RowBox[{"replo", " ", "qoiu0"}]}], "\[Equal]", 
    RowBox[{"ku", " ", "botu", " ", "bou", " ", 
     SuperscriptBox["Pu", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Pou", 
      RowBox[{"sigmaou", "-", "betau"}]], "  ", 
     SuperscriptBox["potu", 
      RowBox[{"-", "sigmaou"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854492241708*^9}, {3.8048545380175877`*^9, 
   3.8048545527071533`*^9}, {3.8048605221100817`*^9, 
   3.8048605232990365`*^9}, {3.8049546267265406`*^9, 3.8049546267265406`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805019670771908*^9, 
   3.805019684785465*^9}, 3.8050198126985607`*^9, 3.8050202964360323`*^9, {
   3.805020977131299*^9, 3.8050209774125957`*^9}, {3.805638042536155*^9, 
   3.8056380426924305`*^9}, {3.8067649535028925`*^9, 
   3.8067649535028925`*^9}, {3.806789674553228*^9, 3.8067897296714444`*^9}},
 CellLabel->
  "In[226]:=",ExpressionUUID->"d16e2950-660f-43e2-895a-44af17fb0b6a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E11", "=", 
   RowBox[{
    RowBox[{"qplu0", "+", 
     RowBox[{"replp", " ", "qpiu0"}]}], "\[Equal]", 
    RowBox[{"ku", " ", "bptu", " ", "bpu", " ", 
     SuperscriptBox["Pu", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Ppu", 
      RowBox[{"sigmapu", "-", "betau"}]], "  ", 
     SuperscriptBox["pptu", 
      RowBox[{"-", "sigmapu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854492241708*^9}, {3.8048545380175877`*^9, 
   3.8048545527071533`*^9}, {3.8048605221100817`*^9, 
   3.8048605232990365`*^9}, {3.8049546267265406`*^9, 3.8049546267265406`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805019670771908*^9, 
   3.805019684785465*^9}, 3.8050198126985607`*^9, 3.8050202964360323`*^9, {
   3.805020977131299*^9, 3.805021024420715*^9}, {3.8056380458491983`*^9, 
   3.805638046021101*^9}, {3.8067649723509226`*^9, 3.8067649723509226`*^9}, {
   3.8067897332190866`*^9, 3.8067897560275936`*^9}},
 CellLabel->
  "In[227]:=",ExpressionUUID->"cfe54ccf-0db7-4801-88fa-6007d3fcd471"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E12", "=", 
   RowBox[{
    RowBox[{"qslu0", "+", 
     RowBox[{"repls", " ", "qsiu0"}]}], "\[Equal]", 
    RowBox[{"ku", " ", "bstu", " ", "bsu", " ", 
     SuperscriptBox["Pu", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Psu", 
      RowBox[{"sigmasu", "-", "betau"}]], "  ", 
     SuperscriptBox["pstu", 
      RowBox[{"-", "sigmasu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854492241708*^9}, {3.8048545380175877`*^9, 
   3.8048545527071533`*^9}, {3.8048605221100817`*^9, 
   3.8048605232990365`*^9}, {3.8049546267265406`*^9, 3.8049546267265406`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805019670771908*^9, 
   3.805019684785465*^9}, 3.8050198126985607`*^9, 3.8050202964360323`*^9, {
   3.805020977131299*^9, 3.805020990602307*^9}, {3.805021027311825*^9, 
   3.8050210469393115`*^9}, {3.8056380485550127`*^9, 
   3.8056380493363886`*^9}, {3.8067897588249187`*^9, 3.8067897783611155`*^9}},
 CellLabel->
  "In[228]:=",ExpressionUUID->"63d14fc8-2bcf-4006-bdcb-7b8b710e0c35"],

Cell["\<\
Supply of imported processed product = Demand for imported processed product\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.7998012380597954`*^9}, {3.799884418200181*^9, 
   3.799884420684106*^9}, {3.8048542235337224`*^9, 3.8048542235649776`*^9}, {
   3.8048542551059437`*^9, 3.804854255152827*^9}, {3.8048543063260717`*^9, 
   3.804854311392005*^9}, {3.8048546319736*^9, 3.8048546323799095`*^9}, 
   3.806766295873494*^9, {3.806766402784531*^9, 
   3.806766402909552*^9}},ExpressionUUID->"aee4aa60-9cad-4f3f-8312-\
69ed87061370"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E13", "=", 
   RowBox[{
    RowBox[{"qalp0", "+", 
     RowBox[{"repla", " ", "qaip0"}]}], "\[Equal]", 
    RowBox[{"kp", " ", "bap", " ", 
     SuperscriptBox["Pp", 
      RowBox[{"etap", "+", "betap"}]], " ", 
     SuperscriptBox["patp", 
      RowBox[{"-", "betap"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
   3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
   3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
   3.8048546364093094`*^9, 3.8048546757308216`*^9}, {3.8049544667426844`*^9, 
   3.8049544667426844`*^9}, 3.805017636828994*^9, 3.8050199344667687`*^9, 
   3.805019969866063*^9, 3.8050206555502205`*^9, {3.8050210534247737`*^9, 
   3.8050210719588156`*^9}, {3.805638052243109*^9, 3.805638052446267*^9}, {
   3.8067648665672507`*^9, 3.8067648665672507`*^9}, {3.806766295873494*^9, 
   3.806766295890339*^9}, {3.806789819037187*^9, 3.80678984569905*^9}, {
   3.8067899767575455`*^9, 3.806789979788899*^9}},
 CellLabel->
  "In[229]:=",ExpressionUUID->"dc442f99-2bf6-4cb3-b474-ca34a001692e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E14", "=", 
   RowBox[{
    RowBox[{"qclp0", "+", 
     RowBox[{"replc", " ", "qcip0"}]}], "\[Equal]", 
    RowBox[{"kp", " ", "bctp", " ", 
     SuperscriptBox["Pp", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pcp", 
      RowBox[{"sigmacp", "-", "betap"}]], " ", 
     SuperscriptBox["pctp", 
      RowBox[{"-", "sigmacp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
   3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
   3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
   3.8048546364093094`*^9, 3.8048547075084224`*^9}, {3.804860454860574*^9, 
   3.804860461533553*^9}, {3.804954510247425*^9, 3.804954510247425*^9}, 
   3.805017646330557*^9, 3.805019944046558*^9, 3.8050199843542175`*^9, 
   3.8050201228437223`*^9, 3.8050206633483715`*^9, {3.805021056300256*^9, 
   3.8050210762098417`*^9}, {3.8056380554623804`*^9, 
   3.8056380555717735`*^9}, {3.8067898592499385`*^9, 3.8067898811166983`*^9}},
 CellLabel->
  "In[230]:=",ExpressionUUID->"8fd0c066-a41d-4bb3-8941-1c1ea14cc382"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E15", "=", 
   RowBox[{
    RowBox[{"qhlp0", "+", 
     RowBox[{"replh", " ", "qhip0"}]}], "\[Equal]", 
    RowBox[{"kp", " ", "bhtp", " ", "bhp", " ", 
     SuperscriptBox["Pp", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Php", 
      RowBox[{"sigmahp", "-", "betap"}]], " ", 
     SuperscriptBox["phtp", 
      RowBox[{"-", "sigmahp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
  3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
  3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
  3.8048546364093094`*^9, 3.804854724823798*^9}, {3.804860465050977*^9, 
  3.804860465769847*^9}, {3.805021058753792*^9, 3.805021058972579*^9}, {
  3.8056380585410113`*^9, 3.805638058884816*^9}, {3.806789883932511*^9, 
  3.806789913783481*^9}},
 CellLabel->
  "In[231]:=",ExpressionUUID->"97c8f4b3-e25d-4002-9d3d-bf446eb05265"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E16", "=", 
   RowBox[{
    RowBox[{"qolp0", "+", 
     RowBox[{"replo", " ", "qoip0"}]}], "\[Equal]", 
    RowBox[{"kp", " ", "botp", " ", "bop", " ", 
     SuperscriptBox["Pp", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pop", 
      RowBox[{"sigmaop", "-", "betap"}]], " ", 
     SuperscriptBox["potp", 
      RowBox[{"-", "sigmaop"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
   3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
   3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
   3.8048546364093094`*^9, 3.804854691797214*^9}, {3.804854727667985*^9, 
   3.8048547417515974`*^9}, {3.804860470270588*^9, 3.8048604712707496`*^9}, {
   3.804954640509137*^9, 3.804954640524764*^9}, 3.8050176541599693`*^9, 
   3.8050199537057533`*^9, 3.8050200081082225`*^9, 3.805020131345148*^9, 
   3.8050206707245793`*^9, {3.805021060755541*^9, 3.8050210902671776`*^9}, {
   3.8056380617710304`*^9, 3.8056380622641325`*^9}, {3.806789916393276*^9, 
   3.8067899376337585`*^9}},
 CellLabel->
  "In[232]:=",ExpressionUUID->"0940c008-f167-45b0-8f67-f75f70a7d4aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E17", "=", 
   RowBox[{
    RowBox[{"qplp0", "+", 
     RowBox[{"replp", " ", "qpip0"}]}], "\[Equal]", 
    RowBox[{"kp", " ", "bptp", " ", "bpp", " ", 
     SuperscriptBox["Pp", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Ppp", 
      RowBox[{"sigmapp", "-", "betap"}]], " ", 
     SuperscriptBox["pptp", 
      RowBox[{"-", "sigmapp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
   3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
   3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
   3.8048546364093094`*^9, 3.8048546757308216`*^9}, {3.8049544667426844`*^9, 
   3.8049544667426844`*^9}, 3.805017636828994*^9, 3.8050199344667687`*^9, 
   3.805019969866063*^9, 3.8050206555502205`*^9, {3.8050210534247737`*^9, 
   3.8050210719588156`*^9}, {3.805021114427477*^9, 3.8050211350415163`*^9}, {
   3.8056380697113733`*^9, 3.805638069878157*^9}, {3.806789940916145*^9, 
   3.8067899607220736`*^9}, {3.8068329705184917`*^9, 3.806832979083044*^9}},
 CellLabel->
  "In[233]:=",ExpressionUUID->"4a6d51bc-ab93-4cda-be00-59be19085ebe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E18", "=", 
   RowBox[{
    RowBox[{"qslp0", "+", 
     RowBox[{"repls", " ", "qsip0"}]}], "\[Equal]", 
    RowBox[{"kp", " ", "bstp", " ", "bsp", " ", 
     SuperscriptBox["Pp", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Psp", 
      RowBox[{"sigmasp", "-", "betap"}]], " ", 
     SuperscriptBox["pstp", 
      RowBox[{"-", "sigmasp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
   3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
   3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
   3.8048546364093094`*^9, 3.8048546757308216`*^9}, {3.8049544667426844`*^9, 
   3.8049544667426844`*^9}, 3.805017636828994*^9, 3.8050199344667687`*^9, 
   3.805019969866063*^9, 3.8050206555502205`*^9, {3.8050210534247737`*^9, 
   3.8050210719588156`*^9}, {3.8050211188813486`*^9, 
   3.8050211455120215`*^9}, {3.805638072172863*^9, 3.8056380723393145`*^9}, {
   3.8067899996030416`*^9, 3.806790014834158*^9}, {3.8068329821785464`*^9, 
   3.8068329827411404`*^9}},
 CellLabel->
  "In[234]:=",ExpressionUUID->"0f1f16ba-f3a9-433f-bc3f-db13778a6b2c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "E1", ",", "E2", ",", "E3", ",", " ", "E4", ",", " ", "E5", ",", " ", 
     "E6", ",", "E7", ",", "E8", ",", "E9", ",", "E10", ",", "E11", ",", 
     "E12", ",", " ", "E13", ",", " ", "E14", ",", " ", "E15", ",", " ", 
     "E16", ",", " ", "E17", ",", " ", "E18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"padu", ",", "padu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"patu", ",", "patu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pcdu", ",", "pcdu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pctu", ",", "pctu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"phdu", ",", "phdu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"phtu", ",", "phtu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"podu", ",", "podu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"potu", ",", "potu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"patp", ",", "patp0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pctp", ",", "pctp0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"phtp", ",", "phtp0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"potp", ",", "potp0"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"ppdu", ",", "ppdu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pptu", ",", "pptu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pptp", ",", "pptp0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"psdu", ",", "psdu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pstu", ",", "pstu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pstp", ",", "pstp0"}], "}"}], ",", 
   RowBox[{"AccuracyGoal", "\[Rule]", " ", "6"}], ",", " ", 
   RowBox[{"PrecisionGoal", "\[Rule]", " ", "6"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799801050741409*^9, 3.7998010802456255`*^9}, {
   3.799801592828159*^9, 3.799801634478999*^9}, {3.7998017203390927`*^9, 
   3.799801763344025*^9}, 3.7998021088038597`*^9, {3.799855159502365*^9, 
   3.799855165706504*^9}, {3.801692496821689*^9, 3.801692518577862*^9}, {
   3.801780123825697*^9, 3.8017801628874054`*^9}, {3.80178020897694*^9, 
   3.8017802303410735`*^9}, {3.804345075920143*^9, 3.8043451100366836`*^9}, {
   3.8048547484844165`*^9, 3.8048549152697835`*^9}, {3.8050178536701374`*^9, 
   3.805017872704455*^9}, {3.8050180911664543`*^9, 3.805018113403982*^9}, {
   3.8050182696893077`*^9, 3.8050182855042944`*^9}, {3.8050202419569035`*^9, 
   3.8050202964360323`*^9}, {3.8050206555502205`*^9, 
   3.8050206707245793`*^9}, {3.8050211495951157`*^9, 
   3.8050212640550547`*^9}, {3.805640520045041*^9, 3.8056405549869733`*^9}, 
   3.8056410453683844`*^9, {3.806766295890339*^9, 3.8067662959059663`*^9}, {
   3.806790033493409*^9, 3.806790075525874*^9}, {3.806790132327119*^9, 
   3.8067902104953566`*^9}, {3.8068345450910096`*^9, 
   3.8068345455442104`*^9}, {3.8068361427784767`*^9, 3.806836163988557*^9}, {
   3.8068362180905004`*^9, 3.806836244028018*^9}, {3.806836474800679*^9, 
   3.8068364886153865`*^9}, {3.8252833848525543`*^9, 3.8252833939106426`*^9}},
 CellLabel->
  "In[235]:=",ExpressionUUID->"6340c5ef-1fdf-4a1b-8913-8de97b421861"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"padu", "\[Rule]", "4.503266626896276`"}], ",", 
   RowBox[{"patu", "\[Rule]", "8.913841100154384`"}], ",", 
   RowBox[{"pcdu", "\[Rule]", "11.854069650067844`"}], ",", 
   RowBox[{"pctu", "\[Rule]", "15.136377336846722`"}], ",", 
   RowBox[{"phdu", "\[Rule]", "1.7655555629295072`"}], ",", 
   RowBox[{"phtu", "\[Rule]", "4.457509134504438`"}], ",", 
   RowBox[{"podu", "\[Rule]", "2.898765355872339`"}], ",", 
   RowBox[{"potu", "\[Rule]", "10.821437572115043`"}], ",", 
   RowBox[{"patp", "\[Rule]", "12.986213430126384`"}], ",", 
   RowBox[{"pctp", "\[Rule]", "16.97780064085107`"}], ",", 
   RowBox[{"phtp", "\[Rule]", "7.921131983002315`"}], ",", 
   RowBox[{"potp", "\[Rule]", "10.518501408990625`"}], ",", 
   RowBox[{"ppdu", "\[Rule]", "1.0010385953002519`"}], ",", 
   RowBox[{"pptu", "\[Rule]", "6.1292263807490475`"}], ",", 
   RowBox[{"pptp", "\[Rule]", "7.011287738553882`"}], ",", 
   RowBox[{"psdu", "\[Rule]", "2.975199738037411`"}], ",", 
   RowBox[{"pstu", "\[Rule]", "9.269164998327284`"}], ",", 
   RowBox[{"pstp", "\[Rule]", "7.575916014994053`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8067906011164465`*^9, 3.8067906285634785`*^9}, 
   3.8068326309942307`*^9, 3.8068329898048162`*^9, 3.806833355120599*^9, 
   3.8068340563226423`*^9, 3.806834363778349*^9, {3.806834552232403*^9, 
   3.8068345690982485`*^9}, 3.80683475689135*^9, 3.806835133896302*^9, 
   3.806835276686602*^9, 3.806835339430457*^9, 3.8068354380532455`*^9, 
   3.8068355638795533`*^9, 3.8068361671453285`*^9, {3.806836222537903*^9, 
   3.806836245075068*^9}, 3.806836451708686*^9, {3.806836481973657*^9, 
   3.806836494676769*^9}, 3.806836811768938*^9, 3.806839110733186*^9, 
   3.806839660216255*^9, 3.8076504292857323`*^9, 3.8076509591856556`*^9, 
   3.8076513888909793`*^9, 3.810037652129752*^9, 3.812469637387309*^9, 
   3.8124699074153347`*^9, 3.8126712332736025`*^9, 3.812801917297058*^9, 
   3.812802320584945*^9, 3.8128023715866423`*^9, 3.8129277240547233`*^9, 
   3.812928120644964*^9, 3.8129285023351016`*^9, 3.8129756898329616`*^9, 
   3.8129760912940664`*^9, 3.815477033279024*^9, 3.815774999873564*^9, 
   3.8169493275400596`*^9, 3.818775944349608*^9, 3.8200583680748053`*^9, 
   3.820358854055868*^9, 3.8252832870790553`*^9, {3.825283386701003*^9, 
   3.8252833952096577`*^9}, 3.8252840174046087`*^9, 3.825413533690098*^9},
 CellLabel->
  "Out[235]=",ExpressionUUID->"23a64578-3328-4cdf-ace1-df6acacc5887"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"padu1", " ", "=", " ", 
   RowBox[{"padu", "/.", "%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549276482487`*^9}, {3.8050202419725313`*^9, 3.8050202419725313`*^9}, {
  3.8067662959372215`*^9, 3.8067662959372215`*^9}},
 CellLabel->
  "In[236]:=",ExpressionUUID->"946f9cfe-6f47-48dd-8266-de1998056519"],

Cell[BoxData[
 RowBox[{
  RowBox[{"patu1", " ", "=", " ", 
   RowBox[{"patu", "/.", "%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549332913156`*^9}, {3.8050202543339787`*^9, 3.8050202543339787`*^9}, {
  3.8067662959372215`*^9, 3.8067662959372215`*^9}},
 CellLabel->
  "In[237]:=",ExpressionUUID->"43559586-6a2c-42e9-a31e-8d54a991c323"],

Cell[BoxData[
 RowBox[{
  RowBox[{"patp1", " ", "=", " ", 
   RowBox[{"patp", "/.", "%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.80485493651056*^9}, {3.8050206555502205`*^9, 3.805020655565849*^9}, {
  3.8067662959372215`*^9, 3.8067662959372215`*^9}},
 CellLabel->
  "In[238]:=",ExpressionUUID->"fe6319c4-183f-4cb1-8921-13252519ec27"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcdu1", " ", "=", " ", 
   RowBox[{"pcdu", "/.", "%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549495621114`*^9}, {3.804854982786557*^9, 3.804854983239752*^9}, {
  3.8050202695240245`*^9, 3.8050202695240245`*^9}, {3.806790037915993*^9, 
  3.806790038353565*^9}},
 CellLabel->
  "In[239]:=",ExpressionUUID->"9dc9d079-0605-42cf-9fae-d970b8bf9b15"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pctu1", " ", "=", " ", 
   RowBox[{"pctu", "/.", "%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549504059906`*^9}, {3.8048549864902515`*^9, 3.804854986960324*^9}, {
  3.805020277728525*^9, 3.805020277744152*^9}, {3.8067900389173164`*^9, 
  3.8067900393861427`*^9}},
 CellLabel->
  "In[240]:=",ExpressionUUID->"52280ee1-ca06-46e2-8fd2-1ee3bf86a7bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pctp1", " ", "=", " ", 
   RowBox[{"pctp", "/.", "%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.8048549519374757`*^9}, {3.8048549888981214`*^9, 3.804854989429453*^9}, {
  3.8050206633639984`*^9, 3.8050206633639984`*^9}, {3.8067900402300277`*^9, 
  3.8067900406988544`*^9}},
 CellLabel->
  "In[241]:=",ExpressionUUID->"16577354-fa8c-4ba9-a552-6e3f71acfce3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"phdu1", " ", "=", " ", 
   RowBox[{"phdu", "/.", "%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549948209057`*^9}, {3.8067900816983824`*^9, 3.8067900822297177`*^9}},
 CellLabel->
  "In[242]:=",ExpressionUUID->"d8dba8ef-0920-4505-bdb4-adc27f532b87"],

Cell[BoxData[
 RowBox[{
  RowBox[{"phtu1", " ", "=", " ", 
   RowBox[{"phtu", "/.", "%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549332913156`*^9}, {3.8048549687687798`*^9, 3.8048549977743783`*^9}, {
  3.806790082667288*^9, 3.806790083073614*^9}},
 CellLabel->
  "In[243]:=",ExpressionUUID->"bd09eadf-153e-4b02-a931-f9871574b095"],

Cell[BoxData[
 RowBox[{
  RowBox[{"phtp1", " ", "=", " ", 
   RowBox[{"phtp", "/.", "%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.80485493651056*^9}, {3.804854969784561*^9, 3.8048550007148633`*^9}, {
  3.806790083667472*^9, 3.8067900842933607`*^9}},
 CellLabel->
  "In[244]:=",ExpressionUUID->"dbbea929-f638-498e-b75b-52c8fc05722d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"podu1", " ", "=", " ", 
   RowBox[{"podu", "/.", "%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549276482487`*^9}, {3.804854975285405*^9, 3.804855007481864*^9}, {
  3.805020287872097*^9, 3.805020287872097*^9}, {3.806790137594819*^9, 
  3.806790138313685*^9}},
 CellLabel->
  "In[245]:=",ExpressionUUID->"ec51b3fd-7e7d-4c61-9972-2d851b2142ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{"potu1", " ", "=", " ", 
   RowBox[{"potu", "/.", "%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549332913156`*^9}, {3.804854976394951*^9, 3.8048549767231264`*^9}, {
  3.8048550098412547`*^9, 3.804855011638406*^9}, {3.80502029645166*^9, 
  3.80502029645166*^9}, {3.8067901387825108`*^9, 3.8067901391888256`*^9}},
 CellLabel->
  "In[246]:=",ExpressionUUID->"2d72f4c8-4704-4135-89b4-ae65638945c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"potp1", " ", "=", " ", 
   RowBox[{"potp", "/.", "%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.80485493651056*^9}, {3.804854977160694*^9, 3.804854978739061*^9}, {
  3.8048550132320137`*^9, 3.8048550149197726`*^9}, {3.8050206707402067`*^9, 
  3.8050206707402067`*^9}, {3.8067901396107683`*^9, 3.806790140032711*^9}},
 CellLabel->
  "In[247]:=",ExpressionUUID->"e4ae86d0-0ecf-4d01-9a43-638ff4316501"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ppdu1", " ", "=", " ", 
   RowBox[{"ppdu", "/.", "%%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549276482487`*^9}, {3.804854975285405*^9, 3.804855007481864*^9}, {
  3.805020287872097*^9, 3.805020287872097*^9}, {3.805021283198599*^9, 
  3.805021290567246*^9}, {3.8067901657648015`*^9, 3.806790166186746*^9}},
 CellLabel->
  "In[248]:=",ExpressionUUID->"363b0dc2-9fe4-4ac6-8270-075099442dc1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pptu1", " ", "=", " ", 
   RowBox[{"pptu", "/.", "%%%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549332913156`*^9}, {3.804854976394951*^9, 3.8048549767231264`*^9}, {
  3.8048550098412547`*^9, 3.804855011638406*^9}, {3.80502029645166*^9, 
  3.80502029645166*^9}, {3.805021293223941*^9, 3.8050212992860556`*^9}, {
  3.8067901665774326`*^9, 3.806790166983748*^9}},
 CellLabel->
  "In[249]:=",ExpressionUUID->"f468faf8-f8bd-4c10-ac7a-f2bb158e1dcd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pptp1", " ", "=", " ", 
   RowBox[{"pptp", "/.", "%%%%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.80485493651056*^9}, {3.804854977160694*^9, 3.804854978739061*^9}, {
  3.8048550132320137`*^9, 3.8048550149197726`*^9}, {3.8050206707402067`*^9, 
  3.8050206707402067`*^9}, {3.8050213014895496`*^9, 3.805021306836628*^9}, {
  3.8067901673588085`*^9, 3.806790167749496*^9}},
 CellLabel->
  "In[250]:=",ExpressionUUID->"cea7b54e-c772-47bd-897d-57c5f521d92a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psdu1", " ", "=", " ", 
   RowBox[{"psdu", "/.", "%%%%%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549276482487`*^9}, {3.804854975285405*^9, 3.804855007481864*^9}, {
  3.805020287872097*^9, 3.805020287872097*^9}, {3.805021309212026*^9, 
  3.805021316136299*^9}, {3.8067902206374283`*^9, 3.806790221028118*^9}},
 CellLabel->
  "In[251]:=",ExpressionUUID->"ed362b77-6bc1-4448-880e-83a403e1ad8b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pstu1", " ", "=", " ", 
   RowBox[{"pstu", "/.", "%%%%%%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549332913156`*^9}, {3.804854976394951*^9, 3.8048549767231264`*^9}, {
  3.8048550098412547`*^9, 3.804855011638406*^9}, {3.80502029645166*^9, 
  3.80502029645166*^9}, {3.8050213184023037`*^9, 3.805021324747714*^9}, {
  3.806790221512575*^9, 3.806790221903265*^9}},
 CellLabel->
  "In[252]:=",ExpressionUUID->"2d3ae847-e6b2-47f7-9486-932bdc12b0a0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pstp1", " ", "=", " ", 
   RowBox[{"pstp", "/.", "%%%%%%%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.80485493651056*^9}, {3.804854977160694*^9, 3.804854978739061*^9}, {
  3.8048550132320137`*^9, 3.8048550149197726`*^9}, {3.8050206707402067`*^9, 
  3.8050206707402067`*^9}, {3.8050213273106437`*^9, 3.8050213333107805`*^9}, {
  3.8067902223564644`*^9, 3.8067902231378403`*^9}},
 CellLabel->
  "In[253]:=",ExpressionUUID->"693b0175-b716-4b97-b073-d664939f0ede"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcdp1", "=", 
   FractionBox[
    RowBox[{"pcdu1", " ", "pcdp0"}], "pcdu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8048581696293454`*^9, 3.8048581775525017`*^9}, 
   3.805017864249967*^9, 3.805018155002266*^9, {3.8050202419725313`*^9, 
   3.8050202695240245`*^9}, {3.805020609852163*^9, 3.8050206231222305`*^9}, {
   3.8067662959528484`*^9, 3.8067662959528484`*^9}, {3.8067900417302685`*^9, 
   3.8067900422303486`*^9}, {3.8067900929349785`*^9, 3.806790095726235*^9}},
 CellLabel->
  "In[254]:=",ExpressionUUID->"3336e42b-db78-4360-b345-f0ee822506bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"phdp1", "=", 
   FractionBox[
    RowBox[{"phdu1", " ", "phdp0"}], "phdu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8048581818031883`*^9, 3.804858187819789*^9}, {
  3.8067901021677036`*^9, 3.8067901037304554`*^9}},
 CellLabel->
  "In[255]:=",ExpressionUUID->"05ed3c06-fcef-484a-adbb-56a816fc8af8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"podp1", "=", 
   FractionBox[
    RowBox[{"podu1", " ", "podp0"}], "podu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.80485819258607*^9, 3.804858199587202*^9}, 
   3.805017872704455*^9, 3.805018163895453*^9, 3.805020287872097*^9, 
   3.805020631092285*^9, {3.806790140923479*^9, 3.806790142809039*^9}},
 CellLabel->
  "In[256]:=",ExpressionUUID->"9f6b8eb1-5805-4427-b26a-cef91f1526c5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ppdp1", "=", 
   FractionBox[
    RowBox[{"ppdu1", " ", "ppdp0"}], "ppdu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.80485819258607*^9, 3.804858199587202*^9}, 
   3.805017872704455*^9, 3.805018163895453*^9, 3.805020287872097*^9, 
   3.805020631092285*^9, {3.8050213519747286`*^9, 3.8050213570912433`*^9}, {
   3.8067901686558914`*^9, 3.8067901699373474`*^9}},
 CellLabel->
  "In[257]:=",ExpressionUUID->"83b67659-eb1d-4707-9fed-d5d961d8df8a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psdp1", "=", 
   FractionBox[
    RowBox[{"psdu1", " ", "psdp0"}], "psdu0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.80485819258607*^9, 3.804858199587202*^9}, 
   3.805017872704455*^9, 3.805018163895453*^9, 3.805020287872097*^9, 
   3.805020631092285*^9, {3.8050213591853447`*^9, 3.8050213667653294`*^9}, {
   3.8067902267790737`*^9, 3.806790228888795*^9}},
 CellLabel->
  "In[258]:=",ExpressionUUID->"907890ee-c08b-4b6d-bdc1-3bad1bd5ef46"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pau1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padu1", 
       RowBox[{"1", "-", "sigmaau"}]], "+", 
      RowBox[{"batu", " ", 
       SuperscriptBox["patu1", 
        RowBox[{"1", "-", "sigmaau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048537407717743`*^9, 3.804853751697942*^9}, {
   3.804858232034235*^9, 3.8048582371444397`*^9}, {3.8049544299701357`*^9, 
   3.8049544299701357`*^9}, {3.805019603210904*^9, 3.805019614650261*^9}, {
   3.8050202419725313`*^9, 3.8050202543339787`*^9}, {3.806764855829815*^9, 
   3.806764855829815*^9}, {3.8067662959684763`*^9, 3.8067662959684763`*^9}, {
   3.806790244674327*^9, 3.8067902607926645`*^9}},
 CellLabel->
  "In[259]:=",ExpressionUUID->"827b48b7-cd55-4505-a89a-8bea05d601f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pcdu1", 
       RowBox[{"1", "-", "sigmacu"}]], "+", 
      RowBox[{"bctu", " ", 
       SuperscriptBox["pctu1", 
        RowBox[{"1", "-", "sigmacu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmacu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.804853754104593*^9, 
   3.8048537632655916`*^9}, {3.8048582389728565`*^9, 
   3.8048582512496104`*^9}, {3.8049544890922947`*^9, 
   3.8049544890922947`*^9}, {3.805019635926775*^9, 3.8050196452420464`*^9}, {
   3.805020269539652*^9, 3.805020277744152*^9}, {3.806764913526594*^9, 
   3.806764913526594*^9}, {3.8067902660916615`*^9, 3.806790279547085*^9}},
 CellLabel->
  "In[260]:=",ExpressionUUID->"10e0a844-12f0-4717-ae97-7bb0e70d876c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Phu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["phdu1", 
       RowBox[{"1", "-", "sigmahu"}]], "+", 
      RowBox[{"bhtu", " ", 
       SuperscriptBox["phtu1", 
        RowBox[{"1", "-", "sigmahu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmahu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048537655159597`*^9, 
   3.8048537724008365`*^9}, {3.804858241066943*^9, 3.804858253249933*^9}, {
   3.8067902825788355`*^9, 3.8067903009746504`*^9}},
 CellLabel->
  "In[261]:=",ExpressionUUID->"88b75a07-2f21-4492-b2d3-ed45dee10998"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pou1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["podu1", 
       RowBox[{"1", "-", "sigmaou"}]], "+", 
      RowBox[{"botu", " ", 
       SuperscriptBox["potu1", 
        RowBox[{"1", "-", "sigmaou"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaou"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}, {
   3.804858242871995*^9, 3.8048582551252365`*^9}, {3.8049546267265406`*^9, 
   3.8049546267265406`*^9}, {3.805019670771908*^9, 3.805019684785465*^9}, {
   3.805020287872097*^9, 3.80502029645166*^9}, {3.8067649535185204`*^9, 
   3.8067649535185204`*^9}, {3.8067903038344975`*^9, 3.806790319633995*^9}},
 CellLabel->
  "In[262]:=",ExpressionUUID->"36baead3-72a4-46ae-9e7b-357bd3170f22"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ppu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["ppdu1", 
       RowBox[{"1", "-", "sigmapu"}]], "+", 
      RowBox[{"bptu", " ", 
       SuperscriptBox["pptu1", 
        RowBox[{"1", "-", "sigmapu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmapu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}, {
   3.804858242871995*^9, 3.8048582551252365`*^9}, {3.8049546267265406`*^9, 
   3.8049546267265406`*^9}, {3.805019670771908*^9, 3.805019684785465*^9}, {
   3.805020287872097*^9, 3.80502029645166*^9}, {3.8050213870187244`*^9, 
   3.8050214029147677`*^9}, {3.8067649723509226`*^9, 
   3.8067649723509226`*^9}, {3.806790322415704*^9, 3.806790339204256*^9}},
 CellLabel->
  "In[263]:=",ExpressionUUID->"0571bbc8-e10f-4994-b3a9-b9907a4032d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdu1", 
       RowBox[{"1", "-", "sigmasu"}]], "+", 
      RowBox[{"bstu", " ", 
       SuperscriptBox["pstu1", 
        RowBox[{"1", "-", "sigmasu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}, {
   3.804858242871995*^9, 3.8048582551252365`*^9}, {3.8049546267265406`*^9, 
   3.8049546267265406`*^9}, {3.805019670771908*^9, 3.805019684785465*^9}, {
   3.805020287872097*^9, 3.80502029645166*^9}, {3.8050214048541455`*^9, 
   3.8050214206570406`*^9}, {3.8067903417984333`*^9, 3.806790355629105*^9}},
 CellLabel->
  "In[264]:=",ExpressionUUID->"25c9e9ad-6c6b-4a6e-badf-d81bcb918d0d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pu1", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pau1", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bcu", " ", 
       SuperscriptBox["Pcu1", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bhu", " ", 
       SuperscriptBox["Phu1", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bou", " ", 
       SuperscriptBox["Pou1", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bpu", " ", 
       SuperscriptBox["Ppu1", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bsu", " ", 
       SuperscriptBox["Psu1", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048536729130955`*^9, 
   3.804853693916567*^9}, {3.804858258172606*^9, 3.804858267559837*^9}, 
   3.805019614650261*^9, 3.8050196452420464`*^9, 3.805019684785465*^9, {
   3.8050198025562887`*^9, 3.8050198126985607`*^9}, {3.8050214303144875`*^9, 
   3.8050214551064477`*^9}, {3.8056406364927936`*^9, 3.8056406441226745`*^9}, 
   3.8067662959684763`*^9, {3.8067903650835047`*^9, 3.8067903972633524`*^9}},
 CellLabel->
  "In[265]:=",ExpressionUUID->"2cf42da1-537d-47cf-a868-6ac8425005fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcp1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pcdp1", 
       RowBox[{"1", "-", "sigmacp"}]], "+", 
      RowBox[{"bctp", " ", 
       SuperscriptBox["pctp1", 
        RowBox[{"1", "-", "sigmacp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmacp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.8048533906588616`*^9, 
   3.804853392674816*^9}, {3.8048538223073983`*^9, 3.8048538261666756`*^9}, 
   3.8048540893066835`*^9, {3.8048582767495184`*^9, 3.8048582802344575`*^9}, {
   3.804954510247425*^9, 3.804954510247425*^9}, 3.805019944046558*^9, 
   3.8050199843542175`*^9, 3.8050206231222305`*^9, 3.8050206633639984`*^9, {
   3.8067904054051847`*^9, 3.8067904216277585`*^9}},
 CellLabel->
  "In[266]:=",ExpressionUUID->"50b2217b-a0f5-4ef2-a665-089b684d852b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Php1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["phdp1", 
       RowBox[{"1", "-", "sigmahp"}]], "+", 
      RowBox[{"bhtp", " ", 
       SuperscriptBox["phtp1", 
        RowBox[{"1", "-", "sigmahp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmahp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048533952064857`*^9, 
   3.8048533971443033`*^9}, {3.8048538294184713`*^9, 3.8048538335596733`*^9}, 
   3.8048540912601304`*^9, {3.804858282906767*^9, 3.8048582862510543`*^9}, {
   3.8067904241750593`*^9, 3.8067904406470127`*^9}},
 CellLabel->
  "In[267]:=",ExpressionUUID->"ca99b36d-0784-4f5c-abb4-899421699bbc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pop1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["podp1", 
       RowBox[{"1", "-", "sigmaop"}]], "+", 
      RowBox[{"botp", " ", 
       SuperscriptBox["potp1", 
        RowBox[{"1", "-", "sigmaop"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaop"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.8048538356537657`*^9, 3.804853840279529*^9}, 3.804854093104184*^9, {
   3.8048582887367105`*^9, 3.8048582922681465`*^9}, {3.804954640524764*^9, 
   3.804954640524764*^9}, 3.8050199537057533`*^9, 3.8050200081082225`*^9, 
   3.805020631092285*^9, 3.8050206707402067`*^9, {3.8067904427267113`*^9, 
   3.80679045960387*^9}},
 CellLabel->
  "In[268]:=",ExpressionUUID->"cd104c3f-d515-420d-85d0-6d5fe0acf9eb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ppp1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["ppdp1", 
       RowBox[{"1", "-", "sigmapp"}]], "+", 
      RowBox[{"bptp", " ", 
       SuperscriptBox["pptp1", 
        RowBox[{"1", "-", "sigmapp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmapp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.8048538356537657`*^9, 3.804853840279529*^9}, 3.804854093104184*^9, {
   3.8048582887367105`*^9, 3.8048582922681465`*^9}, {3.804954640524764*^9, 
   3.804954640524764*^9}, 3.8050199537057533`*^9, 3.8050200081082225`*^9, 
   3.805020631092285*^9, 3.8050206707402067`*^9, {3.805021467544857*^9, 
   3.805021480687713*^9}, {3.8067904619622555`*^9, 3.806790478532527*^9}},
 CellLabel->
  "In[269]:=",ExpressionUUID->"b91acc9e-d0f7-4343-901b-85eb5f9b4f67"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psp1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdp1", 
       RowBox[{"1", "-", "sigmasp"}]], "+", 
      RowBox[{"bstp", " ", 
       SuperscriptBox["pstp1", 
        RowBox[{"1", "-", "sigmasp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.8048538356537657`*^9, 3.804853840279529*^9}, 3.804854093104184*^9, {
   3.8048582887367105`*^9, 3.8048582922681465`*^9}, {3.804954640524764*^9, 
   3.804954640524764*^9}, 3.8050199537057533`*^9, 3.8050200081082225`*^9, 
   3.805020631092285*^9, 3.8050206707402067`*^9, {3.80502148262545*^9, 
   3.8050215032861767`*^9}, {3.8067904806578765`*^9, 3.8067904945524077`*^9}},
 CellLabel->
  "In[270]:=",ExpressionUUID->"f6513031-5cad-4928-be8c-84291667fb4f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pp1", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pcp1", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bhp", " ", 
       SuperscriptBox["Php1", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bop", " ", 
       SuperscriptBox["Pop1", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bpp", " ", 
       SuperscriptBox["Ppp1", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bsp", " ", 
       SuperscriptBox["Psp1", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bap", " ", 
       SuperscriptBox["patp1", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048534322140846`*^9, 
   3.8048534358553085`*^9}, {3.8048536992339973`*^9, 3.8048537091388454`*^9}, 
   3.8048540746935024`*^9, {3.8048582965623837`*^9, 3.8048583071734004`*^9}, {
   3.805019969881691*^9, 3.8050200081082225`*^9}, {3.8050201228437223`*^9, 
   3.805020131345148*^9}, {3.805021510756152*^9, 3.8050215301499543`*^9}, {
   3.805640668944806*^9, 3.805640674181842*^9}, 3.806766295984104*^9, {
   3.8067905030621395`*^9, 3.8067905560228386`*^9}},
 CellLabel->
  "In[271]:=",ExpressionUUID->"cf3a49b1-b3f6-48a3-98f1-2b28e692992d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qadu1", "=", 
   RowBox[{"qadcap", "-", 
    RowBox[{"aadu", " ", 
     SuperscriptBox["padu1", 
      RowBox[{"-", "eauu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
   3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
   3.804858318066416*^9}, 3.805017228776061*^9, 3.805018328178615*^9, 
   3.805018972205937*^9, 3.805020241988159*^9, {3.8050215414955635`*^9, 
   3.8050215416205845`*^9}, {3.806766295984104*^9, 3.806766295999731*^9}},
 CellLabel->
  "In[272]:=",ExpressionUUID->"da2c9595-e3fc-4efc-8340-7fcfa41ee32f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qatu1", " ", "=", " ", 
   RowBox[{"qalu0", "+", 
    RowBox[{"repla", " ", "qaiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, 3.8050175725759478`*^9, 3.8050176841894617`*^9, {
   3.8050215471852226`*^9, 3.8050215473414974`*^9}, {3.805638131820239*^9, 
   3.8056381321796722`*^9}, {3.806766295999731*^9, 3.806766295999731*^9}},
 CellLabel->
  "In[273]:=",ExpressionUUID->"968cd914-3f2c-4fc0-8be1-87db76fa5032"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qatp1", "=", 
   RowBox[{"qalp0", "+", 
    RowBox[{"repla", " ", "qaip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
   3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
   3.8048583295083256`*^9}, 3.805017636828994*^9, {3.805021561592044*^9, 
   3.805021564471135*^9}, {3.805638135757964*^9, 3.8056381359142394`*^9}, {
   3.806766295999731*^9, 3.806766296015359*^9}},
 CellLabel->
  "In[274]:=",ExpressionUUID->"5d201a59-15f3-4a9f-b1d9-6ab7b8e60249"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcdu1", "=", 
   RowBox[{"qcdcap", "-", 
    RowBox[{"acdu", " ", 
     SuperscriptBox["pcdu1", 
      RowBox[{"-", "ecdu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
   3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
   3.804858318066416*^9}, {3.8048583709925175`*^9, 3.8048583807603416`*^9}, 
   3.80501724212201*^9, 3.805018338258299*^9, 3.8050189849580746`*^9, 
   3.805020269539652*^9, {3.805021595591544*^9, 3.805021596091627*^9}, {
   3.8067906511053405`*^9, 3.806790661966323*^9}},
 CellLabel->
  "In[275]:=",ExpressionUUID->"3e642ed7-8a2a-4a7c-84b1-61256cf803c8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qctu1", " ", "=", " ", 
   RowBox[{"qclu0", "+", 
    RowBox[{"replc", " ", "qciu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, {3.804858383088846*^9, 3.804858391482087*^9}, 
   3.805017589247558*^9, 3.8050176939254065`*^9, {3.8050216031396575`*^9, 
   3.8050216036397414`*^9}, {3.8056381411939945`*^9, 3.80563814135027*^9}, {
   3.8067906645475845`*^9, 3.80679067256215*^9}},
 CellLabel->
  "In[276]:=",ExpressionUUID->"14ae33cb-8dc4-47b0-bd6d-02367efb45db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qctp1", "=", 
   RowBox[{"qclp0", "+", 
    RowBox[{"replc", " ", "qcip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
   3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
   3.8048583295083256`*^9}, {3.8048583919821677`*^9, 3.8048583929823275`*^9}, 
   3.805017646330557*^9, {3.80502160743724*^9, 3.80502161089093*^9}, {
   3.805638144147893*^9, 3.805638144288541*^9}, {3.8067906748437815`*^9, 
   3.806790682204375*^9}},
 CellLabel->
  "In[277]:=",ExpressionUUID->"9653b559-0a51-4e27-a205-737b01a7f79d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qcdp1", " ", "=", " ", 
   RowBox[{"qcdpe0", "+", 
    RowBox[{"kp", "  ", 
     SuperscriptBox["Pp1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pcp1", 
      RowBox[{"sigmacp", "-", "betap"}]], " ", 
     SuperscriptBox["pcdp1", 
      RowBox[{"-", "sigmacp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
   3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
   3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
   3.804858331686155*^9, 3.8048583574115205`*^9}, {3.8048583936074276`*^9, 
   3.804858404171567*^9}, {3.804860786055422*^9, 3.8048607864617367`*^9}, {
   3.804954510247425*^9, 3.804954510247425*^9}, 3.805018413272153*^9, 
   3.8050199843542175`*^9, 3.8050201228437223`*^9, 3.8050206231378593`*^9, {
   3.805021615341569*^9, 3.805021615904162*^9}, {3.806790686580677*^9, 
   3.8067907039102373`*^9}, 3.8067907891791697`*^9},
 CellLabel->
  "In[278]:=",ExpressionUUID->"c8f582d1-1442-4d78-8704-4de7307105c1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qhdu1", "=", 
   RowBox[{"qhdcap", "-", 
    RowBox[{"ahdu", " ", 
     SuperscriptBox["phdu1", 
      RowBox[{"-", "ehdu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
  3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
  3.804858318066416*^9}, {3.804858412220029*^9, 3.804858415017352*^9}, {
  3.8067907138132267`*^9, 3.806790721876897*^9}},
 CellLabel->
  "In[279]:=",ExpressionUUID->"f9613ae5-8b16-4e0c-b27c-4a183e59636d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qhtu1", " ", "=", " ", 
   RowBox[{"qhlu0", "+", 
    RowBox[{"replh", " ", "qhiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
  3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
  3.804858323051596*^9}, {3.8048584155486903`*^9, 3.8048584170020504`*^9}, {
  3.8056381467420683`*^9, 3.8056381472602715`*^9}, {3.8067907238147087`*^9, 
  3.8067907377240887`*^9}},
 CellLabel->
  "In[280]:=",ExpressionUUID->"11243cd2-b796-4e01-8542-850f98f840aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qhtp1", "=", 
   RowBox[{"qhlp0", "+", 
    RowBox[{"replh", " ", "qhip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
  3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
  3.8048583295083256`*^9}, {3.8048584174083652`*^9, 3.804858418330388*^9}, {
  3.8056381504455824`*^9, 3.8056381505549755`*^9}, {3.8067907262526007`*^9, 
  3.806790744990882*^9}},
 CellLabel->
  "In[281]:=",ExpressionUUID->"b63af19c-402b-4a43-8c33-41d4f5396395"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qhdp1", " ", "=", " ", 
   RowBox[{"qhdpe0", "+", 
    RowBox[{"kp", " ", "bhp", " ", 
     SuperscriptBox["Pp1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Php1", 
      RowBox[{"sigmahp", "-", "betap"}]], " ", 
     SuperscriptBox["phdp1", 
      RowBox[{"-", "sigmahp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
  3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
  3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
  3.804858331686155*^9, 3.8048583574115205`*^9}, {3.804858419221157*^9, 
  3.804858427725051*^9}, {3.8048607895672665`*^9, 3.8048607922437763`*^9}, {
  3.806790730018713*^9, 3.806790759028332*^9}},
 CellLabel->
  "In[282]:=",ExpressionUUID->"7ee696d2-f285-433f-80dc-784d4d3d5c14"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qodu1", "=", 
   RowBox[{"qodcap", "-", 
    RowBox[{"aodu", " ", 
     SuperscriptBox["podu1", 
      RowBox[{"-", "eodu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
   3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
   3.804858318066416*^9}, {3.8048584341925*^9, 3.804858435911532*^9}, 
   3.8050172582821474`*^9, 3.805018360214622*^9, 3.8050194297527933`*^9, 
   3.805020287872097*^9, {3.8050216372392516`*^9, 3.805021637583057*^9}, {
   3.806790762079934*^9, 3.80679077023733*^9}},
 CellLabel->
  "In[283]:=",ExpressionUUID->"888e3a2d-d307-4c7b-a13a-f42ecd52ab55"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qotu1", " ", "=", " ", 
   RowBox[{"qolu0", "+", 
    RowBox[{"replo", " ", "qoiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, {3.804858436286592*^9, 3.8048584368960643`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805021641771245*^9, 
   3.80502164192752*^9}, {3.8056381535739665`*^9, 3.805638153777124*^9}, {
   3.8067907728158693`*^9, 3.8067907780979123`*^9}},
 CellLabel->
  "In[284]:=",ExpressionUUID->"78166c8f-0a9e-4e78-90eb-12cf3e75d5d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qotp1", "=", 
   RowBox[{"qolp0", "+", 
    RowBox[{"replo", " ", "qoip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
   3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
   3.8048583295083256`*^9}, {3.804858437239869*^9, 3.804858437911852*^9}, 
   3.8050176541599693`*^9, {3.8050216449136066`*^9, 3.805021647273368*^9}, {
   3.8056381566994724`*^9, 3.8056381568244925`*^9}, {3.806790780004469*^9, 
   3.8067907996352224`*^9}},
 CellLabel->
  "In[285]:=",ExpressionUUID->"bff7468d-1892-44a1-ab13-c7d9e1e5d3b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qodp1", " ", "=", " ", 
   RowBox[{"qodpe0", "+", 
    RowBox[{"kp", " ", "bop", " ", 
     SuperscriptBox["Pp1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pop1", 
      RowBox[{"sigmaop", "-", "betap"}]], " ", 
     SuperscriptBox["podp1", 
      RowBox[{"-", "sigmaop"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
   3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
   3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
   3.804858331686155*^9, 3.8048583574115205`*^9}, {3.8048584383181667`*^9, 
   3.804858445621817*^9}, {3.804860795771513*^9, 3.8048607983031683`*^9}, {
   3.804954640524764*^9, 3.804954640524764*^9}, 3.805018457920755*^9, 
   3.8050200081082225`*^9, 3.805020131345148*^9, 3.805020631092285*^9, {
   3.805021650523903*^9, 3.805021650617668*^9}, {3.8067908025915117`*^9, 
   3.806790815191234*^9}},
 CellLabel->
  "In[286]:=",ExpressionUUID->"e5ee9f38-34c7-48ba-a642-b690f9fd2ef6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qpdu1", "=", 
   RowBox[{"qpdcap", "-", 
    RowBox[{"apdu", " ", 
     SuperscriptBox["ppdu1", 
      RowBox[{"-", "epdu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
   3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
   3.804858318066416*^9}, {3.8048584341925*^9, 3.804858435911532*^9}, 
   3.8050172582821474`*^9, 3.805018360214622*^9, 3.8050194297527933`*^9, 
   3.805020287872097*^9, {3.8050216372392516`*^9, 3.805021637583057*^9}, {
   3.805021668340543*^9, 3.8050216815614605`*^9}, {3.806790817660391*^9, 
   3.8067908528121214`*^9}},
 CellLabel->
  "In[287]:=",ExpressionUUID->"9ee139f8-dd61-49ba-9e44-ef070c835f9e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qptu1", " ", "=", " ", 
   RowBox[{"qplu0", "+", 
    RowBox[{"replp", " ", "qpiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, {3.804858436286592*^9, 3.8048584368960643`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805021641771245*^9, 
   3.80502164192752*^9}, {3.8050216824366035`*^9, 3.8050216835617847`*^9}, {
   3.8056381594655485`*^9, 3.8056381596843357`*^9}, {3.8067908322407236`*^9, 
   3.806790834241051*^9}},
 CellLabel->
  "In[288]:=",ExpressionUUID->"a3abd642-d5c4-4b76-b2bc-df6d735ad759"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qptp1", "=", 
   RowBox[{"qplp0", "+", 
    RowBox[{"replp", " ", "qpip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
   3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
   3.8048583295083256`*^9}, {3.804858437239869*^9, 3.804858437911852*^9}, 
   3.8050176541599693`*^9, {3.8050216449136066`*^9, 3.805021647273368*^9}, {
   3.8050216840306115`*^9, 3.805021684905758*^9}, {3.80563816318122*^9, 
   3.8056381632782955`*^9}, {3.8067908351318254`*^9, 3.806790837163415*^9}},
 CellLabel->
  "In[289]:=",ExpressionUUID->"2b79f586-f40a-4ad1-9e25-ed319fec9286"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qpdp1", " ", "=", " ", 
   RowBox[{"qpdpe0", "+", 
    RowBox[{"kp", " ", "bpp", " ", 
     SuperscriptBox["Pp1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Ppp1", 
      RowBox[{"sigmapp", "-", "betap"}]], " ", 
     SuperscriptBox["ppdp1", 
      RowBox[{"-", "sigmapp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
   3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
   3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
   3.804858331686155*^9, 3.8048583574115205`*^9}, {3.8048584383181667`*^9, 
   3.804858445621817*^9}, {3.804860795771513*^9, 3.8048607983031683`*^9}, {
   3.804954640524764*^9, 3.804954640524764*^9}, 3.805018457920755*^9, 
   3.8050200081082225`*^9, 3.805020131345148*^9, 3.805020631092285*^9, {
   3.805021650523903*^9, 3.805021650617668*^9}, {3.805021685860292*^9, 
   3.8050216989683647`*^9}, {3.8067908383210683`*^9, 3.806790843618828*^9}},
 CellLabel->
  "In[290]:=",ExpressionUUID->"d1c876fb-bac7-4a69-a62f-408a82bf20b3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qsdu1", "=", 
   RowBox[{"qsdcap", "-", 
    RowBox[{"asdu", " ", 
     SuperscriptBox["psdu1", 
      RowBox[{"-", "esdu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
   3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
   3.804858318066416*^9}, {3.8048584341925*^9, 3.804858435911532*^9}, 
   3.8050172582821474`*^9, 3.805018360214622*^9, 3.8050194297527933`*^9, 
   3.805020287872097*^9, {3.8050216372392516`*^9, 3.805021637583057*^9}, {
   3.8050216997966228`*^9, 3.805021715239889*^9}, {3.8067908640716743`*^9, 
   3.806790866333302*^9}},
 CellLabel->
  "In[291]:=",ExpressionUUID->"5663a682-3868-430c-b51e-543109457dcf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qstu1", " ", "=", " ", 
   RowBox[{"qslu0", "+", 
    RowBox[{"repls", " ", "qsiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, {3.804858436286592*^9, 3.8048584368960643`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805021641771245*^9, 
   3.80502164192752*^9}, {3.805021722397313*^9, 3.805021724006952*^9}, {
   3.8056381660156755`*^9, 3.805638166328226*^9}, {3.80679086705217*^9, 
   3.806790868833714*^9}},
 CellLabel->
  "In[292]:=",ExpressionUUID->"9e71b931-d617-428a-9a63-c9b1b171e286"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qstp1", "=", 
   RowBox[{"qslp0", "+", 
    RowBox[{"repls", " ", "qsip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
   3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
   3.8048583295083256`*^9}, {3.804858437239869*^9, 3.804858437911852*^9}, 
   3.8050176541599693`*^9, {3.8050216449136066`*^9, 3.805021647273368*^9}, {
   3.805021725788495*^9, 3.8050217265855026`*^9}, {3.805638169362621*^9, 
   3.8056381695657787`*^9}, {3.806790869912019*^9, 3.8067908713028765`*^9}},
 CellLabel->
  "In[293]:=",ExpressionUUID->"a86a308e-d31b-4462-92c0-2bbe06ed4ed8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qsdp1", " ", "=", " ", 
   RowBox[{"qsdpe0", "+", 
    RowBox[{"kp", " ", "bsp", " ", 
     SuperscriptBox["Pp1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Psp1", 
      RowBox[{"sigmasp", "-", "betap"}]], " ", 
     SuperscriptBox["psdp1", 
      RowBox[{"-", "sigmasp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
   3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
   3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
   3.804858331686155*^9, 3.8048583574115205`*^9}, {3.8048584383181667`*^9, 
   3.804858445621817*^9}, {3.804860795771513*^9, 3.8048607983031683`*^9}, {
   3.804954640524764*^9, 3.804954640524764*^9}, 3.805018457920755*^9, 
   3.8050200081082225`*^9, 3.805020131345148*^9, 3.805020631092285*^9, {
   3.805021650523903*^9, 3.805021650617668*^9}, {3.805021727273115*^9, 
   3.8050217388700185`*^9}, {3.8067908718185883`*^9, 3.8067908773058605`*^9}},
 CellLabel->
  "In[294]:=",ExpressionUUID->"b5432474-f281-45eb-9d5c-d18a453cd9e5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5. Results",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.7954529786642447`*^9}, {
  3.79545386036082*^9, 3.7954538618860044`*^9}, {3.795525436722562*^9, 
  3.795525448873003*^9}, {3.7998486591642857`*^9, 3.799848659976923*^9}, {
  3.8199004535482035`*^9, 
  3.8199004539735346`*^9}},ExpressionUUID->"473301bd-dba7-4078-9961-\
38ae68a23b97"],

Cell[TextData[StyleBox["Atlantic Salmon",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, {3.8050217474964285`*^9, 3.805021750496922*^9}, 
   3.805638178490944*^9, 3.8067662960309863`*^9, {3.8067664137719393`*^9, 
   3.806766414193885*^9}, {3.8067909737498302`*^9, 3.8067909803446736`*^9}, {
   3.8252834407952375`*^9, 
   3.825283445440849*^9}},ExpressionUUID->"fa466ce1-cea8-4a8d-9b00-\
4b42818ede2f"],

Cell["Percent change in price of unprocessed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}},ExpressionUUID->"37b6f62e-ab42-474a-883b-\
a789278bd2e7"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"padu1", "-", "padu0"}], ")"}], "100"}], "padu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
   3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
   3.8048585992018385`*^9}, {3.8050178536701374`*^9, 3.8050178536701374`*^9}, 
   3.805020241988159*^9, {3.8067662960466137`*^9, 3.8067662960466137`*^9}},
 CellLabel->
  "In[295]:=",ExpressionUUID->"7851d6b9-66dd-4b24-bb64-9b1361450660"],

Cell[BoxData["1.9322897054318982`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.804858843696556*^9, 3.8048588867233257`*^9, 
   3.804859663324854*^9, 3.804859749619121*^9, 3.804859963843249*^9, 
   3.804860110717795*^9, 3.804860380033531*^9, 3.8048605369574723`*^9, 
   3.8048606690003757`*^9, 3.8048614895786*^9, 3.8048659499980345`*^9, 
   3.8048662735904975`*^9, 3.8048664443215075`*^9, 3.804867250694828*^9, 
   3.8048811911602716`*^9, 3.8048952696276765`*^9, 3.804896148764747*^9, 
   3.8048969463462353`*^9, 3.8050220289442277`*^9, 3.8050234384041944`*^9, 
   3.8050236804166565`*^9, 3.8050238465394917`*^9, 3.805025220561788*^9, 
   3.805638098243934*^9, 3.8056381939463477`*^9, 3.805638615088058*^9, 
   3.8056408746683674`*^9, 3.8056410602569456`*^9, 3.8056658255455894`*^9, 
   3.806790909288615*^9, 3.8067913679743266`*^9, 3.8068326316818457`*^9, 
   3.8068333557363205`*^9, 3.806834056979002*^9, 3.8068343644586463`*^9, 
   3.8068345698014917`*^9, 3.806834757551732*^9, 3.80683513453703*^9, 
   3.8068354387174635`*^9, 3.8068355645046577`*^9, 3.8068364523193407`*^9, 
   3.806836501039502*^9, 3.8068368123342066`*^9, 3.806839111398734*^9, 
   3.8068396609788523`*^9, 3.8076504299656925`*^9, 3.807650959857643*^9, 
   3.8076513895495214`*^9, 3.8100376527762537`*^9, 3.812469638147905*^9, 
   3.8124699080988693`*^9, 3.812671233965144*^9, 3.812801918014621*^9, 
   3.812802321271514*^9, 3.812802372296193*^9, 3.812927724899379*^9, 
   3.8129281213935404`*^9, 3.812928502976537*^9, 3.81297569052057*^9, 
   3.812976091971426*^9, 3.815477033997893*^9, 3.8157750008503046`*^9, 
   3.816949328073516*^9, 3.8187759448860283`*^9, 3.8200583689805164`*^9, 
   3.820358854752417*^9, 3.8252832886272645`*^9, 3.825284018928771*^9, 
   3.8254135348759794`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[295]=",ExpressionUUID->"94fa41af-1cf4-4106-8430-65051638df47"]
}, Open  ]],

Cell["Percent change in quantity of landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.8067662960622416`*^9, {3.806766418665018*^9, 3.8067664189775686`*^9}, 
   3.8067665464737573`*^9},ExpressionUUID->"ff34ab77-1d9f-4ec0-ba1d-\
cae076d2ebb1"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qadu1", "-", "qadu0"}], ")"}], "100"}], "qadu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.805017322701576*^9, 3.805017322701576*^9}, {3.8050217635649242`*^9, 
  3.8050217672842827`*^9}, {3.8067662960622416`*^9, 3.8067662960622416`*^9}},
 CellLabel->
  "In[296]:=",ExpressionUUID->"12284875-4e6e-4aaf-8a4e-b74c3485c4eb"],

Cell[BoxData["9.547744467129927`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.804858843837203*^9, 3.8048588868952274`*^9, 
   3.8048596634655075`*^9, 3.804859749775401*^9, 3.804859963983899*^9, 
   3.804860110889693*^9, 3.804860380189807*^9, 3.8048605370981197`*^9, 
   3.804860669156651*^9, 3.804861489672364*^9, 3.8048659501230545`*^9, 
   3.804866273731145*^9, 3.8048664444309*^9, 3.804867250819849*^9, 
   3.8048811912696643`*^9, 3.804895269705816*^9, 3.80489614887414*^9, 
   3.8048969464556475`*^9, 3.80502202911613*^9, 3.8050234413118887`*^9, 
   3.8050236807292056`*^9, 3.805023846727021*^9, 3.805025220749321*^9, 
   3.8056380984098864`*^9, 3.805638194118269*^9, 3.80563861527559*^9, 
   3.8056408748705235`*^9, 3.8056410606995664`*^9, 3.8056658257487497`*^9, 
   3.806790909523029*^9, 3.806791368193113*^9, 3.8068326318224936`*^9, 
   3.8068333559235096`*^9, 3.806834057166534*^9, 3.8068343646305504`*^9, 
   3.8068345699902678`*^9, 3.806834757660817*^9, 3.806835134708934*^9, 
   3.8068354388581123`*^9, 3.806835564692189*^9, 3.806836452506871*^9, 
   3.806836501242617*^9, 3.8068368125217047`*^9, 3.806839111601902*^9, 
   3.80683966119302*^9, 3.8076504301063414`*^9, 3.8076509600451746`*^9, 
   3.807651389723981*^9, 3.8100376529203653`*^9, 3.812469638305028*^9, 
   3.812469908281012*^9, 3.812671234123268*^9, 3.812801918175745*^9, 
   3.812802321461629*^9, 3.812802372522369*^9, 3.812927725073514*^9, 
   3.812928121588726*^9, 3.8129285032057166`*^9, 3.812975690723727*^9, 
   3.812976092190202*^9, 3.815477034201052*^9, 3.815775001084462*^9, 
   3.8169493280885277`*^9, 3.81877594490104*^9, 3.8200583691516504`*^9, 
   3.8203588549205494`*^9, 3.8252832888184137`*^9, 3.825284019124946*^9, 
   3.8254135350230923`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[296]=",ExpressionUUID->"625a15df-e496-443e-934f-5fae1d3b452c"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.805638279440954*^9}, 3.8067664996269903`*^9, {3.8252834774196997`*^9, 
   3.825283481424814*^9}},ExpressionUUID->"66e3d8bf-0da9-4845-95b9-\
8b8bf770b527"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmaau"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"padu1", " ", 
     RowBox[{"(", 
      RowBox[{"qadu1", "-", "qadue0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"padu0", " ", 
     RowBox[{"(", 
      RowBox[{"qadu0", "-", "qadue0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
   3.805638515113145*^9, 3.8056385175665255`*^9}, {3.805641232235357*^9, 
   3.8056412347513914`*^9}, 3.806764855876698*^9, {3.806766296124751*^9, 
   3.806766296124751*^9}, {3.8067909260569143`*^9, 3.806790963434382*^9}, 
   3.8067913896045895`*^9, {3.825283489091776*^9, 3.8252834951184626`*^9}},
 CellLabel->
  "In[297]:=",ExpressionUUID->"f293df65-97a3-435d-a196-54d89d1d73ff"],

Cell[BoxData["1.6709998555699042`*^6"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQB2KJWxdvP4h54ygdLPH/C5A+0jc78iuQ7rnquBFEM3Ru
uA6iOw1jP4JoD53THN+A9IYNH81B9NVv32JB9J+Nm3JBdKHlmjtg+SOHH4Ho
03IrOL8D6R9OPzV+AOnA4DW5IDrs+XH/lrg3jn6f2CaBaJHVe46DaLf5Cz4J
Jr9xPJR/rmBr+hvHr5/6JoHo38s8HohnvHGsyD21PhxIV3WaPALRmyZOfwGi
N0xaLjsVSDsftvAH0VLhb+tA9CeN6M41QPqiWO9uEO2W7/O0MPeN4xwbzWTm
vDeOTj7MpxwK3jjWRchu3FP8xvHaPq0HemVvHCXmPppxEEgbmClIqzW8cWRd
mlMGolMWP92cCqQBf0erLw==
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[297]=",ExpressionUUID->"8e1ea147-f45c-4066-8a91-e0b26c9c62d7"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"5ed542e3-d498-4e4c-a4dd-\
1b360d55e7d3"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"patu1", "-", "patu0"}], ")"}], "100"}], "patu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
   3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
   3.8048586228946285`*^9}, {3.8050180911664543`*^9, 3.8050180911664543`*^9}, 
   3.8050202543496056`*^9, {3.8067662960778685`*^9, 3.8067662960934963`*^9}},
 CellLabel->
  "In[298]:=",ExpressionUUID->"a7a9764c-bf66-49ef-939e-40c84233ba43"],

Cell[BoxData["6.930977068983161`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.804858844259143*^9, 3.8048588873484216`*^9, 
   3.8048596638874693`*^9, 3.8048597502286253`*^9, 3.8048599644214773`*^9, 
   3.804860111339567*^9, 3.80486038062738*^9, 3.8048605375982*^9, 
   3.804860669609849*^9, 3.8048614900161695`*^9, 3.80486595046686*^9, 
   3.804866274106205*^9, 3.804866444774705*^9, 3.804867251163656*^9, 
   3.8048811915822144`*^9, 3.8048952699714885`*^9, 3.804896149217945*^9, 
   3.8048969467994328`*^9, 3.8050220296005793`*^9, 3.805023447562844*^9, 
   3.805023681463694*^9, 3.8050238471802163`*^9, 3.8050252212806635`*^9, 
   3.8056380988041887`*^9, 3.805638194618332*^9, 3.8056386158318243`*^9, 
   3.8056408755740657`*^9, 3.8056410615808296`*^9, 3.80566582629572*^9, 
   3.8067909096324224`*^9, 3.806791368333762*^9, 3.8068326319943967`*^9, 
   3.806833356095413*^9, 3.8068340573384376`*^9, 3.806834364802454*^9, 
   3.8068345701621714`*^9, 3.806834757758893*^9, 3.806835134880836*^9, 
   3.806835439030016*^9, 3.806835564864093*^9, 3.806836452678774*^9, 
   3.8068365014145207`*^9, 3.806836812631097*^9, 3.8068391119613285`*^9, 
   3.8068396615773277`*^9, 3.8076504304112425`*^9, 3.8076509604046097`*^9, 
   3.807651390067786*^9, 3.810037653181568*^9, 3.812469638597258*^9, 
   3.812469908646298*^9, 3.812671234416498*^9, 3.812801918471977*^9, 
   3.8128023218319197`*^9, 3.8128023729266834`*^9, 3.8129277253987675`*^9, 
   3.812928121967988*^9, 3.812928503659071*^9, 3.8129756910362787`*^9, 
   3.812976092617379*^9, 3.8154770345917425`*^9, 3.815775001725999*^9, 
   3.8169493281326466`*^9, 3.818775944948077*^9, 3.8200583696550455`*^9, 
   3.8203588554159384`*^9, 3.825283289389899*^9, 3.8252840196143255`*^9, 
   3.8254135354313927`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[298]=",ExpressionUUID->"071b3049-e647-4b07-840d-9e5a9db2ccde"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
   3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
   3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
   3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
   3.8048542553403563`*^9, 3.8048542677330275`*^9}, 3.8067662960934963`*^9, {
   3.8067664275570107`*^9, 
   3.8067664278851905`*^9}},ExpressionUUID->"82273b4d-e264-45a3-9a5a-\
0b30019357d7"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qatu1", "-", "qatu0"}], ")"}], "100"}], "qatu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.8050174498061085`*^9, 3.8050174498061085`*^9}, {3.805021785865451*^9, 
  3.805021786224886*^9}, {3.8067662960934963`*^9, 3.806766296109124*^9}},
 CellLabel->
  "In[299]:=",ExpressionUUID->"0d15ba49-a590-43d3-aca9-29acdb783728"],

Cell[BoxData[
 RowBox[{"-", "8.339954000004306`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588444154167`*^9, 3.804858887504696*^9, 
   3.804859664043751*^9, 3.804859750369265*^9, 3.804859964562127*^9, 
   3.8048601114958444`*^9, 3.8048603807992835`*^9, 3.8048605377544746`*^9, 
   3.804860669766124*^9, 3.8048614901255617`*^9, 3.804865950576252*^9, 
   3.8048662742155976`*^9, 3.804866444899753*^9, 3.8048672512730494`*^9, 
   3.804881191675979*^9, 3.8048952700652666`*^9, 3.804896149327338*^9, 
   3.804896946908837*^9, 3.8050220297724805`*^9, 3.8050234479568844`*^9, 
   3.805023681745041*^9, 3.805023847320863*^9, 3.8050252214682283`*^9, 
   3.8056380989604635`*^9, 3.805638194805862*^9, 3.8056386160037284`*^9, 
   3.805640875804243*^9, 3.8056410618768563`*^9, 3.8056658264519978`*^9, 
   3.8067909097418156`*^9, 3.806791368490037*^9, 3.806832632166299*^9, 
   3.806833356267355*^9, 3.806834057510341*^9, 3.806834364943142*^9, 
   3.8068345703184476`*^9, 3.80683475792202*^9, 3.8068351350527387`*^9, 
   3.8068354392019196`*^9, 3.806835565051625*^9, 3.8068364528506765`*^9, 
   3.8068365016020517`*^9, 3.806836812787372*^9, 3.80683911214886*^9, 
   3.8068396617694707`*^9, 3.807650430570366*^9, 3.8076509605777473`*^9, 
   3.8076513902553167`*^9, 3.8100376533236785`*^9, 3.8124696387473745`*^9, 
   3.8124699088234367`*^9, 3.812671234574622*^9, 3.8128019186200933`*^9, 
   3.8128023220180674`*^9, 3.81280237311483*^9, 3.8129277255779057`*^9, 
   3.8129281221611395`*^9, 3.812928504518739*^9, 3.812975691239437*^9, 
   3.8129760928361654`*^9, 3.815477034794901*^9, 3.815775001931121*^9, 
   3.816949328148659*^9, 3.81877594496209*^9, 3.8200583698151712`*^9, 
   3.8203588555790668`*^9, 3.8252832896200423`*^9, 3.8252840198034706`*^9, 
   3.825413535634576*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[299]=",ExpressionUUID->"a58f418b-ec05-4a93-992c-10894b1d641c"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"e23a3c21-0a78-47af-802c-\
c364f4f91f5f"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"patp1", "-", "patp0"}], ")"}], "100"}], "patp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
   3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
   3.804858633427496*^9}, {3.8050182696893077`*^9, 3.8050182696893077`*^9}, 
   3.805020655565849*^9, {3.806766296109124*^9, 3.806766296109124*^9}},
 CellLabel->
  "In[300]:=",ExpressionUUID->"ec6af1d0-396f-4dba-8cea-a3941b570226"],

Cell[BoxData["7.984478880146216`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.8048588445560637`*^9, 3.8048588876453424`*^9, 3.8048596642000327`*^9, 
   3.8048597505412283`*^9, 3.8048599647027774`*^9, 3.8048601116364937`*^9, 
   3.8048603809555593`*^9, 3.804860537895122*^9, 3.8048606699223995`*^9, 
   3.804861490219328*^9, 3.804865950685644*^9, 3.8048662743249903`*^9, 
   3.8048664449934893`*^9, 3.8048672513824425`*^9, 3.804881191769744*^9, 
   3.8048952701590223`*^9, 3.804896149436783*^9, 3.804896947018218*^9, 
   3.8050220299443827`*^9, 3.805023450896061*^9, 3.8050236819950266`*^9, 
   3.8050238474927645`*^9, 3.805025221655735*^9, 3.8056380991011114`*^9, 
   3.805638194977765*^9, 3.8056386161756325`*^9, 3.805640876001395*^9, 
   3.80564106217365*^9, 3.8056658266239023`*^9, 3.8067909098512087`*^9, 
   3.806791368677569*^9, 3.8068326323382015`*^9, 3.806833356439221*^9, 
   3.806834057697872*^9, 3.8068343651150064`*^9, 3.806834570506044*^9, 
   3.8068347580691338`*^9, 3.806835135193386*^9, 3.806835439389451*^9, 
   3.8068355652235284`*^9, 3.806836453022579*^9, 3.8068365017583265`*^9, 
   3.8068368129568367`*^9, 3.8068391123207645`*^9, 3.806839661963623*^9, 
   3.8076504307104745`*^9, 3.807650960749651*^9, 3.8076513904272203`*^9, 
   3.810037653463787*^9, 3.8124696389085007`*^9, 3.812469909000575*^9, 
   3.812671234734747*^9, 3.8128019187762136`*^9, 3.812802322221223*^9, 
   3.812802373296973*^9, 3.81292772575004*^9, 3.812928122345312*^9, 
   3.812928504716893*^9, 3.8129756914269667`*^9, 3.812976093070578*^9, 
   3.815477034982432*^9, 3.81577500213428*^9, 3.81694932816267*^9, 
   3.8187759449771*^9, 3.8200583699823046`*^9, 3.8203588557431974`*^9, 
   3.825283289817213*^9, 3.825284020032629*^9, 3.825413535846717*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[300]=",ExpressionUUID->"e4246bbc-8a24-4d85-b0cc-0113e05bd70b"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, 
   3.806766296109124*^9, {3.806766431357971*^9, 
   3.8067664316705236`*^9}},ExpressionUUID->"f799dbdf-4080-49d8-a20e-\
90387fa96e77"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qatp1", "-", "qatp0"}], ")"}], "100"}], "qatp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.8050175026566935`*^9, 3.8050175026566935`*^9}, {3.8050217915695124`*^9, 
  3.8050217919602027`*^9}, {3.806766296124751*^9, 3.806766296124751*^9}},
 CellLabel->
  "In[301]:=",ExpressionUUID->"efe2e1f7-5f4b-4f80-a068-3179b4d26ead"],

Cell[BoxData[
 RowBox[{"-", "8.334629611059654`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.80485884469671*^9, 3.804858887785989*^9, 3.8048596643406863`*^9, 
   3.8048597506974525`*^9, 3.804859964859055*^9, 3.8048601117927704`*^9, 
   3.8048603810962067`*^9, 3.8048605380513973`*^9, 3.804860670063046*^9, 
   3.804861490328724*^9, 3.804865950795037*^9, 3.8048662744343824`*^9, 
   3.8048664451185102`*^9, 3.8048672515074635`*^9, 3.804881191863509*^9, 
   3.8048952702527895`*^9, 3.8048961495461226`*^9, 3.804896947143239*^9, 
   3.8050220301006565`*^9, 3.8050234512856274`*^9, 3.8050236822763195`*^9, 
   3.8050238476646657`*^9, 3.805025221843261*^9, 3.8056380992417593`*^9, 
   3.805638195102785*^9, 3.805638616347536*^9, 3.8056408761955442`*^9, 
   3.805641062513013*^9, 3.805665826811435*^9, 3.8067909099918575`*^9, 
   3.8067913688494725`*^9, 3.806832632510104*^9, 3.806833356658007*^9, 
   3.8068340578698072`*^9, 3.8068343653337927`*^9, 3.8068345706622553`*^9, 
   3.806834758212245*^9, 3.806835135380916*^9, 3.8068354395457273`*^9, 
   3.806835565396695*^9, 3.8068364532101097`*^9, 3.806836501945856*^9, 
   3.8068368130974836`*^9, 3.806839112508295*^9, 3.806839662155772*^9, 
   3.8076504308485975`*^9, 3.8076509609215546`*^9, 3.807651390599124*^9, 
   3.8100376536068983`*^9, 3.812469639056617*^9, 3.8124699091777143`*^9, 
   3.812671234879861*^9, 3.812801918924329*^9, 3.8128023224243975`*^9, 
   3.8128023734791155`*^9, 3.8129277259481955`*^9, 3.81292812253443*^9, 
   3.81292850490604*^9, 3.812975691614498*^9, 3.812976093289363*^9, 
   3.815477035185593*^9, 3.815775002355486*^9, 3.816949328177682*^9, 
   3.8187759449921117`*^9, 3.820058370151435*^9, 3.8203588559163313`*^9, 
   3.8252832900134134`*^9, 3.8252840202618074`*^9, 3.8254135361129227`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[301]=",ExpressionUUID->"8b684715-bae0-4bf6-afff-e6ffaa6e759e"]
}, Open  ]],

Cell[TextData[StyleBox["Chinook Salmon",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQfeDUR41u/zeOh9LEDEG0y38FbxB9ou2RL4jOviqR
AaLFtk8B03Imt5pBdAfL+RYQrVSSsw5EJ3x5vhlEP9459TuI/sbD9wtE65vJ
HFsEpHcmh58E0Zsi590G0ZL6s+6D6AkzMj6D6Ern019B9LMY2T8gmuu1+1+w
/Hth9sVAWq/5NJjedv2NkUXEG0cpW1cTEJ025ctPvcg3jjkiX8E055Nnf0E0
f8pzML0qYTm/IZCWfXQSTE99paACordk24LpIwd3nGkA0kLn/4BpFz6NlQ9i
3jh2T4gD09Fq7aZqDW8cQ95tA9MA1TSbug==
  "],ExpressionUUID->"3c230a6e-b45f-406a-b862-d16c7d588e39"],

Cell["Percent change in price of unprocessed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}},ExpressionUUID->"d31b970b-01b3-4a91-a1a6-\
1f6a8fc987d5"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pcdu1", "-", "pcdu0"}], ")"}], "100"}], "pcdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
  3.8048585992018385`*^9}, {3.804858707793745*^9, 3.804858709669033*^9}, {
  3.8050178642655945`*^9, 3.8050178642655945`*^9}, {3.805020241988159*^9, 
  3.805020269539652*^9}, {3.805021810715742*^9, 3.805021814481985*^9}, {
  3.806790994472859*^9, 3.8067909951917286`*^9}},
 CellLabel->
  "In[302]:=",ExpressionUUID->"00ca3398-e60a-4f27-9f2f-ebb60f90afab"],

Cell[BoxData["0.9011563479328178`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.8048588448373566`*^9, 3.8048588879266357`*^9, 
   3.8048596644969683`*^9, 3.804859750838105*^9, 3.804859965019943*^9, 
   3.804860111964675*^9, 3.8048603812524815`*^9, 3.8048605381920447`*^9, 
   3.804860670219321*^9, 3.804861490422487*^9, 3.8048659509044294`*^9, 
   3.8048662745594025`*^9, 3.8048664452122755`*^9, 3.8048672516168933`*^9, 
   3.8048811919729013`*^9, 3.8048952703465557`*^9, 3.804896149655515*^9, 
   3.804896947252631*^9, 3.805022030272558*^9, 3.80502345424335*^9, 
   3.8050236825107317`*^9, 3.80502384782094*^9, 3.8050252220151663`*^9, 
   3.8056380993724422`*^9, 3.805638195274688*^9, 3.8056386168788757`*^9, 
   3.8056408769231057`*^9, 3.8056410634725213`*^9, 3.8056658273584056`*^9, 
   3.8067910604357824`*^9, 3.8067913690370045`*^9, 3.8068326329320483`*^9, 
   3.80683335703307*^9, 3.806834058229212*^9, 3.806834365690423*^9, 
   3.806834571084216*^9, 3.806834758503549*^9, 3.8068351357247214`*^9, 
   3.806835439858279*^9, 3.8068355657561517`*^9, 3.806836453553916*^9, 
   3.806836502352172*^9, 3.8068368133944087`*^9, 3.806839112680199*^9, 
   3.8068396623609314`*^9, 3.8076504309892454`*^9, 3.807650961077831*^9, 
   3.8076513907553997`*^9, 3.81003765375101*^9, 3.812469639204733*^9, 
   3.8124699093518505`*^9, 3.812671235030979*^9, 3.8128019190714436`*^9, 
   3.8128023226215334`*^9, 3.8128023736602573`*^9, 3.8129277261453495`*^9, 
   3.8129281227215843`*^9, 3.8129285051041946`*^9, 3.8129756918020277`*^9, 
   3.812976093523776*^9, 3.8154770353887496`*^9, 3.815775002589637*^9, 
   3.8169493281926928`*^9, 3.8187759450061226`*^9, 3.820058370337581*^9, 
   3.820358856081461*^9, 3.8252832902135515`*^9, 3.8252840205260167`*^9, 
   3.82541353631508*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[302]=",ExpressionUUID->"1c11497d-1c98-4165-9e59-c4eb6f450927"]
}, Open  ]],

Cell["Percent change in quantity of landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.806766296140379*^9, 3.8067664457995396`*^9, 
   3.8067665464893847`*^9},ExpressionUUID->"e62e74d7-9a4e-444a-8002-\
5e78b3fe9904"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qcdu1", "-", "qcdu0"}], ")"}], "100"}], "qcdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.8048587148420916`*^9, 3.8048587164829683`*^9}, {3.805017337173911*^9, 
  3.805017337173911*^9}, {3.8050218183576193`*^9, 3.805021818437133*^9}, {
  3.8067909985203004`*^9, 3.8067909991766605`*^9}},
 CellLabel->
  "In[303]:=",ExpressionUUID->"ea07afa0-19bc-4d7b-a798-fbd50f5b1b9b"],

Cell[BoxData["1.7941072115880692`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.80485884497801*^9, 3.804858888051656*^9, 
   3.804859664637623*^9, 3.804859750994385*^9, 3.8048599651660595`*^9, 
   3.8048601121053247`*^9, 3.8048603814087563`*^9, 3.804860538363948*^9, 
   3.804860670359969*^9, 3.804861490563135*^9, 3.8048659510138216`*^9, 
   3.804866274668795*^9, 3.8048664453372965`*^9, 3.8048672517262497`*^9, 
   3.8048811920666666`*^9, 3.8048952704403224`*^9, 3.8048961497805357`*^9, 
   3.8048969473620243`*^9, 3.805022030428833*^9, 3.805023457356555*^9, 
   3.8050236827920246`*^9, 3.8050238480084696`*^9, 3.8050252222026987`*^9, 
   3.80563809951309*^9, 3.805638195399708*^9, 3.8056386170507793`*^9, 
   3.8056408771722975`*^9, 3.805641063753812*^9, 3.8056658275459385`*^9, 
   3.806791060654569*^9, 3.806791369240164*^9, 3.8068326331039524`*^9, 
   3.806833357220601*^9, 3.8068340584011154`*^9, 3.806834365863776*^9, 
   3.806834571302987*^9, 3.8068347586448374`*^9, 3.8068351358966246`*^9, 
   3.806835440030183*^9, 3.8068355659280353`*^9, 3.8068364537400436`*^9, 
   3.8068365025240755`*^9, 3.8068368135506816`*^9, 3.8068391128521023`*^9, 
   3.8068396625561037`*^9, 3.8076504311298933`*^9, 3.8076509612497435`*^9, 
   3.8076513909273133`*^9, 3.8100376538931203`*^9, 3.8124696393558507`*^9, 
   3.812469909539998*^9, 3.8126712351821237`*^9, 3.8128019192185574`*^9, 
   3.8128023228136826`*^9, 3.8128023738464036`*^9, 3.8129277263505106`*^9, 
   3.8129281229177275`*^9, 3.812928505302348*^9, 3.812975692005187*^9, 
   3.8129760937425613`*^9, 3.8154770355919085`*^9, 3.8157750028038487`*^9, 
   3.8169493282102623`*^9, 3.8187759450211344`*^9, 3.82005837050171*^9, 
   3.820358856265607*^9, 3.825283290418684*^9, 3.8252840207461853`*^9, 
   3.8254135365642757`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[303]=",ExpressionUUID->"b07f5fee-3a05-47ae-a622-c5ccfa8859c4"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 
  3.80485427153401*^9}},ExpressionUUID->"74709d3e-c995-4aa7-a7fe-\
8d66933766b1"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pcdp1", "-", "pcdp0"}], ")"}], "100"}], "pcdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
  3.8048586124851284`*^9}, {3.8048587237965918`*^9, 3.804858725653945*^9}, {
  3.805018155002266*^9, 3.805018155002266*^9}, {3.80502060986779*^9, 
  3.8050206231378593`*^9}, {3.80502182287536*^9, 3.805021825703562*^9}, {
  3.8067910027130775`*^9, 3.8067910034788265`*^9}},
 CellLabel->
  "In[304]:=",ExpressionUUID->"a7b058b0-b67f-46ad-9eac-b1634f448551"],

Cell[BoxData["0.9011563479328168`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.8048588451232333`*^9, 3.804858888207929*^9, 
   3.804859664778276*^9, 3.8048597511350365`*^9, 3.8048599653141775`*^9, 
   3.8048601122616014`*^9, 3.804860381565032*^9, 3.8048605385514774`*^9, 
   3.804860670516244*^9, 3.804861490656901*^9, 3.80486595112325*^9, 
   3.8048662747938147`*^9, 3.8048664454310617`*^9, 3.8048672518512707`*^9, 
   3.8048811921604753`*^9, 3.804895270549718*^9, 3.804896149889929*^9, 
   3.8048969474714165`*^9, 3.8050220306007347`*^9, 3.805023460435156*^9, 
   3.8050236830576897`*^9, 3.8050238481491156`*^9, 3.8050252224058585`*^9, 
   3.8056380996537375`*^9, 3.8056381955716143`*^9, 3.805638617222684*^9, 
   3.8056408773874636`*^9, 3.8056410640194798`*^9, 3.805665827733471*^9, 
   3.8067910607795925`*^9, 3.806791369365184*^9, 3.8068326332759075`*^9, 
   3.806833357376878*^9, 3.806834058573019*^9, 3.8068343660346127`*^9, 
   3.8068345714748907`*^9, 3.8068347587854853`*^9, 3.8068351360685267`*^9, 
   3.806835440217715*^9, 3.8068355661155653`*^9, 3.806836453911968*^9, 
   3.806836502727234*^9, 3.8068368137069564`*^9, 3.806839113024007*^9, 
   3.8068396627392254`*^9, 3.807650431286168*^9, 3.807650961437266*^9, 
   3.80765139109923*^9, 3.8100376540822954`*^9, 3.8124696395049677`*^9, 
   3.812469909715135*^9, 3.812671235334217*^9, 3.8128019193686743`*^9, 
   3.8128023230098352`*^9, 3.8128023740425563`*^9, 3.812927726543662*^9, 
   3.812928123117883*^9, 3.8129285054944973`*^9, 3.8129756922239733`*^9, 
   3.8129760939926033`*^9, 3.815477035795067*^9, 3.815775003033983*^9, 
   3.816949328225691*^9, 3.818775945036146*^9, 3.8200583706658387`*^9, 
   3.8203588564337378`*^9, 3.825283290665877*^9, 3.8252840209684057`*^9, 
   3.825413536767472*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[304]=",ExpressionUUID->"7a526ed3-93cf-4c43-b0e2-3061f73333fe"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
   3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
   3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
   3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
   3.804854255481004*^9, 3.8048542778511686`*^9}, 3.806766296140379*^9, 
   3.8067664458151674`*^9},ExpressionUUID->"4eddad94-7d11-490a-a946-\
fa0004029ced"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qcdp1", "-", "qcdp0"}], ")"}], "100"}], "qcdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}, {
  3.804858773231639*^9, 3.804858774231792*^9}, {3.8050173975775113`*^9, 
  3.8050173975775113`*^9}, {3.805021830157384*^9, 3.8050218302824044`*^9}, {
  3.8067910070575476`*^9, 3.8067910078546224`*^9}},
 CellLabel->
  "In[305]:=",ExpressionUUID->"3fb76938-949c-45e7-b678-fb85bf19b336"],

Cell[BoxData["9.84545174401278`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.80485884526388*^9, 3.804858888348575*^9, 
   3.804859664934558*^9, 3.804859751291317*^9, 3.8048599654602933`*^9, 
   3.804860112417878*^9, 3.8048603817056828`*^9, 3.8048605386921253`*^9, 
   3.8048606706725187`*^9, 3.804861490766294*^9, 3.804865951232607*^9, 
   3.8048662749344625`*^9, 3.8048664455404553`*^9, 3.804867251960664*^9, 
   3.804881192269824*^9, 3.804895270643484*^9, 3.804896149999321*^9, 
   3.804896947580855*^9, 3.80502203080389*^9, 3.8050234611852717`*^9, 
   3.8050236832921095`*^9, 3.80502384830544*^9, 3.805025222640274*^9, 
   3.805638099794386*^9, 3.805638195727886*^9, 3.805638617394588*^9, 
   3.8056408776586723`*^9, 3.805641064366538*^9, 3.8056658279366317`*^9, 
   3.8067910608889832`*^9, 3.8067913695370874`*^9, 3.8068326334477596`*^9, 
   3.8068333575644093`*^9, 3.8068340587449226`*^9, 3.8068343662047453`*^9, 
   3.806834571646795*^9, 3.8068347589588056`*^9, 3.80683513624043*^9, 
   3.806835440405246*^9, 3.806835566287469*^9, 3.806836454083851*^9, 
   3.8068365028991375`*^9, 3.8068368138632317`*^9, 3.8068391132115383`*^9, 
   3.806839662919364*^9, 3.807650431426817*^9, 3.80765096160917*^9, 
   3.8076513912867393`*^9, 3.8100376542393894`*^9, 3.8124696396530843`*^9, 
   3.812469909890272*^9, 3.8126712354863358`*^9, 3.8128019195187907`*^9, 
   3.8128023231979814`*^9, 3.8128023742277393`*^9, 3.8129277267608314`*^9, 
   3.8129281233110332`*^9, 3.8129285056986556`*^9, 3.8129756924427605`*^9, 
   3.812976094227058*^9, 3.815477036013853*^9, 3.8157750032661643`*^9, 
   3.8169493282427044`*^9, 3.8187759450511684`*^9, 3.8200583708299913`*^9, 
   3.820358856600869*^9, 3.8252832908670187`*^9, 3.825284021192564*^9, 
   3.8254135369886093`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[305]=",ExpressionUUID->"d77362d4-27f3-4665-ad06-dd1683e20c02"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.805638279440954*^9}, 3.8067664996269903`*^9, {3.8252835486361027`*^9, 
   3.8252835526071653`*^9}},ExpressionUUID->"21f30dff-389c-44ba-9ac3-\
942bc15fb559"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmacu"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"pcdu1", " ", 
     RowBox[{"(", 
      RowBox[{"qcdu1", "-", "qcdue0", "-", 
       RowBox[{"cr", " ", "qcdp1"}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"pcdu0", " ", 
     RowBox[{"(", 
      RowBox[{"qcdu0", "-", "qcdue0", "-", 
       RowBox[{"cr", " ", "qcdp0"}]}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
   3.8056383460882015`*^9, 3.8056383532743115`*^9}, {3.8056385033293953`*^9, 
   3.805638505829816*^9}, {3.8056412172638407`*^9, 3.8056412203593426`*^9}, 
   3.806764913526594*^9, {3.806791034593245*^9, 3.806791101122366*^9}, {
   3.806834842040166*^9, 3.806834846165829*^9}, {3.8252839112991467`*^9, 
   3.8252839130284605`*^9}},
 CellLabel->
  "In[306]:=",ExpressionUUID->"0f1339f8-ac6f-44a9-b767-3bba2bc1a9be"],

Cell[BoxData["21248.94855885364`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAOIzr05fXBv1xvFBUfwdEH3DxOs3iN4QdUt0PZA+8d5S
F0SHM8xyANG+LbNddgPppM/rNz2IeePIvdHvJogODfX5/wVI35lwLvIrkJ5w
vWgjiLb4++g6iL6yedJHEP3t0jeOb0B6+no7ERC9bZOSBYiuqtSMA9EyW57k
gukN9+6AaLbjvx6B6Dz9q5zfgbSaq47mDxCt/zgXRD9e8cm/Je6NY98/i0kg
2njtu+Mg+mrZmU+CyW8cn23+WbA1/Y3jNfFDk0D0pbaSB+IZbxyb4r+uDwfS
bfy5j0A0c/zZFyA6jOu+7FQg7apU4A+iOdJt60F0mvbUzjUgvsu53SD6yMe2
p4W5bxyrF+QnM+e9cTSz5zjlUPDG8Z6o0sY9xW8cT52Pf6BX9sZRuFli5kEg
vcEsSVqt4Y2joOnaMhCdUqu2JRVIAwBO4dDw
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[306]=",ExpressionUUID->"a90622e4-a759-41f2-bc82-6185f03c3723"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.8056382995792217`*^9}, 3.8067665212567716`*^9, {3.825283556672326*^9, 
   3.825283559653644*^9}},ExpressionUUID->"5a3a5221-9287-4570-9eb8-\
c2c85a6bdac6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmacp"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"pcdp1", " ", 
     RowBox[{"(", 
      RowBox[{"qcdp1", "-", "qcdpe0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"pcdp0", " ", 
     RowBox[{"(", 
      RowBox[{"qcdp0", "-", "qcdpe0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.805638311659393*^9, 3.805638322630473*^9}, {3.805638356669798*^9, 
  3.805638367128154*^9}, {3.8056385080645676`*^9, 3.805638510488124*^9}, {
  3.805641223483641*^9, 3.8056412269529533`*^9}, {3.806791047112771*^9, 
  3.8067910547617445`*^9}, {3.812803799740489*^9, 3.812803813203967*^9}, {
  3.8252839087031155`*^9, 3.825283914865853*^9}},
 CellLabel->
  "In[307]:=",ExpressionUUID->"07a48ead-29e0-4de5-88d7-a45a5169bb31"],

Cell[BoxData["290409.77308989246`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBOIzr05fXBv1xvHUttJrIPpIvsgdEC201f83iDYpfCK6
HkhbFLjogmi3/3mOIHoZy0KX3UB6w+dtmx7EvHEMMAy9CaInXQ38/wVISwhe
ifwKpG+EV24E0SW1L66DaAGTGR9BdNCE3xzfgPTXTRoWINrgp24ciA4xeZUL
oiM3PL4Doj2OMzwG0Yv0b3F+B9IZkkaaP0Dm/H6RC6KfaHz3b4kDuvuf7SQQ
PUf3y3EQnWRz8ZNgMlCc5X/B1vQ3jjGrjk8C08crH4hnvHHMa/+1PhxIa0mX
PALRTc6XX4DoM1NOz4kA0vPjn8lOBdIT1cv8QfQGBZd6EL1Ze07nGiAddeTq
bhDNVdT7tDD3jeP+ttpk5rw3jpqmnKccCt445vxW2rinGOjOldkP9MqA7nBV
nnkQSC/IyJdWa3jjeCh+axmITpHT3ZIKpAGYndPU
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[307]=",ExpressionUUID->"83c8158c-6e77-4424-aded-73019ed97ee7"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"dea2e921-ee46-4743-ab05-\
a7e3945b6a26"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pctu1", "-", "pctu0"}], ")"}], "100"}], "pctu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
  3.8048586228946285`*^9}, {3.8048587279378014`*^9, 3.804858729797462*^9}, {
  3.8050181010897365`*^9, 3.8050181010897365`*^9}, {3.8050202543496056`*^9, 
  3.805020277744152*^9}, {3.8050218338142357`*^9, 3.8050218364865456`*^9}, {
  3.806791012324047*^9, 3.8067910132773314`*^9}},
 CellLabel->
  "In[308]:=",ExpressionUUID->"f484b1cf-f337-48dc-b352-e79d65e44fd2"],

Cell[BoxData["6.075036524382225`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.804858845404583*^9, 3.8048588885048494`*^9, 
   3.804859665075212*^9, 3.8048597514319687`*^9, 3.804859965603407*^9, 
   3.804860112558527*^9, 3.804860381877582*^9, 3.8048605388484*^9, 
   3.8048606708287935`*^9, 3.8048614909069424`*^9, 3.804865951357627*^9, 
   3.8048662750438547`*^9, 3.804866445649886*^9, 3.804867252070057*^9, 
   3.8048811923635893`*^9, 3.804895270768507*^9, 3.8048961501087136`*^9, 
   3.8048969476902018`*^9, 3.8050220309757924`*^9, 3.8050234641701083`*^9, 
   3.8050236835108857`*^9, 3.805023848467813*^9, 3.8050252228278065`*^9, 
   3.8056380999506607`*^9, 3.8056381959154167`*^9, 3.80563861758212*^9, 
   3.8056408779298816`*^9, 3.805641064622828*^9, 3.8056658281085367`*^9, 
   3.806791060998377*^9, 3.806791369724617*^9, 3.8068326336196632`*^9, 
   3.806833357767568*^9, 3.8068340589168267`*^9, 3.8068343664219155`*^9, 
   3.806834571818699*^9, 3.8068347591069207`*^9, 3.8068351364279594`*^9, 
   3.806835440624033*^9, 3.8068355664750013`*^9, 3.806836454255765*^9, 
   3.806836503071041*^9, 3.8068368140195074`*^9, 3.806839113737505*^9, 
   3.8068396634737988`*^9, 3.8076504318643975`*^9, 3.8076509621092534`*^9, 
   3.80765139180245*^9, 3.8100376546877365`*^9, 3.812469640125454*^9, 
   3.8124699104136815`*^9, 3.8126712359657116`*^9, 3.8128019199961615`*^9, 
   3.8128023238244677`*^9, 3.812802374789136*^9, 3.8129277274103365`*^9, 
   3.8129281238864803`*^9, 3.812928506346159*^9, 3.8129756930053544`*^9, 
   3.8129760949146338`*^9, 3.815477036623347*^9, 3.8157750041258364`*^9, 
   3.816949328305806*^9, 3.818775945107202*^9, 3.82005837153452*^9, 
   3.820358857280407*^9, 3.825283291724736*^9, 3.8252840218741074`*^9, 
   3.8254135376601453`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[308]=",ExpressionUUID->"dfb262ad-f8c3-45ff-8e4a-3c40fe89f148"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
   3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
   3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
   3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
   3.8048542553403563`*^9, 3.8048542677330275`*^9}, 3.8067662961560063`*^9, 
   3.8067664458307953`*^9},ExpressionUUID->"9a48f72c-e683-4eef-a766-\
d6eafcb44256"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qctu1", "-", "qctu0"}], ")"}], "100"}], "qctu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.8048587746537323`*^9, 3.8048587754194756`*^9}, {3.8050174603547196`*^9, 
  3.8050174603547196`*^9}, {3.805021840377807*^9, 3.8050218405184546`*^9}, {
  3.8067910172311115`*^9, 3.8067910181218853`*^9}},
 CellLabel->
  "In[309]:=",ExpressionUUID->"17d0570a-d752-44e3-b70f-5ed7e347d13e"],

Cell[BoxData[
 RowBox[{"-", "5.729671223833389`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588455608006`*^9, 3.8048588886454954`*^9, 
   3.804859665231494*^9, 3.804859751588249*^9, 3.8048599657555275`*^9, 
   3.8048601127148046`*^9, 3.8048603820338573`*^9, 3.804860539004675*^9, 
   3.804860670985069*^9, 3.8048614911257286`*^9, 3.8048659514670196`*^9, 
   3.804866275153248*^9, 3.804866445790497*^9, 3.804867252195078*^9, 
   3.8048811924886093`*^9, 3.804895270877902*^9, 3.8048961502181063`*^9, 
   3.804896947799594*^9, 3.805022031147694*^9, 3.8050234645764217`*^9, 
   3.8050236837296696`*^9, 3.805023848662756*^9, 3.80502522301534*^9, 
   3.8056381000913086`*^9, 3.8056381960873194`*^9, 3.8056386177540436`*^9, 
   3.8056408781530533`*^9, 3.805641064888511*^9, 3.8056658283116965`*^9, 
   3.80679106110777*^9, 3.8067913698965197`*^9, 3.806832633869705*^9, 
   3.8068333579394836`*^9, 3.8068340590887303`*^9, 3.80683436659305*^9, 
   3.806834572053113*^9, 3.8068347592550364`*^9, 3.8068351365686073`*^9, 
   3.8068354408115635`*^9, 3.806835566615649*^9, 3.806836454443286*^9, 
   3.8068365032585735`*^9, 3.80683681419141*^9, 3.806839113909409*^9, 
   3.806839663678959*^9, 3.8076504320050545`*^9, 3.8076509622811575`*^9, 
   3.807651391974354*^9, 3.8100376548378534`*^9, 3.8124696402775764`*^9, 
   3.8124699105988255`*^9, 3.812671236122834*^9, 3.8128019201572866`*^9, 
   3.8128023240266314`*^9, 3.812802374973279*^9, 3.8129277276215*^9, 
   3.8129281240766277`*^9, 3.812928506501279*^9, 3.8129756932085123`*^9, 
   3.8129760951646743`*^9, 3.815477036826514*^9, 3.8157750043470087`*^9, 
   3.8169493283224273`*^9, 3.8187759451222134`*^9, 3.8200583717026525`*^9, 
   3.8203588574495907`*^9, 3.8252832919228773`*^9, 3.825284022085225*^9, 
   3.825413537870325*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[309]=",ExpressionUUID->"600dc25e-35c3-4e94-9001-f10f4af4d562"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"6f46316a-26e2-4291-a63f-\
5ef5c6a7794c"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pctp1", "-", "pctp0"}], ")"}], "100"}], "pctp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
  3.804858633427496*^9}, {3.804858731626238*^9, 3.804858732688901*^9}, {
  3.805018278409396*^9, 3.805018278409396*^9}, {3.805020655565849*^9, 
  3.8050206633639984`*^9}, {3.805021844206562*^9, 3.8050218469101295`*^9}, {
  3.8067910215912085`*^9, 3.806791022497611*^9}},
 CellLabel->
  "In[310]:=",ExpressionUUID->"db586c54-20d0-41e4-9765-405464a7d02b"],

Cell[BoxData["6.465918596644249`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.804858845701447*^9, 3.80485888880177*^9, 3.804859665387776*^9, 
   3.804859751728901*^9, 3.8048599659046464`*^9, 3.8048601128710814`*^9, 
   3.8048603821901336`*^9, 3.8048605391609497`*^9, 3.804860671141344*^9, 
   3.8048614912663765`*^9, 3.8048659515764117`*^9, 3.804866275262643*^9, 
   3.804866445884262*^9, 3.804867252304471*^9, 3.804881192582374*^9, 
   3.804895270971669*^9, 3.8048961503431263`*^9, 3.804896947924615*^9, 
   3.8050220313039675`*^9, 3.8050234676862774`*^9, 3.805023683948454*^9, 
   3.8050238488229685`*^9, 3.8050252231888547`*^9, 3.8056381002319565`*^9, 
   3.805638196243595*^9, 3.805638617957183*^9, 3.8056408783732233`*^9, 
   3.8056410651541643`*^9, 3.8056658284992294`*^9, 3.806791061217163*^9, 
   3.8067913700684233`*^9, 3.806832634025981*^9, 3.806833358111376*^9, 
   3.8068340592606335`*^9, 3.806834366758884*^9, 3.806834572240644*^9, 
   3.8068347594061527`*^9, 3.80683513674051*^9, 3.8068354409834676`*^9, 
   3.806835566787553*^9, 3.8068364546151896`*^9, 3.8068365034773593`*^9, 
   3.806836814349491*^9, 3.80683911409694*^9, 3.80683966388214*^9, 
   3.807650432145697*^9, 3.807650962468689*^9, 3.8076513921462574`*^9, 
   3.810037655026*^9, 3.812469640435695*^9, 3.8124699107739615`*^9, 
   3.8126712362859616`*^9, 3.8128019203164105`*^9, 3.812802324232785*^9, 
   3.8128023751714334`*^9, 3.8129277278526797`*^9, 3.812928124278785*^9, 
   3.8129285067054377`*^9, 3.8129756934116707`*^9, 3.812976095399087*^9, 
   3.815477037014097*^9, 3.8157750045741873`*^9, 3.81694932833844*^9, 
   3.8187759451362247`*^9, 3.8200583718717856`*^9, 3.8203588576166725`*^9, 
   3.825283292127059*^9, 3.825284022303458*^9, 3.825413538091476*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[310]=",ExpressionUUID->"0c66c3f4-4d57-41f7-a8dd-c82bd0662876"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, 
   3.8067662961716337`*^9, 
   3.8067664458307953`*^9},ExpressionUUID->"c0839bdc-fe31-4602-a763-\
d373a33c6f16"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qctp1", "-", "qctp0"}], ")"}], "100"}], "qctp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.804858776153962*^9, 3.804858777294763*^9}, {3.8050175127677307`*^9, 
  3.8050175127677307`*^9}, {3.805021850488841*^9, 3.80502185062949*^9}, {
  3.806791026216976*^9, 3.806791027201516*^9}},
 CellLabel->
  "In[311]:=",ExpressionUUID->"837a0856-9802-469c-8aee-bc228d453609"],

Cell[BoxData[
 RowBox[{"-", "6.641950409301223`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.8048588458420935`*^9, 3.804858888926789*^9, 3.8048596655284295`*^9, 
   3.8048597518851805`*^9, 3.804859966064773*^9, 3.8048601130273585`*^9, 
   3.804860382346409*^9, 3.8048605393172245`*^9, 3.804860671281991*^9, 
   3.80486149137577*^9, 3.8048659516858044`*^9, 3.804866275372032*^9, 
   3.804866446009283*^9, 3.804867252413864*^9, 3.8048811926917667`*^9, 
   3.8048952710810633`*^9, 3.8048961504525194`*^9, 3.804896948034007*^9, 
   3.805022031491497*^9, 3.805023468092591*^9, 3.8050236842453737`*^9, 
   3.805023848988509*^9, 3.8050252233763876`*^9, 3.8056381003726044`*^9, 
   3.805638196384244*^9, 3.80563861814472*^9, 3.8056408785963945`*^9, 
   3.8056410655448523`*^9, 3.805665828672367*^9, 3.8067910613734393`*^9, 
   3.8067913702715836`*^9, 3.8068326341978855`*^9, 3.8068333582832794`*^9, 
   3.80683405941691*^9, 3.806834366932019*^9, 3.806834572412548*^9, 
   3.806834759565138*^9, 3.8068351369124126`*^9, 3.806835441124116*^9, 
   3.8068355669594555`*^9, 3.8068364547870936`*^9, 3.806836503649263*^9, 
   3.8068368145057645`*^9, 3.8068391142844706`*^9, 3.806839664087278*^9, 
   3.807650432302005*^9, 3.8076509626405926`*^9, 3.8076513923181615`*^9, 
   3.810037655175115*^9, 3.8124696405938177`*^9, 3.8124699109470963`*^9, 
   3.812671236449088*^9, 3.8128019204775352`*^9, 3.8128023244399643`*^9, 
   3.8128023753575783`*^9, 3.8129277280538635`*^9, 3.8129281244719443`*^9, 
   3.8129285069045925`*^9, 3.8129756935992007`*^9, 3.8129760956335*^9, 
   3.8154770372328043`*^9, 3.8157750048114076`*^9, 3.8169493283554525`*^9, 
   3.8187759451512365`*^9, 3.820058372039917*^9, 3.820358857783804*^9, 
   3.8252832923351717`*^9, 3.8252840225285864`*^9, 3.8254135383036456`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[311]=",ExpressionUUID->"08a081d2-ac2b-487c-924f-d81a40754f84"]
}, Open  ]],

Cell[TextData[StyleBox["Chum Salmon",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQfeDUR41u/zeOh9LEDEG0y38FbxB9ou2RL4jOviqR
AaLFtk8B03Imt5pBdAfL+RYQrVSSsw5EJ3x5vhlEP9459TuI/sbD9wtE65vJ
HFsEpHcmh58E0Zsi590G0ZL6s+6D6AkzMj6D6Ern019B9LMY2T8gmuu1+1+w
/Hth9sVAWq/5NJjedv2NkUXEG0cpW1cTEJ025ctPvcg3jjkiX8E055Nnf0E0
f8pzML0qYTm/IZCWfXQSTN8rUVMF0Xu+hYLpdU+KrjcAaaYXh8B04I+iHQ9i
3jieaVkEphnYSmzVGoDhs+Q0mAYAEUidfw==
  "],ExpressionUUID->"0ba7f740-1ccf-4c0a-8976-8f2466cded3a"],

Cell["Percent change in price of unprocessed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}},ExpressionUUID->"3d66264f-629c-44c5-9dbd-\
5d67f5927cbd"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"phdu1", "-", "phdu0"}], ")"}], "100"}], "phdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
  3.8048585992018385`*^9}, {3.8048587385491753`*^9, 3.8048587395967627`*^9}, {
  3.8067911162517724`*^9, 3.8067911172831945`*^9}},
 CellLabel->
  "In[312]:=",ExpressionUUID->"2a02d074-8b67-4ef2-97ac-70841c84a99d"],

Cell[BoxData["1.5913207278616268`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.8048588459827404`*^9, 3.8048588890674353`*^9, 
   3.8048596656690836`*^9, 3.804859752041461*^9, 3.80485996621189*^9, 
   3.8048601131836357`*^9, 3.8048603824870806`*^9, 3.804860539504755*^9, 
   3.804860671438266*^9, 3.8048614914695363`*^9, 3.8048659517951965`*^9, 
   3.804866275497053*^9, 3.8048664461030483`*^9, 3.8048672525232573`*^9, 
   3.8048811927855315`*^9, 3.8048952711748304`*^9, 3.8048961505619116`*^9, 
   3.8048969481434*^9, 3.8050220316633987`*^9, 3.8050234712493286`*^9, 
   3.8050236844798255`*^9, 3.8050238491447835`*^9, 3.805025223548292*^9, 
   3.8056381005132513`*^9, 3.805638196540518*^9, 3.805638618680574*^9, 
   3.8056408794150257`*^9, 3.8056410664043665`*^9, 3.8056658292193384`*^9, 
   3.806791370834173*^9, 3.806832634729224*^9, 3.806833358830897*^9, 
   3.806834059979504*^9, 3.8068343674847064`*^9, 3.8068345729282913`*^9, 
   3.8068347600263324`*^9, 3.8068351374437475`*^9, 3.806835441657734*^9, 
   3.8068355674907904`*^9, 3.806836455302805*^9, 3.80683650419623*^9, 
   3.806836815005845*^9, 3.8068391144563727`*^9, 3.8068396642815285`*^9, 
   3.8076504324426117`*^9, 3.807650962812496*^9, 3.807651392490065*^9, 
   3.810037655342245*^9, 3.8124696407489386`*^9, 3.812469911122232*^9, 
   3.8126712366162367`*^9, 3.8128019206356583`*^9, 3.812802324631147*^9, 
   3.812802375546725*^9, 3.812927728255993*^9, 3.8129281246570787`*^9, 
   3.812928507112773*^9, 3.8129756938023586`*^9, 3.8129760958679132`*^9, 
   3.8154770374203343`*^9, 3.8157750050345726`*^9, 3.8169493283694644`*^9, 
   3.818775945165248*^9, 3.8200583722060475`*^9, 3.8203588579549384`*^9, 
   3.825283292548332*^9, 3.8252840227897863`*^9, 3.8254135385188003`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[312]=",ExpressionUUID->"8f04fdd3-6245-4a97-8cec-c0dc759e162e"]
}, Open  ]],

Cell["Percent change in quantity of landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.8067662961716337`*^9, 3.806766445846423*^9, 
   3.8067665464893847`*^9},ExpressionUUID->"0fe098be-b29f-4ce6-bab0-\
f04522167f30"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qhdu1", "-", "qhdu0"}], ")"}], "100"}], "qhdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.804858781717317*^9, 3.80485878271747*^9}, {3.806791121471592*^9, 
  3.8067911225030107`*^9}},
 CellLabel->
  "In[313]:=",ExpressionUUID->"7d4c9a37-f057-46db-b5c4-4cfdb1bc79f0"],

Cell[BoxData["3.1482925689745604`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.8048588461233864`*^9, 3.804858889208082*^9, 
   3.8048596658097377`*^9, 3.8048597521977406`*^9, 3.804859966359081*^9, 
   3.8048601133242846`*^9, 3.804860382643334*^9, 3.8048605396610303`*^9, 
   3.8048606715945415`*^9, 3.804861491578929*^9, 3.8048659519045897`*^9, 
   3.8048662756220727`*^9, 3.804866446228069*^9, 3.804867252632651*^9, 
   3.804881192894924*^9, 3.804895271284257*^9, 3.8048961506713037`*^9, 
   3.8048969482527924`*^9, 3.8050220318665547`*^9, 3.8050234744998317`*^9, 
   3.805023684729825*^9, 3.805023849339243*^9, 3.805025223782708*^9, 
   3.8056381006695275`*^9, 3.8056381966811657`*^9, 3.8056386188524776`*^9, 
   3.8056408796522083`*^9, 3.8056410666928825`*^9, 3.805665829453754*^9, 
   3.806791371006078*^9, 3.8068326349636383`*^9, 3.8068333590340557`*^9, 
   3.806834060151408*^9, 3.8068343676441174`*^9, 3.806834573178301*^9, 
   3.806834760173441*^9, 3.806835137615651*^9, 3.806835441845302*^9, 
   3.806835567662693*^9, 3.8068364554747086`*^9, 3.8068365043681335`*^9, 
   3.8068368151621203`*^9, 3.80683911465953*^9, 3.8068396645006027`*^9, 
   3.807650432598888*^9, 3.807650962968772*^9, 3.807651392661969*^9, 
   3.8100376554953785`*^9, 3.812469640904059*^9, 3.812469911297368*^9, 
   3.8126712367763424`*^9, 3.8128019208027887`*^9, 3.8128023248142366`*^9, 
   3.8128023757328696`*^9, 3.812927728451145*^9, 3.81292812483922*^9, 
   3.8129285073179135`*^9, 3.812975694005517*^9, 3.812976096102326*^9, 
   3.8154770376234913`*^9, 3.815775005265747*^9, 3.8169493283844757`*^9, 
   3.8187759451792583`*^9, 3.8200583724072056`*^9, 3.820358858134079*^9, 
   3.8252832927885275`*^9, 3.825284022996934*^9, 3.8254135387730045`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[313]=",ExpressionUUID->"0afeb3b6-cce4-4f38-ac87-c029c78da4d6"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 
  3.80485427153401*^9}},ExpressionUUID->"7de371d5-81f7-476d-9f31-\
0363bd80cce3"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"phdp1", "-", "phdp0"}], ")"}], "100"}], "phdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
  3.8048586124851284`*^9}, {3.804858740206231*^9, 3.804858741003228*^9}, {
  3.806791127222297*^9, 3.806791128019306*^9}},
 CellLabel->
  "In[314]:=",ExpressionUUID->"505233e9-3de1-4a29-9d0e-86ea14ae24b7"],

Cell[BoxData["1.591320727861614`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.804858846279661*^9, 3.804858889348729*^9, 
   3.8048596659503913`*^9, 3.804859752338393*^9, 3.80485996649973*^9, 
   3.8048601134805613`*^9, 3.804860382783988*^9, 3.804860539801677*^9, 
   3.8048606717351885`*^9, 3.8048614916726947`*^9, 3.8048659520296097`*^9, 
   3.8048662757314653`*^9, 3.8048664463218336`*^9, 3.8048672527420435`*^9, 
   3.8048811929886894`*^9, 3.80489527139362*^9, 3.804896150780697*^9, 
   3.8048969483621855`*^9, 3.8050220320384564`*^9, 3.8050234777659616`*^9, 
   3.8050236849486156`*^9, 3.805023849490115*^9, 3.8050252239702854`*^9, 
   3.8056381008113737`*^9, 3.8056381968530684`*^9, 3.8056386190712643`*^9, 
   3.805640879907406*^9, 3.8056410669585505`*^9, 3.8056658296413093`*^9, 
   3.8067913711154704`*^9, 3.806832635135562*^9, 3.80683335920596*^9, 
   3.8068340603233433`*^9, 3.8068343678234086`*^9, 3.8068345733502045`*^9, 
   3.806834760323044*^9, 3.8068351377875533`*^9, 3.806835442017167*^9, 
   3.806835567834597*^9, 3.806836455646612*^9, 3.806836504633803*^9, 
   3.8068368153340225`*^9, 3.806839114831433*^9, 3.8068396647007585`*^9, 
   3.807650432755164*^9, 3.807650963140676*^9, 3.8076513928338733`*^9, 
   3.810037655647482*^9, 3.812469641074191*^9, 3.8124699114755077`*^9, 
   3.8126712369444733`*^9, 3.812801920974922*^9, 3.8128023249983797`*^9, 
   3.812802375917012*^9, 3.8129277286432962`*^9, 3.8129281250343723`*^9, 
   3.812928507515067*^9, 3.8129756942086744`*^9, 3.8129760963367395`*^9, 
   3.815477037826649*^9, 3.8157750054779186`*^9, 3.8169493283994884`*^9, 
   3.8187759451932693`*^9, 3.8200583725893483`*^9, 3.8203588583222265`*^9, 
   3.8252832929977255`*^9, 3.825284023219118*^9, 3.8254135390001793`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[314]=",ExpressionUUID->"f3a0887d-df28-4653-8fbc-8f0b8828a4d8"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
   3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
   3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
   3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
   3.804854255481004*^9, 3.8048542778511686`*^9}, 3.8067662961872616`*^9, 
   3.80676644586205*^9},ExpressionUUID->"8ae1ed5b-0ea8-45f8-946d-\
944ec7d06db1"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qhdp1", "-", "qhdp0"}], ")"}], "100"}], "qhdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}, {
  3.8048587831862926`*^9, 3.804858783952036*^9}, {3.806791131255471*^9, 
  3.806791132318147*^9}},
 CellLabel->
  "In[315]:=",ExpressionUUID->"5fd82f32-b684-4fbb-930c-804e026d4a08"],

Cell[BoxData["7.49690255150273`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.804858846420307*^9, 3.8048588894893756`*^9, 
   3.804859666091045*^9, 3.804859752494673*^9, 3.8048599666403804`*^9, 
   3.8048601136212463`*^9, 3.804860382940258*^9, 3.8048605399579525`*^9, 
   3.804860671907091*^9, 3.8048614917664604`*^9, 3.804865952139002*^9, 
   3.804866275856485*^9, 3.804866446446854*^9, 3.8048672528514366`*^9, 
   3.8048811930980816`*^9, 3.8048952714873867`*^9, 3.8048961508900895`*^9, 
   3.8048969484715776`*^9, 3.8050220322103577`*^9, 3.805023478187902*^9, 
   3.8050236851517644`*^9, 3.8050238496873655`*^9, 3.805025224142146*^9, 
   3.8056381009832764`*^9, 3.8056381971031094`*^9, 3.805638619274424*^9, 
   3.8056408802266517`*^9, 3.8056410672085915`*^9, 3.805665829840061*^9, 
   3.806791371240492*^9, 3.8068326353074455`*^9, 3.806833359377886*^9, 
   3.806834060495216*^9, 3.8068343679852743`*^9, 3.8068345735064807`*^9, 
   3.806834760473551*^9, 3.8068351379594803`*^9, 3.8068354421890697`*^9, 
   3.806835568022128*^9, 3.806836455818516*^9, 3.806836504821334*^9, 
   3.8068368154902973`*^9, 3.8068391150034294`*^9, 3.806839664877897*^9, 
   3.807650432895813*^9, 3.807650963312627*^9, 3.8076513929901485`*^9, 
   3.810037655804604*^9, 3.8124696412313137`*^9, 3.8124699116646557`*^9, 
   3.8126712371086006`*^9, 3.812801921137048*^9, 3.812802325201538*^9, 
   3.8128023760961514`*^9, 3.8129277288714714`*^9, 3.812928125248538*^9, 
   3.812928507731236*^9, 3.8129756944274597`*^9, 3.812976096581458*^9, 
   3.8154770380923166`*^9, 3.81577500569508*^9, 3.816949328426608*^9, 
   3.81877594520728*^9, 3.8200583727654867`*^9, 3.8203588584933615`*^9, 
   3.8252832931948633`*^9, 3.825284023436314*^9, 3.825413539216378*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[315]=",ExpressionUUID->"e12e5615-ff6e-47cf-b425-a689a2817e34"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.805638279440954*^9}, 3.806766499642617*^9, {3.8252836193080306`*^9, 
   3.8252836244910607`*^9}},ExpressionUUID->"f7c8ac24-1772-44a2-8fd4-\
34926eabe768"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmahu"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"phdu1", " ", 
     RowBox[{"(", 
      RowBox[{"qhdu1", "-", "qhdue0", "-", 
       RowBox[{"cr", " ", "qhdp1"}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"phdu0", " ", 
     RowBox[{"(", 
      RowBox[{"qhdu0", "-", "qhdue0", "-", 
       RowBox[{"cr", " ", "qhdp0"}]}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.805638382813442*^9, 3.8056383904499063`*^9}, {3.805638490231865*^9, 
  3.805638492576459*^9}, {3.8056412032132607`*^9, 3.805641206526474*^9}, {
  3.8067911577354965`*^9, 3.8067911603453064`*^9}, {3.806834919262081*^9, 
  3.8068349384534397`*^9}, {3.825283859001442*^9, 3.825283863661045*^9}},
 CellLabel->
  "In[316]:=",ExpressionUUID->"f59586ff-0f98-4466-8cbf-e8037d2facd9"],

Cell[BoxData["694491.4418963674`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB+Izr05fXBv1xvFBu+ZDEJ1wsu03iH4xzVBsPZCeuG6i
LojuvvnADkTzPXnrshtIi22uu/kg5o3jhfC2/1+A9BwJjqivQHpm4uqNIHr/
DpkbINrP7OxHEP1jsgbnNxD/1lJ5EM23NdoCRPP3JcWB6E4zuTwQ3bRJ7C6I
3udp9RhEr9nIzfUdSPfPTtX8AaRXTlTMA9HbVikGtMS9cXzXUDAJRHfoq54A
0XfW/vskmPzGcV2sTuHW9DeOJ57/mgSiUw6teCCe8cZxaaLmhnAg7fJ5zSMQ
/es9x0sQ/S1ISW4qkN7Yss4fRHd01dWDaCG9q51rgPR8aak9ILqz5OTTwtw3
jitm701mzgPq1+Q75VDwxvGSiPrGPcVvHBkY5z3QK3vjGGMdOvMgkN4otlZa
reGN4wfOr2Ug+u333C2pQBoAt07Mlg==
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[316]=",ExpressionUUID->"b272f739-b0d5-4333-b203-26106533f30b"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.8056382995792217`*^9}, 3.8067665212567716`*^9, {3.825283629738141*^9, 
   3.825283632120994*^9}},ExpressionUUID->"dcbbb31f-19e7-44bd-a931-\
55852205923a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmahp"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"phdp1", " ", 
     RowBox[{"(", 
      RowBox[{"qhdp1", "-", "qhdpe0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"phdp0", " ", 
     RowBox[{"(", 
      RowBox[{"qhdp0", "-", "qhdpe0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.805638311659393*^9, 3.805638322630473*^9}, {3.805638393085109*^9, 
  3.8056384022321267`*^9}, {3.8056384953269224`*^9, 3.805638497874226*^9}, {
  3.805641209558215*^9, 3.8056412124349337`*^9}, {3.8067911659881773`*^9, 
  3.8067911680978994`*^9}, {3.8128037739794383`*^9, 3.8128037867463756`*^9}, {
  3.8252838654334145`*^9, 3.8252838681615868`*^9}},
 CellLabel->
  "In[317]:=",ExpressionUUID->"c8061686-4796-4f70-a3b4-31ba8b7b2d73"],

Cell[BoxData["971261.4827082559`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAOIzr05fXBv1xvHUttJrIDqkZ8kDEL3oZM9vEH1iirXY
eiDNv36uLohekD3XHkT7/f/qshtI+25uvvkg5o0j743u/1+AtJ8kX9RXIH3l
4YaNIDrkjeINEN2+7dJHEJ2wUpfzG5D2ME20ANGOfOlxIPrYNuU8ED3BQOYu
iP510v4xiH6zUZDrO5C+MztH8weQNlBRzwPRb1apBbTEvXHUYiybBKKv6euc
ANEf/rB8Fkx+48iea1i4Nf2N48tMhskguvPT2gfiGW8cb2XobQgH0mqcmx+B
aJEjfC9B9Mk5jTMjgDRvpYbcVCD9p3OLP4g+pNlWD6LD1t3uXAOkX0kr7gHR
F76cf1qY+8ZxYeHpZOa8N47P5PlPORS8cZzEpLFxT/Ebx1LelQ/0yt44cgYk
zDwIpHe82i2t1vDG8W/u3zIQbRVXuiUVSAMA57fOiA==
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[317]=",ExpressionUUID->"cd7a816a-0d99-447c-be03-f940da958e40"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"595cd19d-1187-4444-8116-\
3c5f95c9094e"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"phtu1", "-", "phtu0"}], ")"}], "100"}], "phtu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
  3.8048586228946285`*^9}, {3.8048587414876785`*^9, 3.8048587423628125`*^9}, {
  3.8067911350373473`*^9, 3.8067911364550705`*^9}},
 CellLabel->
  "In[318]:=",ExpressionUUID->"54ef8831-e826-4661-bf9d-4173471e7600"],

Cell[BoxData["4.241665583236186`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.8048588465765815`*^9, 3.804858889630022*^9, 
   3.8048596662473273`*^9, 3.8048597526353245`*^9, 3.8048599667810307`*^9, 
   3.8048601137774878`*^9, 3.804860383112162*^9, 3.8048605401142273`*^9, 
   3.804860672047739*^9, 3.8048614918758535`*^9, 3.804865952232767*^9, 
   3.8048662759658775`*^9, 3.8048664465406685`*^9, 3.80486725296095*^9, 
   3.804881193191847*^9, 3.804895271581153*^9, 3.80489615101511*^9, 
   3.8048969485809703`*^9, 3.8050220323822594`*^9, 3.805023481297758*^9, 
   3.805023685401803*^9, 3.8050238498436394`*^9, 3.80502522431405*^9, 
   3.805638101139552*^9, 3.805638197275014*^9, 3.805638619477617*^9, 
   3.8056408805278835`*^9, 3.805641067458632*^9, 3.8056658300275936`*^9, 
   3.806791371412396*^9, 3.8068326354637213`*^9, 3.8068333595497656`*^9, 
   3.8068340606514916`*^9, 3.8068343681688323`*^9, 3.8068345736783843`*^9, 
   3.806834760617854*^9, 3.806835138131358*^9, 3.806835442360972*^9, 
   3.806835568240915*^9, 3.8068364559904194`*^9, 3.8068365050088654`*^9, 
   3.806836815662201*^9, 3.8068391155659294`*^9, 3.8068396653993053`*^9, 
   3.807650433364641*^9, 3.8076509638595457`*^9, 3.807651393552763*^9, 
   3.810037656310997*^9, 3.812469641703684*^9, 3.812469912188111*^9, 
   3.8126712375989842`*^9, 3.8128019216134276`*^9, 3.8128023257749834`*^9, 
   3.812802376644578*^9, 3.812927729494956*^9, 3.812928125832992*^9, 
   3.812928508407775*^9, 3.8129756950681896`*^9, 3.8129760972221875`*^9, 
   3.8154770387017927`*^9, 3.815775006580762*^9, 3.816949328488657*^9, 
   3.8187759452663264`*^9, 3.820058373485057*^9, 3.8203588591809053`*^9, 
   3.825283294082569*^9, 3.825284024138822*^9, 3.8254135399389277`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[318]=",ExpressionUUID->"9c68419a-7e7f-41c2-b53c-1eb5ed3030fb"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
   3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
   3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
   3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
   3.8048542553403563`*^9, 3.8048542677330275`*^9}, 3.8067662961872616`*^9, 
   3.806766445877678*^9},ExpressionUUID->"0d1da58d-1aa7-4703-9e86-\
87f82453e588"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qhtu1", "-", "qhtu0"}], ")"}], "100"}], "qhtu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.804858784498994*^9, 3.8048587856866765`*^9}, {3.8067911397940073`*^9, 
  3.8067911408566847`*^9}},
 CellLabel->
  "In[319]:=",ExpressionUUID->"8550f87b-1995-4769-afe4-52aa757c92e5"],

Cell[BoxData[
 RowBox[{"-", "2.886031514679025`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.804858846717228*^9, 3.804858889770669*^9, 
   3.804859666387981*^9, 3.804859752807233*^9, 3.8048599669373083`*^9, 
   3.8048601139337645`*^9, 3.8048603832684374`*^9, 3.8048605402705026`*^9, 
   3.804860672204014*^9, 3.8048614919852467`*^9, 3.804865952357787*^9, 
   3.8048662760752697`*^9, 3.804866446665639*^9, 3.804867253070223*^9, 
   3.8048811933012834`*^9, 3.804895271690548*^9, 3.804896151124502*^9, 
   3.804896948690363*^9, 3.8050220325385337`*^9, 3.8050234817196984`*^9, 
   3.805023685651842*^9, 3.8050238499843435`*^9, 3.8050252244859548`*^9, 
   3.8056381012974787`*^9, 3.8056381974469175`*^9, 3.8056386196494894`*^9, 
   3.8056408807750745`*^9, 3.805641067755555*^9, 3.8056658302151337`*^9, 
   3.8067913715374155`*^9, 3.806832635635626*^9, 3.8068333597216682`*^9, 
   3.8068340608402963`*^9, 3.806834368342169*^9, 3.8068345738502884`*^9, 
   3.806834760790681*^9, 3.8068351383345165`*^9, 3.806835442532879*^9, 
   3.806835568428446*^9, 3.806836456162324*^9, 3.8068365051963973`*^9, 
   3.8068368158341026`*^9, 3.806839115737833*^9, 3.806839665631487*^9, 
   3.807650433520917*^9, 3.8076509640314503`*^9, 3.8076513937246466`*^9, 
   3.8100376564801507`*^9, 3.812469641861808*^9, 3.8124699123612547`*^9, 
   3.812671237763113*^9, 3.812801921777547*^9, 3.812802325974162*^9, 
   3.812802376824718*^9, 3.8129277297221317`*^9, 3.812928126020138*^9, 
   3.8129285086199317`*^9, 3.8129756952088366`*^9, 3.8129760974566*^9, 
   3.815477038904952*^9, 3.815775006808966*^9, 3.81694932850419*^9, 
   3.8187759452813387`*^9, 3.820058373656186*^9, 3.8203588593780613`*^9, 
   3.8252832942857127`*^9, 3.825284024348011*^9, 3.825413540150109*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[319]=",ExpressionUUID->"a2e9c892-d30b-4820-8e40-8fd447d99d14"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"64be1c49-a58d-4f9b-bf04-\
f2b3f67564ff"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"phtp1", "-", "phtp0"}], ")"}], "100"}], "phtp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
  3.804858633427496*^9}, {3.804858743050418*^9, 3.8048587439411793`*^9}, {
  3.8067911435758862`*^9, 3.806791144926152*^9}},
 CellLabel->
  "In[320]:=",ExpressionUUID->"0033ad0d-1379-457a-9dc2-1a86231bb164"],

Cell[BoxData["5.072080594186778`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.804858846857889*^9, 3.804858889926943*^9, 3.804859666544263*^9, 
   3.8048597529478846`*^9, 3.804859967093587*^9, 3.804860114090042*^9, 
   3.804860383409086*^9, 3.80486054041115*^9, 3.8048606723602886`*^9, 
   3.8048614920947437`*^9, 3.8048659524671793`*^9, 3.804866276184663*^9, 
   3.8048664467594037`*^9, 3.804867253179615*^9, 3.8048811934106317`*^9, 
   3.804895271799943*^9, 3.8048961512338953`*^9, 3.8048969487997556`*^9, 
   3.805022032710436*^9, 3.8050234850014563`*^9, 3.805023685854998*^9, 
   3.8050238501655254`*^9, 3.805025224673488*^9, 3.805638101451598*^9, 
   3.8056381976031933`*^9, 3.805638619821391*^9, 3.8056408810212636`*^9, 
   3.805641068005595*^9, 3.8056658304182963`*^9, 3.8067913716624365`*^9, 
   3.8068326357919016`*^9, 3.806833359893571*^9, 3.8068340610121994`*^9, 
   3.8068343685453277`*^9, 3.8068345739753084`*^9, 3.806834760936408*^9, 
   3.806835138522046*^9, 3.806835442782917*^9, 3.8068355686003494`*^9, 
   3.8068364563498554`*^9, 3.8068365053839283`*^9, 3.8068368160060053`*^9, 
   3.806839115909737*^9, 3.806839665808625*^9, 3.807650433692821*^9, 
   3.807650964203354*^9, 3.80765139389655*^9, 3.810037656635248*^9, 
   3.8124696420219336`*^9, 3.812469912539341*^9, 3.8126712379242387`*^9, 
   3.8128019219396734`*^9, 3.8128023261762967`*^9, 3.812802377006859*^9, 
   3.812927729949375*^9, 3.8129281262142887`*^9, 3.812928508806076*^9, 
   3.8129756954119954`*^9, 3.8129760976650143`*^9, 3.8154770391237383`*^9, 
   3.8157750070591354`*^9, 3.816949328520848*^9, 3.818775945297351*^9, 
   3.82005837382732*^9, 3.8203588595542135`*^9, 3.825283294487899*^9, 
   3.8252840245781884`*^9, 3.8254135403722486`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[320]=",ExpressionUUID->"84ff0ebe-0983-4993-aad3-9e594d581a24"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, 
   3.8067662962028894`*^9, 
   3.806766445877678*^9},ExpressionUUID->"1287b6cf-c7e5-4552-a2a6-\
c873534b38be"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qhtp1", "-", "qhtp0"}], ")"}], "100"}], "qhtp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.8048587864211645`*^9, 3.804858787812003*^9}, {3.8067911482079515`*^9, 
  3.8067911502341533`*^9}},
 CellLabel->
  "In[321]:=",ExpressionUUID->"04e6fdef-ca93-4416-a1ff-70212c4de514"],

Cell[BoxData[
 RowBox[{"-", "1.3465471426573556`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.804858846998521*^9, 3.8048588900675893`*^9, 3.8048596666849174`*^9, 
   3.8048597530885797`*^9, 3.8048599672342367`*^9, 3.804860114246319*^9, 
   3.804860383565363*^9, 3.8048605405830526`*^9, 3.8048606725165644`*^9, 
   3.804861492204033*^9, 3.804865952576572*^9, 3.804866276294055*^9, 
   3.804866446884424*^9, 3.804867253320263*^9, 3.8048811935200243`*^9, 
   3.8048952719093375`*^9, 3.8048961513589153`*^9, 3.8048969488935204`*^9, 
   3.805022032882337*^9, 3.805023485424994*^9, 3.805023686105037*^9, 
   3.8050238503416615`*^9, 3.805025224907903*^9, 3.8056381015958214`*^9, 
   3.805638197745079*^9, 3.8056386200089226`*^9, 3.805640881291472*^9, 
   3.80564106830252*^9, 3.805665830621447*^9, 3.80679137183434*^9, 
   3.8068326360419436`*^9, 3.8068333600811014`*^9, 3.806834061184102*^9, 
   3.806834368725418*^9, 3.806834574225348*^9, 3.8068347611098347`*^9, 
   3.806835138693949*^9, 3.806835442907937*^9, 3.806835568772254*^9, 
   3.806836456521758*^9, 3.8068365056339703`*^9, 3.8068368161779084`*^9, 
   3.806839116093135*^9, 3.806839665986765*^9, 3.8076504338490973`*^9, 
   3.8076509643596296`*^9, 3.8076513940684547`*^9, 3.810037656794372*^9, 
   3.812469642194068*^9, 3.812469912723485*^9, 3.812671238100377*^9, 
   3.8128019221108074`*^9, 3.8128023263864613`*^9, 3.8128023771849976`*^9, 
   3.8129277301644783`*^9, 3.81292812640844*^9, 3.812928508997225*^9, 
   3.8129756956151533`*^9, 3.8129760978838*^9, 3.8154770393268967`*^9, 
   3.8157750072933145`*^9, 3.8169493285348587`*^9, 3.8187759453133636`*^9, 
   3.820058373999455*^9, 3.8203588597313395`*^9, 3.825283294695053*^9, 
   3.825284024804349*^9, 3.8254135405884237`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[321]=",ExpressionUUID->"1994aa17-1ce0-49d7-b0ad-5eb7d7cbd095"]
}, Open  ]],

Cell[TextData[StyleBox["Coho Salmon",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, {3.804858674828244*^9, 3.8048586759846716`*^9}, {
   3.805021921987334*^9, 3.8050219236606793`*^9}, 3.8067662962028894`*^9, {
   3.8067911758971725`*^9, 3.806791178381957*^9}, {3.8252838513314724`*^9, 
   3.825283853950494*^9}},ExpressionUUID->"0da5a705-ebaa-47a5-9c78-\
216be9b445f4"],

Cell["Percent change in price of unprocessed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}},ExpressionUUID->"d6dd7271-b8f9-4b87-8e07-\
d998adc6d6c9"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"podu1", "-", "podu0"}], ")"}], "100"}], "podu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
   3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
   3.8048585992018385`*^9}, {3.8048587486137724`*^9, 3.804858750004611*^9}, {
   3.805017872704455*^9, 3.805017872704455*^9}, 3.805020287887725*^9, {
   3.8067911972540445`*^9, 3.80679119794166*^9}},
 CellLabel->
  "In[322]:=",ExpressionUUID->"eac04235-9dae-4c9d-9d14-9beadbe1df28"],

Cell[BoxData["2.058421852351482`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.804858847139168*^9, 3.804858890192608*^9, 
   3.804859666825571*^9, 3.8048597532291985`*^9, 3.8048599673748865`*^9, 
   3.804860114402596*^9, 3.8048603837216387`*^9, 3.8048605407393417`*^9, 
   3.8048606726728387`*^9, 3.804861492313425*^9, 3.8048659526859646`*^9, 
   3.8048662764034476`*^9, 3.8048664469938164`*^9, 3.8048672534297056`*^9, 
   3.8048811936294165`*^9, 3.804895272018732*^9, 3.8048961514683075`*^9, 
   3.8048969490185413`*^9, 3.805022033054239*^9, 3.805023488706752*^9, 
   3.8050236863081937`*^9, 3.805023850498782*^9, 3.805025225095439*^9, 
   3.805638101752097*^9, 3.805638197915598*^9, 3.80563862057152*^9, 
   3.805640882167178*^9, 3.805641069162032*^9, 3.8056658318749647`*^9, 
   3.8067913722875414`*^9, 3.8068326365420275`*^9, 3.8068333606124926`*^9, 
   3.806834061699469*^9, 3.806834369237815*^9, 3.8068345747566843`*^9, 
   3.8068347615832014`*^9, 3.8068351392096567`*^9, 3.806835443408021*^9, 
   3.806835569334848*^9, 3.8068364570528316`*^9, 3.806836506180937*^9, 
   3.806836816740543*^9, 3.8068391162509727`*^9, 3.806839666160901*^9, 
   3.807650434005373*^9, 3.8076509645784163`*^9, 3.8076513942403584`*^9, 
   3.810037656950493*^9, 3.8124696423491898`*^9, 3.812469912899623*^9, 
   3.812671238266507*^9, 3.8128019222739353`*^9, 3.812802326568604*^9, 
   3.812802377371142*^9, 3.812927730352626*^9, 3.8129281266005907`*^9, 
   3.812928509193383*^9, 3.8129756958339386`*^9, 3.812976098118213*^9, 
   3.8154770395300555`*^9, 3.8157750074985075`*^9, 3.8169493285518723`*^9, 
   3.818775945329376*^9, 3.8200583741735916`*^9, 3.820358859903474*^9, 
   3.825283294942263*^9, 3.8252840250585375`*^9, 3.825413540824621*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[322]=",ExpressionUUID->"45705070-1212-4fc7-9393-065b39248b63"]
}, Open  ]],

Cell["Percent change in quantity of landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.8067662962185163`*^9, 3.806766445893306*^9, 
   3.8067665465050125`*^9},ExpressionUUID->"6ab2d942-3780-4d10-a84d-\
bca6c00b9067"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qodu1", "-", "qodu0"}], ")"}], "100"}], "qodu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.804858792627643*^9, 3.804858798896052*^9}, {3.8050173592553644`*^9, 
  3.8050173592553644`*^9}, {3.8050219270518637`*^9, 3.8050219271612563`*^9}, {
  3.8067911984417443`*^9, 3.8067911991137314`*^9}},
 CellLabel->
  "In[323]:=",ExpressionUUID->"699c7382-61c3-4087-9ac8-2d4750e55a95"],

Cell[BoxData["4.072234421808805`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.8048588472798543`*^9, 3.8048588903332553`*^9, 
   3.8048596669662247`*^9, 3.8048597533854685`*^9, 3.8048599675155373`*^9, 
   3.8048601145432453`*^9, 3.8048603838622866`*^9, 3.8048605408956027`*^9, 
   3.804860672829114*^9, 3.804861492438445*^9, 3.8048659527953568`*^9, 
   3.8048662765128403`*^9, 3.8048664471032095`*^9, 3.804867253539048*^9, 
   3.804881193738809*^9, 3.804895272128127*^9, 3.8048961515777006`*^9, 
   3.8048969491279335`*^9, 3.805022033194886*^9, 3.805023492051019*^9, 
   3.805023686589486*^9, 3.8050238507269583`*^9, 3.805025225267357*^9, 
   3.8056381019083724`*^9, 3.8056381981187563`*^9, 3.8056386207746763`*^9, 
   3.8056408824643764`*^9, 3.80564106941296*^9, 3.805665832062481*^9, 
   3.806791372443817*^9, 3.806832636713931*^9, 3.806833360784396*^9, 
   3.806834061918254*^9, 3.8068343693981333`*^9, 3.806834574928587*^9, 
   3.8068347617430696`*^9, 3.806835139412833*^9, 3.8068354435799255`*^9, 
   3.80683556952238*^9, 3.8068364572247353`*^9, 3.8068365063684716`*^9, 
   3.806836816912401*^9, 3.8068391164772663`*^9, 3.8068396663380394`*^9, 
   3.8076504341616497`*^9, 3.8076509647504325`*^9, 3.807651394459144*^9, 
   3.8100376571406407`*^9, 3.812469642512317*^9, 3.8124699130707593`*^9, 
   3.8126712384386415`*^9, 3.812801922442067*^9, 3.8128023267477446`*^9, 
   3.8128023775522895`*^9, 3.81292773053677*^9, 3.8129281267857733`*^9, 
   3.812928509378521*^9, 3.812975696052725*^9, 3.812976098321371*^9, 
   3.815477039733215*^9, 3.81577500772765*^9, 3.816949328566884*^9, 
   3.8187759453443875`*^9, 3.820058374346753*^9, 3.820358860075609*^9, 
   3.825283295154377*^9, 3.8252840252837143`*^9, 3.8254135410878286`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[323]=",ExpressionUUID->"0e41d849-72b2-4fbe-acdc-bae60576bca8"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 
  3.80485427153401*^9}},ExpressionUUID->"d2845b1f-67a4-4183-b6ef-\
b498601995fd"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"podp1", "-", "podp0"}], ")"}], "100"}], "podp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
   3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
   3.8048586124851284`*^9}, {3.804858750567197*^9, 3.8048587511610384`*^9}, {
   3.805018163895453*^9, 3.8050181639110804`*^9}, 3.805020631092285*^9, {
   3.80679119958256*^9, 3.806791200270173*^9}},
 CellLabel->
  "In[324]:=",ExpressionUUID->"7c1759df-3d72-4500-860c-2dd4c373c9a0"],

Cell[BoxData["2.0584218523514757`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.804858847436088*^9, 3.8048588904739017`*^9, 
   3.8048596671068783`*^9, 3.804859753526121*^9, 3.804859967671815*^9, 
   3.804860114699522*^9, 3.80486038403419*^9, 3.8048605410518775`*^9, 
   3.8048606730010166`*^9, 3.8048614925478373`*^9, 3.80486595290475*^9, 
   3.804866276622233*^9, 3.8048664472126026`*^9, 3.8048672536484404`*^9, 
   3.8048811938325744`*^9, 3.8048952722375216`*^9, 3.804896151687093*^9, 
   3.8048969492373266`*^9, 3.805022033366787*^9, 3.805023495457796*^9, 
   3.8050236867770157`*^9, 3.8050238508691483`*^9, 3.805025225439246*^9, 
   3.805638102080275*^9, 3.805638198290659*^9, 3.805638620946581*^9, 
   3.8056408827305813`*^9, 3.8056410696473737`*^9, 3.8056658322416816`*^9, 
   3.806791372584466*^9, 3.806832636870207*^9, 3.806833360987191*^9, 
   3.8068340620901575`*^9, 3.8068343696075215`*^9, 3.806834575100491*^9, 
   3.8068347619149723`*^9, 3.8068351395847173`*^9, 3.8068354437987113`*^9, 
   3.806835569694283*^9, 3.8068364574747767`*^9, 3.8068365065559998`*^9, 
   3.8068368171132045`*^9, 3.80683911664917*^9, 3.8068396665191813`*^9, 
   3.8076504343179255`*^9, 3.807650964922223*^9, 3.807651394631048*^9, 
   3.8100376573027663`*^9, 3.8124696426704407`*^9, 3.8124699132428923`*^9, 
   3.8126712386027703`*^9, 3.812801922608197*^9, 3.8128023269318886`*^9, 
   3.812802377730421*^9, 3.8129277307219477`*^9, 3.812928126976886*^9, 
   3.81292850957067*^9, 3.8129756962559237`*^9, 3.812976098555784*^9, 
   3.815477039936373*^9, 3.8157750079418163`*^9, 3.816949328581895*^9, 
   3.8187759453604*^9, 3.8200583745478854`*^9, 3.8203588602527485`*^9, 
   3.825283295362543*^9, 3.825284025495909*^9, 3.825413541295985*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[324]=",ExpressionUUID->"bdd91140-1835-4e44-8366-10e60aba0892"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
   3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
   3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
   3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
   3.804854255481004*^9, 3.8048542778511686`*^9}, 3.8067662962185163`*^9, 
   3.806766445908933*^9},ExpressionUUID->"312e9735-b698-47d1-8a41-\
0d85b37f1f59"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qodp1", "-", "qodp0"}], ")"}], "100"}], "qodp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}, {
  3.8048587995680304`*^9, 3.8048588001931267`*^9}, {3.8050174161743164`*^9, 
  3.8050174161743164`*^9}, {3.805021931896407*^9, 3.805021932052683*^9}, {
  3.806791200801509*^9, 3.806791201770419*^9}},
 CellLabel->
  "In[325]:=",ExpressionUUID->"bf9dee48-da0c-4799-9b7a-a8cf2a44140f"],

Cell[BoxData["7.466355608492363`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.8048588475923624`*^9, 3.8048588906145487`*^9, 
   3.8048596672475457`*^9, 3.8048597536824007`*^9, 3.8048599678124647`*^9, 
   3.8048601148557987`*^9, 3.8048603841904664`*^9, 3.804860541192525*^9, 
   3.804860673141664*^9, 3.80486149265723*^9, 3.804865953014142*^9, 
   3.8048662767316256`*^9, 3.8048664473219957`*^9, 3.804867253757833*^9, 
   3.8048811939419665`*^9, 3.804895272346916*^9, 3.8048961517964897`*^9, 
   3.804896949346719*^9, 3.8050220335386887`*^9, 3.805023495879737*^9, 
   3.8050236869645443`*^9, 3.8050238510266843`*^9, 3.8050252256111526`*^9, 
   3.805638102231194*^9, 3.8056381984469347`*^9, 3.805638621134112*^9, 
   3.8056408830548315`*^9, 3.805641069928669*^9, 3.8056658324292097`*^9, 
   3.8067913727094865`*^9, 3.806832637120249*^9, 3.8068333611747227`*^9, 
   3.806834062262061*^9, 3.8068343697842855`*^9, 3.806834575334905*^9, 
   3.8068347621025023`*^9, 3.8068351397409925`*^9, 3.806835443970615*^9, 
   3.806835569866186*^9, 3.806836457646679*^9, 3.8068365068060412`*^9, 
   3.8068368173163614`*^9, 3.8068391168210735`*^9, 3.8068396667433567`*^9, 
   3.807650434474203*^9, 3.807650965078498*^9, 3.807651394802952*^9, 
   3.8100376574638915`*^9, 3.812469642829566*^9, 3.8124699134150267`*^9, 
   3.8126712387658987`*^9, 3.812801922773326*^9, 3.812802327125038*^9, 
   3.81280237790856*^9, 3.8129277309070587`*^9, 3.8129281272060647`*^9, 
   3.812928509772827*^9, 3.8129756964590397`*^9, 3.812976098774577*^9, 
   3.815477040139532*^9, 3.8157750081629915`*^9, 3.816949328596907*^9, 
   3.818775945376413*^9, 3.8200583747230234`*^9, 3.820358860448902*^9, 
   3.8252832955837226`*^9, 3.8252840257000732`*^9, 3.825413541548164*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[325]=",ExpressionUUID->"eeeb01d7-ee86-46f2-afaf-806f15d83313"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.805638279440954*^9}, 3.806766499642617*^9, {3.8252836714886055`*^9, 
   3.8252836754036503`*^9}},ExpressionUUID->"d456ddaf-7494-4d82-be28-\
242333493e6e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmaou"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"podu1", " ", 
     RowBox[{"(", 
      RowBox[{"qodu1", "-", "qodue0", "-", 
       RowBox[{"cr", " ", "qodp1"}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"podu0", " ", 
     RowBox[{"(", 
      RowBox[{"qodu0", "-", "qodue0", "-", 
       RowBox[{"cr", " ", "qodp0"}]}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
   3.8056384216076107`*^9, 3.8056384298283195`*^9}, {3.805638482271556*^9, 
   3.805638484475052*^9}, {3.8056411863774834`*^9, 3.8056411898406487`*^9}, 
   3.8067649535185204`*^9, {3.8067912083973675`*^9, 3.8067912170489283`*^9}, {
   3.806834952903533*^9, 3.8068349754876604`*^9}, {3.8252838743263626`*^9, 
   3.8252838761177745`*^9}},
 CellLabel->
  "In[326]:=",ExpressionUUID->"0e215f92-9e3e-460f-bb0c-fa3125e0c73c"],

Cell[BoxData["66323.23075968673`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBeIzr05fXBv1xvH16YO/QXTMuX6x9UC6yfKZLohWVj5n
A6Jb9+q67gbSIqZrbz6IeeNoErXv/xcgXTPDIeorkGZ/8mQjiD5TFnYDRM8v
jeP8BqR9N+ipgOjY7ZMtQHSVwOw4EC22MzIPRN8zCr4Lon18yh6D6CMLXLm+
A+mAM/M1fwDphpzYPBD9QCckoCXujaMH84pJIJrFKP4EiN6eZfJZMPmN44HN
8YVb0984XnplNBlET91194F4xhvHef9jN4QDaea3Lx+B6OtbnV6C6JoTyXJT
gfSJtW/8QfR9rf31IHqXgWjXGiDd7Rm/B0QHfed6Vpj7xvG3OG8Kcx6QP1X4
lEPBG8eeNp2Ne4rfOO7ee+eBXtkbR0XFKTMPAun8hp/Sag1vHGd125aD6H7+
XVtSgTQAUVXBcA==
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[326]=",ExpressionUUID->"b83e0027-be18-4555-9307-17a1eabc2b52"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.8056382995792217`*^9}, 3.806766521272399*^9, {3.825283679433784*^9, 
   3.8252836848700104`*^9}},ExpressionUUID->"82a8b5f2-8067-46f3-bd04-\
7b49c5ef145c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmaop"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"podp1", " ", 
     RowBox[{"(", 
      RowBox[{"qodp1", "-", "qodpe0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"podp0", " ", 
     RowBox[{"(", 
      RowBox[{"qodp0", "-", "qodpe0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.805638311659393*^9, 3.805638322630473*^9}, {3.805638433988842*^9, 
  3.8056384793310328`*^9}, {3.805641192616592*^9, 3.8056411960702763`*^9}, {
  3.8067912106247272`*^9, 3.806791213547085*^9}, {3.8128037344676867`*^9, 
  3.8128037579589677`*^9}, {3.8252838778431034`*^9, 3.825283880507153*^9}},
 CellLabel->
  "In[327]:=",ExpressionUUID->"13c246d6-ddc6-4db3-a757-18c808abb93c"],

Cell[BoxData["617013.779281209`"], "Output",
 CellChangeTimes->{{3.8128037511706877`*^9, 3.8128037604248896`*^9}, 
   3.8129277313103724`*^9, 3.8129281275863647`*^9, 3.812928510171137*^9, 
   3.812975696880984*^9, 3.812976099196513*^9, 3.81547704054585*^9, 
   3.8157750087714972`*^9, 3.8169493286400704`*^9, 3.8187759454204473`*^9, 
   3.8200583752504373`*^9, 3.820358860985368*^9, 3.825283296255233*^9, 
   3.825284026182411*^9, 3.8254135420605884`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[327]=",ExpressionUUID->"826521cf-c18e-40ac-8c0f-dc6534fe7ef9"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"44538c4e-1e32-4e62-83c8-\
b7718d9697ea"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"potu1", "-", "potu0"}], ")"}], "100"}], "potu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
   3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
   3.8048586228946285`*^9}, {3.804858751489214*^9, 3.8048587520986824`*^9}, {
   3.805018113403982*^9, 3.8050181134196095`*^9}, 3.80502029645166*^9, {
   3.8067912025517993`*^9, 3.8067912033019247`*^9}},
 CellLabel->
  "In[328]:=",ExpressionUUID->"4b5f3777-f0ec-482e-99c6-1607ad258f3c"],

Cell[BoxData["4.686442605350132`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.8048588477330093`*^9, 3.8048588907551947`*^9, 
   3.8048596674038343`*^9, 3.804859753823053*^9, 3.8048599679531155`*^9, 
   3.804860114996448*^9, 3.8048603843467426`*^9, 3.8048605413487997`*^9, 
   3.804860673297939*^9, 3.8048614927666225`*^9, 3.8048659531235347`*^9, 
   3.8048662768410177`*^9, 3.804866447431389*^9, 3.804867253867225*^9, 
   3.804881194051359*^9, 3.804895272440683*^9, 3.804896151905878*^9, 
   3.804896949456112*^9, 3.805022033711192*^9, 3.8050234991864624`*^9, 
   3.805023687198978*^9, 3.805023851182804*^9, 3.8050252257830553`*^9, 
   3.8056381023874693`*^9, 3.80563819860321*^9, 3.805638621337271*^9, 
   3.8056408833710747`*^9, 3.805641070163082*^9, 3.805665832616743*^9, 
   3.806791372834508*^9, 3.806832637292153*^9, 3.8068333613466263`*^9, 
   3.806834062433965*^9, 3.80683436995742*^9, 3.8068345755068083`*^9, 
   3.806834762264247*^9, 3.8068351399129534`*^9, 3.8068354441425247`*^9, 
   3.806835570053718*^9, 3.806836457818582*^9, 3.8068365069935727`*^9, 
   3.806836817503892*^9, 3.806839117337613*^9, 3.8068396672697687`*^9, 
   3.807650434989913*^9, 3.807650965625462*^9, 3.8076513953030357`*^9, 
   3.810037657958275*^9, 3.812469643322951*^9, 3.812469913946443*^9, 
   3.8126712392682915`*^9, 3.812801923279719*^9, 3.8128023276844883`*^9, 
   3.812802378448985*^9, 3.812927731506524*^9, 3.81292812779152*^9, 
   3.812928510393309*^9, 3.8129756970841417`*^9, 3.8129760993996706`*^9, 
   3.815477040749008*^9, 3.815775008946598*^9, 3.8169493286570845`*^9, 
   3.818775945435459*^9, 3.820058375488623*^9, 3.8203588611624627`*^9, 
   3.8252832964634495`*^9, 3.825284026388605*^9, 3.825413542324806*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[328]=",ExpressionUUID->"a1878e83-be8d-4605-9584-5e115fdd2e12"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
   3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
   3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
   3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
   3.8048542553403563`*^9, 3.8048542677330275`*^9}, 3.8067662962341437`*^9, 
   3.806766445924561*^9},ExpressionUUID->"7d0cf9a0-3acd-42fb-ac58-\
b758e20e9bab"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qotu1", "-", "qotu0"}], ")"}], "100"}], "qotu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.804858800630694*^9, 3.8048588012870445`*^9}, {3.8050174723410645`*^9, 
  3.8050174723410645`*^9}, {3.805021936100234*^9, 3.8050219362096276`*^9}, {
  3.8067912037966504`*^9, 3.8067912045217257`*^9}},
 CellLabel->
  "In[329]:=",ExpressionUUID->"5f50749e-a91c-4991-99cb-2687d628f86c"],

Cell[BoxData[
 RowBox[{"-", "2.799391112286053`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588478736553`*^9, 3.8048588909114695`*^9, 
   3.8048596675600967`*^9, 3.804859753963705*^9, 3.804859968109393*^9, 
   3.804860115168353*^9, 3.8048603844873915`*^9, 3.8048605415207024`*^9, 
   3.8048606734385867`*^9, 3.8048614928760147`*^9, 3.804865953232927*^9, 
   3.8048662769660378`*^9, 3.8048664475407825`*^9, 3.804867253961108*^9, 
   3.8048811941607513`*^9, 3.804895272550078*^9, 3.8048961520152717`*^9, 
   3.804896949565504*^9, 3.8050220339143486`*^9, 3.8050234996084023`*^9, 
   3.805023687417741*^9, 3.80502385132647*^9, 3.805025226017471*^9, 
   3.805638102543745*^9, 3.805638198775112*^9, 3.80563862154043*^9, 
   3.8056408836763105`*^9, 3.805641070397495*^9, 3.8056658328667865`*^9, 
   3.8067913729595284`*^9, 3.806832637448428*^9, 3.806833361502903*^9, 
   3.8068340625902405`*^9, 3.8068343701335564`*^9, 3.8068347624517775`*^9, 
   3.806835140084798*^9, 3.8068354443144226`*^9, 3.8068355702256217`*^9, 
   3.806836457990485*^9, 3.806836507165476*^9, 3.8068368176601667`*^9, 
   3.806839117572027*^9, 3.806839667446907*^9, 3.807650435146189*^9, 
   3.807650965797365*^9, 3.80765139553745*^9, 3.810037658155428*^9, 
   3.812469643485077*^9, 3.81246991412158*^9, 3.8126712394384236`*^9, 
   3.8128019234478493`*^9, 3.812802327891646*^9, 3.81280237862512*^9, 
   3.812927731694683*^9, 3.812928127977665*^9, 3.8129285106024714`*^9, 
   3.8129756972873316`*^9, 3.812976099618457*^9, 3.8154770409521666`*^9, 
   3.8157750091768007`*^9, 3.8169493286781*^9, 3.8187759454514713`*^9, 
   3.8200583757328157`*^9, 3.8203588613416033`*^9, 3.8252832966796284`*^9, 
   3.8252840266187596`*^9, 3.8254135425849686`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[329]=",ExpressionUUID->"2fbbbf13-6f42-461f-95ff-739bdc981fda"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"e745e36a-4f70-481c-8fb6-\
6bb8fe578131"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"potp1", "-", "potp0"}], ")"}], "100"}], "potp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
   3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
   3.804858633427496*^9}, {3.804858752504995*^9, 3.804858754192754*^9}, {
   3.8050182855042944`*^9, 3.8050182855042944`*^9}, 3.8050206707402067`*^9, {
   3.806791205068693*^9, 3.8067912058344407`*^9}},
 CellLabel->
  "In[330]:=",ExpressionUUID->"305151c4-d677-4e89-8ccb-7d1d76c8b5ed"],

Cell[BoxData["6.37438610090042`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.8048588480143023`*^9, 3.8048588910677433`*^9, 3.8048596677007504`*^9, 
   3.8048597541199846`*^9, 3.804859968250043*^9, 3.804860115309002*^9, 
   3.8048603846436667`*^9, 3.804860541708233*^9, 3.804860673594861*^9, 
   3.804861492985408*^9, 3.804865953357947*^9, 3.8048662770754304`*^9, 
   3.804866447650175*^9, 3.804867254086011*^9, 3.8048811942701445`*^9, 
   3.8048952726594725`*^9, 3.8048961521246634`*^9, 3.8048969496748967`*^9, 
   3.8050220340862503`*^9, 3.805023502999552*^9, 3.805023687652151*^9, 
   3.8050238514882965`*^9, 3.8050252262050037`*^9, 3.8056381027156477`*^9, 
   3.805638198947016*^9, 3.8056386217123346`*^9, 3.8056408839465184`*^9, 
   3.8056410706319075`*^9, 3.8056658330543194`*^9, 3.806791373100177*^9, 
   3.8068326376203327`*^9, 3.806833361643551*^9, 3.806834062762145*^9, 
   3.806834370306692*^9, 3.8068347626080527`*^9, 3.8068351402098174`*^9, 
   3.806835444486326*^9, 3.806835570444408*^9, 3.8068364581623874`*^9, 
   3.80683650733738*^9, 3.8068368178320956`*^9, 3.8068391177595587`*^9, 
   3.806839667623045*^9, 3.8076504353024654`*^9, 3.8076509659848957`*^9, 
   3.8076513957093534`*^9, 3.8100376583195553`*^9, 3.812469643645201*^9, 
   3.812469914292714*^9, 3.812671239608556*^9, 3.812801923612978*^9, 
   3.812802328098795*^9, 3.8128023788012877`*^9, 3.812927731890823*^9, 
   3.8129281281808224`*^9, 3.8129285108126345`*^9, 3.8129756974748297`*^9, 
   3.812976099821748*^9, 3.8154770411709538`*^9, 3.8157750093839445`*^9, 
   3.8169493286941123`*^9, 3.818775945466483*^9, 3.820058375944982*^9, 
   3.8203588615277495`*^9, 3.8252832968977537`*^9, 3.8252840268209095`*^9, 
   3.825413542822171*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[330]=",ExpressionUUID->"33f90b24-73ae-4157-996d-76c20dce63e5"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, 
   3.8067662962341437`*^9, 
   3.806766445924561*^9},ExpressionUUID->"e36a07fd-56c3-4cfb-8912-\
9cdfc5e191d1"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qotp1", "-", "qotp0"}], ")"}], "100"}], "qotp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.804858801740239*^9, 3.8048588038343105`*^9}, {3.805017523503875*^9, 
  3.805017523503875*^9}, {3.8050219403353195`*^9, 3.805021940413457*^9}, {
  3.806791206490799*^9, 3.8067912072565517`*^9}},
 CellLabel->
  "In[331]:=",ExpressionUUID->"8aa73854-3a13-4f13-ad44-e3ae30c9c42c"],

Cell[BoxData[
 RowBox[{"-", "5.165644712537071`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.804858848154949*^9, 3.804858891192762*^9, 3.8048596678726606`*^9, 
   3.804859754260637*^9, 3.80485996839496*^9, 3.804860115465279*^9, 
   3.804860384799943*^9, 3.80486054184888*^9, 3.80486067373553*^9, 
   3.80486149309489*^9, 3.804865953482967*^9, 3.804866277169195*^9, 
   3.804866447759568*^9, 3.804867254195405*^9, 3.8048811943795366`*^9, 
   3.804895272768914*^9, 3.8048961522340565`*^9, 3.8048969497842894`*^9, 
   3.805022034258152*^9, 3.8050235034371195`*^9, 3.8050236878709345`*^9, 
   3.8050238516521263`*^9, 3.805025226376909*^9, 3.8056381028719225`*^9, 
   3.805638199150173*^9, 3.8056386218842387`*^9, 3.805640884216727*^9, 
   3.805641070960086*^9, 3.805665833241892*^9, 3.8067913732564535`*^9, 
   3.8068326377922363`*^9, 3.806833361815468*^9, 3.8068340629809313`*^9, 
   3.806834370481829*^9, 3.806834762779955*^9, 3.8068351404286027`*^9, 
   3.806835444626975*^9, 3.80683557063194*^9, 3.806836458349918*^9, 
   3.806836507524911*^9, 3.806836818003972*^9, 3.8068391179314623`*^9, 
   3.8068396678602314`*^9, 3.8076504354587417`*^9, 3.8076509661567993`*^9, 
   3.807651395865678*^9, 3.8100376584816813`*^9, 3.8124696438083277`*^9, 
   3.8124699144648485`*^9, 3.8126712397716827`*^9, 3.8128019237811084`*^9, 
   3.8128023282809367`*^9, 3.8128023789813995`*^9, 3.812927732089978*^9, 
   3.812928128364966*^9, 3.812928511013791*^9, 3.812975697693616*^9, 
   3.8129761000394564`*^9, 3.815477041374112*^9, 3.815775009592126*^9, 
   3.816949328710174*^9, 3.8187759454824963`*^9, 3.8200583761221237`*^9, 
   3.8203588617108955`*^9, 3.825283297151987*^9, 3.82528402702609*^9, 
   3.825413543042327*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[331]=",ExpressionUUID->"b911a057-0cb2-4102-8a41-718577084540"]
}, Open  ]],

Cell[TextData[StyleBox["Pink Salmon",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQfeDUR41u/zeOh9LEDEG0y38FbxB9ou2RL4jOviqR
AaLFtk8B03Imt5pBdAfL+RYQrVSSsw5EJ3x5vhlEP9459TuI/sbD9wtE65vJ
HFsEpHcmh58E0Zsi590G0ZL6s+6D6AkzMj6D6Ern019B9LMY2T8gmuu1+1+w
/Hth9sVAWq/5NJjedv2NkUXEG0cpW1cTEJ025ctPvcg3jjkiX8E055Nnf0E0
f8pzML0qYTm/IZCWfXQSTP9qiFID0XlN9WDadob9nQYg7alSCqbvnTF6CKJl
zvmD6Qq9nuMPYt448hlsAtNs+jy+ag1vHBtvO4JpAK4xol8=
  "],ExpressionUUID->"21048f8a-6686-4931-a3eb-27fb0ceb9296"],

Cell["Percent change in price of unprocessed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}},ExpressionUUID->"450fdd62-51c3-4ecb-af6d-\
2332ff3da21c"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"ppdu1", "-", "ppdu0"}], ")"}], "100"}], "ppdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
   3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
   3.8048585992018385`*^9}, {3.8048587486137724`*^9, 3.804858750004611*^9}, {
   3.805017872704455*^9, 3.805017872704455*^9}, 3.805020287887725*^9, {
   3.8050219705421343`*^9, 3.8050219718079715`*^9}, {3.8067912368607244`*^9, 
   3.8067912375952215`*^9}},
 CellLabel->
  "In[332]:=",ExpressionUUID->"56090cfd-1d7b-48fd-b0de-5dcca13a9788"],

Cell[BoxData["0.40507475428804984`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.804858847139168*^9, 3.804858890192608*^9, 
   3.804859666825571*^9, 3.8048597532291985`*^9, 3.8048599673748865`*^9, 
   3.804860114402596*^9, 3.8048603837216387`*^9, 3.8048605407393417`*^9, 
   3.8048606726728387`*^9, 3.804861492313425*^9, 3.8048659526859646`*^9, 
   3.8048662764034476`*^9, 3.8048664469938164`*^9, 3.8048672534297056`*^9, 
   3.8048811936294165`*^9, 3.804895272018732*^9, 3.8048961514683075`*^9, 
   3.8048969490185413`*^9, 3.8050220344300537`*^9, 3.8050235068126426`*^9, 
   3.805023688074092*^9, 3.8050238518552823`*^9, 3.805025226548814*^9, 
   3.8056381030281982`*^9, 3.805638199306449*^9, 3.8056386224624605`*^9, 
   3.8056408851934795`*^9, 3.80564107169458*^9, 3.805665833820078*^9, 
   3.80679137378784*^9, 3.8068326383548265`*^9, 3.80683336236207*^9, 
   3.8068340635311565`*^9, 3.8068343710459857`*^9, 3.806834763292764*^9, 
   3.8068351409443107`*^9, 3.8068354451559415`*^9, 3.8068355711632786`*^9, 
   3.8068364589437666`*^9, 3.8068365081187563`*^9, 3.806836818504053*^9, 
   3.806839118103366*^9, 3.8068396680353675`*^9, 3.807650435615017*^9, 
   3.807650966313095*^9, 3.8076513960375333`*^9, 3.8100376586538153`*^9, 
   3.8124696439814625`*^9, 3.812469914635981*^9, 3.812671239940814*^9, 
   3.8128019239482384`*^9, 3.8128023284680815`*^9, 3.812802379161539*^9, 
   3.812927732297139*^9, 3.81292812855011*^9, 3.812928511209944*^9, 
   3.8129756978967743`*^9, 3.812976100250623*^9, 3.8154770415772705`*^9, 
   3.815775009824295*^9, 3.8169493287262993`*^9, 3.818775945497512*^9, 
   3.820058376308267*^9, 3.8203588618920383`*^9, 3.825283297373108*^9, 
   3.825284027288271*^9, 3.8254135432615147`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[332]=",ExpressionUUID->"020c68e0-d79d-4a00-8f0f-ba0825169e60"]
}, Open  ]],

Cell["Percent change in quantity of landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.8067662962497716`*^9, 3.8067664459401884`*^9, 
   3.8067665465050125`*^9},ExpressionUUID->"24eb6752-0047-4e28-89e2-\
f95f91f72967"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qpdu1", "-", "qpdu0"}], ")"}], "100"}], "qpdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.804858792627643*^9, 3.804858798896052*^9}, {3.8050173592553644`*^9, 
  3.8050173592553644`*^9}, {3.8050219270518637`*^9, 3.8050219271612563`*^9}, {
  3.8050219723393106`*^9, 3.805021972995671*^9}, {3.8067912400956354`*^9, 
  3.8067912407676687`*^9}},
 CellLabel->
  "In[333]:=",ExpressionUUID->"94afbe0c-530f-4e5c-ac5d-c29ef322b4d6"],

Cell[BoxData["2.0175693878460326`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.8048588472798543`*^9, 3.8048588903332553`*^9, 
   3.8048596669662247`*^9, 3.8048597533854685`*^9, 3.8048599675155373`*^9, 
   3.8048601145432453`*^9, 3.8048603838622866`*^9, 3.8048605408956027`*^9, 
   3.804860672829114*^9, 3.804861492438445*^9, 3.8048659527953568`*^9, 
   3.8048662765128403`*^9, 3.8048664471032095`*^9, 3.804867253539048*^9, 
   3.804881193738809*^9, 3.804895272128127*^9, 3.8048961515777006`*^9, 
   3.8048969491279335`*^9, 3.8050220346019554`*^9, 3.805023510345631*^9, 
   3.8050236882928762`*^9, 3.805023852039565*^9, 3.805025226736346*^9, 
   3.805638103200101*^9, 3.805638199447096*^9, 3.805638622634364*^9, 
   3.805640885474696*^9, 3.8056410719133654`*^9, 3.8056658340701213`*^9, 
   3.806791373960896*^9, 3.806832638526729*^9, 3.8068333625339737`*^9, 
   3.806834063703061*^9, 3.806834371219144*^9, 3.8068347634646673`*^9, 
   3.806835141116214*^9, 3.806835445327845*^9, 3.8068355713508096`*^9, 
   3.80683645911567*^9, 3.806836508306287*^9, 3.806836818675955*^9, 
   3.8068391182752705`*^9, 3.8068396682085037`*^9, 3.8076504357869205`*^9, 
   3.8076509664849787`*^9, 3.8076513962094374`*^9, 3.8100376588169413`*^9, 
   3.8124696441445894`*^9, 3.812469914821125*^9, 3.8126712401079435`*^9, 
   3.812801924115368*^9, 3.81280232865823*^9, 3.812802379337676*^9, 
   3.8129277324872866`*^9, 3.812928128742259*^9, 3.8129285114111*^9, 
   3.812975698099933*^9, 3.812976100460802*^9, 3.815477041780429*^9, 
   3.8157750100414586`*^9, 3.8169493287443132`*^9, 3.8187759455135202`*^9, 
   3.820058376488408*^9, 3.8203588620691786`*^9, 3.8252832975882807`*^9, 
   3.8252840275074816`*^9, 3.8254135435237474`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[333]=",ExpressionUUID->"e011244b-9bde-4198-886b-6ca3c607e190"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 
  3.80485427153401*^9}},ExpressionUUID->"db0a1358-4a60-450f-b7cf-\
5f324b03ab1d"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"ppdp1", "-", "ppdp0"}], ")"}], "100"}], "ppdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
   3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
   3.8048586124851284`*^9}, {3.804858750567197*^9, 3.8048587511610384`*^9}, {
   3.805018163895453*^9, 3.8050181639110804`*^9}, 3.805020631092285*^9, {
   3.805021973339478*^9, 3.8050219739802103`*^9}, {3.8067912431273904`*^9, 
   3.8067912438150063`*^9}},
 CellLabel->
  "In[334]:=",ExpressionUUID->"723820a5-12be-4dc4-87e2-370f42900cb2"],

Cell[BoxData["0.4050747542880524`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.804858847436088*^9, 3.8048588904739017`*^9, 
   3.8048596671068783`*^9, 3.804859753526121*^9, 3.804859967671815*^9, 
   3.804860114699522*^9, 3.80486038403419*^9, 3.8048605410518775`*^9, 
   3.8048606730010166`*^9, 3.8048614925478373`*^9, 3.80486595290475*^9, 
   3.804866276622233*^9, 3.8048664472126026`*^9, 3.8048672536484404`*^9, 
   3.8048811938325744`*^9, 3.8048952722375216`*^9, 3.804896151687093*^9, 
   3.8048969492373266`*^9, 3.8050220347738743`*^9, 3.8050235138774276`*^9, 
   3.805023688480405*^9, 3.805023852186414*^9, 3.8050252269082675`*^9, 
   3.8056381033563952`*^9, 3.8056381996033716`*^9, 3.8056386228218966`*^9, 
   3.80564088576492*^9, 3.805641072194661*^9, 3.805665834257654*^9, 
   3.806791374101545*^9, 3.8068326386986313`*^9, 3.8068333627058773`*^9, 
   3.8068340638749647`*^9, 3.8068343713969193`*^9, 3.8068347636321898`*^9, 
   3.806835141272488*^9, 3.8068354454997487`*^9, 3.806835571585224*^9, 
   3.8068364592875743`*^9, 3.8068365085094852`*^9, 3.806836818847858*^9, 
   3.806839118447173*^9, 3.8068396683866405`*^9, 3.8076504359900804`*^9, 
   3.807650966688138*^9, 3.807651396365712*^9, 3.81003765898207*^9, 
   3.8124696443067274`*^9, 3.81246991499426*^9, 3.81267124028308*^9, 
   3.812801924294507*^9, 3.812802328844411*^9, 3.8128023795308266`*^9, 
   3.8129277326844397`*^9, 3.8129281289314055`*^9, 3.812928511602249*^9, 
   3.812975698349975*^9, 3.8129761006759553`*^9, 3.815477041999216*^9, 
   3.815775010271655*^9, 3.8169493287613277`*^9, 3.8187759455285316`*^9, 
   3.8200583766705675`*^9, 3.8203588622513227`*^9, 3.825283297804446*^9, 
   3.825284027713608*^9, 3.825413543745886*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[334]=",ExpressionUUID->"71bc94c2-1824-4e6c-89ea-ec6f85adf1f1"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
   3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
   3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
   3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
   3.804854255481004*^9, 3.8048542778511686`*^9}, 3.8067662962497716`*^9, 
   3.8067664459558163`*^9},ExpressionUUID->"d63966ad-6121-4cf6-b01f-\
2fbdecdec67b"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qpdp1", "-", "qpdp0"}], ")"}], "100"}], "qpdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}, {
  3.8048587995680304`*^9, 3.8048588001931267`*^9}, {3.8050174161743164`*^9, 
  3.8050174161743164`*^9}, {3.805021931896407*^9, 3.805021932052683*^9}, {
  3.8050219743865285`*^9, 3.8050219750897713`*^9}, {3.8067912466279707`*^9, 
  3.806791247659393*^9}},
 CellLabel->
  "In[335]:=",ExpressionUUID->"68f53163-64e4-4bab-97c5-0be5b965d0c8"],

Cell[BoxData["3.3227704981753425`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.8048588475923624`*^9, 3.8048588906145487`*^9, 
   3.8048596672475457`*^9, 3.8048597536824007`*^9, 3.8048599678124647`*^9, 
   3.8048601148557987`*^9, 3.8048603841904664`*^9, 3.804860541192525*^9, 
   3.804860673141664*^9, 3.80486149265723*^9, 3.804865953014142*^9, 
   3.8048662767316256`*^9, 3.8048664473219957`*^9, 3.804867253757833*^9, 
   3.8048811939419665`*^9, 3.804895272346916*^9, 3.8048961517964897`*^9, 
   3.804896949346719*^9, 3.8050220349770126`*^9, 3.805023514330623*^9, 
   3.805023688699188*^9, 3.8050238523270607`*^9, 3.8050252271426663`*^9, 
   3.8056381035126514`*^9, 3.805638199759647*^9, 3.8056386229938*^9, 
   3.805640886142211*^9, 3.8056410724134684`*^9, 3.8056658344608145`*^9, 
   3.8067913742578206`*^9, 3.806832638870535*^9, 3.806833362862153*^9, 
   3.8068340640893507`*^9, 3.806834371552621*^9, 3.8068347637884645`*^9, 
   3.806835141491274*^9, 3.806835445671652*^9, 3.806835571772758*^9, 
   3.8068364594595118`*^9, 3.806836508681349*^9, 3.806836819019761*^9, 
   3.806839118660551*^9, 3.8068396685668*^9, 3.807650436146356*^9, 
   3.8076509668444138`*^9, 3.8076513965844975`*^9, 3.810037659181224*^9, 
   3.8124696444828544`*^9, 3.8124699151674232`*^9, 3.812671240466224*^9, 
   3.812801924462665*^9, 3.8128023290395255`*^9, 3.8128023797089643`*^9, 
   3.812927732896672*^9, 3.8129281291195517`*^9, 3.812928511817417*^9, 
   3.8129756985531344`*^9, 3.812976100889122*^9, 3.8154770422180023`*^9, 
   3.815775010479813*^9, 3.816949328776338*^9, 3.8187759455445447`*^9, 
   3.8200583768787193`*^9, 3.8203588624304647`*^9, 3.8252832980236225`*^9, 
   3.825284027948789*^9, 3.8254135439910717`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[335]=",ExpressionUUID->"80cb8a26-310c-4096-87ab-cfff9513506e"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.805638279440954*^9}, 3.806766499658245*^9, {3.8252837309428363`*^9, 
   3.825283733318684*^9}},ExpressionUUID->"7aaec84f-28ec-43dc-9c0d-\
7c24baf7c1d2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmapu"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"ppdu1", " ", 
     RowBox[{"(", 
      RowBox[{"qpdu1", "-", "qpdue0", "-", 
       RowBox[{"cr", " ", "qpdp1"}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"ppdu0", " ", 
     RowBox[{"(", 
      RowBox[{"qpdu0", "-", "qpdue0", "-", 
       RowBox[{"cr", " ", "qpdp0"}]}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
   3.8056384216076107`*^9, 3.8056384298283195`*^9}, {3.805638482271556*^9, 
   3.805638484475052*^9}, {3.8056385455867786`*^9, 3.8056385532289257`*^9}, {
   3.805641159935579*^9, 3.805641170014205*^9}, 3.8067649723509226`*^9, {
   3.8067912615370016`*^9, 3.8067912718124795`*^9}, {3.8068349889168606`*^9, 
   3.806835017547966*^9}, {3.825283885614107*^9, 3.825283887776798*^9}},
 CellLabel->
  "In[336]:=",ExpressionUUID->"0f6d3918-5b7f-4641-bec4-b82597f6ff62"],

Cell[BoxData["59932.538113939125`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBOIXX1Os1ke9cSxyyHfdDaRlHB/efBDzxnHbnZ//vwBp
hhkVUV+BtNxd2U0g2lG07waIdvoylfMbkE7oztEE0UccT1mA6AMiF+NA9Kzd
U/NAdKRp710Q/dJvy2MQHbO4hus7kK5YfEvzB5D+cXR6HojWWt8Z0BL3xnFN
64NJIDrPZMYJEP2GJfuzYPIbx0erpxRuTX/jeO5t1mQQbWcj8lA8441jifmU
DeFAeqOF+mMQHZld8xJE3/JcLDcVSAse0AwA0Yc2MDSA6AnGEV1rgPS5SYv3
gOiGKt9nhblA8RNhKcx5bxy7vCRPORS8cdxw33DjnuI3jh+ZlB7qlQHNU70y
8yCQ/vDHQ0atAejPhtZyEP3oEtvWVCANAOsLsko=
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[336]=",ExpressionUUID->"eb74d6d8-3eb1-4b00-b28d-97bcf296caa2"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.8056382995792217`*^9}, 3.806766521272399*^9, {3.8252837361168594`*^9, 
   3.8252837381844673`*^9}},ExpressionUUID->"9dee2c40-173a-42b9-aeeb-\
7e163ad84820"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmapp"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"ppdp1", " ", 
     RowBox[{"(", 
      RowBox[{"qpdp1", "-", "qpdpe0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"ppdp0", " ", 
     RowBox[{"(", 
      RowBox[{"qpdp0", "-", "qpdpe0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.805638311659393*^9, 3.805638322630473*^9}, {3.805638433988842*^9, 
  3.8056384793310328`*^9}, {3.8056385581946573`*^9, 3.805638565431512*^9}, {
  3.8056411773904*^9, 3.8056411807971945`*^9}, {3.8067912634123125`*^9, 
  3.8067912659558535`*^9}, {3.8128036947797976`*^9, 3.812803715137645*^9}, {
  3.8252838897253084`*^9, 3.8252838924954576`*^9}},
 CellLabel->
  "In[337]:=",ExpressionUUID->"bfde672c-99ff-4d1c-a60f-c070caec272f"],

Cell[BoxData["825783.70837374`"], "Output",
 CellChangeTimes->{3.8128037169140244`*^9, 3.812927733378979*^9, 
  3.812928129488839*^9, 3.812928512212736*^9, 3.8129756989594526`*^9, 
  3.8129761013304567`*^9, 3.815477042639948*^9, 3.8157750111483173`*^9, 
  3.8169493288215504`*^9, 3.818775945588579*^9, 3.820058377428146*^9, 
  3.8203588629478707`*^9, 3.825283298719204*^9, 3.825284028437189*^9, 
  3.8254135444334188`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[337]=",ExpressionUUID->"7b6bb156-3447-46fd-b379-fafa7ceb951b"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"2090d4c0-b256-42fd-b0b9-\
855673c13eef"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pptu1", "-", "pptu0"}], ")"}], "100"}], "pptu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
   3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
   3.8048586228946285`*^9}, {3.804858751489214*^9, 3.8048587520986824`*^9}, {
   3.805018113403982*^9, 3.8050181134196095`*^9}, 3.80502029645166*^9, {
   3.8050219755586004`*^9, 3.805021976308726*^9}, {3.806791251003697*^9, 
   3.8067912517381935`*^9}},
 CellLabel->
  "In[338]:=",ExpressionUUID->"de86e58c-bebe-4284-aaa1-d0f138eda711"],

Cell[BoxData["7.573883113139672`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.8048588477330093`*^9, 3.8048588907551947`*^9, 
   3.8048596674038343`*^9, 3.804859753823053*^9, 3.8048599679531155`*^9, 
   3.804860114996448*^9, 3.8048603843467426`*^9, 3.8048605413487997`*^9, 
   3.804860673297939*^9, 3.8048614927666225`*^9, 3.8048659531235347`*^9, 
   3.8048662768410177`*^9, 3.804866447431389*^9, 3.804867253867225*^9, 
   3.804881194051359*^9, 3.804895272440683*^9, 3.804896151905878*^9, 
   3.804896949456112*^9, 3.8050220351489143`*^9, 3.8050235177999105`*^9, 
   3.805023688886718*^9, 3.8050238524833345`*^9, 3.8050252273301992`*^9, 
   3.805638103684554*^9, 3.805638199932612*^9, 3.805638623165704*^9, 
   3.8056408864944825`*^9, 3.805641072616604*^9, 3.805665834648348*^9, 
   3.8067913743828416`*^9, 3.806832639042439*^9, 3.8068333630809402`*^9, 
   3.806834064261255*^9, 3.806834371771408*^9, 3.8068347639759955`*^9, 
   3.8068351416475487`*^9, 3.806835445906106*^9, 3.8068355719290295`*^9, 
   3.80683645970952*^9, 3.806836508853252*^9, 3.8068368192072906`*^9, 
   3.806839119191495*^9, 3.8068396691452293`*^9, 3.807650436630823*^9, 
   3.8076509673601255`*^9, 3.8076513971002054`*^9, 3.810037659680612*^9, 
   3.8124696449712367`*^9, 3.8124699156837974`*^9, 3.8126712409716196`*^9, 
   3.812801924968031*^9, 3.81280232959599*^9, 3.8128023802383757`*^9, 
   3.8129277336621995`*^9, 3.8129281296819887`*^9, 3.812928512416887*^9, 
   3.812975699146983*^9, 3.812976101549242*^9, 3.8154770428431063`*^9, 
   3.815775011380512*^9, 3.816949328836562*^9, 3.818775945603591*^9, 
   3.8200583776172943`*^9, 3.820358863092985*^9, 3.825283298937332*^9, 
   3.825284028643392*^9, 3.825413544692626*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[338]=",ExpressionUUID->"6e27bd25-37fd-4dfe-85b7-b32a947e9bce"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
   3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
   3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
   3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
   3.8048542553403563`*^9, 3.8048542677330275`*^9}, 3.806766296265399*^9, 
   3.8067664459714437`*^9},ExpressionUUID->"9b717b62-22c7-40d2-8555-\
3d175d47ea17"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qptu1", "-", "qptu0"}], ")"}], "100"}], "qptu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.804858800630694*^9, 3.8048588012870445`*^9}, {3.8050174723410645`*^9, 
  3.8050174723410645`*^9}, {3.805021936100234*^9, 3.8050219362096276`*^9}, {
  3.805021976793182*^9, 3.8050219775120525`*^9}, {3.8067912539429417`*^9, 
  3.806791254645234*^9}},
 CellLabel->
  "In[339]:=",ExpressionUUID->"80ee4855-2358-4c1e-8eb0-cfa9ea0d31e9"],

Cell[BoxData[
 RowBox[{"-", "10.187256561843704`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588478736553`*^9, 3.8048588909114695`*^9, 
   3.8048596675600967`*^9, 3.804859753963705*^9, 3.804859968109393*^9, 
   3.804860115168353*^9, 3.8048603844873915`*^9, 3.8048605415207024`*^9, 
   3.8048606734385867`*^9, 3.8048614928760147`*^9, 3.804865953232927*^9, 
   3.8048662769660378`*^9, 3.8048664475407825`*^9, 3.804867253961108*^9, 
   3.8048811941607513`*^9, 3.804895272550078*^9, 3.8048961520152717`*^9, 
   3.804896949565504*^9, 3.8050220353208165`*^9, 3.805023518253105*^9, 
   3.8050236890898733`*^9, 3.8050238526239815`*^9, 3.8050252275021043`*^9, 
   3.80563810384083*^9, 3.8056382001670246`*^9, 3.80563862335087*^9, 
   3.8056408867907104`*^9, 3.8056410728353896`*^9, 3.8056658348515077`*^9, 
   3.80679137452349*^9, 3.8068326392924814`*^9, 3.806833363252844*^9, 
   3.8068340644331584`*^9, 3.8068343719589396`*^9, 3.8068347641411495`*^9, 
   3.8068351418194513`*^9, 3.80683544606234*^9, 3.8068355721009393`*^9, 
   3.806836459897051*^9, 3.806836509103294*^9, 3.8068368193791933`*^9, 
   3.8068391193677483`*^9, 3.806839669316364*^9, 3.807650436787089*^9, 
   3.8076509675164013`*^9, 3.8076513972721086`*^9, 3.8100376598437386`*^9, 
   3.8124696451353655`*^9, 3.812469915860936*^9, 3.812671241135786*^9, 
   3.812801925136161*^9, 3.8128023298081226`*^9, 3.812802380417515*^9, 
   3.8129277338673587`*^9, 3.812928129874138*^9, 3.812928512621046*^9, 
   3.81297569936578*^9, 3.8129761017836547`*^9, 3.815477043061892*^9, 
   3.8157750116146827`*^9, 3.816949328851574*^9, 3.818775945619603*^9, 
   3.8200583778034406`*^9, 3.820358863274127*^9, 3.825283299152502*^9, 
   3.825284028861494*^9, 3.8254135449148254`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[339]=",ExpressionUUID->"f49a98eb-ac37-4bf3-a627-789c7361e641"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"80e05d25-81b9-4c74-8b36-\
582590678ca5"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pptp1", "-", "pptp0"}], ")"}], "100"}], "pptp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
   3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
   3.804858633427496*^9}, {3.804858752504995*^9, 3.804858754192754*^9}, {
   3.8050182855042944`*^9, 3.8050182855042944`*^9}, 3.8050206707402067`*^9, {
   3.8050219781371574`*^9, 3.8050219789810486`*^9}, {3.8067912565049343`*^9, 
   3.80679125711439*^9}},
 CellLabel->
  "In[340]:=",ExpressionUUID->"8de93699-9283-4fb5-8557-04fa7ddb7614"],

Cell[BoxData["5.802331427237394`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.8048588480143023`*^9, 3.8048588910677433`*^9, 3.8048596677007504`*^9, 
   3.8048597541199846`*^9, 3.804859968250043*^9, 3.804860115309002*^9, 
   3.8048603846436667`*^9, 3.804860541708233*^9, 3.804860673594861*^9, 
   3.804861492985408*^9, 3.804865953357947*^9, 3.8048662770754304`*^9, 
   3.804866447650175*^9, 3.804867254086011*^9, 3.8048811942701445`*^9, 
   3.8048952726594725`*^9, 3.8048961521246634`*^9, 3.8048969496748967`*^9, 
   3.805022035492718*^9, 3.805023521786112*^9, 3.805023689277403*^9, 
   3.8050238527802753`*^9, 3.8050252276740093`*^9, 3.8056381039971046`*^9, 
   3.8056382003233*^9, 3.8056386235563216`*^9, 3.805640887131996*^9, 
   3.8056410730385475`*^9, 3.805665835101551*^9, 3.8067913747110195`*^9, 
   3.806832639464384*^9, 3.806833363424802*^9, 3.8068340645894346`*^9, 
   3.806834372099588*^9, 3.806834764333034*^9, 3.806835141990941*^9, 
   3.806835446234242*^9, 3.8068355722728357`*^9, 3.8068364600689545`*^9, 
   3.8068365092751975`*^9, 3.806836819551109*^9, 3.806839119539652*^9, 
   3.806839669489499*^9, 3.8076504369433646`*^9, 3.8076509677195606`*^9, 
   3.8076513974283843`*^9, 3.8100376600118685`*^9, 3.8124696452965317`*^9, 
   3.8124699160300684`*^9, 3.812671241310895*^9, 3.8128019253153*^9, 
   3.8128023300092793`*^9, 3.812802380597655*^9, 3.812927734058507*^9, 
   3.8129281301093206`*^9, 3.812928512802246*^9, 3.812975699568926*^9, 
   3.81297610200244*^9, 3.815477043265051*^9, 3.815775011832864*^9, 
   3.8169493288665857`*^9, 3.818775945634615*^9, 3.8200583780086365`*^9, 
   3.820358863460273*^9, 3.8252832994067492`*^9, 3.825284029084668*^9, 
   3.8254135451349955`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[340]=",ExpressionUUID->"c68fe749-5758-4ebb-9020-499375a5c8e3"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, 
   3.806766296265399*^9, 
   3.8067664459714437`*^9},ExpressionUUID->"ac46c285-8b93-4bb6-bcdb-\
f882303c7001"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qptp1", "-", "qptp0"}], ")"}], "100"}], "qptp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.804858801740239*^9, 3.8048588038343105`*^9}, {3.805017523503875*^9, 
  3.805017523503875*^9}, {3.8050219403353195`*^9, 3.805021940413457*^9}, {
  3.8050219796061535`*^9, 3.8050219820909452`*^9}, {3.8067912594116497`*^9, 
  3.8067912600836363`*^9}},
 CellLabel->
  "In[341]:=",ExpressionUUID->"a1c615de-cb31-4f3e-a739-b80014746c13"],

Cell[BoxData[
 RowBox[{"-", "3.2330224328204906`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.804858848154949*^9, 3.804858891192762*^9, 3.8048596678726606`*^9, 
   3.804859754260637*^9, 3.80485996839496*^9, 3.804860115465279*^9, 
   3.804860384799943*^9, 3.80486054184888*^9, 3.80486067373553*^9, 
   3.80486149309489*^9, 3.804865953482967*^9, 3.804866277169195*^9, 
   3.804866447759568*^9, 3.804867254195405*^9, 3.8048811943795366`*^9, 
   3.804895272768914*^9, 3.8048961522340565`*^9, 3.8048969497842894`*^9, 
   3.8050220356646194`*^9, 3.8050235222393055`*^9, 3.8050236894805593`*^9, 
   3.805023852999039*^9, 3.805025227845913*^9, 3.8056381041690073`*^9, 
   3.805638200463972*^9, 3.8056386237282257`*^9, 3.8056408874221973`*^9, 
   3.805641073351098*^9, 3.805665835289084*^9, 3.8067913748829217`*^9, 
   3.8068326396362886`*^9, 3.806833363596651*^9, 3.806834064761338*^9, 
   3.806834372277938*^9, 3.8068347645292253`*^9, 3.8068351421590714`*^9, 
   3.80683544637489*^9, 3.8068355724447384`*^9, 3.806836460240859*^9, 
   3.806836509478361*^9, 3.8068368197229986`*^9, 3.8068391197428107`*^9, 
   3.8068396696636353`*^9, 3.8076504371465235`*^9, 3.807650967891464*^9, 
   3.807651397647171*^9, 3.810037660181*^9, 3.812469645458618*^9, 
   3.8124699162022038`*^9, 3.812671241481019*^9, 3.812801925481429*^9, 
   3.812802330186418*^9, 3.81280238077179*^9, 3.812927734245652*^9, 
   3.812928130296466*^9, 3.8129285129863834`*^9, 3.8129756997877145`*^9, 
   3.8129761022212257`*^9, 3.8154770434682164`*^9, 3.8157750120520687`*^9, 
   3.816949328882598*^9, 3.818775945649627*^9, 3.820058378187742*^9, 
   3.820358863655428*^9, 3.82528329961893*^9, 3.8252840292998514`*^9, 
   3.825413545360134*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[341]=",ExpressionUUID->"01e64a97-9b33-4538-9653-9e57858d6f1c"]
}, Open  ]],

Cell[TextData[StyleBox["Sockeye Salmon",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, {3.804858674828244*^9, 3.8048586759846716`*^9}, {
   3.805021921987334*^9, 3.8050219236606793`*^9}, {3.805021990843542*^9, 
   3.805021993390811*^9}, {3.8067912830814295`*^9, 3.8067912848213053`*^9}, 
   3.825283747476693*^9},ExpressionUUID->"cfdf10cf-34a8-40d8-b0b1-\
39725aa5bbd3"],

Cell["Percent change in price of unprocessed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}},ExpressionUUID->"87808b10-38b2-412a-a34f-\
6e65d6b3752c"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"psdu1", "-", "psdu0"}], ")"}], "100"}], "psdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
   3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
   3.8048585992018385`*^9}, {3.8048587486137724`*^9, 3.804858750004611*^9}, {
   3.805017872704455*^9, 3.805017872704455*^9}, 3.805020287887725*^9, {
   3.8050220006263056`*^9, 3.8050220011576376`*^9}, {3.8067912937864294`*^9, 
   3.8067912942095757`*^9}},
 CellLabel->
  "In[342]:=",ExpressionUUID->"56d3ee65-2e64-4653-9ce7-3699a45d9e92"],

Cell[BoxData["1.8555199601989487`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.804858847139168*^9, 3.804858890192608*^9, 
   3.804859666825571*^9, 3.8048597532291985`*^9, 3.8048599673748865`*^9, 
   3.804860114402596*^9, 3.8048603837216387`*^9, 3.8048605407393417`*^9, 
   3.8048606726728387`*^9, 3.804861492313425*^9, 3.8048659526859646`*^9, 
   3.8048662764034476`*^9, 3.8048664469938164`*^9, 3.8048672534297056`*^9, 
   3.8048811936294165`*^9, 3.804895272018732*^9, 3.8048961514683075`*^9, 
   3.8048969490185413`*^9, 3.805022035836521*^9, 3.8050235258023567`*^9, 
   3.805023689652461*^9, 3.805023853170941*^9, 3.8050252280334463`*^9, 
   3.805638104340911*^9, 3.805638200620223*^9, 3.8056386242595654`*^9, 
   3.8056408884620004`*^9, 3.805641074038709*^9, 3.80566583586731*^9, 
   3.8067913754039445`*^9, 3.8068326401519995`*^9, 3.8068333641592455`*^9, 
   3.806834065323949*^9, 3.806834372830785*^9, 3.8068347650197945`*^9, 
   3.806835142695588*^9, 3.8068354468306274`*^9, 3.8068355730385857`*^9, 
   3.806836460834708*^9, 3.806836510009695*^9, 3.8068368202699614`*^9, 
   3.8068391199303493`*^9, 3.8068396698377714`*^9, 3.807650437318427*^9, 
   3.807650968063368*^9, 3.8076513978190746`*^9, 3.810037660352133*^9, 
   3.8124696456407614`*^9, 3.812469916374338*^9, 3.8126712416511517`*^9, 
   3.8128019256505613`*^9, 3.8128023303625565`*^9, 3.8128023809549327`*^9, 
   3.812927734446809*^9, 3.812928130486615*^9, 3.8129285131724744`*^9, 
   3.8129756999908695`*^9, 3.812976102440011*^9, 3.8154770436713676`*^9, 
   3.815775012272212*^9, 3.8169493288986106`*^9, 3.81877594566564*^9, 
   3.820058378370886*^9, 3.8203588638415747`*^9, 3.825283299835039*^9, 
   3.825284029556035*^9, 3.8254135455723286`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[342]=",ExpressionUUID->"2eed3bec-8afe-47dc-aaf5-9c1238d7db05"]
}, Open  ]],

Cell["Percent change in quantity of landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.8067662962810264`*^9, 3.806766445987071*^9, 
   3.80676654652064*^9},ExpressionUUID->"340dbded-46cb-42bc-b420-\
65dd828b0c5b"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qsdu1", "-", "qsdu0"}], ")"}], "100"}], "qsdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.804858792627643*^9, 3.804858798896052*^9}, {3.8050173592553644`*^9, 
  3.8050173592553644`*^9}, {3.8050219270518637`*^9, 3.8050219271612563`*^9}, {
  3.8050220013295393`*^9, 3.805022001657715*^9}, {3.8067912973038373`*^9, 
  3.8067912980539627`*^9}},
 CellLabel->
  "In[343]:=",ExpressionUUID->"97a2aaff-8b6f-4bc3-b744-39d4f05435f7"],

Cell[BoxData["3.648093572431588`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.8048588472798543`*^9, 3.8048588903332553`*^9, 
   3.8048596669662247`*^9, 3.8048597533854685`*^9, 3.8048599675155373`*^9, 
   3.8048601145432453`*^9, 3.8048603838622866`*^9, 3.8048605408956027`*^9, 
   3.804860672829114*^9, 3.804861492438445*^9, 3.8048659527953568`*^9, 
   3.8048662765128403`*^9, 3.8048664471032095`*^9, 3.804867253539048*^9, 
   3.804881193738809*^9, 3.804895272128127*^9, 3.8048961515777006`*^9, 
   3.8048969491279335`*^9, 3.8050220360396776`*^9, 3.805023529474801*^9, 
   3.805023689902499*^9, 3.805023853342844*^9, 3.805025228267862*^9, 
   3.8056381044928074`*^9, 3.8056382007608705`*^9, 3.805638624431469*^9, 
   3.8056408887682347`*^9, 3.805641074241867*^9, 3.8056658361017256`*^9, 
   3.806791375528965*^9, 3.8068326403864136`*^9, 3.8068333643155212`*^9, 
   3.8068340654958363`*^9, 3.8068343730183163`*^9, 3.8068347651879053`*^9, 
   3.806835142851904*^9, 3.8068354470494146`*^9, 3.806835573226117*^9, 
   3.806836461006612*^9, 3.8068365102441096`*^9, 3.806836820457492*^9, 
   3.8068391201022453`*^9, 3.8068396700679517`*^9, 3.807650437474702*^9, 
   3.8076509682352715`*^9, 3.8076513979909782`*^9, 3.810037660520263*^9, 
   3.8124696458049192`*^9, 3.81246991654247*^9, 3.8126712418252883`*^9, 
   3.812801925819693*^9, 3.812802330538694*^9, 3.812802381133071*^9, 
   3.812927734629951*^9, 3.812928130672761*^9, 3.81292851335962*^9, 
   3.812975700194028*^9, 3.812976102666047*^9, 3.8154770438901615`*^9, 
   3.8157750125093813`*^9, 3.816949328915698*^9, 3.8187759456806507`*^9, 
   3.82005837855503*^9, 3.820358864027722*^9, 3.8252833000552044`*^9, 
   3.825284029780244*^9, 3.8254135458415217`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[343]=",ExpressionUUID->"54cd18dc-9149-49eb-992e-98d85c897ac9"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 
  3.80485427153401*^9}},ExpressionUUID->"65d42bae-b5c3-4483-b02f-\
77a2a2d19e21"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"psdp1", "-", "psdp0"}], ")"}], "100"}], "psdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
   3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
   3.8048586124851284`*^9}, {3.804858750567197*^9, 3.8048587511610384`*^9}, {
   3.805018163895453*^9, 3.8050181639110804`*^9}, 3.805020631092285*^9, {
   3.805022001845244*^9, 3.805022002157792*^9}, {3.8067913023515496`*^9, 
   3.8067913028985157`*^9}},
 CellLabel->
  "In[344]:=",ExpressionUUID->"ec89fe8d-c64b-4802-9fa0-5fda4fec5080"],

Cell[BoxData["1.8555199601989543`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.804858847436088*^9, 3.8048588904739017`*^9, 
   3.8048596671068783`*^9, 3.804859753526121*^9, 3.804859967671815*^9, 
   3.804860114699522*^9, 3.80486038403419*^9, 3.8048605410518775`*^9, 
   3.8048606730010166`*^9, 3.8048614925478373`*^9, 3.80486595290475*^9, 
   3.804866276622233*^9, 3.8048664472126026`*^9, 3.8048672536484404`*^9, 
   3.8048811938325744`*^9, 3.8048952722375216`*^9, 3.804896151687093*^9, 
   3.8048969492373266`*^9, 3.8050220362115784`*^9, 3.8050235331784983`*^9, 
   3.805023690074402*^9, 3.805023853499117*^9, 3.8050252284397664`*^9, 
   3.80563810466471*^9, 3.805638200932774*^9, 3.80563862465195*^9, 
   3.805640889080476*^9, 3.805641074507535*^9, 3.805665836312825*^9, 
   3.8067913757008705`*^9, 3.806832640573945*^9, 3.806833364487425*^9, 
   3.8068340656521125`*^9, 3.806834373190221*^9, 3.806834765383057*^9, 
   3.806835143023766*^9, 3.8068354472235785`*^9, 3.8068355733980207`*^9, 
   3.8068364611785154`*^9, 3.806836510431641*^9, 3.8068368206293945`*^9, 
   3.806839120284373*^9, 3.8068396702430887`*^9, 3.8076504376466184`*^9, 
   3.807650968407175*^9, 3.807651398162917*^9, 3.810037660702405*^9, 
   3.8124696459710197`*^9, 3.812469916714605*^9, 3.812671241996446*^9, 
   3.8128019259898267`*^9, 3.812802330720837*^9, 3.8128023813132105`*^9, 
   3.812927734813094*^9, 3.812928130864911*^9, 3.8129285135387735`*^9, 
   3.812975700397186*^9, 3.8129761028848324`*^9, 3.8154770440933137`*^9, 
   3.815775012729556*^9, 3.8169493289308577`*^9, 3.818775945696664*^9, 
   3.8200583787381744`*^9, 3.8203588642118673`*^9, 3.825283300264372*^9, 
   3.825284030002383*^9, 3.825413546061715*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[344]=",ExpressionUUID->"c2bdec5d-99ee-40df-9c35-ad169946a545"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
   3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
   3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
   3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
   3.804854255481004*^9, 3.8048542778511686`*^9}, 3.806766296296654*^9, 
   3.8067664460027585`*^9},ExpressionUUID->"9d2d41d9-d662-4692-b0f9-\
275af69086a3"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qsdp1", "-", "qsdp0"}], ")"}], "100"}], "qsdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}, {
  3.8048587995680304`*^9, 3.8048588001931267`*^9}, {3.8050174161743164`*^9, 
  3.8050174161743164`*^9}, {3.805021931896407*^9, 3.805021932052683*^9}, {
  3.8050220023296947`*^9, 3.805022002689125*^9}, {3.806791306624547*^9, 
  3.8067913073277874`*^9}},
 CellLabel->
  "In[345]:=",ExpressionUUID->"c68f8a88-0d37-4eca-8a0f-53c6953ed701"],

Cell[BoxData["3.5937835508166733`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.8048588475923624`*^9, 3.8048588906145487`*^9, 
   3.8048596672475457`*^9, 3.8048597536824007`*^9, 3.8048599678124647`*^9, 
   3.8048601148557987`*^9, 3.8048603841904664`*^9, 3.804860541192525*^9, 
   3.804860673141664*^9, 3.80486149265723*^9, 3.804865953014142*^9, 
   3.8048662767316256`*^9, 3.8048664473219957`*^9, 3.804867253757833*^9, 
   3.8048811939419665`*^9, 3.804895272346916*^9, 3.8048961517964897`*^9, 
   3.804896949346719*^9, 3.8050220363991084`*^9, 3.8050235340536337`*^9, 
   3.805023690246303*^9, 3.805023853639764*^9, 3.8050252286272993`*^9, 
   3.805638104820986*^9, 3.805638201089049*^9, 3.8056386248238406`*^9, 
   3.805640889450761*^9, 3.805641074710693*^9, 3.8056658365069833`*^9, 
   3.8067913758415174`*^9, 3.806832640730221*^9, 3.8068333646593285`*^9, 
   3.8068340658240166`*^9, 3.8068343733308687`*^9, 3.806834765550187*^9, 
   3.806835143195668*^9, 3.806835447395483*^9, 3.8068355735699244`*^9, 
   3.806836461350419*^9, 3.8068365106816826`*^9, 3.806836820801302*^9, 
   3.8068391204607935`*^9, 3.806839670420227*^9, 3.807650437818507*^9, 
   3.807650968563452*^9, 3.807651398334786*^9, 3.8100376608665323`*^9, 
   3.812469646135148*^9, 3.8124699168917437`*^9, 3.8126712421695576`*^9, 
   3.8128019261579585`*^9, 3.812802330922042*^9, 3.8128023814893475`*^9, 
   3.812927735005291*^9, 3.8129281310540595`*^9, 3.8129285137309465`*^9, 
   3.8129757006003437`*^9, 3.8129761031173267`*^9, 3.8154770443121*^9, 
   3.8157750129507256`*^9, 3.81694932894687*^9, 3.8187759457116756`*^9, 
   3.820058378923319*^9, 3.8203588643960133`*^9, 3.8252833005336514`*^9, 
   3.8252840302246075`*^9, 3.8254135462868547`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[345]=",ExpressionUUID->"f48469c9-c581-4a50-b5f7-c4d34ad5e887"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.805638279440954*^9}, 3.806766499658245*^9, {3.8252838183538227`*^9, 
   3.825283821073922*^9}},ExpressionUUID->"3a1d09b7-e021-4be5-9440-\
183f46789866"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmasu"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"psdu1", " ", 
     RowBox[{"(", 
      RowBox[{"qsdu1", "-", "qsdue0", "-", 
       RowBox[{"cr", " ", "qsdp1"}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"psdu0", " ", 
     RowBox[{"(", 
      RowBox[{"qsdu0", "-", "qsdue0", "-", 
       RowBox[{"cr", " ", "qsdp0"}]}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.8056384216076107`*^9, 3.8056384298283195`*^9}, {3.805638482271556*^9, 
  3.805638484475052*^9}, {3.8056385728292103`*^9, 3.805638582553885*^9}, {
  3.805641139929985*^9, 3.8056411496359625`*^9}, {3.806791326776063*^9, 
  3.806791349982044*^9}, {3.8068350380292435`*^9, 3.80683506059543*^9}, {
  3.8128035786253977`*^9, 3.812803581596712*^9}, {3.8252838251210685`*^9, 
  3.8252838289541073`*^9}},
 CellLabel->
  "In[346]:=",ExpressionUUID->"f13aef5f-971b-4fd5-973c-dd47a644d343"],

Cell[BoxData["2.6529009346656566`*^6"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBGKdmLfm66PeOE5r3+i6G0hveyd460HMG0eb+yYMX4H0
hrKNUSB60/2wTSDa5NGxGyB6xt6znN+AtM6Es3ogWvwIkyWI/ryCPR5EG9hd
yAPRUi0n7oLoOYGfH4PonKXbuL4D6boYEa0fQJpN73IeiM423B/QEvfGUaRD
YjKIPrHt/AkQHfBz4WfB5DeOzc0nC7emv3F88mvhZBD9osv7oXjGG8dXG05t
CAfSvanJj0E0x7qtL0H0fN7nclOB9ItrGQEg+mmGbQOI9jOb1bUGSJ8482oP
iHaqnfCsMPeN45n8pSnMeW8c1+2XO+VQAHSXo/nGPcVvHKVNUx7qlb1xdGkQ
mnUQSIeaz5BRa3jj2Gd9rhxEf58YuDUVSAMA/UKx0A==
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[346]=",ExpressionUUID->"ae41c65d-ee60-4d52-aab0-7f31406d2bb3"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.8056382995792217`*^9}, 3.8067665212880273`*^9, {3.806791328885791*^9, 
   3.8067913448405657`*^9}, {3.8252838121780415`*^9, 
   3.8252838159979744`*^9}},ExpressionUUID->"94b7fb62-ff27-41b0-b6cf-\
9ff2d7401e61"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmasp"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"psdp1", " ", 
     RowBox[{"(", 
      RowBox[{"qsdp1", "-", "qsdpe0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"psdp0", " ", 
     RowBox[{"(", 
      RowBox[{"qsdp0", "-", "qsdpe0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.805638311659393*^9, 3.805638322630473*^9}, {3.805638433988842*^9, 
  3.8056384793310328`*^9}, {3.805638585596484*^9, 3.8056385956233883`*^9}, {
  3.805641132394824*^9, 3.805641135817252*^9}, {3.806791330555209*^9, 
  3.8067913326024265`*^9}, {3.812803500646705*^9, 3.8128035331450024`*^9}, {
  3.812803660533145*^9, 3.812803671381589*^9}, {3.8252838319194*^9, 
  3.8252838364278836`*^9}},
 CellLabel->
  "In[347]:=",ExpressionUUID->"c3180513-ab60-4ec9-8f7d-e65b660c3a99"],

Cell[BoxData["3.9614232109590024`*^6"], "Output",
 CellChangeTimes->{
  3.8056382863724117`*^9, 3.805638323678563*^9, {3.805638445362606*^9, 
   3.8056384571096716`*^9}, 3.8056386259021473`*^9, 3.805640891530364*^9, 
   3.805641076054661*^9, 3.8056411369424357`*^9, 3.8056658377454967`*^9, 
   3.806791376779174*^9, 3.806832641808526*^9, 3.8068333657176375`*^9, 
   3.806834066886694*^9, 3.806834374371389*^9, 3.8068347665856695`*^9, 
   3.806835144258343*^9, 3.806835448380022*^9, 3.8068355746794853`*^9, 
   3.806836462453657*^9, 3.8068365117599883`*^9, 3.8068368218795953`*^9, 
   3.8068391208524585`*^9, 3.8068396707785215`*^9, 3.8076504381935673`*^9, 
   3.8076509689385147`*^9, 3.8076513987098484`*^9, 3.8100376612248106`*^9, 
   3.8124696464624043`*^9, 3.812469917237014*^9, 3.8126712425358424`*^9, 
   3.812801926503229*^9, 3.812802331296314*^9, 3.8128023818526297`*^9, {
   3.8128035153391447`*^9, 3.812803535571888*^9}, 3.8128036728737483`*^9, 
   3.8129277354265747`*^9, 3.812928131469402*^9, 3.8129285140991945`*^9, 
   3.812975701022287*^9, 3.8129761035453243`*^9, 3.8154770447184176`*^9, 
   3.815775013646269*^9, 3.816949328994908*^9, 3.8187759457577147`*^9, 
   3.8200583794987707`*^9, 3.82035886492643*^9, 3.825283301197117*^9, 
   3.8252840307029357`*^9, 3.825413546962392*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[347]=",ExpressionUUID->"e4ac51ae-7dfa-4d03-b85a-24107eb3dda6"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"db4d22e8-f123-44d4-bff8-\
821aad05b9af"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pstu1", "-", "pstu0"}], ")"}], "100"}], "pstu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
   3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
   3.8048586228946285`*^9}, {3.804858751489214*^9, 3.8048587520986824`*^9}, {
   3.805018113403982*^9, 3.8050181134196095`*^9}, 3.80502029645166*^9, {
   3.805022002845399*^9, 3.8050220032048297`*^9}, {3.806791310305574*^9, 
   3.8067913110556993`*^9}},
 CellLabel->
  "In[348]:=",ExpressionUUID->"7b735c7b-feec-43a8-8952-9518e3c43679"],

Cell[BoxData["6.283137622429074`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.8048588477330093`*^9, 3.8048588907551947`*^9, 
   3.8048596674038343`*^9, 3.804859753823053*^9, 3.8048599679531155`*^9, 
   3.804860114996448*^9, 3.8048603843467426`*^9, 3.8048605413487997`*^9, 
   3.804860673297939*^9, 3.8048614927666225`*^9, 3.8048659531235347`*^9, 
   3.8048662768410177`*^9, 3.804866447431389*^9, 3.804867253867225*^9, 
   3.804881194051359*^9, 3.804895272440683*^9, 3.804896151905878*^9, 
   3.804896949456112*^9, 3.8050220365710096`*^9, 3.8050235376791954`*^9, 
   3.8050236904025784`*^9, 3.8050238537980585`*^9, 3.805025228799204*^9, 
   3.8056381049772606`*^9, 3.805638201323462*^9, 3.8056386249957447`*^9, 
   3.805640889845065*^9, 3.805641074913851*^9, 3.805665836704134*^9, 
   3.8067913759665384`*^9, 3.8068326409021254`*^9, 3.806833364831233*^9, 
   3.8068340659802923`*^9, 3.806834373487193*^9, 3.806834765696938*^9, 
   3.8068351433519435`*^9, 3.8068354475674105`*^9, 3.8068355738043437`*^9, 
   3.8068364615066953`*^9, 3.806836510853586*^9, 3.806836820988827*^9, 
   3.806839121025593*^9, 3.8068396709586487`*^9, 3.8076504383498435`*^9, 
   3.807650969110418*^9, 3.8076513988817525`*^9, 3.8100376613899384`*^9, 
   3.812469646628535*^9, 3.812469917406146*^9, 3.8126712427099776`*^9, 
   3.812801926670359*^9, 3.8128023315105033`*^9, 3.812802382028767*^9, 
   3.8129277356497498`*^9, 3.8129281316625338`*^9, 3.8129285142843385`*^9, 
   3.8129757012567005`*^9, 3.812976103764141*^9, 3.815477044921576*^9, 
   3.815775013868516*^9, 3.8169493290190763`*^9, 3.8187759457757263`*^9, 
   3.820058379682915*^9, 3.8203588650845547`*^9, 3.825283301416273*^9, 
   3.82528403092113*^9, 3.825413547245635*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[348]=",ExpressionUUID->"8ec64b2a-5be0-41c3-b938-b9ddc23aecdd"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
   3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
   3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
   3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
   3.8048542553403563`*^9, 3.8048542677330275`*^9}, 3.806766296296654*^9, 
   3.8067664460183263`*^9},ExpressionUUID->"4a4ee525-f758-4e09-8791-\
db558dedf73d"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qstu1", "-", "qstu0"}], ")"}], "100"}], "qstu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.804858800630694*^9, 3.8048588012870445`*^9}, {3.8050174723410645`*^9, 
  3.8050174723410645`*^9}, {3.805021936100234*^9, 3.8050219362096276`*^9}, {
  3.8050220033611035`*^9, 3.8050220037373953`*^9}, {3.8067913141964664`*^9, 
  3.8067913149622197`*^9}},
 CellLabel->
  "In[349]:=",ExpressionUUID->"573d1fcc-bc54-41d7-b61c-dd7a0174e352"],

Cell[BoxData[
 RowBox[{"-", "9.266520096722`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588478736553`*^9, 3.8048588909114695`*^9, 
   3.8048596675600967`*^9, 3.804859753963705*^9, 3.804859968109393*^9, 
   3.804860115168353*^9, 3.8048603844873915`*^9, 3.8048605415207024`*^9, 
   3.8048606734385867`*^9, 3.8048614928760147`*^9, 3.804865953232927*^9, 
   3.8048662769660378`*^9, 3.8048664475407825`*^9, 3.804867253961108*^9, 
   3.8048811941607513`*^9, 3.804895272550078*^9, 3.8048961520152717`*^9, 
   3.804896949565504*^9, 3.8050220367429113`*^9, 3.8050235381636443`*^9, 
   3.8050236905744786`*^9, 3.8050238539344997`*^9, 3.8050252289867373`*^9, 
   3.8056381051335363`*^9, 3.8056382014953647`*^9, 3.805638625183276*^9, 
   3.805640890159307*^9, 3.8056410751170087`*^9, 3.80566583690129*^9, 
   3.806791376107187*^9, 3.806832641089656*^9, 3.8068333649719067`*^9, 
   3.806834066183451*^9, 3.806834373659048*^9, 3.8068347658688407`*^9, 
   3.806835143570729*^9, 3.8068354477236624`*^9, 3.80683557399187*^9, 
   3.8068364616785994`*^9, 3.8068365110254908`*^9, 3.8068368211763573`*^9, 
   3.806839121186432*^9, 3.8068396711908307`*^9, 3.807650438521747*^9, 
   3.8076509692666936`*^9, 3.8076513990536566`*^9, 3.810037661557068*^9, 
   3.812469646806675*^9, 3.8124699175752773`*^9, 3.8126712428791094`*^9, 
   3.812801926842493*^9, 3.8128023317366276`*^9, 3.8128023822069063`*^9, 
   3.812927735851907*^9, 3.8129281318526816`*^9, 3.81292851446352*^9, 
   3.812975701459859*^9, 3.8129761039945097`*^9, 3.8154770451403613`*^9, 
   3.8157750140876513`*^9, 3.8169493290350885`*^9, 3.818775945791738*^9, 
   3.820058379871063*^9, 3.8203588652787066`*^9, 3.8252833016794796`*^9, 
   3.825284031133263*^9, 3.8254135474707923`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[349]=",ExpressionUUID->"e924dab0-53c1-47b3-ba0b-1bc989ce473b"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"d0b7c15b-ffd6-480e-aaae-\
f85490456529"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pstp1", "-", "pstp0"}], ")"}], "100"}], "pstp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
   3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
   3.804858633427496*^9}, {3.804858752504995*^9, 3.804858754192754*^9}, {
   3.8050182855042944`*^9, 3.8050182855042944`*^9}, 3.8050206707402067`*^9, {
   3.805022004034316*^9, 3.805022004518766*^9}, {3.806791318155949*^9, 
   3.806791318946712*^9}},
 CellLabel->
  "In[350]:=",ExpressionUUID->"fdb2e803-a85d-4f0e-8038-c45ff26d0bf6"],

Cell[BoxData["8.754364219102474`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.8048588480143023`*^9, 3.8048588910677433`*^9, 3.8048596677007504`*^9, 
   3.8048597541199846`*^9, 3.804859968250043*^9, 3.804860115309002*^9, 
   3.8048603846436667`*^9, 3.804860541708233*^9, 3.804860673594861*^9, 
   3.804861492985408*^9, 3.804865953357947*^9, 3.8048662770754304`*^9, 
   3.804866447650175*^9, 3.804867254086011*^9, 3.8048811942701445`*^9, 
   3.8048952726594725`*^9, 3.8048961521246634`*^9, 3.8048969496748967`*^9, 
   3.8050220369148164`*^9, 3.80502354188297*^9, 3.80502369074638*^9, 
   3.8050238541532726`*^9, 3.805025229158642*^9, 3.805638105305439*^9, 
   3.805638201667282*^9, 3.80563862535518*^9, 3.805640890476551*^9, 
   3.8056410753201666`*^9, 3.805665837150487*^9, 3.8067913762478356`*^9, 
   3.8068326412615604`*^9, 3.806833365190668*^9, 3.80683406638662*^9, 
   3.8068343738835382`*^9, 3.8068347660563707`*^9, 3.806835143727004*^9, 
   3.806835447879938*^9, 3.8068355741637745`*^9, 3.8068364619286413`*^9, 
   3.8068365112599044`*^9, 3.806836821363888*^9, 3.806839121372651*^9, 
   3.8068396713679695`*^9, 3.8076504386936507`*^9, 3.8076509694385977`*^9, 
   3.80765139922556*^9, 3.810037661733205*^9, 3.8124696469758067`*^9, 
   3.8124699177494125`*^9, 3.812671243051243*^9, 3.812801927013626*^9, 
   3.812802331970809*^9, 3.812802382382044*^9, 3.812927736047058*^9, 
   3.812928132048834*^9, 3.8129285146486216`*^9, 3.8129757016630163`*^9, 
   3.812976104207675*^9, 3.8154770453278913`*^9, 3.815775014309807*^9, 
   3.816949329050101*^9, 3.8187759458067503`*^9, 3.820058380054207*^9, 
   3.8203588654678555`*^9, 3.8252833019027023`*^9, 3.825284031353443*^9, 
   3.8254135476999993`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[350]=",ExpressionUUID->"765d4eb4-ca55-4159-ada2-838365b8fece"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, 
   3.8067662963122816`*^9, 
   3.8067664460183263`*^9},ExpressionUUID->"041c5226-fdfa-4c79-81a8-\
519a191d2372"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qstp1", "-", "qstp0"}], ")"}], "100"}], "qstp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.804858801740239*^9, 3.8048588038343105`*^9}, {3.805017523503875*^9, 
  3.805017523503875*^9}, {3.8050219403353195`*^9, 3.805021940413457*^9}, {
  3.805022004690667*^9, 3.8050220065659575`*^9}, {3.8067913219916935`*^9, 
  3.806791322788702*^9}},
 CellLabel->
  "In[351]:=",ExpressionUUID->"5f9ee1b1-28df-43c7-a49e-dc5c6e8a2f98"],

Cell[BoxData[
 RowBox[{"-", "12.934518902355313`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.804858848154949*^9, 3.804858891192762*^9, 3.8048596678726606`*^9, 
   3.804859754260637*^9, 3.80485996839496*^9, 3.804860115465279*^9, 
   3.804860384799943*^9, 3.80486054184888*^9, 3.80486067373553*^9, 
   3.80486149309489*^9, 3.804865953482967*^9, 3.804866277169195*^9, 
   3.804866447759568*^9, 3.804867254195405*^9, 3.8048811943795366`*^9, 
   3.804895272768914*^9, 3.8048961522340565`*^9, 3.8048969497842894`*^9, 
   3.8050220371335964`*^9, 3.8050235423517923`*^9, 3.805023690980791*^9, 
   3.8050238543227386`*^9, 3.805025229393057*^9, 3.8056381055242243`*^9, 
   3.8056382018079295`*^9, 3.8056386255270844`*^9, 3.805640890791795*^9, 
   3.80564107561709*^9, 3.8056658373486643`*^9, 3.8067913764197397`*^9, 
   3.8068326414803467`*^9, 3.806833365373884*^9, 3.806834066558514*^9, 
   3.806834374048668*^9, 3.8068347662262363`*^9, 3.8068351438989067`*^9, 
   3.80683544806747*^9, 3.806835574335678*^9, 3.8068364621005445`*^9, 
   3.8068365114318085`*^9, 3.8068368215357904`*^9, 3.806839121544381*^9, 
   3.8068396715411043`*^9, 3.807650438865555*^9, 3.8076509696105013`*^9, 
   3.807651399381837*^9, 3.8100376618993473`*^9, 3.8124696471429377`*^9, 
   3.8124699179285517`*^9, 3.8126712432293816`*^9, 3.8128019271887617`*^9, 
   3.812802332162958*^9, 3.812802382555179*^9, 3.8129277362342033`*^9, 
   3.812928132254994*^9, 3.812928514846793*^9, 3.8129757018661747`*^9, 
   3.812976104425845*^9, 3.8154770455310497`*^9, 3.8157750145429783`*^9, 
   3.8169493290661135`*^9, 3.8187759458227625`*^9, 3.820058380265373*^9, 
   3.8203588656540017`*^9, 3.825283302123829*^9, 3.825284031572605*^9, 
   3.8254135479631634`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[351]=",ExpressionUUID->"002c9f7d-a4a3-4aeb-bdcb-160c9c3b58c7"]
}, Open  ]],

Cell[TextData[StyleBox["Price Indexes",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
  3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
  3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
  3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
  3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
  3.8048584943088517`*^9}, {3.804858674828244*^9, 
  3.8048586889112*^9}},ExpressionUUID->"13815c13-7ce0-400f-bac6-d5bef354e17d"],

Cell["Percent change in unprocessed price index", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998489833914266`*^9, 3.79984901086983*^9}, {3.7998491773192368`*^9, 
   3.79984917888201*^9}, {3.7998492779954705`*^9, 3.799849344403957*^9}, {
   3.799855217193923*^9, 3.7998552176158657`*^9}, 3.804345400385578*^9, {
   3.8043488808930616`*^9, 3.8043489145962877`*^9}, {3.8048542237212534`*^9, 
   3.8048542237212534`*^9}, {3.8048542553091016`*^9, 
   3.8048542553091016`*^9}},ExpressionUUID->"8d6f960c-cea6-4ac7-9d42-\
3184797329a6"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Pu1", "-", "Pu0"}], ")"}], "100"}], "Pu0"]], "Input",
 CellChangeTimes->{{3.79984918480492*^9, 3.799849273791636*^9}, {
  3.7998552126150475`*^9, 3.7998552128807173`*^9}, {3.8017816587699327`*^9, 
  3.8017816805942984`*^9}, {3.804345394438952*^9, 3.8043453971470623`*^9}, {
  3.804348884814114*^9, 3.804348889233554*^9}},
 CellLabel->
  "In[352]:=",ExpressionUUID->"4be7ba51-cceb-4e00-9209-e3ee85fa7c30"],

Cell[BoxData["6.102580701316423`"], "Output",
 CellChangeTimes->{
  3.7998492746667833`*^9, 3.7998495923806477`*^9, 3.7998508747820983`*^9, 
   3.7998510932094183`*^9, 3.7998552215383844`*^9, 3.7998552591406136`*^9, 
   3.799856732964707*^9, 3.7998567782777624`*^9, 3.799857195292985*^9, {
   3.79985741126893*^9, 3.799857481157101*^9}, 3.7998575225746374`*^9, {
   3.799857623596133*^9, 3.799857665541498*^9}, 3.7998577599781284`*^9, {
   3.8016608497619348`*^9, 3.801660862874851*^9}, 3.801662764470834*^9, 
   3.8016634678095245`*^9, 3.8016642628400764`*^9, {3.801664312666783*^9, 
   3.8016643351216216`*^9}, 3.801664460338441*^9, {3.8016653833153267`*^9, 
   3.8016653970378222`*^9}, 3.8016654290440674`*^9, {3.801666723097561*^9, 
   3.8016667511780653`*^9}, 3.8016667864140167`*^9, {3.801666960325522*^9, 
   3.8016669841279755`*^9}, 3.801667113594228*^9, 3.8016672275438757`*^9, 
   3.8016673978818293`*^9, 3.8016675839057274`*^9, {3.8016678479599924`*^9, 
   3.8016678631653695`*^9}, 3.8016679342935286`*^9, {3.801668183552487*^9, 
   3.8016682040499134`*^9}, {3.801668269038266*^9, 3.8016682954359474`*^9}, {
   3.801668345072152*^9, 3.801668369796582*^9}, 3.801668420866907*^9, 
   3.8016684524994974`*^9, 3.801668487394171*^9, 3.801668541287839*^9, 
   3.801692587562277*^9, 3.80169264102909*^9, 3.8016927462307262`*^9, 
   3.8016929523093896`*^9, 3.8016932298288126`*^9, 3.801693287020975*^9, 
   3.8016933968966064`*^9, 3.801693489102943*^9, 3.801776983907366*^9, 
   3.8017772015105257`*^9, 3.801777273900032*^9, 3.8017776517080097`*^9, 
   3.8017780057445364`*^9, 3.801778074046605*^9, 3.8017783131783795`*^9, 
   3.8017783439221983`*^9, 3.8017786553876815`*^9, 3.801779138145771*^9, 
   3.8017792488796043`*^9, 3.801779506310661*^9, 3.8017795492418423`*^9, 
   3.8017796217887506`*^9, 3.801779709371714*^9, 3.801779817116694*^9, 
   3.8017798533916473`*^9, 3.801779899000266*^9, {3.8017799405079165`*^9, 
   3.801779967450033*^9}, 3.8017802560183163`*^9, 3.801780306746418*^9, 
   3.801780344211422*^9, {3.8017804439702563`*^9, 3.8017804721700673`*^9}, 
   3.8017805409035826`*^9, 3.8017805802003374`*^9, 3.8017806656129417`*^9, 
   3.8017811762878675`*^9, 3.801781222587922*^9, 3.801781688096794*^9, {
   3.8017819978231897`*^9, 3.801782035287342*^9}, 3.8017820890438232`*^9, {
   3.8017822319383073`*^9, 3.8017822491911564`*^9}, 3.8030750870008593`*^9, 
   3.8030751540073695`*^9, 3.803075259202407*^9, 3.8030754034217415`*^9, 
   3.8030755054493756`*^9, 3.8031139645613594`*^9, 3.803114084480019*^9, 
   3.8031141469538784`*^9, 3.803114191096325*^9, 3.803114297645469*^9, 
   3.803114393611354*^9, 3.8031185696297293`*^9, 3.803118638170224*^9, 
   3.803118702047079*^9, {3.8031187473594465`*^9, 3.803118769043373*^9}, 
   3.80311880845013*^9, 3.8031205934932847`*^9, 3.803120630774397*^9, 
   3.8031244174185233`*^9, 3.8031245169131594`*^9, 3.8031249102831197`*^9, 
   3.803124991509452*^9, 3.803125759075655*^9, 3.803126253346963*^9, 
   3.803128483130848*^9, 3.8031286690979834`*^9, 3.8032924987962933`*^9, 
   3.803303084561537*^9, 3.8033032747697845`*^9, 3.8033104115209475`*^9, 
   3.803312901030964*^9, 3.803313231275567*^9, 3.803391647600006*^9, 
   3.803392062973687*^9, 3.8033921283218317`*^9, 3.803392520065557*^9, 
   3.8033926306852746`*^9, 3.8033944589630575`*^9, 3.8033947991320267`*^9, 
   3.803394914026799*^9, 3.803397326004096*^9, 3.8033974445483875`*^9, 
   3.8033980677407513`*^9, 3.8033984374911313`*^9, 3.803398591318152*^9, 
   3.8035096208316846`*^9, 3.8035103296726255`*^9, 3.803511721217949*^9, 
   3.803512180748121*^9, 3.804345496959716*^9, 3.804345535141422*^9, 
   3.8043455688236265`*^9, 3.8043459771150684`*^9, 3.804346900651185*^9, 
   3.804347743976942*^9, {3.8043478447983723`*^9, 3.8043478587622347`*^9}, 
   3.8043478907551184`*^9, 3.8043479285926*^9, {3.8043482361294065`*^9, 
   3.804348258143536*^9}, 3.804348936898817*^9, 3.804349006147746*^9, 
   3.8043490998016157`*^9, 3.8045199879901805`*^9, 3.804520290649263*^9, 
   3.8045204189345813`*^9, 3.8045205647204466`*^9, 3.804521041946695*^9, 
   3.8045210804643292`*^9, 3.8045211595556393`*^9, 3.8045213929101944`*^9, 
   3.8045214710169363`*^9, 3.8045458082556286`*^9, 3.8045458827903852`*^9, 
   3.804546096639233*^9, 3.8045461955027046`*^9, 3.8045873500938845`*^9, 
   3.804590445246277*^9, 3.80459171067251*^9, 3.8045918182908363`*^9, 
   3.804858848295595*^9, 3.8048588913334084`*^9, 3.8048596680133142`*^9, 
   3.804859754401289*^9, 3.80485996853561*^9, 3.8048601156215563`*^9, 
   3.8048603849562187`*^9, 3.804860542005155*^9, 3.8048606738917837`*^9, 
   3.804861493206768*^9, 3.8048659536079865`*^9, 3.8048662772785873`*^9, 
   3.804866447868962*^9, 3.8048672543047976`*^9, 3.8048811944889293`*^9, 
   3.8048952728938904`*^9, 3.8048961523434486`*^9, 3.804896949893682*^9, 
   3.805022037321126*^9, 3.8050235460867453`*^9, 3.8050236911526933`*^9, 
   3.8050238544790134`*^9, 3.8050252295805902`*^9, 3.805638105696127*^9, 
   3.805638201964205*^9, 3.805638626074051*^9, 3.805640895737607*^9, 
   3.805641078336277*^9, 3.8056658400271454`*^9, 3.806791376951078*^9, 
   3.8068326419804306`*^9, 3.806833365858286*^9, 3.8068340670429707`*^9, 
   3.806834374551753*^9, 3.806834766757572*^9, 3.8068351444302425`*^9, 
   3.806835448536298*^9, 3.806835574905506*^9, 3.8068364626255608`*^9, 
   3.8068365119318924`*^9, 3.8068368220358706`*^9, 3.806839121712882*^9, 
   3.806839671713239*^9, 3.8076504390218306`*^9, 3.8076509698136606`*^9, 
   3.80765139955374*^9, 3.810037662103492*^9, 3.8124696473110685`*^9, 
   3.8124699180966825`*^9, 3.8126712434085217`*^9, 3.8128019273719044`*^9, 
   3.8128023323450994`*^9, 3.812802382737322*^9, 3.8129277364153447`*^9, 
   3.8129281324541616`*^9, 3.8129285150369234`*^9, 3.812975702069332*^9, 
   3.81297610463701*^9, 3.815477045734206*^9, 3.8157750147821817`*^9, 
   3.8169493290811253`*^9, 3.8187759458387756`*^9, 3.820058380451519*^9, 
   3.820358865851156*^9, 3.825283302351015*^9, 3.825284031827801*^9, 
   3.8254135482153945`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[352]=",ExpressionUUID->"13df86d5-d886-4f8f-99a5-a42f72facc36"]
}, Open  ]],

Cell["Percent change in processed price index", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8043489043563223`*^9, 3.80434890819631*^9}, {3.8048542238619013`*^9, 
  3.8048542238619013`*^9}, {3.804854255465377*^9, 
  3.804854255465377*^9}},ExpressionUUID->"c459d460-c983-4424-b98e-\
d057822b1f1b"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Pp1", "-", "Pp0"}], ")"}], "100"}], "Pp0"]], "Input",
 CellLabel->
  "In[353]:=",ExpressionUUID->"ea1630c7-69ec-469b-95ed-58312d9bf06e"],

Cell[BoxData["7.434719424316971`"], "Output",
 CellChangeTimes->{3.8252837937977114`*^9, 3.825284032045985*^9, 
  3.8254135484275446`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[353]=",ExpressionUUID->"08629e73-3982-4877-9f99-43ca95f8a55a"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1025, 959},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 1592, 30, 196, "Title",ExpressionUUID->"859cf04b-9ead-4320-a51d-805da0a25176"],
Cell[2175, 54, 5221, 75, 388, "Text",ExpressionUUID->"63cc22a9-a49e-4abf-8469-ccecf697abef"],
Cell[7399, 131, 225, 4, 28, "Input",ExpressionUUID->"0c777ea8-191a-4659-be18-f91ea0d0ffda"],
Cell[CellGroupData[{
Cell[7649, 139, 404, 7, 62, "Section",ExpressionUUID->"fae1ca55-f007-437e-ac6e-09bb4f78b71c"],
Cell[CellGroupData[{
Cell[8078, 150, 422, 7, 43, "Subsubsection",ExpressionUUID->"5e9f2ce4-0508-477e-8e97-bfee64ddaa0b"],
Cell[8503, 159, 524, 7, 30, "Text",ExpressionUUID->"1cc24e23-68c9-4c30-b4bc-07547c48adec"],
Cell[9030, 168, 986, 16, 34, "Text",ExpressionUUID->"984d5b54-7d64-4b24-8c95-9ec097a13014"],
Cell[10019, 186, 1979, 28, 44, "Input",ExpressionUUID->"8ce1a048-b83e-4f20-84d6-e5ec15b6f8ef"],
Cell[12001, 216, 1034, 17, 34, "Text",ExpressionUUID->"e17014d0-d7b4-41e4-bbc8-7a7418311a44"],
Cell[13038, 235, 2014, 29, 44, "Input",ExpressionUUID->"055efbdb-f3e0-4860-881d-c7aa622d1cfb"],
Cell[15055, 266, 1028, 17, 34, "Text",ExpressionUUID->"8c61d351-d9e2-4fba-ab89-0060bb890ca8"],
Cell[16086, 285, 1933, 28, 44, "Input",ExpressionUUID->"736de165-bccb-4534-80f2-371fc7549bff"],
Cell[18022, 315, 978, 16, 34, "Text",ExpressionUUID->"146e6a6e-dd90-4a0a-ba2f-6b9711acc0f3"],
Cell[19003, 333, 1901, 27, 44, "Input",ExpressionUUID->"68e3b805-5eb8-437a-a7f8-432c5dc38fa6"],
Cell[20907, 362, 1030, 17, 34, "Text",ExpressionUUID->"82f60873-0d07-4667-8aa5-970e73bfbf1b"],
Cell[21940, 381, 1965, 29, 44, "Input",ExpressionUUID->"0d44e1c6-e9d4-484e-888a-97e11d7e3438"],
Cell[23908, 412, 1036, 17, 34, "Text",ExpressionUUID->"df48dec8-a94e-449a-800b-b121ab20ce80"],
Cell[24947, 431, 1966, 29, 44, "Input",ExpressionUUID->"5fa0e8dd-4806-45d0-b98b-4ec2bc340d09"],
Cell[26916, 462, 1028, 17, 34, "Text",ExpressionUUID->"eff427f1-f6ab-421c-9430-5e9eaa7b3495"],
Cell[27947, 481, 1941, 28, 44, "Input",ExpressionUUID->"766ef20f-c865-472e-bc31-e106c6106cf4"],
Cell[29891, 511, 1072, 18, 34, "Text",ExpressionUUID->"33f04322-948b-41d9-8bd5-6a5283201ac3"],
Cell[30966, 531, 1970, 28, 44, "Input",ExpressionUUID->"0a22d713-413c-4a7f-a36c-b4c35ca6976f"],
Cell[32939, 561, 1024, 17, 34, "Text",ExpressionUUID->"4dc55192-c670-4fc5-b72a-5f6cac310279"],
Cell[33966, 580, 1969, 29, 44, "Input",ExpressionUUID->"63e07d97-a9e9-4202-8f45-003b041f85f6"],
Cell[35938, 611, 1078, 18, 34, "Text",ExpressionUUID->"8f3aa904-cf29-4c64-83f9-8766573942e5"],
Cell[37019, 631, 1964, 28, 44, "Input",ExpressionUUID->"8fc80ee2-6195-4576-8637-013ee963321d"],
Cell[38986, 661, 1082, 18, 34, "Text",ExpressionUUID->"db0a87a9-5362-4c57-aa6f-217ca86abc00"],
Cell[40071, 681, 2026, 29, 44, "Input",ExpressionUUID->"8604bae3-115b-49d5-9188-1cc3cda84174"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42134, 715, 400, 7, 43, "Subsubsection",ExpressionUUID->"b7af82b0-2be1-478f-8538-b8dbf8fc18a3"],
Cell[42537, 724, 554, 8, 30, "Text",ExpressionUUID->"842f053b-01ed-4a0d-8c05-eac6c3d988fb"],
Cell[43094, 734, 1172, 21, 33, "Text",ExpressionUUID->"e9e13dfc-4438-4f78-9413-80c7121887df"],
Cell[44269, 757, 1638, 24, 44, "Input",ExpressionUUID->"45be8dc0-b9d4-4d0f-a0da-e6c1cfe04bbc"],
Cell[45910, 783, 1223, 21, 33, "Text",ExpressionUUID->"fed937c8-b7fe-4979-80a5-64730cf0d225"],
Cell[47136, 806, 1589, 23, 44, "Input",ExpressionUUID->"c6d174b2-4072-4602-bf86-ac72813840e5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48762, 834, 494, 7, 43, "Subsubsection",ExpressionUUID->"41c9e23b-2568-4dea-8856-6974855a912e"],
Cell[49259, 843, 510, 7, 30, "Text",ExpressionUUID->"b87fff88-b17b-4707-8439-863bb154da77"],
Cell[49772, 852, 949, 15, 34, "Text",ExpressionUUID->"1c8b2880-5c23-43bc-bda6-8096ea7097e7"],
Cell[50724, 869, 1083, 17, 44, "Input",ExpressionUUID->"06b1b446-6d5d-48a9-a8b1-e6b7ad803bd2"],
Cell[51810, 888, 815, 13, 34, "Text",ExpressionUUID->"4cd24a48-b529-412b-81d7-203f199acd7b"],
Cell[52628, 903, 1082, 17, 44, "Input",ExpressionUUID->"adbd9106-dcde-48fa-9f82-5f26883c8abe"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53747, 925, 541, 8, 43, "Subsubsection",ExpressionUUID->"95d6f91a-87fd-4972-af18-f5878e9f1034"],
Cell[54291, 935, 823, 11, 30, "Text",ExpressionUUID->"9154bae9-d984-49b3-95f6-67334e99da3c"],
Cell[55117, 948, 1157, 19, 34, "Text",ExpressionUUID->"faed53d2-b1b4-4933-ad9a-44bfedb31820"],
Cell[56277, 969, 3157, 45, 44, "Input",ExpressionUUID->"e71883ba-93a1-4219-bd68-67879f88fe63"],
Cell[59437, 1016, 1205, 20, 34, "Text",ExpressionUUID->"a78f82bd-044c-47ec-8070-7fb0ac92002c"],
Cell[60645, 1038, 3151, 45, 44, "Input",ExpressionUUID->"3570a921-8175-4c5b-ac71-ad5fa82485de"],
Cell[63799, 1085, 1149, 19, 34, "Text",ExpressionUUID->"2afef52f-60fe-4a17-8f37-a8537e5a5833"],
Cell[64951, 1106, 3024, 43, 44, "Input",ExpressionUUID->"8084d100-1196-49fa-a6db-fe6657cbfd2a"],
Cell[67978, 1151, 1149, 19, 34, "Text",ExpressionUUID->"f95e3d40-404c-4bdd-acaf-3e0d8fa31c45"],
Cell[69130, 1172, 3093, 44, 44, "Input",ExpressionUUID->"c1974cde-0bee-4337-89d4-4d8be79bede4"],
Cell[72226, 1218, 1149, 19, 34, "Text",ExpressionUUID->"f1a5b7b7-f382-43e1-a711-1236b62de146"],
Cell[73378, 1239, 2995, 42, 44, "Input",ExpressionUUID->"8416828b-6e0d-4043-b421-691ce31c4cb1"],
Cell[76376, 1283, 1153, 19, 34, "Text",ExpressionUUID->"23007b82-697c-4d8e-b7be-e0fc0f90657b"],
Cell[77532, 1304, 3007, 42, 44, "Input",ExpressionUUID->"917179e3-d8df-4f69-a8d3-384801ef2ab8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80576, 1351, 588, 9, 43, "Subsubsection",ExpressionUUID->"60d1625c-38c8-4333-b500-d6f0248de0dc"],
Cell[81167, 1362, 554, 8, 30, "Text",ExpressionUUID->"c218cfaf-f121-46c8-84af-6b36366766ed"],
Cell[81724, 1372, 952, 14, 34, "Text",ExpressionUUID->"e99c9f51-317a-47f6-99b0-d273b0ef4e49"],
Cell[82679, 1388, 2311, 33, 44, "Input",ExpressionUUID->"0e61cea0-3282-45a7-bd8e-9e8e785d69eb"],
Cell[84993, 1423, 951, 14, 34, "Text",ExpressionUUID->"4f913130-b827-4a8a-9386-ea8cf55ed4a5"],
Cell[85947, 1439, 2339, 33, 44, "Input",ExpressionUUID->"daaf0596-c33a-4587-81b3-e028c2d51607"],
Cell[88289, 1474, 948, 14, 34, "Text",ExpressionUUID->"7f94b918-9475-41a9-affc-4976377ce143"],
Cell[89240, 1490, 2311, 33, 44, "Input",ExpressionUUID->"61c0c99e-cd47-4677-a666-19e1cd12c8f5"],
Cell[91554, 1525, 946, 14, 34, "Text",ExpressionUUID->"ad365565-264d-4c4f-a2c6-1799b8ac85b6"],
Cell[92503, 1541, 2339, 33, 44, "Input",ExpressionUUID->"c77200e6-564e-48a4-9d46-75e553d26040"],
Cell[94845, 1576, 998, 15, 34, "Text",ExpressionUUID->"90aec3ec-d5be-42a8-b149-46cf7864dc69"],
Cell[95846, 1593, 2313, 33, 44, "Input",ExpressionUUID->"91ca236f-1de5-4270-b969-bd269e28ac56"],
Cell[98162, 1628, 1003, 15, 34, "Text",ExpressionUUID->"7d438e40-58be-4399-a644-a94a399fb0d8"],
Cell[99168, 1645, 2361, 33, 44, "Input",ExpressionUUID->"3e57279e-e33a-4cae-870a-123d34efdc5f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101566, 1683, 676, 10, 43, "Subsubsection",ExpressionUUID->"cecbba16-d571-4f97-aaa1-2afca9e7ab68"],
Cell[102245, 1695, 595, 9, 30, "Text",ExpressionUUID->"50805045-734f-43fa-a736-3bf97da70c58"],
Cell[102843, 1706, 2466, 35, 44, "Input",ExpressionUUID->"53379da6-b7f9-4200-b622-21275c340c98"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[105358, 1747, 445, 7, 62, "Section",ExpressionUUID->"42640f35-dcc0-471f-8c42-243e4168908f"],
Cell[CellGroupData[{
Cell[105828, 1758, 392, 6, 43, "Subsubsection",ExpressionUUID->"f4fd8f61-0f63-41cb-a668-bbd4ef6d9901"],
Cell[106223, 1766, 745, 11, 48, "Text",ExpressionUUID->"539de5b1-ab7d-4914-adc5-12aa73a8f409"],
Cell[106971, 1779, 572, 9, 34, "Text",ExpressionUUID->"60181d41-91aa-4d8f-85e3-df4f6b94fedb"],
Cell[107546, 1790, 1263, 20, 44, "Input",ExpressionUUID->"4ecde827-d0a5-44ad-8f2a-1ab84264d7b8"],
Cell[108812, 1812, 2050, 32, 47, "Input",ExpressionUUID->"fc8eb168-ab40-4abf-a2f7-a6c4a5fe0448"],
Cell[110865, 1846, 617, 10, 34, "Text",ExpressionUUID->"f3cc00d0-bddc-4634-a1bf-24b3f621029a"],
Cell[111485, 1858, 1249, 20, 44, "Input",ExpressionUUID->"6682d775-94cf-4a53-8c9a-592c4584bd42"],
Cell[112737, 1880, 2001, 31, 47, "Input",ExpressionUUID->"f3e5d568-3d3d-4b18-837d-13bce03e24d6"],
Cell[114741, 1913, 617, 10, 34, "Text",ExpressionUUID->"3b24adc2-24ff-40aa-b60d-0dfc8d6c04d0"],
Cell[115361, 1925, 1265, 20, 44, "Input",ExpressionUUID->"aba9680d-c0d7-4bcf-aed7-0787606061b0"],
Cell[116629, 1947, 2019, 31, 47, "Input",ExpressionUUID->"a81323c0-f581-4d29-94ee-cd5c44c14b81"],
Cell[118651, 1980, 668, 10, 34, "Text",ExpressionUUID->"b21e1c34-a206-4e4a-b34c-7976f272bbd5"],
Cell[119322, 1992, 1296, 20, 44, "Input",ExpressionUUID->"c3fb319a-7734-4450-9427-c60dc29e2cdb"],
Cell[120621, 2014, 2117, 33, 47, "Input",ExpressionUUID->"977552a6-aaf5-4f0f-b57e-a052f10a9db2"],
Cell[122741, 2049, 665, 10, 34, "Text",ExpressionUUID->"d56df26b-671f-4f02-b25c-d14637634741"],
Cell[123409, 2061, 1297, 20, 44, "Input",ExpressionUUID->"1f90fa36-e1a2-4518-ba97-444f0e6e14ef"],
Cell[124709, 2083, 2038, 32, 47, "Input",ExpressionUUID->"39683c2b-cd55-4bab-afc2-f50ad5743fba"],
Cell[126750, 2117, 671, 10, 34, "Text",ExpressionUUID->"3b502147-1b24-4336-86aa-e76f3083ec61"],
Cell[127424, 2129, 1249, 20, 44, "Input",ExpressionUUID->"400c8e39-93cb-4fef-a9fb-41930d195d3f"],
Cell[128676, 2151, 1922, 30, 47, "Input",ExpressionUUID->"cfe43c25-be78-4227-bac0-674e47880d70"]
}, Open  ]],
Cell[CellGroupData[{
Cell[130635, 2186, 459, 8, 43, "Subsubsection",ExpressionUUID->"1435c260-9585-4f19-9653-05d7d7af47d6"],
Cell[131097, 2196, 1085, 15, 120, "Text",ExpressionUUID->"53a3216b-4452-4e14-bf79-1b874933f265"],
Cell[132185, 2213, 861, 13, 34, "Text",ExpressionUUID->"0108ff7c-6b7d-467d-9429-f60e5ce3f0a6"],
Cell[133049, 2228, 1430, 22, 44, "Input",ExpressionUUID->"6561412e-06fd-4c57-ae93-47270a6df98e"],
Cell[134482, 2252, 1469, 24, 47, "Input",ExpressionUUID->"09c8ff30-42fd-4efc-951c-d2cfbedd4dcc"],
Cell[135954, 2278, 860, 13, 34, "Text",ExpressionUUID->"804d554e-5318-41d2-8646-4e9771c33e7b"],
Cell[136817, 2293, 1321, 21, 44, "Input",ExpressionUUID->"abd93098-806c-4525-be8c-4d88e9e76f05"],
Cell[138141, 2316, 1449, 24, 47, "Input",ExpressionUUID->"c11b0971-44f2-457e-a56f-d2e8e07d9df7"],
Cell[139593, 2342, 860, 13, 34, "Text",ExpressionUUID->"bac80548-6326-4b09-91b4-3a8babe0fce9"],
Cell[140456, 2357, 1379, 21, 44, "Input",ExpressionUUID->"99c6e44e-061a-4ff5-961c-12a04ff14f1d"],
Cell[141838, 2380, 1491, 24, 47, "Input",ExpressionUUID->"b2da8702-0316-46b8-9356-5aa032c6c832"],
Cell[143332, 2406, 860, 13, 34, "Text",ExpressionUUID->"a950b809-90de-46b4-ae9e-fe691d7f9539"],
Cell[144195, 2421, 1413, 22, 44, "Input",ExpressionUUID->"afc8f065-ee22-4e37-948b-934b709956c4"],
Cell[145611, 2445, 1523, 25, 47, "Input",ExpressionUUID->"bffbf241-e5a3-4e32-be55-4013deb3732d"],
Cell[147137, 2472, 863, 13, 34, "Text",ExpressionUUID->"053b0852-bae3-47e1-b57a-18605fe9d787"],
Cell[148003, 2487, 1469, 23, 44, "Input",ExpressionUUID->"e1ddfe9a-548c-4dc9-bd0f-2b29fc1ca0ae"],
Cell[149475, 2512, 1490, 24, 47, "Input",ExpressionUUID->"ecb360a1-d972-4160-8e9f-525353ea954d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[151002, 2541, 463, 7, 43, "Subsubsection",ExpressionUUID->"246296ea-0732-4b24-b603-873edc8eb9ee"],
Cell[151468, 2550, 543, 8, 30, "Text",ExpressionUUID->"a9da071a-83af-494b-aca2-ab2517e0dd64"],
Cell[152014, 2560, 771, 12, 34, "Text",ExpressionUUID->"5eeb56a2-8276-438b-b8fc-a60517a10f9e"],
Cell[152788, 2574, 322, 5, 34, "Text",ExpressionUUID->"8e7aaf54-40c3-4c06-968a-bf000fc3683c"],
Cell[153113, 2581, 1642, 28, 44, "Input",ExpressionUUID->"4f31d8a3-142a-4e41-9984-1a88a6f968f4"],
Cell[154758, 2611, 1678, 26, 47, "Input",ExpressionUUID->"3ff847f8-e519-4d22-a466-267ec672c9ff"],
Cell[156439, 2639, 522, 8, 34, "Text",ExpressionUUID->"2bd48578-c6de-4693-a8fb-1fc636f0d55d"],
Cell[156964, 2649, 1604, 27, 44, "Input",ExpressionUUID->"29350a81-3a4a-4b4b-a909-8f3dc67795fb"],
Cell[158571, 2678, 1675, 26, 47, "Input",ExpressionUUID->"6af3a0db-6bd1-4bd8-b13c-06058f2aad81"],
Cell[160249, 2706, 212, 4, 34, "Text",ExpressionUUID->"b7ca48c0-5cea-419f-9ae5-3c8d750f0bd6"],
Cell[160464, 2712, 1628, 29, 44, "Input",ExpressionUUID->"49bbfc31-81e6-46c1-a11b-7bf50613d980"],
Cell[162095, 2743, 1797, 32, 44, "Input",ExpressionUUID->"21327809-8401-4b20-ae5b-310e4df12604"],
Cell[163895, 2777, 818, 12, 34, "Text",ExpressionUUID->"2f760a0f-826a-4c23-88e8-6b62d2ba5e8c"],
Cell[164716, 2791, 322, 5, 34, "Text",ExpressionUUID->"cdd433f1-1d34-4033-b965-883a6fae43a7"],
Cell[165041, 2798, 1612, 27, 44, "Input",ExpressionUUID->"8ccfd944-c19b-49ca-bd97-ae7982c4c14d"],
Cell[166656, 2827, 1592, 25, 47, "Input",ExpressionUUID->"8b465579-3011-4468-9c89-a2f6795256be"],
Cell[168251, 2854, 520, 8, 34, "Text",ExpressionUUID->"3ab41c4f-4d22-4e73-8a63-6f31352d4bfc"],
Cell[168774, 2864, 1576, 27, 44, "Input",ExpressionUUID->"e01165ce-f1d5-466c-bd97-2cfeb5fb52a7"],
Cell[170353, 2893, 1653, 26, 47, "Input",ExpressionUUID->"cf846bbd-4358-4ded-a3bd-51431faf16f0"],
Cell[172009, 2921, 210, 4, 34, "Text",ExpressionUUID->"a3bad53e-8398-4804-bd2d-a6381cb1ab7e"],
Cell[172222, 2927, 1550, 27, 44, "Input",ExpressionUUID->"adf09bb8-ba09-42d4-8fa1-3851ed8f03f8"],
Cell[173775, 2956, 1716, 29, 44, "Input",ExpressionUUID->"eecac173-9bd3-4c06-b1be-e9c182499ee0"],
Cell[175494, 2987, 870, 13, 34, "Text",ExpressionUUID->"1bc0f1be-bf75-4682-932b-da72338a3e6e"],
Cell[176367, 3002, 326, 5, 34, "Text",ExpressionUUID->"19cd8008-9b3e-4577-b387-59d517eea78a"],
Cell[176696, 3009, 1556, 24, 44, "Input",ExpressionUUID->"371d9049-7ce7-40f7-b41b-29c4bc91fb4b"],
Cell[178255, 3035, 1630, 26, 47, "Input",ExpressionUUID->"aac04036-7655-40bb-aad7-1dc7991d1003"],
Cell[179888, 3063, 524, 8, 34, "Text",ExpressionUUID->"68f85e6b-0349-4de7-8ccf-73e47fdd4326"],
Cell[180415, 3073, 1681, 28, 44, "Input",ExpressionUUID->"fc53ee63-8e40-4683-b321-8821e0a01696"],
Cell[182099, 3103, 1694, 26, 47, "Input",ExpressionUUID->"a19c8c06-1203-453b-97b9-81d7697dca09"],
Cell[183796, 3131, 210, 4, 34, "Text",ExpressionUUID->"bf9eb003-68a1-40ef-9c11-7e27d96cb08b"],
Cell[184009, 3137, 1729, 31, 44, "Input",ExpressionUUID->"7d33a6af-ed15-4356-8e81-ee1b51ecb618"],
Cell[185741, 3170, 1834, 33, 44, "Input",ExpressionUUID->"35bf12f1-9497-43a8-93f9-a343c7e57c0a"],
Cell[187578, 3205, 916, 14, 34, "Text",ExpressionUUID->"f13bd789-56a5-4027-a64b-1f93cd848a5b"],
Cell[188497, 3221, 322, 5, 34, "Text",ExpressionUUID->"d36e7e58-d2e2-4fbf-affd-1ae4c276f542"],
Cell[188822, 3228, 1718, 29, 44, "Input",ExpressionUUID->"e3583c1c-0b7d-498c-9dc9-be43612a7e2d"],
Cell[190543, 3259, 1592, 25, 47, "Input",ExpressionUUID->"166a8e37-7c0b-44ee-ae6b-4d2b15981d20"],
Cell[192138, 3286, 519, 8, 34, "Text",ExpressionUUID->"ac13854e-8673-4092-ac2c-66542f673fb3"],
Cell[192660, 3296, 1637, 28, 44, "Input",ExpressionUUID->"aaf62327-53e1-464d-9269-855cd6a8d47e"],
Cell[194300, 3326, 1702, 27, 47, "Input",ExpressionUUID->"830979a0-2024-4f7e-94ef-e6fd5d545f12"],
Cell[196005, 3355, 210, 4, 34, "Text",ExpressionUUID->"250d6782-febc-4d59-9ef9-18f77ed030ef"],
Cell[196218, 3361, 1588, 27, 44, "Input",ExpressionUUID->"d335b394-b7ba-460c-8916-2bfed61ddef4"],
Cell[197809, 3390, 1745, 30, 44, "Input",ExpressionUUID->"5c57897c-e6e0-4547-adec-f264f983fc1c"],
Cell[199557, 3422, 969, 14, 34, "Text",ExpressionUUID->"11f1841d-c81d-474a-b0c1-4e2613574733"],
Cell[200529, 3438, 324, 5, 34, "Text",ExpressionUUID->"01d4ba99-9c2b-4fc4-b629-0f08936288b9"],
Cell[200856, 3445, 1644, 28, 44, "Input",ExpressionUUID->"9e84867b-f9b9-42cf-9eed-4e824f4a1706"],
Cell[202503, 3475, 1623, 26, 47, "Input",ExpressionUUID->"98eaeb8e-715e-43ab-ab2b-514540ca6fbe"],
Cell[204129, 3503, 524, 8, 34, "Text",ExpressionUUID->"e594c0aa-de19-4692-af73-236d36ff1386"],
Cell[204656, 3513, 1640, 28, 44, "Input",ExpressionUUID->"d0c9dc2b-643a-4c85-b86d-881765c9c441"],
Cell[206299, 3543, 1661, 26, 47, "Input",ExpressionUUID->"97a149fc-08a4-4fe9-88c3-c69289bd6ca6"],
Cell[207963, 3571, 210, 4, 34, "Text",ExpressionUUID->"a7964455-aa60-47f3-89b1-2bc13a62ab52"],
Cell[208176, 3577, 1718, 32, 44, "Input",ExpressionUUID->"43dbadf4-e672-4f76-9011-c2105e6d5cee"],
Cell[209897, 3611, 1750, 30, 44, "Input",ExpressionUUID->"deeacab3-4398-4bbd-8b8a-420ec18f72de"],
Cell[211650, 3643, 1022, 15, 34, "Text",ExpressionUUID->"48d7b07e-5cca-4391-ad57-42870fd6ee17"],
Cell[212675, 3660, 324, 5, 34, "Text",ExpressionUUID->"37201b6d-f3ef-4a7f-9a30-f982e4510a3c"],
Cell[213002, 3667, 1595, 27, 44, "Input",ExpressionUUID->"ae10a51e-203c-49fc-b34c-3bab85f2f593"],
Cell[214600, 3696, 1601, 25, 47, "Input",ExpressionUUID->"bbe25b2d-bbf5-45c8-98c1-b268a76c3c79"],
Cell[216204, 3723, 522, 8, 34, "Text",ExpressionUUID->"d9aa3b4d-191b-46e8-b6d9-0c7164d1e004"],
Cell[216729, 3733, 1600, 27, 44, "Input",ExpressionUUID->"9485f714-e9cc-42a5-989a-eec3da2d3d9d"],
Cell[218332, 3762, 1672, 26, 47, "Input",ExpressionUUID->"780be44e-d362-41c6-bc75-eb26841e8c10"],
Cell[220007, 3790, 210, 4, 34, "Text",ExpressionUUID->"b0ccb7c1-d819-4a7e-876e-fe7e5bf532db"],
Cell[220220, 3796, 1586, 27, 44, "Input",ExpressionUUID->"ef17bc6d-a4c5-40a9-85a0-e1e90d4683ba"],
Cell[221809, 3825, 1629, 25, 44, "Input",ExpressionUUID->"5869e936-4b85-417d-9535-9acd134d3627"],
Cell[223441, 3852, 449, 7, 34, "Text",ExpressionUUID->"cd6f868f-52a1-4b7d-bdd8-1e0c25075729"],
Cell[223893, 3861, 836, 13, 28, "Input",ExpressionUUID->"411685ec-4e7e-4e82-ae79-6c9d904a1b83"],
Cell[224732, 3876, 742, 12, 28, "Input",ExpressionUUID->"34e10a13-0897-4126-a042-cb29ac11441b"],
Cell[225477, 3890, 836, 13, 28, "Input",ExpressionUUID->"6db908f8-9ec3-41b6-8085-74a4b5f16e26"],
Cell[226316, 3905, 740, 12, 28, "Input",ExpressionUUID->"47372b87-46e4-4e84-abb6-b4b18d167dd3"],
Cell[227059, 3919, 762, 12, 28, "Input",ExpressionUUID->"5cef1721-b569-43ee-b7b4-73bb1e65ec8f"],
Cell[227824, 3933, 690, 11, 28, "Input",ExpressionUUID->"72241c77-9f0f-489b-8a81-f6b0d3b357f1"],
Cell[228517, 3946, 886, 14, 28, "Input",ExpressionUUID->"7642a00a-7e5c-4224-8711-9ffc11e1be68"],
Cell[229406, 3962, 782, 12, 28, "Input",ExpressionUUID->"912b37a4-b188-4750-8262-c62c624d05cf"],
Cell[230191, 3976, 928, 14, 28, "Input",ExpressionUUID->"b2292b82-0665-4f04-80e1-a2dee86e9765"],
Cell[231122, 3992, 786, 12, 28, "Input",ExpressionUUID->"2f08f5a1-311d-43ce-870b-fb2dfac7f219"],
Cell[231911, 4006, 931, 14, 28, "Input",ExpressionUUID->"b10de096-9726-4741-8e0d-30b85301d56f"],
Cell[232845, 4022, 838, 13, 28, "Input",ExpressionUUID->"fc71cdd8-ff97-488c-8f54-4ec2ef85e7be"]
}, Open  ]],
Cell[CellGroupData[{
Cell[233720, 4040, 473, 7, 43, "Subsubsection",ExpressionUUID->"e6348688-762b-443a-892a-529db277f3c6"],
Cell[234196, 4049, 669, 9, 48, "Text",ExpressionUUID->"454c406c-2e9f-4bb5-aae3-13295ab94eff"],
Cell[234868, 4060, 991, 17, 44, "Input",ExpressionUUID->"d36c758b-7ed8-4713-92ae-51ee7315a7bf"],
Cell[235862, 4079, 1065, 18, 44, "Input",ExpressionUUID->"ebbcdefa-e8b4-418d-bbcc-8a1406b8ea24"],
Cell[236930, 4099, 835, 15, 44, "Input",ExpressionUUID->"3302594c-3311-486c-975d-02c4f6420f26"],
Cell[237768, 4116, 1042, 18, 44, "Input",ExpressionUUID->"1673fb4d-d680-490d-a146-b94de2c1ce9e"],
Cell[238813, 4136, 811, 15, 44, "Input",ExpressionUUID->"6a1cb2bd-9ccd-4c6e-a7ca-0c0cc8e3fd86"],
Cell[239627, 4153, 1067, 18, 44, "Input",ExpressionUUID->"778b1d34-2b16-4641-afe4-958ffaa66eba"],
Cell[240697, 4173, 839, 15, 44, "Input",ExpressionUUID->"17bf2afb-74a4-4899-a403-1ee2cb2495d4"],
Cell[241539, 4190, 1118, 19, 44, "Input",ExpressionUUID->"7f003a9b-1f8b-4d9e-a4a9-1aca2619de06"],
Cell[242660, 4211, 890, 16, 44, "Input",ExpressionUUID->"37bb7d17-06ad-414f-a3a0-68314fec7d91"],
Cell[243553, 4229, 1068, 18, 44, "Input",ExpressionUUID->"e1812860-5f1c-4169-94a1-19394261051f"],
Cell[244624, 4249, 838, 15, 44, "Input",ExpressionUUID->"afaa7c76-91eb-4a00-b049-87075744925a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[245499, 4269, 495, 8, 43, "Subsubsection",ExpressionUUID->"5a9ca741-86a3-462d-a8a9-6fee3c9310a0"],
Cell[245997, 4279, 539, 9, 30, "Text",ExpressionUUID->"c0266644-bc10-4206-b984-978ef0416051"],
Cell[246539, 4290, 1543, 24, 44, "Input",ExpressionUUID->"802c6b9b-1962-431d-b17b-a621193520c7"],
Cell[248085, 4316, 1473, 23, 44, "Input",ExpressionUUID->"cb959750-59dd-405b-8ff0-098877582c11"],
Cell[249561, 4341, 1468, 23, 44, "Input",ExpressionUUID->"63bde8db-8dca-4231-b99b-9dc06652c0ae"],
Cell[251032, 4366, 1495, 23, 44, "Input",ExpressionUUID->"fc85e40d-813d-4459-9fa3-8bef78a8fce4"],
Cell[252530, 4391, 1535, 24, 44, "Input",ExpressionUUID->"422e32a6-79a0-4a83-9eca-a130a7bfd0fe"],
Cell[254068, 4417, 1545, 24, 44, "Input",ExpressionUUID->"8a6ec7a1-47a4-4e5f-837b-ec8dc5daca28"]
}, Open  ]],
Cell[CellGroupData[{
Cell[255650, 4446, 335, 5, 43, "Subsubsection",ExpressionUUID->"19d1fea4-b481-466d-b51c-306eaf6e60b0"],
Cell[CellGroupData[{
Cell[256010, 4455, 312, 8, 28, "Input",ExpressionUUID->"d71e9edd-cd25-47c5-a8ba-562ba90ec246"],
Cell[256325, 4465, 395, 6, 32, "Output",ExpressionUUID->"1295d508-425f-4567-9db6-16e338dd3dcf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[256757, 4476, 451, 10, 28, "Input",ExpressionUUID->"b5257770-7669-43d7-9c1a-bdb826fb06f2"],
Cell[257211, 4488, 908, 13, 32, "Output",ExpressionUUID->"6404d630-3d63-42b4-b4d1-cce9bcb0461e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[258156, 4506, 400, 9, 28, "Input",ExpressionUUID->"4f9f1654-1aad-48c8-b656-5d405430fe68"],
Cell[258559, 4517, 854, 12, 32, "Output",ExpressionUUID->"a69bec5a-7be7-44ef-afc6-12c978718eec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[259450, 4534, 501, 10, 28, "Input",ExpressionUUID->"c748519c-6bfb-4c72-9cdc-8bc25b257406"],
Cell[259954, 4546, 909, 13, 32, "Output",ExpressionUUID->"997f95e6-6f37-4820-ba66-1e936d96aac6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[260900, 4564, 402, 9, 28, "Input",ExpressionUUID->"9145fced-15b2-47bc-8826-d99470fda361"],
Cell[261305, 4575, 852, 12, 32, "Output",ExpressionUUID->"db83d8c7-ac3f-4d9e-ab76-71b5f583ec87"]
}, Open  ]],
Cell[CellGroupData[{
Cell[262194, 4592, 541, 11, 28, "Input",ExpressionUUID->"da31f88c-ffc5-4b6b-99e0-2f2b3b053f93"],
Cell[262738, 4605, 932, 13, 32, "Output",ExpressionUUID->"3a7f4c9d-ec0a-4f04-ba0a-747355298c26"]
}, Open  ]],
Cell[CellGroupData[{
Cell[263707, 4623, 404, 9, 28, "Input",ExpressionUUID->"7bfcd954-2105-4eee-ada3-e486fd33ff54"],
Cell[264114, 4634, 861, 12, 32, "Output",ExpressionUUID->"ef170ac2-50a6-48aa-92e6-3721a69c34c5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[265012, 4651, 497, 10, 28, "Input",ExpressionUUID->"64f21cd7-4bc8-4331-a623-54225eba06cc"],
Cell[265512, 4663, 917, 13, 32, "Output",ExpressionUUID->"5ce24511-676e-4eef-8bf9-c86c0fa69beb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[266466, 4681, 402, 9, 28, "Input",ExpressionUUID->"80efdd6a-883c-466c-8dc3-9bef8f7e6a27"],
Cell[266871, 4692, 863, 12, 32, "Output",ExpressionUUID->"056be80f-4262-40ec-86cd-54162f79675c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[267771, 4709, 443, 10, 28, "Input",ExpressionUUID->"d3b97b9f-e211-491f-b3e8-ade2b1540012"],
Cell[268217, 4721, 913, 13, 32, "Output",ExpressionUUID->"1062b641-54c1-42e3-8b55-761d743992c7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[269167, 4739, 351, 8, 28, "Input",ExpressionUUID->"383526ba-b438-46d4-8677-896d5f8d4c05"],
Cell[269521, 4749, 829, 12, 32, "Output",ExpressionUUID->"c24718aa-806f-443d-abe0-5e1991a48452"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[270411, 4768, 446, 7, 62, "Section",ExpressionUUID->"0211a225-8a35-4582-b9ef-4f2047c88c34"],
Cell[270860, 4777, 966, 16, 28, "Input",ExpressionUUID->"9d5a52cf-3316-4cb2-80ab-9c9bede1d617"],
Cell[271829, 4795, 1036, 17, 28, "Input",ExpressionUUID->"563be225-6049-49ee-806a-d676b042abd2"],
Cell[272868, 4814, 968, 16, 28, "Input",ExpressionUUID->"586a9c09-4290-443b-bf7d-c0d9a9d73e0a"],
Cell[273839, 4832, 1036, 17, 28, "Input",ExpressionUUID->"64e92a99-a9c8-424b-ad08-340b3749b512"],
Cell[274878, 4851, 894, 15, 28, "Input",ExpressionUUID->"d41b583f-dae0-48e9-b4c3-be318f3fd670"],
Cell[275775, 4868, 966, 16, 28, "Input",ExpressionUUID->"4ff425df-281f-4ea5-98ba-80b9dac98a0d"],
Cell[276744, 4886, 966, 16, 28, "Input",ExpressionUUID->"bcd1b8c2-12df-4a34-b46e-55c2ab4cc24e"],
Cell[277713, 4904, 1036, 17, 28, "Input",ExpressionUUID->"7ba43ca5-42d7-4dd1-9e4d-54130dec78d9"],
Cell[278752, 4923, 990, 16, 28, "Input",ExpressionUUID->"a670896e-3a79-4021-8343-54a5ece8d061"],
Cell[279745, 4941, 1064, 17, 28, "Input",ExpressionUUID->"e277d6ca-3f55-4be1-9d33-c1ff6a01c5a3"],
Cell[280812, 4960, 990, 16, 28, "Input",ExpressionUUID->"d10dcd0c-1bec-4815-805a-88cd35a2b449"],
Cell[281805, 4978, 1061, 17, 28, "Input",ExpressionUUID->"53646c65-6bf2-44ab-80e9-9a7f3d2e9934"],
Cell[282869, 4997, 1722, 29, 28, "Input",ExpressionUUID->"a3ab304f-2aee-4fbd-bfd7-6f5a12f02f88"],
Cell[284594, 5028, 1752, 29, 28, "Input",ExpressionUUID->"719d6bd9-ab83-433d-bc57-a6b508965f6b"],
Cell[286349, 5059, 1356, 24, 28, "Input",ExpressionUUID->"ca4a1562-a6dc-469b-905d-0d39aef96b5a"],
Cell[287708, 5085, 1599, 27, 28, "Input",ExpressionUUID->"12c30e9d-754a-45e0-8c39-1b72a9f6c4ad"],
Cell[289310, 5114, 1258, 22, 28, "Input",ExpressionUUID->"288ea92c-c9be-4ba0-82d7-1acdbbeb49ee"],
Cell[290571, 5138, 1717, 29, 28, "Input",ExpressionUUID->"b2ccd627-d7eb-4881-8b69-b0a9aa854d3c"],
Cell[292291, 5169, 1356, 24, 28, "Input",ExpressionUUID->"07cb80e4-b70d-4a54-9c85-400d2cb9ea9b"],
Cell[293650, 5195, 1848, 31, 28, "Input",ExpressionUUID->"c58f1e24-fc21-48b5-a52b-8ef5b76fd29a"],
Cell[295501, 5228, 1400, 24, 28, "Input",ExpressionUUID->"58ea194b-8382-4059-9a56-4bd3f7863104"],
Cell[296904, 5254, 1766, 30, 28, "Input",ExpressionUUID->"452c9f24-2134-4294-98c5-98d220bcf96c"],
Cell[298673, 5286, 1396, 24, 28, "Input",ExpressionUUID->"ebbbcfd0-9681-4755-aac2-3374db013fbe"],
Cell[CellGroupData[{
Cell[300094, 5314, 223, 4, 44, "Subsubsection",ExpressionUUID->"eaf6ed4f-37fe-45de-a9ec-4e216ee77481"],
Cell[300320, 5320, 957, 18, 48, "Input",ExpressionUUID->"251b4ab0-22c0-46e3-b8e5-e9aa3e6836c2"],
Cell[301280, 5340, 1808, 29, 28, "Input",ExpressionUUID->"84a21240-2395-4207-a627-0bd1de0b1bd2"],
Cell[303091, 5371, 955, 18, 48, "Input",ExpressionUUID->"ddefb4fb-ed0b-41c9-b34f-815fdb269d09"],
Cell[304049, 5391, 1811, 29, 28, "Input",ExpressionUUID->"9804a220-ad8a-4ea2-b0a3-d983552dacc8"],
Cell[305863, 5422, 833, 16, 48, "Input",ExpressionUUID->"f305acde-6487-41d5-8850-a22925249eb5"],
Cell[306699, 5440, 1688, 27, 28, "Input",ExpressionUUID->"f5232fbe-62d7-4e00-986d-f2c32840b136"],
Cell[308390, 5469, 962, 18, 48, "Input",ExpressionUUID->"ac224861-1ffc-4908-a6d4-f00c1b91f388"],
Cell[309355, 5489, 1814, 29, 28, "Input",ExpressionUUID->"22c1ee31-aa92-4f38-bac8-c199f7968ae9"],
Cell[311172, 5520, 1014, 19, 48, "Input",ExpressionUUID->"2c6e2342-421a-4708-b8b8-5c667135aa12"],
Cell[312189, 5541, 1863, 29, 28, "Input",ExpressionUUID->"e4a181ee-069f-4237-bdb1-e29ece128f2d"],
Cell[314055, 5572, 1018, 19, 48, "Input",ExpressionUUID->"745d2426-5f4e-4ea4-8d95-2cd7241500ec"],
Cell[315076, 5593, 1862, 29, 28, "Input",ExpressionUUID->"94b6edbf-8c1e-4ac1-9ae1-85e6f5b9f009"]
}, Open  ]],
Cell[CellGroupData[{
Cell[316975, 5627, 247, 4, 44, "Subsubsection",ExpressionUUID->"12bc2ed7-48ae-40fa-b416-727b1343aa1b"],
Cell[317225, 5633, 2639, 41, 49, "Input",ExpressionUUID->"1bd69a31-8d5e-4be7-ac7b-526a6a7dc4b5"],
Cell[319867, 5676, 1183, 24, 41, "Input",ExpressionUUID->"bfe09279-c02a-4e14-b37a-2ead85213dd7"],
Cell[321053, 5702, 2639, 41, 49, "Input",ExpressionUUID->"d2ca5df3-78b6-49e1-b854-f20b9894de8a"],
Cell[323695, 5745, 1156, 24, 41, "Input",ExpressionUUID->"e9996e19-c9e2-4bad-80d6-e5d1f107f50b"],
Cell[324854, 5771, 2419, 38, 49, "Input",ExpressionUUID->"385ca98f-830d-4059-a353-b4dd92eaff40"],
Cell[327276, 5811, 949, 21, 41, "Input",ExpressionUUID->"11633740-7877-4529-9267-5101c3b28f3f"],
Cell[328228, 5834, 2689, 42, 49, "Input",ExpressionUUID->"387dcf33-3dbb-4670-99ab-85ffff228603"],
Cell[330920, 5878, 1203, 25, 41, "Input",ExpressionUUID->"764696a7-2ccb-4e84-8698-455b1318fc9e"],
Cell[332126, 5905, 2686, 42, 49, "Input",ExpressionUUID->"7e8bc4a9-59b5-4213-a12b-64692d4817e6"],
Cell[334815, 5949, 1247, 25, 41, "Input",ExpressionUUID->"6881808e-6ee8-4fbf-a097-67964535b9e6"],
Cell[336065, 5976, 2665, 42, 49, "Input",ExpressionUUID->"973e0b37-8182-4fda-9e0f-5a79f4428a28"],
Cell[338733, 6020, 1203, 25, 41, "Input",ExpressionUUID->"47fa4eb1-e757-4dc0-863e-a3881a527a94"],
Cell[339939, 6047, 951, 20, 47, "Input",ExpressionUUID->"62eabe97-1954-43ae-855a-7d2c54b35cbd"],
Cell[340893, 6069, 793, 18, 46, "Input",ExpressionUUID->"4d9b0a1f-c966-472a-b552-6af5401f68b8"],
Cell[341689, 6089, 945, 20, 47, "Input",ExpressionUUID->"47587f17-c0fe-4f2d-a12a-ff180e9cd8e7"],
Cell[342637, 6111, 1002, 21, 47, "Input",ExpressionUUID->"2bd131a2-c9c0-49aa-a8ac-c0ffda5dda8c"],
Cell[343642, 6134, 1007, 21, 47, "Input",ExpressionUUID->"f941036b-720f-480c-b55f-675c0c274d1d"],
Cell[344652, 6157, 1554, 36, 39, "Input",ExpressionUUID->"e6724399-0426-4abd-bb4b-27370550b482"],
Cell[346209, 6195, 2612, 41, 49, "Input",ExpressionUUID->"29fbc036-d510-40fe-8daf-9600259594f0"],
Cell[348824, 6238, 1151, 24, 41, "Input",ExpressionUUID->"d597280d-cf66-4efd-a4df-e8e3cfc822e5"],
Cell[349978, 6264, 2471, 39, 49, "Input",ExpressionUUID->"046a6855-34da-4a95-a501-75e89b292345"],
Cell[352452, 6305, 1007, 22, 41, "Input",ExpressionUUID->"d22c127a-b4b1-4a89-8bd5-9291c05be00a"],
Cell[353462, 6329, 2671, 42, 49, "Input",ExpressionUUID->"93b2d3b9-f4dc-4bec-b540-3dc836afe09b"],
Cell[356136, 6373, 1196, 24, 41, "Input",ExpressionUUID->"ad032d2a-ff52-44d7-8d69-ecdf737d464c"],
Cell[357335, 6399, 2717, 42, 49, "Input",ExpressionUUID->"d89a45b1-455b-4c84-bfb2-4d419410a0cb"],
Cell[360055, 6443, 1242, 25, 41, "Input",ExpressionUUID->"e0dfef6b-9095-46bd-b1db-493e8ded06e6"],
Cell[361300, 6470, 2712, 42, 49, "Input",ExpressionUUID->"251ab582-9b64-4b8f-8f2a-b01aa1edb46b"],
Cell[364015, 6514, 1250, 25, 41, "Input",ExpressionUUID->"10c092d2-c064-4dbd-b087-f6d73fab8a94"],
Cell[365268, 6541, 1005, 21, 49, "Input",ExpressionUUID->"8305e50c-adba-4ce2-96df-65790eba427b"],
Cell[366276, 6564, 969, 20, 49, "Input",ExpressionUUID->"54f686b0-44db-4784-8a4e-7cfac2c72f32"],
Cell[367248, 6586, 1094, 22, 49, "Input",ExpressionUUID->"abbcb4b4-51f3-478d-a36c-47dc2ecc337b"],
Cell[368345, 6610, 1151, 23, 49, "Input",ExpressionUUID->"d45e55d8-cf88-4b9a-97a8-b5feb88adfba"],
Cell[369499, 6635, 444, 13, 49, "Input",ExpressionUUID->"13662bd9-e26a-4f27-9881-ab00ec57da1f"],
Cell[369946, 6650, 1711, 38, 41, "Input",ExpressionUUID->"a4a909b7-206c-40c9-bf6f-7340e63204b5"],
Cell[371660, 6690, 1885, 32, 47, "Input",ExpressionUUID->"0f3e7553-f6e2-4c16-ad42-a622b32f2bcb"],
Cell[373548, 6724, 1032, 20, 50, "Input",ExpressionUUID->"3ef16ad7-9288-471b-b407-adece8171bc8"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[374629, 6750, 509, 8, 62, "Section",ExpressionUUID->"a7cca8e1-1791-4b70-9a68-3ca375af4ec2"],
Cell[375141, 6760, 1202, 24, 41, "Input",ExpressionUUID->"ef893d96-bd08-4069-9c34-459925ad7abd"],
Cell[376346, 6786, 1229, 25, 41, "Input",ExpressionUUID->"8ed78591-642f-4073-ae37-f3504a3aa756"],
Cell[377578, 6813, 1023, 22, 41, "Input",ExpressionUUID->"ce99f432-061e-4019-ad09-c149f12ad464"],
Cell[378604, 6837, 1282, 26, 41, "Input",ExpressionUUID->"885540a3-c558-4d46-8645-7a9b84d95c48"],
Cell[379889, 6865, 1334, 27, 41, "Input",ExpressionUUID->"26e7f073-06b1-4e5a-8eff-d9badcd29a3b"],
Cell[381226, 6894, 1278, 26, 41, "Input",ExpressionUUID->"46b47e41-b29a-438d-a4f1-ca328fe5a8e2"],
Cell[382507, 6922, 1671, 37, 39, "Input",ExpressionUUID->"fcad075f-b133-4c8a-bbfe-1247200c7621"],
Cell[384181, 6961, 613, 12, 48, "Input",ExpressionUUID->"23f8d671-37dc-4151-9949-66fd776c3fb2"],
Cell[384797, 6975, 411, 9, 48, "Input",ExpressionUUID->"2a61f943-defe-466e-9826-0ea9a239ab59"],
Cell[385211, 6986, 557, 11, 48, "Input",ExpressionUUID->"3a2e6051-8d58-45c7-9742-83a507bdd9ba"],
Cell[385771, 6999, 609, 12, 48, "Input",ExpressionUUID->"e1f04e98-a3b4-4090-b339-40efac64b9ef"],
Cell[386383, 7013, 613, 12, 48, "Input",ExpressionUUID->"d9bd73b9-ccb4-4725-a60e-aba4d548a5c0"],
Cell[386999, 7027, 1204, 24, 41, "Input",ExpressionUUID->"a48f174d-0b4e-4016-89cb-12950409eed7"],
Cell[388206, 7053, 1052, 22, 41, "Input",ExpressionUUID->"d25cd3d4-d9b3-4009-ac7e-4fadd097d429"],
Cell[389261, 7077, 1245, 25, 41, "Input",ExpressionUUID->"32ef4bb7-8042-4bd0-bd2d-98b82f2e0275"],
Cell[390509, 7104, 1297, 26, 41, "Input",ExpressionUUID->"08466a49-25b4-495a-aed9-6e7b567f6770"],
Cell[391809, 7132, 1299, 26, 41, "Input",ExpressionUUID->"4534289d-cc08-4831-a2b9-f2744c2fce2a"],
Cell[393111, 7160, 1678, 37, 41, "Input",ExpressionUUID->"f0685b32-fed0-4748-827d-4b13ae9f2b4c"],
Cell[394792, 7199, 204, 4, 34, "Text",ExpressionUUID->"f53d5384-df04-49e5-9c59-86eacf427b49"],
Cell[394999, 7205, 560, 10, 34, "Text",ExpressionUUID->"a73e3fe0-db97-486d-b715-1d3b31d8449a"],
Cell[395562, 7217, 1563, 31, 28, "Input",ExpressionUUID->"7054bfa1-6724-4536-94f8-428722fa9818"],
Cell[397128, 7250, 2021, 41, 28, "Input",ExpressionUUID->"8d9a5d54-6195-4864-9379-ebaa47dda552"],
Cell[399152, 7293, 1634, 35, 28, "Input",ExpressionUUID->"b0114ba0-c557-4d16-ae5b-21ff20f003b6"],
Cell[400789, 7330, 2145, 42, 28, "Input",ExpressionUUID->"b96827f8-268f-402a-b86f-72a53198ccf1"],
Cell[402937, 7374, 2140, 42, 28, "Input",ExpressionUUID->"0968519c-053b-4dae-becf-1dda4af898b0"],
Cell[405080, 7418, 2150, 42, 28, "Input",ExpressionUUID->"c2996b52-8c55-4eee-9698-15dc1c36aea2"],
Cell[407233, 7462, 716, 12, 34, "Text",ExpressionUUID->"f2222292-c02a-4dff-bfb0-5253e658f6aa"],
Cell[407952, 7476, 1352, 27, 28, "Input",ExpressionUUID->"791f993f-332f-45c9-b74d-5610bfc47b08"],
Cell[409307, 7505, 1330, 26, 28, "Input",ExpressionUUID->"e0970f00-5295-4a08-929a-eb9fdaf290f2"],
Cell[410640, 7533, 1078, 23, 28, "Input",ExpressionUUID->"ff7b668f-42fc-496d-9711-68ef3214bd65"],
Cell[411721, 7558, 1387, 27, 28, "Input",ExpressionUUID->"d16e2950-660f-43e2-895a-44af17fb0b6a"],
Cell[413111, 7587, 1387, 27, 28, "Input",ExpressionUUID->"cfe54ccf-0db7-4801-88fa-6007d3fcd471"],
Cell[414501, 7616, 1387, 27, 28, "Input",ExpressionUUID->"63d14fc8-2bcf-4006-bdcb-7b8b710e0c35"],
Cell[415891, 7645, 757, 12, 34, "Text",ExpressionUUID->"aee4aa60-9cad-4f3f-8312-69ed87061370"],
Cell[416651, 7659, 1139, 22, 28, "Input",ExpressionUUID->"dc442f99-2bf6-4cb3-b474-ca34a001692e"],
Cell[417793, 7683, 1138, 23, 28, "Input",ExpressionUUID->"8fd0c066-a41d-4bb3-8941-1c1ea14cc382"],
Cell[418934, 7708, 964, 21, 28, "Input",ExpressionUUID->"97c8f4b3-e25d-4002-9d3d-bf446eb05265"],
Cell[419901, 7731, 1202, 24, 28, "Input",ExpressionUUID->"0940c008-f167-45b0-8f67-f75f70a7d4aa"],
Cell[421106, 7757, 1178, 23, 28, "Input",ExpressionUUID->"4a6d51bc-ab93-4cda-be00-59be19085ebe"],
Cell[422287, 7782, 1186, 24, 28, "Input",ExpressionUUID->"0f1f16ba-f3a9-433f-bc3f-db13778a6b2c"],
Cell[CellGroupData[{
Cell[423498, 7810, 3065, 66, 86, "Input",ExpressionUUID->"6340c5ef-1fdf-4a1b-8913-8de97b421861"],
Cell[426566, 7878, 2465, 39, 71, "Output",ExpressionUUID->"23a64578-3328-4cdf-ace1-df6acacc5887"]
}, Open  ]],
Cell[429046, 7920, 469, 9, 28, "Input",ExpressionUUID->"946f9cfe-6f47-48dd-8266-de1998056519"],
Cell[429518, 7931, 468, 9, 28, "Input",ExpressionUUID->"43559586-6a2c-42e9-a31e-8d54a991c323"],
Cell[429989, 7942, 463, 9, 28, "Input",ExpressionUUID->"fe6319c4-183f-4cb1-8921-13252519ec27"],
Cell[430455, 7953, 517, 10, 28, "Input",ExpressionUUID->"9dc9d079-0605-42cf-9fae-d970b8bf9b15"],
Cell[430975, 7965, 518, 10, 28, "Input",ExpressionUUID->"52280ee1-ca06-46e2-8fd2-1ee3bf86a7bf"],
Cell[431496, 7977, 522, 10, 28, "Input",ExpressionUUID->"16577354-fa8c-4ba9-a552-6e3f71acfce3"],
Cell[432021, 7989, 422, 8, 28, "Input",ExpressionUUID->"d8dba8ef-0920-4505-bdb4-adc27f532b87"],
Cell[432446, 7999, 470, 9, 28, "Input",ExpressionUUID->"bd09eadf-153e-4b02-a931-f9871574b095"],
Cell[432919, 8010, 467, 9, 28, "Input",ExpressionUUID->"dbbea929-f638-498e-b75b-52c8fc05722d"],
Cell[433389, 8021, 519, 10, 28, "Input",ExpressionUUID->"ec51b3fd-7e7d-4c61-9972-2d851b2142ff"],
Cell[433911, 8033, 570, 10, 28, "Input",ExpressionUUID->"2d72f4c8-4704-4135-89b4-ae65638945c4"],
Cell[434484, 8045, 571, 10, 28, "Input",ExpressionUUID->"e4ae86d0-0ecf-4d01-9a43-638ff4316501"],
Cell[435058, 8057, 570, 10, 28, "Input",ExpressionUUID->"363b0dc2-9fe4-4ac6-8270-075099442dc1"],
Cell[435631, 8069, 622, 11, 28, "Input",ExpressionUUID->"f468faf8-f8bd-4c10-ac7a-f2bb158e1dcd"],
Cell[436256, 8082, 625, 11, 28, "Input",ExpressionUUID->"cea7b54e-c772-47bd-897d-57c5f521d92a"],
Cell[436884, 8095, 573, 10, 28, "Input",ExpressionUUID->"ed362b77-6bc1-4448-880e-83a403e1ad8b"],
Cell[437460, 8107, 623, 11, 28, "Input",ExpressionUUID->"2d3ae847-e6b2-47f7-9486-932bdc12b0a0"],
Cell[438086, 8120, 632, 11, 28, "Input",ExpressionUUID->"693b0175-b716-4b97-b073-d664939f0ede"],
Cell[438721, 8133, 589, 11, 48, "Input",ExpressionUUID->"3336e42b-db78-4360-b345-f0ee822506bc"],
Cell[439313, 8146, 334, 8, 48, "Input",ExpressionUUID->"05ed3c06-fcef-484a-adbb-56a816fc8af8"],
Cell[439650, 8156, 420, 9, 48, "Input",ExpressionUUID->"9f6b8eb1-5805-4427-b26a-cef91f1526c5"],
Cell[440073, 8167, 478, 10, 48, "Input",ExpressionUUID->"83b67659-eb1d-4707-9fed-d5d961d8df8a"],
Cell[440554, 8179, 476, 10, 48, "Input",ExpressionUUID->"907890ee-c08b-4b6d-bdc1-3bad1bd5ef46"],
Cell[441033, 8191, 1259, 25, 41, "Input",ExpressionUUID->"827b48b7-cd55-4505-a89a-8bea05d601f9"],
Cell[442295, 8218, 1233, 25, 41, "Input",ExpressionUUID->"10e0a844-12f0-4717-ae97-7bb0e70d876c"],
Cell[443531, 8245, 1029, 22, 41, "Input",ExpressionUUID->"88b75a07-2f21-4492-b2d3-ed45dee10998"],
Cell[444563, 8269, 1277, 25, 41, "Input",ExpressionUUID->"36baead3-72a4-46ae-9e7b-357bd3170f22"],
Cell[445843, 8296, 1329, 26, 41, "Input",ExpressionUUID->"0571bbc8-e10f-4994-b3a9-b9907a4032d9"],
Cell[447175, 8324, 1277, 25, 41, "Input",ExpressionUUID->"25c9e9ad-6c6b-4a6e-badf-d81bcb918d0d"],
Cell[448455, 8351, 1686, 37, 39, "Input",ExpressionUUID->"2cf42da1-537d-47cf-a868-6ac8425005fa"],
Cell[450144, 8390, 1259, 25, 41, "Input",ExpressionUUID->"50b2217b-a0f5-4ef2-a665-089b684d852b"],
Cell[451406, 8417, 1109, 23, 41, "Input",ExpressionUUID->"ca99b36d-0784-4f5c-abb4-899421699bbc"],
Cell[452518, 8442, 1301, 26, 41, "Input",ExpressionUUID->"cd104c3f-d515-420d-85d0-6d5fe0acf9eb"],
Cell[453822, 8470, 1348, 26, 41, "Input",ExpressionUUID->"b91acc9e-d0f7-4343-901b-85eb5f9b4f67"],
Cell[455173, 8498, 1351, 26, 41, "Input",ExpressionUUID->"f6513031-5cad-4928-be8c-84291667fb4f"],
Cell[456527, 8526, 1741, 38, 41, "Input",ExpressionUUID->"cf3a49b1-b3f6-48a3-98f1-2b28e692992d"],
Cell[458271, 8566, 631, 13, 28, "Input",ExpressionUUID->"da2c9595-e3fc-4efc-8340-7fcfa41ee32f"],
Cell[458905, 8581, 597, 11, 28, "Input",ExpressionUUID->"968cd914-3f2c-4fc0-8be1-87db76fa5032"],
Cell[459505, 8594, 563, 11, 28, "Input",ExpressionUUID->"5d201a59-15f3-4a9f-b1d9-6ab7b8e60249"],
Cell[460071, 8607, 684, 14, 28, "Input",ExpressionUUID->"3e642ed7-8a2a-4a7c-84b1-61256cf803c8"],
Cell[460758, 8623, 645, 12, 28, "Input",ExpressionUUID->"14ae33cb-8dc4-47b0-bd6d-02367efb45db"],
Cell[461406, 8637, 615, 12, 28, "Input",ExpressionUUID->"9653b559-0a51-4e27-a205-737b01a7f79d"],
Cell[462024, 8651, 1067, 21, 28, "Input",ExpressionUUID->"c8f582d1-1442-4d78-8704-4de7307105c1"],
Cell[463094, 8674, 534, 12, 28, "Input",ExpressionUUID->"f9613ae5-8b16-4e0c-b27c-4a183e59636d"],
Cell[463631, 8688, 551, 11, 28, "Input",ExpressionUUID->"11243cd2-b796-4e01-8542-850f98f840aa"],
Cell[464185, 8701, 543, 11, 28, "Input",ExpressionUUID->"b63af19c-402b-4a43-8c33-41d4f5396395"],
Cell[464731, 8714, 849, 18, 28, "Input",ExpressionUUID->"7ee696d2-f285-433f-80dc-784d4d3d5c14"],
Cell[465583, 8734, 680, 14, 28, "Input",ExpressionUUID->"888e3a2d-d307-4c7b-a13a-f42ecd52ab55"],
Cell[466266, 8750, 644, 12, 28, "Input",ExpressionUUID->"78166c8f-0a9e-4e78-90eb-12cf3e75d5d0"],
Cell[466913, 8764, 621, 12, 28, "Input",ExpressionUUID->"bff7468d-1892-44a1-ab13-c7d9e1e5d3b5"],
Cell[467537, 8778, 1050, 21, 28, "Input",ExpressionUUID->"e5ee9f38-34c7-48ba-a642-b690f9fd2ef6"],
Cell[468590, 8801, 735, 15, 28, "Input",ExpressionUUID->"9ee139f8-dd61-49ba-9e44-ef070c835f9e"],
Cell[469328, 8818, 698, 13, 28, "Input",ExpressionUUID->"a3abd642-d5c4-4b76-b2bc-df6d735ad759"],
Cell[470029, 8833, 666, 12, 28, "Input",ExpressionUUID->"2b79f586-f40a-4ad1-9e25-ed319fec9286"],
Cell[470698, 8847, 1098, 21, 28, "Input",ExpressionUUID->"d1c876fb-bac7-4a69-a62f-408a82bf20b3"],
Cell[471799, 8870, 735, 15, 28, "Input",ExpressionUUID->"5663a682-3868-430c-b51e-543109457dcf"],
Cell[472537, 8887, 689, 13, 28, "Input",ExpressionUUID->"9e71b931-d617-428a-9a63-c9b1b171e286"],
Cell[473229, 8902, 667, 12, 28, "Input",ExpressionUUID->"a86a308e-d31b-4462-92c0-2bbe06ed4ed8"],
Cell[473899, 8916, 1100, 21, 28, "Input",ExpressionUUID->"b5432474-f281-45eb-9d5c-d18a453cd9e5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[475036, 8942, 544, 9, 62, "Section",ExpressionUUID->"473301bd-dba7-4078-9961-38ae68a23b97"],
Cell[475583, 8953, 1159, 17, 34, "Text",ExpressionUUID->"fa466ce1-cea8-4a8d-9b00-4b42818ede2f"],
Cell[476745, 8972, 747, 10, 34, "Text",ExpressionUUID->"37b6f62e-ab42-474a-883b-a789278bd2e7"],
Cell[CellGroupData[{
Cell[477517, 8986, 506, 10, 48, "Input",ExpressionUUID->"7851d6b9-66dd-4b24-bb64-9b1361450660"],
Cell[478026, 8998, 6174, 86, 48, "Output",ExpressionUUID->"94fa41af-1cf4-4106-8430-65051638df47"]
}, Open  ]],
Cell[484215, 9087, 877, 12, 34, "Text",ExpressionUUID->"ff34ab77-1d9f-4ec0-ba1d-cae076d2ebb1"],
Cell[CellGroupData[{
Cell[485117, 9103, 576, 11, 48, "Input",ExpressionUUID->"12284875-4e6e-4aaf-8a4e-b74c3485c4eb"],
Cell[485696, 9116, 6144, 86, 48, "Output",ExpressionUUID->"625a15df-e496-443e-934f-5fae1d3b452c"]
}, Open  ]],
Cell[491855, 9205, 972, 13, 34, "Text",ExpressionUUID->"66e3d8bf-0da9-4845-95b9-8b8bf770b527"],
Cell[CellGroupData[{
Cell[492852, 9222, 787, 18, 28, "Input",ExpressionUUID->"f293df65-97a3-435d-a196-54d89d1d73ff"],
Cell[493642, 9242, 604, 12, 48, "Output",ExpressionUUID->"8e1ea147-f45c-4066-8a91-e0b26c9c62d7"]
}, Open  ]],
Cell[494261, 9257, 789, 11, 34, "Text",ExpressionUUID->"5ed542e3-d498-4e4c-a4dd-1b360d55e7d3"],
Cell[CellGroupData[{
Cell[495075, 9272, 515, 10, 47, "Input",ExpressionUUID->"a7a9764c-bf66-49ef-939e-40c84233ba43"],
Cell[495593, 9284, 6153, 86, 48, "Output",ExpressionUUID->"071b3049-e647-4b07-840d-9e5a9db2ccde"]
}, Open  ]],
Cell[501761, 9373, 925, 13, 34, "Text",ExpressionUUID->"82273b4d-e264-45a3-9a5a-0b30019357d7"],
Cell[CellGroupData[{
Cell[502711, 9390, 581, 11, 47, "Input",ExpressionUUID->"0d15ba49-a590-43d3-aca9-29acdb783728"],
Cell[503295, 9403, 6179, 87, 48, "Output",ExpressionUUID->"a58f418b-ec05-4a93-992c-10894b1d641c"]
}, Open  ]],
Cell[509489, 9493, 733, 10, 34, "Text",ExpressionUUID->"e23a3c21-0a78-47af-802c-c364f4f91f5f"],
Cell[CellGroupData[{
Cell[510247, 9507, 503, 10, 47, "Input",ExpressionUUID->"ec6af1d0-396f-4dba-8cea-a3941b570226"],
Cell[510753, 9519, 6107, 85, 48, "Output",ExpressionUUID->"e4246bbc-8a24-4d85-b0cc-0113e05bd70b"]
}, Open  ]],
Cell[516875, 9607, 866, 12, 34, "Text",ExpressionUUID->"f799dbdf-4080-49d8-a20e-90387fa96e77"],
Cell[CellGroupData[{
Cell[517766, 9623, 575, 11, 47, "Input",ExpressionUUID->"efe2e1f7-5f4b-4f80-a068-3179b4d26ead"],
Cell[518344, 9636, 6134, 86, 48, "Output",ExpressionUUID->"8b684715-bae0-4bf6-afff-e6ffaa6e759e"]
}, Open  ]],
Cell[524493, 9725, 511, 9, 34, "Text",ExpressionUUID->"3c230a6e-b45f-406a-b862-d16c7d588e39"],
Cell[525007, 9736, 747, 10, 34, "Text",ExpressionUUID->"d31b970b-01b3-4a91-a1a6-1f6a8fc987d5"],
Cell[CellGroupData[{
Cell[525779, 9750, 623, 12, 48, "Input",ExpressionUUID->"00ca3398-e60a-4f27-9f2f-ebb60f90afab"],
Cell[526405, 9764, 6179, 86, 48, "Output",ExpressionUUID->"1c11497d-1c98-4165-9e59-c4eb6f450927"]
}, Open  ]],
Cell[532599, 9853, 851, 12, 34, "Text",ExpressionUUID->"e62e74d7-9a4e-444a-8002-5e78b3fe9904"],
Cell[CellGroupData[{
Cell[533475, 9869, 627, 12, 48, "Input",ExpressionUUID->"ea07afa0-19bc-4d7b-a798-fbd50f5b1b9b"],
Cell[534105, 9883, 6183, 86, 48, "Output",ExpressionUUID->"b07f5fee-3a05-47ae-a622-c5ccfa8859c4"]
}, Open  ]],
Cell[540303, 9972, 800, 11, 34, "Text",ExpressionUUID->"74709d3e-c995-4aa7-a7fe-8d66933766b1"],
Cell[CellGroupData[{
Cell[541128, 9987, 624, 12, 48, "Input",ExpressionUUID->"a7b058b0-b67f-46ad-9eac-b1634f448551"],
Cell[541755, 10001, 6185, 86, 48, "Output",ExpressionUUID->"7a526ed3-93cf-4c43-b0e2-3061f73333fe"]
}, Open  ]],
Cell[547955, 10090, 903, 12, 34, "Text",ExpressionUUID->"4eddad94-7d11-490a-a946-fa0004029ced"],
Cell[CellGroupData[{
Cell[548883, 10106, 634, 12, 48, "Input",ExpressionUUID->"3fb76938-949c-45e7-b678-fb85bf19b336"],
Cell[549520, 10120, 6167, 86, 48, "Output",ExpressionUUID->"d77362d4-27f3-4665-ad06-dd1683e20c02"]
}, Open  ]],
Cell[555702, 10209, 974, 13, 34, "Text",ExpressionUUID->"21f30dff-389c-44ba-9ac3-942bc15fb559"],
Cell[CellGroupData[{
Cell[556701, 10226, 905, 21, 28, "Input",ExpressionUUID->"0f1339f8-ac6f-44a9-b767-3bba2bc1a9be"],
Cell[557609, 10249, 673, 13, 48, "Output",ExpressionUUID->"a90622e4-a759-41f2-bc82-6185f03c3723"]
}, Open  ]],
Cell[558297, 10265, 970, 13, 34, "Text",ExpressionUUID->"5a3a5221-9287-4570-9eb8-c2c85a6bdac6"],
Cell[CellGroupData[{
Cell[559292, 10282, 832, 19, 28, "Input",ExpressionUUID->"07a48ead-29e0-4de5-88d7-a45a5169bb31"],
Cell[560127, 10303, 678, 13, 48, "Output",ExpressionUUID->"83c8158c-6e77-4424-aded-73019ed97ee7"]
}, Open  ]],
Cell[560820, 10319, 789, 11, 34, "Text",ExpressionUUID->"dea2e921-ee46-4743-ab05-a7e3945b6a26"],
Cell[CellGroupData[{
Cell[561634, 10334, 638, 12, 47, "Input",ExpressionUUID->"f484b1cf-f337-48dc-b352-e79d65e44fd2"],
Cell[562275, 10348, 6161, 86, 48, "Output",ExpressionUUID->"dfb262ad-f8c3-45ff-8e4a-3c40fe89f148"]
}, Open  ]],
Cell[568451, 10437, 895, 12, 34, "Text",ExpressionUUID->"9a48f72c-e683-4eef-a766-d6eafcb44256"],
Cell[CellGroupData[{
Cell[569371, 10453, 638, 12, 47, "Input",ExpressionUUID->"17d0570a-d752-44e3-b70f-5ed7e347d13e"],
Cell[570012, 10467, 6183, 87, 48, "Output",ExpressionUUID->"600dc25e-35c3-4e94-9001-f10f4af4d562"]
}, Open  ]],
Cell[576210, 10557, 733, 10, 34, "Text",ExpressionUUID->"6f46316a-26e2-4291-a63f-5ef5c6a7794c"],
Cell[CellGroupData[{
Cell[576968, 10571, 624, 12, 47, "Input",ExpressionUUID->"db586c54-20d0-41e4-9765-405464a7d02b"],
Cell[577595, 10585, 6105, 85, 48, "Output",ExpressionUUID->"0c66c3f4-4d57-41f7-a8dd-c82bd0662876"]
}, Open  ]],
Cell[583715, 10673, 844, 12, 34, "Text",ExpressionUUID->"c0839bdc-fe31-4602-a763-d373a33c6f16"],
Cell[CellGroupData[{
Cell[584584, 10689, 619, 12, 47, "Input",ExpressionUUID->"837a0856-9802-469c-8aee-bc228d453609"],
Cell[585206, 10703, 6142, 86, 48, "Output",ExpressionUUID->"08a081d2-ac2b-487c-924f-d81a40754f84"]
}, Open  ]],
Cell[591363, 10792, 508, 9, 34, "Text",ExpressionUUID->"0ba7f740-1ccf-4c0a-8976-8f2466cded3a"],
Cell[591874, 10803, 747, 10, 34, "Text",ExpressionUUID->"3d66264f-629c-44c5-9dbd-5d67f5927cbd"],
Cell[CellGroupData[{
Cell[592646, 10817, 481, 10, 48, "Input",ExpressionUUID->"2a02d074-8b67-4ef2-97ac-70841c84a99d"],
Cell[593130, 10829, 6156, 85, 48, "Output",ExpressionUUID->"8f04fdd3-6245-4a97-8cec-c0dc759e162e"]
}, Open  ]],
Cell[599301, 10917, 851, 12, 34, "Text",ExpressionUUID->"0fe098be-b29f-4ce6-bab0-f04522167f30"],
Cell[CellGroupData[{
Cell[600177, 10933, 523, 11, 48, "Input",ExpressionUUID->"7d4c9a37-f057-46db-b5c4-4cfdb1bc79f0"],
Cell[600703, 10946, 6142, 85, 48, "Output",ExpressionUUID->"0afeb3b6-cce4-4f38-ac87-c029c78da4d6"]
}, Open  ]],
Cell[606860, 11034, 800, 11, 34, "Text",ExpressionUUID->"7de371d5-81f7-476d-9f31-0363bd80cce3"],
Cell[CellGroupData[{
Cell[607685, 11049, 474, 10, 48, "Input",ExpressionUUID->"505233e9-3de1-4a29-9d0e-86ea14ae24b7"],
Cell[608162, 11061, 6163, 85, 48, "Output",ExpressionUUID->"f3a0887d-df28-4653-8fbc-8f0b8828a4d8"]
}, Open  ]],
Cell[614340, 11149, 902, 12, 34, "Text",ExpressionUUID->"8ae1ed5b-0ea8-45f8-946d-944ec7d06db1"],
Cell[CellGroupData[{
Cell[615267, 11165, 531, 11, 48, "Input",ExpressionUUID->"5fd82f32-b684-4fbb-930c-804e026d4a08"],
Cell[615801, 11178, 6140, 85, 48, "Output",ExpressionUUID->"e12e5615-ff6e-47cf-b425-a689a2817e34"]
}, Open  ]],
Cell[621956, 11266, 972, 13, 34, "Text",ExpressionUUID->"f7c8ac24-1772-44a2-8fd4-34926eabe768"],
Cell[CellGroupData[{
Cell[622953, 11283, 871, 20, 28, "Input",ExpressionUUID->"f59586ff-0f98-4466-8cbf-e8037d2facd9"],
Cell[623827, 11305, 669, 13, 48, "Output",ExpressionUUID->"b272f739-b0d5-4333-b203-26106533f30b"]
}, Open  ]],
Cell[624511, 11321, 970, 13, 34, "Text",ExpressionUUID->"dcbbb31f-19e7-44bd-a931-55852205923a"],
Cell[CellGroupData[{
Cell[625506, 11338, 842, 19, 28, "Input",ExpressionUUID->"c8061686-4796-4f70-a3b4-31ba8b7b2d73"],
Cell[626351, 11359, 681, 13, 48, "Output",ExpressionUUID->"cd7a816a-0d99-447c-be03-f940da958e40"]
}, Open  ]],
Cell[627047, 11375, 789, 11, 34, "Text",ExpressionUUID->"595cd19d-1187-4444-8116-3c5f95c9094e"],
Cell[CellGroupData[{
Cell[627861, 11390, 488, 10, 48, "Input",ExpressionUUID->"54ef8831-e826-4661-bf9d-4173471e7600"],
Cell[628352, 11402, 6127, 85, 48, "Output",ExpressionUUID->"9c68419a-7e7f-41c2-b53c-1eb5ed3030fb"]
}, Open  ]],
Cell[634494, 11490, 893, 12, 34, "Text",ExpressionUUID->"0d1da58d-1aa7-4703-9e86-87f82453e588"],
Cell[CellGroupData[{
Cell[635412, 11506, 535, 11, 48, "Input",ExpressionUUID->"8550f87b-1995-4769-afe4-52aa757c92e5"],
Cell[635950, 11519, 6148, 86, 48, "Output",ExpressionUUID->"a2e9c892-d30b-4820-8e40-8fd447d99d14"]
}, Open  ]],
Cell[642113, 11608, 733, 10, 34, "Text",ExpressionUUID->"64be1c49-a58d-4f9b-bf04-f2b3f67564ff"],
Cell[CellGroupData[{
Cell[642871, 11622, 478, 10, 48, "Input",ExpressionUUID->"0033ad0d-1379-457a-9dc2-1a86231bb164"],
Cell[643352, 11634, 6090, 85, 48, "Output",ExpressionUUID->"84ff0ebe-0983-4993-aad3-9e594d581a24"]
}, Open  ]],
Cell[649457, 11722, 842, 12, 34, "Text",ExpressionUUID->"1287b6cf-c7e5-4552-a2a6-c873534b38be"],
Cell[CellGroupData[{
Cell[650324, 11738, 527, 11, 48, "Input",ExpressionUUID->"04e6fdef-ca93-4416-a1ff-70212c4de514"],
Cell[650854, 11751, 6103, 86, 48, "Output",ExpressionUUID->"1994aa17-1ce0-49d7-b0ad-5eb7d7cbd095"]
}, Open  ]],
Cell[656972, 11840, 1127, 16, 34, "Text",ExpressionUUID->"0da5a705-ebaa-47a5-9c78-216be9b445f4"],
Cell[658102, 11858, 747, 10, 34, "Text",ExpressionUUID->"d6dd7271-b8f9-4b87-8e07-d998adc6d6c9"],
Cell[CellGroupData[{
Cell[658874, 11872, 551, 11, 48, "Input",ExpressionUUID->"eac04235-9dae-4c9d-9d14-9beadbe1df28"],
Cell[659428, 11885, 6142, 85, 48, "Output",ExpressionUUID->"45705070-1212-4fc7-9393-065b39248b63"]
}, Open  ]],
Cell[665585, 11973, 851, 12, 34, "Text",ExpressionUUID->"6ab2d942-3780-4d10-a84d-bca6c00b9067"],
Cell[CellGroupData[{
Cell[666461, 11989, 629, 12, 48, "Input",ExpressionUUID->"699c7382-61c3-4087-9ac8-2d4750e55a95"],
Cell[667093, 12003, 6139, 85, 48, "Output",ExpressionUUID->"0e41d849-72b2-4fbe-acdc-bae60576bca8"]
}, Open  ]],
Cell[673247, 12091, 800, 11, 34, "Text",ExpressionUUID->"d2845b1f-67a4-4183-b6ef-b498601995fd"],
Cell[CellGroupData[{
Cell[674072, 12106, 552, 11, 48, "Input",ExpressionUUID->"7c1759df-3d72-4500-860c-2dd4c373c9a0"],
Cell[674627, 12119, 6149, 85, 48, "Output",ExpressionUUID->"bdd91140-1835-4e44-8366-10e60aba0892"]
}, Open  ]],
Cell[680791, 12207, 903, 12, 34, "Text",ExpressionUUID->"312e9735-b698-47d1-8a41-0d85b37f1f59"],
Cell[CellGroupData[{
Cell[681719, 12223, 632, 12, 48, "Input",ExpressionUUID->"bf9dee48-da0c-4799-9b7a-a8cf2a44140f"],
Cell[682354, 12237, 6145, 85, 48, "Output",ExpressionUUID->"eeeb01d7-ee86-46f2-afaf-806f15d83313"]
}, Open  ]],
Cell[688514, 12325, 972, 13, 34, "Text",ExpressionUUID->"d456ddaf-7494-4d82-be28-242333493e6e"],
Cell[CellGroupData[{
Cell[689511, 12342, 911, 21, 28, "Input",ExpressionUUID->"0e215f92-9e3e-460f-bb0c-fa3125e0c73c"],
Cell[690425, 12365, 653, 13, 48, "Output",ExpressionUUID->"b83e0027-be18-4555-9307-17a1eabc2b52"]
}, Open  ]],
Cell[691093, 12381, 970, 13, 34, "Text",ExpressionUUID->"82a8b5f2-8067-46f3-bd04-7b49c5ef145c"],
Cell[CellGroupData[{
Cell[692088, 12398, 787, 18, 28, "Input",ExpressionUUID->"13c246d6-ddc6-4db3-a757-18c808abb93c"],
Cell[692878, 12418, 576, 9, 48, "Output",ExpressionUUID->"826521cf-c18e-40ac-8c0f-dc6534fe7ef9"]
}, Open  ]],
Cell[693469, 12430, 789, 11, 34, "Text",ExpressionUUID->"44538c4e-1e32-4e62-83c8-b7718d9697ea"],
Cell[CellGroupData[{
Cell[694283, 12445, 562, 11, 47, "Input",ExpressionUUID->"4b5f3777-f0ec-482e-99c6-1607ad258f3c"],
Cell[694848, 12458, 6115, 85, 48, "Output",ExpressionUUID->"a1878e83-be8d-4605-9584-5e115fdd2e12"]
}, Open  ]],
Cell[700978, 12546, 893, 12, 34, "Text",ExpressionUUID->"7d0cf9a0-3acd-42fb-ac58-b758e20e9bab"],
Cell[CellGroupData[{
Cell[701896, 12562, 636, 12, 47, "Input",ExpressionUUID->"5f50749e-a91c-4991-99cb-2687d628f86c"],
Cell[702535, 12576, 6124, 86, 48, "Output",ExpressionUUID->"2fbbbf13-6f42-461f-95ff-739bdc981fda"]
}, Open  ]],
Cell[708674, 12665, 733, 10, 34, "Text",ExpressionUUID->"e745e36a-4f70-481c-8fb6-6bb8fe578131"],
Cell[CellGroupData[{
Cell[709432, 12679, 557, 11, 47, "Input",ExpressionUUID->"305151c4-d677-4e89-8ccb-7d1d76c8b5ed"],
Cell[709992, 12692, 6077, 85, 48, "Output",ExpressionUUID->"33f90b24-73ae-4157-996d-76c20dce63e5"]
}, Open  ]],
Cell[716084, 12780, 842, 12, 34, "Text",ExpressionUUID->"e36a07fd-56c3-4cfb-8912-9cdfc5e191d1"],
Cell[CellGroupData[{
Cell[716951, 12796, 622, 12, 47, "Input",ExpressionUUID->"8aa73854-3a13-4f13-ad44-e3ae30c9c42c"],
Cell[717576, 12810, 6071, 86, 48, "Output",ExpressionUUID->"b911a057-0cb2-4102-8a41-718577084540"]
}, Open  ]],
Cell[723662, 12899, 520, 9, 34, "Text",ExpressionUUID->"21048f8a-6686-4931-a3eb-27fb0ceb9296"],
Cell[724185, 12910, 747, 10, 34, "Text",ExpressionUUID->"450fdd62-51c3-4ecb-af6d-2332ff3da21c"],
Cell[CellGroupData[{
Cell[724957, 12924, 608, 12, 48, "Input",ExpressionUUID->"56090cfd-1d7b-48fd-b0de-5dcca13a9788"],
Cell[725568, 12938, 6127, 85, 48, "Output",ExpressionUUID->"020c68e0-d79d-4a00-8f0f-ba0825169e60"]
}, Open  ]],
Cell[731710, 13026, 853, 12, 34, "Text",ExpressionUUID->"24eb6752-0047-4e28-89e2-f95f91f72967"],
Cell[CellGroupData[{
Cell[732588, 13042, 680, 13, 48, "Input",ExpressionUUID->"94afbe0c-530f-4e5c-ac5d-c29ef322b4d6"],
Cell[733271, 13057, 6118, 85, 48, "Output",ExpressionUUID->"e011244b-9bde-4198-886b-6ca3c607e190"]
}, Open  ]],
Cell[739404, 13145, 800, 11, 34, "Text",ExpressionUUID->"db0a1358-4a60-450f-b7cf-5f324b03ab1d"],
Cell[CellGroupData[{
Cell[740229, 13160, 609, 12, 48, "Input",ExpressionUUID->"723820a5-12be-4dc4-87e2-370f42900cb2"],
Cell[740841, 13174, 6127, 85, 48, "Output",ExpressionUUID->"71bc94c2-1824-4e6c-89ea-ec6f85adf1f1"]
}, Open  ]],
Cell[746983, 13262, 905, 12, 34, "Text",ExpressionUUID->"d63966ad-6121-4cf6-b01f-2fbdecdec67b"],
Cell[CellGroupData[{
Cell[747913, 13278, 687, 13, 48, "Input",ExpressionUUID->"68f53163-64e4-4bab-97c5-0be5b965d0c8"],
Cell[748603, 13293, 6117, 85, 48, "Output",ExpressionUUID->"80cb8a26-310c-4096-87ab-cfff9513506e"]
}, Open  ]],
Cell[754735, 13381, 970, 13, 34, "Text",ExpressionUUID->"7aaec84f-28ec-43dc-9c0d-7c24baf7c1d2"],
Cell[CellGroupData[{
Cell[755730, 13398, 953, 21, 28, "Input",ExpressionUUID->"0f6d3918-5b7f-4641-bec4-b82597f6ff62"],
Cell[756686, 13421, 617, 12, 48, "Output",ExpressionUUID->"eb74d6d8-3eb1-4b00-b28d-97bcf296caa2"]
}, Open  ]],
Cell[757318, 13436, 972, 13, 34, "Text",ExpressionUUID->"9dee2c40-173a-42b9-aeeb-7e163ad84820"],
Cell[CellGroupData[{
Cell[758315, 13453, 838, 19, 28, "Input",ExpressionUUID->"bfde672c-99ff-4d1c-a60f-c070caec272f"],
Cell[759156, 13474, 543, 9, 48, "Output",ExpressionUUID->"7b6bb156-3447-46fd-b379-fafa7ceb951b"]
}, Open  ]],
Cell[759714, 13486, 789, 11, 34, "Text",ExpressionUUID->"2090d4c0-b256-42fd-b0b9-855673c13eef"],
Cell[CellGroupData[{
Cell[760528, 13501, 612, 12, 47, "Input",ExpressionUUID->"de86e58c-bebe-4284-aaa1-d0f138eda711"],
Cell[761143, 13515, 6102, 85, 48, "Output",ExpressionUUID->"6e27bd25-37fd-4dfe-85b7-b32a947e9bce"]
}, Open  ]],
Cell[767260, 13603, 893, 12, 34, "Text",ExpressionUUID->"9b717b62-22c7-40d2-8555-3d175d47ea17"],
Cell[CellGroupData[{
Cell[768178, 13619, 685, 13, 47, "Input",ExpressionUUID->"80ee4855-2358-4c1e-8eb0-cfa9ea0d31e9"],
Cell[768866, 13634, 6133, 86, 48, "Output",ExpressionUUID->"f49a98eb-ac37-4bf3-a627-789c7361e641"]
}, Open  ]],
Cell[775014, 13723, 733, 10, 34, "Text",ExpressionUUID->"80e05d25-81b9-4c74-8b36-582590678ca5"],
Cell[CellGroupData[{
Cell[775772, 13737, 610, 12, 47, "Input",ExpressionUUID->"8de93699-9283-4fb5-8557-04fa7ddb7614"],
Cell[776385, 13751, 6062, 85, 48, "Output",ExpressionUUID->"c68fe749-5758-4ebb-9020-499375a5c8e3"]
}, Open  ]],
Cell[782462, 13839, 842, 12, 34, "Text",ExpressionUUID->"ac46c285-8b93-4bb6-bcdb-f882303c7001"],
Cell[CellGroupData[{
Cell[783329, 13855, 677, 13, 47, "Input",ExpressionUUID->"a1c615de-cb31-4f3e-a739-b80014746c13"],
Cell[784009, 13870, 6064, 86, 48, "Output",ExpressionUUID->"01e64a97-9b33-4538-9653-9e57858d6f1c"]
}, Open  ]],
Cell[790088, 13959, 1128, 16, 34, "Text",ExpressionUUID->"cfdf10cf-34a8-40d8-b0b1-39725aa5bbd3"],
Cell[791219, 13977, 747, 10, 34, "Text",ExpressionUUID->"87808b10-38b2-412a-a34f-6e65d6b3752c"],
Cell[CellGroupData[{
Cell[791991, 13991, 608, 12, 48, "Input",ExpressionUUID->"56d3ee65-2e64-4653-9ce7-3699a45d9e92"],
Cell[792602, 14005, 6128, 85, 48, "Output",ExpressionUUID->"2eed3bec-8afe-47dc-aaf5-9c1238d7db05"]
}, Open  ]],
Cell[798745, 14093, 848, 12, 34, "Text",ExpressionUUID->"340dbded-46cb-42bc-b420-65dd828b0c5b"],
Cell[CellGroupData[{
Cell[799618, 14109, 680, 13, 48, "Input",ExpressionUUID->"97a2aaff-8b6f-4bc3-b744-39d4f05435f7"],
Cell[800301, 14124, 6118, 85, 48, "Output",ExpressionUUID->"54cd18dc-9149-49eb-992e-98d85c897ac9"]
}, Open  ]],
Cell[806434, 14212, 800, 11, 34, "Text",ExpressionUUID->"65d42bae-b5c3-4483-b02f-77a2a2d19e21"],
Cell[CellGroupData[{
Cell[807259, 14227, 607, 12, 48, "Input",ExpressionUUID->"ec89fe8d-c64b-4802-9fa0-5fda4fec5080"],
Cell[807869, 14241, 6119, 85, 48, "Output",ExpressionUUID->"c2bdec5d-99ee-40df-9c35-ad169946a545"]
}, Open  ]],
Cell[814003, 14329, 903, 12, 34, "Text",ExpressionUUID->"9d2d41d9-d662-4692-b0f9-275af69086a3"],
Cell[CellGroupData[{
Cell[814931, 14345, 685, 13, 48, "Input",ExpressionUUID->"c68f8a88-0d37-4eca-8a0f-53c6953ed701"],
Cell[815619, 14360, 6124, 85, 48, "Output",ExpressionUUID->"f48469c9-c581-4a50-b5f7-c4d34ad5e887"]
}, Open  ]],
Cell[821758, 14448, 970, 13, 34, "Text",ExpressionUUID->"3a1d09b7-e021-4be5-9440-183f46789866"],
Cell[CellGroupData[{
Cell[822753, 14465, 974, 22, 28, "Input",ExpressionUUID->"f13aef5f-971b-4fd5-973c-dd47a644d343"],
Cell[823730, 14489, 624, 12, 48, "Output",ExpressionUUID->"ae41c65d-ee60-4d52-aab0-7f31406d2bb3"]
}, Open  ]],
Cell[824369, 14504, 1026, 14, 34, "Text",ExpressionUUID->"94b7fb62-ff27-41b0-b6cf-9ff2d7401e61"],
Cell[CellGroupData[{
Cell[825420, 14522, 881, 20, 28, "Input",ExpressionUUID->"c3180513-ab60-4ec9-8f7d-e65b660c3a99"],
Cell[826304, 14544, 1416, 21, 48, "Output",ExpressionUUID->"e4ac51ae-7dfa-4d03-b85a-24107eb3dda6"]
}, Open  ]],
Cell[827735, 14568, 789, 11, 34, "Text",ExpressionUUID->"db4d22e8-f123-44d4-bff8-821aad05b9af"],
Cell[CellGroupData[{
Cell[828549, 14583, 612, 12, 47, "Input",ExpressionUUID->"7b735c7b-feec-43a8-8952-9518e3c43679"],
Cell[829164, 14597, 6111, 85, 48, "Output",ExpressionUUID->"8ec64b2a-5be0-41c3-b938-b9ddc23aecdd"]
}, Open  ]],
Cell[835290, 14685, 893, 12, 34, "Text",ExpressionUUID->"4a4ee525-f758-4e09-8791-db558dedf73d"],
Cell[CellGroupData[{
Cell[836208, 14701, 689, 13, 47, "Input",ExpressionUUID->"573d1fcc-bc54-41d7-b61c-dd7a0174e352"],
Cell[836900, 14716, 6137, 86, 48, "Output",ExpressionUUID->"e924dab0-53c1-47b3-ba0b-1bc989ce473b"]
}, Open  ]],
Cell[843052, 14805, 733, 10, 34, "Text",ExpressionUUID->"d0b7c15b-ffd6-480e-aaae-f85490456529"],
Cell[CellGroupData[{
Cell[843810, 14819, 605, 12, 47, "Input",ExpressionUUID->"fdb2e803-a85d-4f0e-8038-c45ff26d0bf6"],
Cell[844418, 14833, 6062, 85, 48, "Output",ExpressionUUID->"765d4eb4-ca55-4159-ada2-838365b8fece"]
}, Open  ]],
Cell[850495, 14921, 844, 12, 34, "Text",ExpressionUUID->"041c5226-fdfa-4c79-81a8-519a191d2372"],
Cell[CellGroupData[{
Cell[851364, 14937, 673, 13, 47, "Input",ExpressionUUID->"5f9ee1b1-28df-43c7-a49e-dc5c6e8a2f98"],
Cell[852040, 14952, 6082, 86, 48, "Output",ExpressionUUID->"002c9f7d-a4a3-4aeb-bdcb-160c9c3b58c7"]
}, Open  ]],
Cell[858137, 15041, 936, 13, 34, "Text",ExpressionUUID->"13815c13-7ce0-400f-bac6-d5bef354e17d"],
Cell[859076, 15056, 1021, 14, 34, "Text",ExpressionUUID->"8d6f960c-cea6-4ac7-9d42-3184797329a6"],
Cell[CellGroupData[{
Cell[860122, 15074, 473, 10, 44, "Input",ExpressionUUID->"4be7ba51-cceb-4e00-9209-e3ee85fa7c30"],
Cell[860598, 15086, 6106, 85, 48, "Output",ExpressionUUID->"13df86d5-d886-4f8f-99a5-a42f72facc36"]
}, Open  ]],
Cell[866719, 15174, 774, 11, 34, "Text",ExpressionUUID->"c459d460-c983-4424-b98e-d057822b1f1b"],
Cell[CellGroupData[{
Cell[867518, 15189, 205, 6, 47, "Input",ExpressionUUID->"ea1630c7-69ec-469b-95ed-58312d9bf06e"],
Cell[867726, 15197, 259, 5, 48, "Output",ExpressionUUID->"08629e73-3982-4877-9f99-43ca95f8a55a"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

