(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1061301,      18494]
NotebookOptionsPosition[    989215,      17572]
NotebookOutlinePosition[    989557,      17587]
CellTagsIndexPosition[    989514,      17584]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["IUU Fishing: Economic Effects of IUU Imports on U.S. Commercial \
Fishers\n",
  FontSize->36],
 StyleBox["Species: Albacore, bigeye, bluefin, skipjack, yellowfin, bonito, \
other/NEI tuna",
  FontSize->24],
 StyleBox["\n",
  FontSize->18],
 StyleBox["Model Release",
  FontSize->18,
  FontSlant->"Italic"]
}], "Title",
 CellChangeTimes->{{3.7159437701501894`*^9, 3.715943776742571*^9}, {
   3.7160177883406353`*^9, 3.716017799612287*^9}, {3.716044926298222*^9, 
   3.7160449278653135`*^9}, {3.7167127367223215`*^9, 3.716712737322365*^9}, {
   3.716716446852584*^9, 3.716716448548705*^9}, {3.717141741657609*^9, 
   3.717141743761731*^9}, {3.717937945363772*^9, 3.7179379529402757`*^9}, {
   3.7185331704286838`*^9, 3.7185331826684923`*^9}, {3.7185539001319838`*^9, 
   3.7185539082355175`*^9}, {3.7847892842210164`*^9, 
   3.7847892988406277`*^9}, {3.787835927539494*^9, 3.7878359285709715`*^9}, {
   3.7879338873743715`*^9, 3.7879338874784536`*^9}, {3.791201099377099*^9, 
   3.7912011013376207`*^9}, 3.7954520024204845`*^9, {3.798810740721634*^9, 
   3.798810744523918*^9}, {3.799789945142694*^9, 3.7997899492227287`*^9}, {
   3.7998541778687954`*^9, 3.7998541814351215`*^9}, {3.8016687240812187`*^9, 
   3.8016687246281986`*^9}, {3.8017788040189447`*^9, 
   3.8017788092541156`*^9}, {3.819664877798711*^9, 3.819664951849766*^9}, {
   3.8199010796026187`*^9, 3.8199010810067167`*^9}, {3.8249771280972795`*^9, 
   3.824977134543296*^9}, {3.8252737056085243`*^9, 3.8252737197895765`*^9}, {
   3.8252843459454284`*^9, 3.825284362302237*^9}, {3.8254164750686984`*^9, 
   3.825416475583069*^9}},ExpressionUUID->"2abf6fd9-002f-4185-871b-\
88add9eaf8e9"],

Cell[TextData[{
 StyleBox["Read Me :",
  FontWeight->"Bold"],
 "\nThis model accompanies the USITC report, ",
 StyleBox["Seafood Obtained via Illegal, Unreported, and Unregulated Fishing: \
U.S. Imports and Economic Impact on U.S. Commercial Fisheries",
  FontSlant->"Italic"],
 ", Inv. 332-575. The report includes a quantitative analysis of the economic \
impact of IUU imports on U.S. commercial fishers and U.S. commercial fishing \
production, trade, and prices. Economic effects are modeled by species, with \
each species-level model customized to fit the unique features of the U.S. \
domestic industry. Consumers of seafood products choose between domestic \
marine-capture sources, imports, and in some models, domestic aquaculture \
products. Imports include both legal and IUU sources that enter the U.S. at \
the same price, so consumers cannot distinguish an IUU from non-IUU product. \
2018 data is used to establish an initial equilibrium with imports of IUU \
products included in the baseline. The model then removes the IUU imports, as \
estimated in chapter 3, and solves for a new equilibrium absent those \
products. \n\nIn the tuna model, there are domestic and imported  varieties \
of albacore, bigeye, bluefin, skipjack, yellowfin, bonito, and NEI tuna \
species. The model includes cross-species substitution, so relative price \
changes in one species affects the other species. Landings of some of the \
domestic varieties are potentially constrained by catch limits. There are two \
markets modeled: unprocessed and processed products. Landings  flow to three \
destinations: the unprocessed market, the processed market, or are exported \
outside the country. The price of the processed product is a constant markup \
over the price of the unprocessed price index, so increases in prices of \
unprocessed fish affect the price of processing.\n\nData inputs in the \
simulation are in the BLUE-shaded cells (with sources for the input data \
listed in the cell above). Outputs are in the GREEN-shaded cells. The white \
cells are intermediate calculations. "
}], "Text",
 CellChangeTimes->{{3.8151793544957237`*^9, 3.8151793654382553`*^9}, {
   3.815180147319877*^9, 3.8151801612046986`*^9}, 3.8193117353392124`*^9, {
   3.819364667233782*^9, 3.819364673128374*^9}, {3.819364986036234*^9, 
   3.81936502379967*^9}, {3.8193652789237294`*^9, 3.819365313721591*^9}, {
   3.819365363147914*^9, 3.819365382037648*^9}, {3.8193654602015305`*^9, 
   3.8193655738330727`*^9}, {3.819365634647441*^9, 3.8193657347144046`*^9}, {
   3.8193659700247307`*^9, 3.819365970554162*^9}, 3.8193660018247957`*^9, {
   3.819366258029726*^9, 3.819366301792824*^9}, {3.819366347287284*^9, 
   3.819366415704628*^9}, {3.8193664545638943`*^9, 3.819366511109967*^9}, {
   3.819366610713606*^9, 3.8193669391806083`*^9}, {3.8193669763456044`*^9, 
   3.8193670889590435`*^9}, {3.819367863082618*^9, 3.8193678631977077`*^9}, {
   3.819400007994233*^9, 3.819400030667904*^9}, {3.819400277598463*^9, 
   3.8194002936449785`*^9}, {3.8194011542913923`*^9, 
   3.8194012480694838`*^9}, {3.8194013222643557`*^9, 
   3.8194013264886327`*^9}, {3.8194013868456955`*^9, 
   3.8194013890784397`*^9}, {3.819401463985852*^9, 3.819401508238408*^9}, {
   3.8194019318657284`*^9, 3.8194019329005365`*^9}, {3.819665080356598*^9, 
   3.8196650954828777`*^9}, {3.8196652430795116`*^9, 3.819665263767852*^9}, {
   3.8196694045310993`*^9, 3.819669946270366*^9}, {3.819669976834861*^9, 
   3.8196705383246193`*^9}, {3.819670606948246*^9, 3.819670798460183*^9}, {
   3.819670860785177*^9, 3.8196709679574733`*^9}, {3.8196710056524982`*^9, 
   3.819671491943797*^9}, 3.819671563400182*^9, {3.819672484886944*^9, 
   3.8196724859338183`*^9}, {3.8199011533041058`*^9, 
   3.8199012321717076`*^9}, {3.8199021437167053`*^9, 3.819902144786538*^9}, {
   3.819904727337638*^9, 3.8199047710337067`*^9}, {3.820012303009897*^9, 
   3.820012307046046*^9}, {3.820012457109111*^9, 3.820012461730715*^9}, {
   3.821228471311254*^9, 3.821228478115568*^9}, {3.821228583604739*^9, 
   3.8212286069008274`*^9}, {3.821254034767659*^9, 3.8212540557230434`*^9}, {
   3.8212540945664053`*^9, 3.8212541288301916`*^9}, {3.821254184887725*^9, 
   3.8212542155085*^9}, {3.8249772744922485`*^9, 3.824977299960084*^9}, {
   3.824977554120001*^9, 3.8249776832165327`*^9}, {3.8249777599192657`*^9, 
   3.824977766653509*^9}, {3.82507490832841*^9, 3.825074908517795*^9}, 
   3.8250749591061897`*^9, {3.8250758189670277`*^9, 3.8250758195591617`*^9}, {
   3.8252737421440673`*^9, 3.825273870534485*^9}, {3.825284402800866*^9, 
   3.82528449314127*^9}, {3.8254164651168904`*^9, 3.825416467525764*^9}, {
   3.825416868731206*^9, 3.825416869097484*^9}},
 FontSize->12,
 Background->GrayLevel[
  0.85],ExpressionUUID->"d7c26f78-d972-4d0f-9a31-d7e886f36279"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ClearAll", "[", "f", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.791207469588732*^9, 3.7912074737709374`*^9}},
 CellLabel->
  "In[1425]:=",ExpressionUUID->"0c777ea8-191a-4659-be18-f91ea0d0ffda"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1. Model Parameters",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.795452962713849*^9}, {
  3.8196715794204283`*^9, 
  3.8196715805723763`*^9}},ExpressionUUID->"517e06c5-2c61-4dfb-8aa4-\
4255270c5ce4"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.1 Within-Species Elasticity of Substitution", \
"Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.819814333471882*^9, 3.8198143380684657`*^9}, 
   3.825091280816696*^9, {3.825273895919343*^9, 3.8252738984303055`*^9}, 
   3.825283933963739*^9},ExpressionUUID->"03237029-5661-4427-a540-\
f97f18ade571"],

Cell[TextData[StyleBox["Source: USITC\[CloseCurlyQuote]s econometric \
estimation using the trade cost method in Riker (2020). More information can \
be found in the technical appendix (appendix I). ",
 FontSize->12]], "Text",
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, 3.819672507377739*^9, 3.8252839339647446`*^9},
 FontSlant->"Italic",ExpressionUUID->"3f36d597-7089-46be-8bb4-f60d80facfed"],

Cell[TextData[{
 StyleBox["Unprocessed yellowfin:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of unprocessed yellowfin"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, 
   3.8252839339647446`*^9, {3.8252845324468517`*^9, 
   3.825284539425264*^9}},ExpressionUUID->"f278dafb-b0a3-47f2-b42a-\
c6740bad2fe6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmayu", " ", "=", "2.874731"}], " ", ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, 3.8048512034675865`*^9, {
   3.8048685945427647`*^9, 3.804868597324478*^9}, {3.804954434205166*^9, 
   3.8049544511156607`*^9}, {3.804954523810551*^9, 3.804954527582795*^9}, {
   3.8129689948020325`*^9, 3.812969030475193*^9}, 3.812969079206317*^9, 
   3.8129702895830336`*^9, 3.8129709824482408`*^9, 3.8252845446323204`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1426]:=",ExpressionUUID->"0d44e1c6-e9d4-484e-888a-97e11d7e3438"],

Cell[TextData[{
 StyleBox["Unprocessed skipjack:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of unprocessed skipjack"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, 
   3.8252839339647446`*^9, {3.8252845324468517`*^9, 
   3.8252845736648846`*^9}},ExpressionUUID->"305da441-e4b2-4c88-a30a-\
0f4485fe70b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmasu", " ", "=", " ", "8.450249"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.804851215720364*^9}, {3.804868607217617*^9, 3.8048686106688566`*^9}, 
   3.8049544891235495`*^9, {3.8049545291611643`*^9, 3.804954545944648*^9}, {
   3.812969165398632*^9, 3.812969204514695*^9}, 3.8129703022257013`*^9, 
   3.8129709916057954`*^9, 3.825284579310294*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1427]:=",ExpressionUUID->"68e3b805-5eb8-437a-a7f8-432c5dc38fa6"],

Cell[TextData[{
 StyleBox["Unprocessed albacore:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of unprocessed albacore"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, 
   3.8252839339647446`*^9, {3.8252845324468517`*^9, 3.8252845736648846`*^9}, {
   3.825284618102441*^9, 
   3.825284623376564*^9}},ExpressionUUID->"cd852049-49e8-4d96-85f5-\
0073c5261f5a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmaau", " ", "=", " ", "2.006154"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.804851225082076*^9}, 3.8048805400169473`*^9, {3.804954566685294*^9, 
   3.8049545899388914`*^9}, {3.812969296397897*^9, 3.8129693146987495`*^9}, 
   3.8129703171961193`*^9, 3.812971005714184*^9, {3.825284584207082*^9, 
   3.8252845849596925`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1428]:=",ExpressionUUID->"8ce1a048-b83e-4f20-84d6-e5ec15b6f8ef"],

Cell[TextData[{
 StyleBox["Unprocessed bigeye:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of unprocessed bigeye"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, 
   3.8252839339647446`*^9, {3.8252845324468517`*^9, 3.8252845736648846`*^9}, {
   3.8252846274887404`*^9, 
   3.825284632744852*^9}},ExpressionUUID->"068bf186-8ce7-4a16-8c9b-\
ab0065f645fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmabu", " ", "=", "2.580973"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.8048512302547855`*^9}, 3.804881140319895*^9, {3.8049546169116735`*^9, 
   3.804954630601733*^9}, 3.80495466178432*^9, {3.812969369564887*^9, 
   3.81296941374617*^9}, 3.8129703294636903`*^9, 3.812971016118782*^9, 
   3.8252845893721*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1429]:=",ExpressionUUID->"055efbdb-f3e0-4860-881d-c7aa622d1cfb"],

Cell[TextData[{
 StyleBox["Unprocessed bluefin:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of unprocessed bluefin"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, 
   3.8252839339647446`*^9, {3.8252845324468517`*^9, 3.8252845736648846`*^9}, {
   3.8252846382731247`*^9, 
   3.825284644249772*^9}},ExpressionUUID->"99d6af54-25a6-4f2f-9804-\
c57eac0a6168"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmafu", " ", "=", "6.044084"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.8048512302547855`*^9}, 3.804881140319895*^9, {3.8049546169116735`*^9, 
   3.804954630601733*^9}, {3.80495466178432*^9, 3.804954682787569*^9}, 
   3.8049547511373854`*^9, {3.81296943029541*^9, 3.812969456348509*^9}, {
   3.812969496543204*^9, 3.8129695008094664`*^9}, 3.812970340886936*^9, 
   3.8129710210571156`*^9, 3.825284593065971*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1430]:=",ExpressionUUID->"736de165-bccb-4534-80f2-371fc7549bff"],

Cell[TextData[{
 StyleBox["Unprocessed other/NEI tuna:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of unprocessed other tuna"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, 
   3.8252839339647446`*^9, {3.8252845324468517`*^9, 3.8252845736648846`*^9}, {
   3.8252846489534473`*^9, 
   3.8252846552994204`*^9}},ExpressionUUID->"a4660fac-a3ed-4d1d-9dcb-\
7d8476dde418"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmaou", " ", "=", "2.006154"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.8048512302547855`*^9}, 3.804881140319895*^9, {3.8049546169116735`*^9, 
   3.804954630601733*^9}, {3.80495466178432*^9, 3.8049547375584216`*^9}, 
   3.8056388361404037`*^9, 3.8129693366684985`*^9, 3.8129703551564035`*^9, 
   3.8129710279176483`*^9, 3.8252845967188168`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1431]:=",ExpressionUUID->"5fa0e8dd-4806-45d0-b98b-4ec2bc340d09"],

Cell[TextData[{
 StyleBox["Unprocessed bonito:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of unprocessed bonito"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, 
   3.8252839339647446`*^9, {3.8252845324468517`*^9, 3.8252845736648846`*^9}, {
   3.8252846609548063`*^9, 
   3.8252846649478827`*^9}},ExpressionUUID->"41262d7e-860c-4b62-9eb7-\
6e2dec4210a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmanu", " ", "=", " ", "8.450249"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.79979069392809*^9, 
   3.799790713217596*^9}, {3.7997908432747364`*^9, 3.799790848338091*^9}, {
   3.801687910574066*^9, 3.8016879229358225`*^9}, {3.804343514868375*^9, 
   3.804343515596942*^9}, {3.80434555373389*^9, 3.8043455543823943`*^9}, {
   3.804346846918324*^9, 3.8043468505211263`*^9}, {3.8043468863910894`*^9, 
   3.8043468898667946`*^9}, 3.8045868777607365`*^9, {3.8048512034675865`*^9, 
   3.8048512302547855`*^9}, 3.804881140319895*^9, {3.8049546169116735`*^9, 
   3.804954630601733*^9}, {3.80495466178432*^9, 3.8049547375584216`*^9}, {
   3.80563878800198*^9, 3.8056388199259*^9}, {3.8056389382701254`*^9, 
   3.8056389386295586`*^9}, 3.812969223033142*^9, 3.8129703103676443`*^9, 
   3.8129710339655437`*^9, 3.8252846003346786`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1432]:=",ExpressionUUID->"a4d05cc6-db6e-481b-a738-0d8a052a4bd8"],

Cell[TextData[{
 StyleBox["Processed yellowfin:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of processed yellowfin"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, 
   3.8252839339647446`*^9, {3.8252845324468517`*^9, 3.825284539425264*^9}, {
   3.825284690537822*^9, 
   3.8252846940615654`*^9}},ExpressionUUID->"4ea1a8bf-4a19-43ca-a0e3-\
ec4ba042a21b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmayp", " ", "=", "2.874731"}], " ", ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.7997907022612257`*^9, 
   3.799790709387388*^9}, 3.7997908508541403`*^9, {3.8016879044513836`*^9, 
   3.801687907933004*^9}, {3.80434351778264*^9, 3.804343518580264*^9}, {
   3.804345558282427*^9, 3.8043455585966744`*^9}, {3.804346895174925*^9, 
   3.8043468962187347`*^9}, 3.804586879762295*^9, 3.8048512431162453`*^9, 
   3.804868602716875*^9, {3.804954457851077*^9, 3.8049544706351156`*^9}, 
   3.80495455340016*^9, 3.812969085302324*^9, 3.8129702924116173`*^9, 
   3.8129709850111732`*^9, 3.82528468132362*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1433]:=",ExpressionUUID->"c017ae61-50e3-4e2b-95bf-5feaa1a06257"],

Cell[TextData[{
 StyleBox["Processed skipjack:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of processed skipjack"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, 
   3.8252839339647446`*^9, {3.8252845324468517`*^9, 3.8252845736648846`*^9}, {
   3.8252847018696055`*^9, 
   3.825284706462146*^9}},ExpressionUUID->"21ff44cf-7e4a-471f-a380-\
85b4996c402f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmasp", " ", "=", " ", "8.450249"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.7997907022612257`*^9, 
   3.799790709387388*^9}, 3.7997908508541403`*^9, {3.8016879044513836`*^9, 
   3.801687907933004*^9}, {3.80434351778264*^9, 3.804343518580264*^9}, {
   3.804345558282427*^9, 3.8043455585966744`*^9}, {3.804346895174925*^9, 
   3.8043468962187347`*^9}, 3.804586879762295*^9, 3.8048512467105775`*^9, 
   3.8048686172796335`*^9, 3.8049545102161703`*^9, {3.804954548665053*^9, 
   3.804954559137251*^9}, 3.81296922934925*^9, 3.812970305351205*^9, 
   3.81297099680643*^9, 3.8252847103492193`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1434]:=",ExpressionUUID->"533415a2-f3ea-4ef5-85ba-7748e917b5c2"],

Cell[TextData[{
 StyleBox["Processed albacore:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of processed albacore"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, 
   3.8252839339647446`*^9, {3.8252845324468517`*^9, 3.8252845736648846`*^9}, {
   3.825284618102441*^9, 3.825284623376564*^9}, {3.825284719269147*^9, 
   3.8252847238706827`*^9}},ExpressionUUID->"1081b860-73e1-40b0-8e00-\
de2e82acab7d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmaap", " ", "=", " ", "2.006154"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.7997907022612257`*^9, 
   3.799790709387388*^9}, 3.7997908508541403`*^9, {3.8016879044513836`*^9, 
   3.801687907933004*^9}, {3.80434351778264*^9, 3.804343518580264*^9}, {
   3.804345558282427*^9, 3.8043455585966744`*^9}, {3.804346895174925*^9, 
   3.8043468962187347`*^9}, 3.804586879762295*^9, 3.804851250648714*^9, 
   3.8048805424751306`*^9, {3.8049545764368024`*^9, 3.804954592626807*^9}, 
   3.8129693408723125`*^9, 3.8129703225719852`*^9, 3.812971009183519*^9, 
   3.8252847269961567`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1435]:=",ExpressionUUID->"a8f7002f-56e2-4375-9543-6dc993f93f6b"],

Cell[TextData[{
 StyleBox["Processed bigeye:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of processed bigeye"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, 
   3.8252839339647446`*^9, {3.8252845324468517`*^9, 3.8252845736648846`*^9}, {
   3.8252846274887404`*^9, 3.825284632744852*^9}, {3.8252847360391636`*^9, 
   3.8252847404176674`*^9}},ExpressionUUID->"c3fdf390-356d-4cc6-8d85-\
6440cd02d47e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmabp", " ", "=", "2.580973"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.7997907022612257`*^9, 
   3.799790709387388*^9}, 3.7997908508541403`*^9, {3.8016879044513836`*^9, 
   3.801687907933004*^9}, {3.80434351778264*^9, 3.804343518580264*^9}, {
   3.804345558282427*^9, 3.8043455585966744`*^9}, {3.804346895174925*^9, 
   3.8043468962187347`*^9}, 3.804586879762295*^9, 3.8048512543836975`*^9, 
   3.804881142554628*^9, {3.804954647729004*^9, 3.804954693556073*^9}, 
   3.81296942312251*^9, 3.8129703352923145`*^9, 3.8129710555492535`*^9, 
   3.8252847439713697`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1436]:=",ExpressionUUID->"8dd6a94f-4fc4-4e80-ab90-562d9f76b879"],

Cell[TextData[{
 StyleBox["Processed bluefin:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of processed bluefin"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, 
   3.8252839339647446`*^9, {3.8252845324468517`*^9, 3.8252845736648846`*^9}, {
   3.8252846382731247`*^9, 3.825284644249772*^9}, {3.825284750703635*^9, 
   3.825284754931944*^9}},ExpressionUUID->"41003bd7-61eb-44f3-877d-\
50672c5544bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmafp", " ", "=", "6.044084"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.7997907022612257`*^9, 
   3.799790709387388*^9}, 3.7997908508541403`*^9, {3.8016879044513836`*^9, 
   3.801687907933004*^9}, {3.80434351778264*^9, 3.804343518580264*^9}, {
   3.804345558282427*^9, 3.8043455585966744`*^9}, {3.804346895174925*^9, 
   3.8043468962187347`*^9}, 3.804586879762295*^9, 3.8048512543836975`*^9, 
   3.804881142554628*^9, {3.804954647729004*^9, 3.8049546978379855`*^9}, 
   3.804954747700694*^9, 3.812969512780004*^9, 3.8129703449813247`*^9, 
   3.81297106450389*^9, 3.8252847581724887`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1437]:=",ExpressionUUID->"57daa648-c088-4e52-bcaf-7fd6e60f3c95"],

Cell[TextData[{
 StyleBox["Processed other/NEI tuna:",
  FontWeight->"Bold"],
 " elasticity of substitution across varieties of processed other tuna"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8043434902111883`*^9, 
   3.804343509058856*^9}, {3.8043435528349133`*^9, 3.804343553318289*^9}, 
   3.807310274768487*^9, {3.825091389194928*^9, 3.8250913935786924`*^9}, 
   3.825091463304398*^9, {3.8252740935018883`*^9, 3.8252741080312543`*^9}, 
   3.8252839339647446`*^9, {3.8252845324468517`*^9, 3.8252845736648846`*^9}, {
   3.8252846489534473`*^9, 3.8252846552994204`*^9}, {3.8252847674077024`*^9, 
   3.825284771185656*^9}},ExpressionUUID->"3e4064cc-9d82-48ab-8bf9-\
7623327d68d5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmaop", " ", "=", "2.006154"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.7997907022612257`*^9, 
   3.799790709387388*^9}, 3.7997908508541403`*^9, {3.8016879044513836`*^9, 
   3.801687907933004*^9}, {3.80434351778264*^9, 3.804343518580264*^9}, {
   3.804345558282427*^9, 3.8043455585966744`*^9}, {3.804346895174925*^9, 
   3.8043468962187347`*^9}, 3.804586879762295*^9, 3.8048512543836975`*^9, 
   3.804881142554628*^9, {3.804954647729004*^9, 3.804954734682952*^9}, 
   3.81296935199905*^9, 3.8129703506869574`*^9, 3.8129710717082305`*^9, 
   3.82528477534096*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1438]:=",ExpressionUUID->"5450ec01-cd65-490d-ae15-228cbfd00b31"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.2 Cross-Species Elasticity of Substitution", \
"Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, 3.8196725148810096`*^9, {
   3.8198143408736553`*^9, 3.819814345001872*^9}, 
   3.825283933965747*^9},ExpressionUUID->"3531cf0e-4bdb-47e5-a3b9-\
150e2b2fb400"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate and Interviews with \
Industry Participants.",
 FontSize->12]], "Text",
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725148810096`*^9, 3.820012465372556*^9, {3.8200125245600863`*^9, 
   3.8200125375572243`*^9}, 3.8252839339667053`*^9},
 FontSlant->"Italic",ExpressionUUID->"f243d91d-e511-408d-bee1-61c634cee729"],

Cell[TextData[{
 StyleBox["Unprocessed:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across unprocessed products",
  FontSize->14]
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, {3.819672030964613*^9, 3.8196720315651684`*^9}, {
   3.819672128429147*^9, 3.819672157389882*^9}, 3.8196725148810096`*^9, {
   3.8198159557829914`*^9, 3.819815955882069*^9}, {3.824978024405224*^9, 
   3.824978028343289*^9}, 
   3.8252839339667053`*^9},ExpressionUUID->"3fc7ed24-77c5-455b-8ca4-\
f0c589a68f88"],

Cell[BoxData[
 RowBox[{
  RowBox[{"betau", "=", "3.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.7997907022612257`*^9, 
   3.799790709387388*^9}, 3.7997908508541403`*^9, {3.8016879044513836`*^9, 
   3.801687907933004*^9}, {3.80434351778264*^9, 3.804343518580264*^9}, {
   3.804345558282427*^9, 3.8043455585966744`*^9}, {3.804346895174925*^9, 
   3.8043468962187347`*^9}, 3.804586879762295*^9, 3.8048512543836975`*^9, {
   3.804851294142619*^9, 3.8048513020969067`*^9}, {3.8048596891343603`*^9, 
   3.8048596894469223`*^9}, {3.804866261943138*^9, 3.804866262021276*^9}, {
   3.8129756645879774`*^9, 3.81297566507374*^9}, {3.812976065003236*^9, 
   3.812976065347055*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1439]:=",ExpressionUUID->"4fd17059-e35b-4fb4-a35c-25e07440d9a4"],

Cell[TextData[{
 StyleBox["Processed:",
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[" elasticity of substitution across processed products",
  FontSize->14]
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7988095955521545`*^9, 
   3.7988095975004187`*^9}, {3.799061778490183*^9, 3.7990617986470795`*^9}, {
   3.799790675748479*^9, 3.799790691623108*^9}, {3.8057104606814175`*^9, 
   3.805710471168848*^9}, {3.8057107549562483`*^9, 3.805710755237546*^9}, {
   3.8196717127197847`*^9, 3.8196717150136585`*^9}, {3.8196717749776273`*^9, 
   3.819671804606634*^9}, {3.819671893067898*^9, 3.819671897578418*^9}, {
   3.8196720341255374`*^9, 3.8196720347751384`*^9}, {3.8196721610431147`*^9, 
   3.8196721644200883`*^9}, 3.8196725148810096`*^9, {3.8198159580197334`*^9, 
   3.81981595815784*^9}, {3.8249780325525694`*^9, 3.8249780336674385`*^9}, 
   3.8252839339667053`*^9},ExpressionUUID->"56f7e9fc-6e92-4f88-a28d-\
81abff6d4228"],

Cell[BoxData[
 RowBox[{
  RowBox[{"betap", "=", "3.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954523705766106`*^9, 3.795452399957446*^9}, {3.795777226915077*^9, 
   3.795777227071198*^9}, {3.7958865543611183`*^9, 3.7958865833766713`*^9}, {
   3.798809914212205*^9, 3.7988099143741198`*^9}, {3.799060943455057*^9, 
   3.7990609486270747`*^9}, {3.799410440906518*^9, 3.799410449559279*^9}, {
   3.7994105216446056`*^9, 3.799410532503096*^9}, {3.7997907022612257`*^9, 
   3.799790709387388*^9}, 3.7997908508541403`*^9, {3.8016879044513836`*^9, 
   3.801687907933004*^9}, {3.80434351778264*^9, 3.804343518580264*^9}, {
   3.804345558282427*^9, 3.8043455585966744`*^9}, {3.804346895174925*^9, 
   3.8043468962187347`*^9}, 3.804586879762295*^9, 3.8048512543836975`*^9, {
   3.8048512977994776`*^9, 3.8048513053474474`*^9}, {3.8048596921193275`*^9, 
   3.8048596924318895`*^9}, {3.812975668068129*^9, 3.812975668579527*^9}, {
   3.812976067972455*^9, 3.812976068316268*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1440]:=",ExpressionUUID->"db89f93a-949b-46ca-894d-70d3b9066f1e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.3 Industry Price Elasticity of Demand", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, 3.8196725271002216`*^9, {3.819814291546197*^9, 
   3.819814297331707*^9}, {3.8198143479321556`*^9, 3.8198143530561504`*^9}, 
   3.8252839339667053`*^9},ExpressionUUID->"4a3c1059-a976-4ef7-99b8-\
2bf766b2ed1f"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate.",
 FontSize->12]], "Text",
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725271002216`*^9, 3.820012468652115*^9, {3.8200125463901167`*^9, 
   3.8200125607253003`*^9}, 3.8252839339667053`*^9},
 FontSlant->"Italic",ExpressionUUID->"597e6432-cce0-4c12-a0ae-e809c370a5e3"],

Cell[TextData[StyleBox["Unprocessed",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.8016643815964966`*^9, 3.80166438203933*^9}, {
   3.8031104952208443`*^9, 3.8031105339530745`*^9}, {3.803118428298416*^9, 
   3.8031184400395803`*^9}, 3.8033028142898912`*^9, {3.80571075980079*^9, 
   3.8057107601133404`*^9}, {3.8196721218802958`*^9, 
   3.8196721245096445`*^9}, {3.8196721773104386`*^9, 3.8196721827752504`*^9}, 
   3.8196725271002216`*^9, 
   3.8252839339667053`*^9},ExpressionUUID->"082b57cb-ebe3-4204-9d92-\
61c87951f3dc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"etau", "=", " ", 
   RowBox[{"-", "1.0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, 
   3.8016643791586046`*^9, {3.801780399382991*^9, 3.8017804002581425`*^9}, 
   3.803110491929274*^9, {3.819672112733116*^9, 3.819672113234567*^9}, 
   3.819672527101222*^9, 3.8252839339677377`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1441]:=",ExpressionUUID->"ef0cd2cc-52e7-4867-9480-1d37f54c21bb"],

Cell[TextData[StyleBox["Processed",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.8016643815964966`*^9, 
   3.8016643912751904`*^9}, {3.8031105485584755`*^9, 
   3.8031105510724382`*^9}, {3.805710761160388*^9, 3.805710761519824*^9}, {
   3.819672173174797*^9, 3.8196721856998253`*^9}, 3.819672527101222*^9, 
   3.8252839339677377`*^9},ExpressionUUID->"5504e614-8769-4076-8e8b-\
fce7daf050a8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"etap", "=", " ", 
   RowBox[{"-", "1.0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016643791586046`*^9, 3.801664387008879*^9}, {3.80178040319617*^9, 
   3.801780404211971*^9}, {3.819672116662634*^9, 3.819672117252161*^9}, 
   3.819672527101222*^9, 3.8252839339687376`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1442]:=",ExpressionUUID->"7cf74d41-9cc5-4d57-8fe6-2b581b7d2fab"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.4 Illegal Imports Replacement Rates", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, {3.81967219811668*^9, 3.819672213143815*^9}, 
   3.819672537084565*^9, {3.819814300125886*^9, 3.8198143058253307`*^9}, {
   3.8198143561535683`*^9, 3.8198143611354523`*^9}, 
   3.8252839339687376`*^9},ExpressionUUID->"20964efa-eaca-4fe6-a533-\
46d0e1979dda"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate.  Further discussion on \
qualitative factors and rate determination can be found in appendix I of the \
USITC\[CloseCurlyQuote]s report.",
 FontSize->12]], "Text",
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196723427492237`*^9, 3.8196725370855665`*^9, {3.819815993710532*^9, 
   3.819815996531728*^9}, {3.8198381383987584`*^9, 3.819838144753663*^9}, {
   3.8198382402870555`*^9, 3.8198383754614663`*^9}, 3.8200124721278267`*^9, {
   3.820012579354833*^9, 3.8200125899691114`*^9}, 3.8252839339687376`*^9},
 FontSlant->"Italic",ExpressionUUID->"77231342-2d17-438f-bc05-f5b32cebff9d"],

Cell[TextData[{
 StyleBox["Yellowfin: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of yellowfin"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}, {3.8252743225014563`*^9, 3.8252743303151894`*^9}, 
   3.8252839339687376`*^9, {3.8252848205032315`*^9, 
   3.825284826700097*^9}},ExpressionUUID->"c1cdbe04-4f74-42c7-a18c-\
3f5f31a57dd5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"reply", " ", "=", "0.30"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662885297171*^9}, {3.8016683902542915`*^9, 
   3.801668392194314*^9}, {3.801668476343513*^9, 3.8016684764529057`*^9}, {
   3.8016685159337964`*^9, 3.801668531426852*^9}, 3.801692415143248*^9, {
   3.8016926196184893`*^9, 3.801692619774764*^9}, {3.801780289233728*^9, 
   3.8017802906278515`*^9}, 3.8033028464480004`*^9, 3.8033032141861067`*^9, {
   3.80339474346602*^9, 3.803394743762943*^9}, {3.8033948509102745`*^9, 
   3.80339485100404*^9}, 3.803397269400152*^9, 3.804343569032516*^9, {
   3.8043441779843903`*^9, 3.8043441785348186`*^9}, {3.804345528212033*^9, 
   3.8043455283191147`*^9}, {3.8043482483389072`*^9, 3.804348250335457*^9}, {
   3.804348999502578*^9, 3.8043489995996523`*^9}, {3.8043490925820007`*^9, 
   3.8043490927291145`*^9}, {3.80451933962536*^9, 3.804519339859774*^9}, {
   3.8045205567782145`*^9, 3.804520557247041*^9}, {3.804521073038145*^9, 
   3.8045210732569275`*^9}, {3.804521152663441*^9, 3.804521152757205*^9}, {
   3.804521464187267*^9, 3.8045214643279123`*^9}, {3.804545874319066*^9, 
   3.8045458744753385`*^9}, {3.8045460890897703`*^9, 
   3.8045460891835356`*^9}, {3.804546190142262*^9, 3.804546190595456*^9}, {
   3.8045868865938334`*^9, 3.8045868868282475`*^9}, {3.8045916336063304`*^9, 
   3.8045916336844664`*^9}, {3.804591811382941*^9, 3.804591811507962*^9}, 
   3.8048513408389482`*^9, {3.804858869583768*^9, 3.8048588697400417`*^9}, {
   3.8048672372703323`*^9, 3.8048672375047445`*^9}, 3.8048969343130455`*^9, {
   3.805017086905365*^9, 3.805017089015106*^9}, {3.805637808410037*^9, 
   3.8056378090038867`*^9}, {3.8056379076532135`*^9, 3.805637931934962*^9}, 
   3.8056379957718706`*^9, {3.807307006333758*^9, 3.807307019161743*^9}, {
   3.8073081603908587`*^9, 3.80730816050895*^9}, {3.807309185794177*^9, 
   3.8073091859813223`*^9}, {3.807882911754636*^9, 3.8078829119109116`*^9}, {
   3.807884045379134*^9, 3.807884045504155*^9}, {3.8078848547846518`*^9, 
   3.8078848548940444`*^9}, {3.8100444413184404`*^9, 
   3.8100444416727176`*^9}, {3.8124705169102864`*^9, 3.812470517165485*^9}, {
   3.8139968297754774`*^9, 3.813996831832076*^9}, {3.8139968681033115`*^9, 
   3.8139968685956936`*^9}, {3.8139996387472754`*^9, 
   3.8139996393177185`*^9}, {3.814026832390547*^9, 3.8140268398093185`*^9}, {
   3.81402701375874*^9, 3.814027015747288*^9}, {3.825284830184804*^9, 
   3.825284830666236*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1443]:=",ExpressionUUID->"e71883ba-93a1-4219-bd68-67879f88fe63"],

Cell[TextData[{
 StyleBox["Skipjack: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of skipjack"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}, {3.8252743225014563`*^9, 3.8252743303151894`*^9}, 
   3.8252839339687376`*^9, {3.8252848205032315`*^9, 
   3.825284850075366*^9}},ExpressionUUID->"60932962-a7e4-4584-a2ea-\
aab5ab59a767"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"repls", " ", "=", " ", "0.50"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662885297171*^9}, {3.8016683902542915`*^9, 
   3.801668392194314*^9}, {3.801668476343513*^9, 3.8016684764529057`*^9}, {
   3.8016685159337964`*^9, 3.801668531426852*^9}, 3.801692415143248*^9, {
   3.8016926196184893`*^9, 3.801692619774764*^9}, {3.801780289233728*^9, 
   3.8017802906278515`*^9}, 3.8033028464480004`*^9, 3.8033032141861067`*^9, {
   3.80339474346602*^9, 3.803394743762943*^9}, {3.8033948509102745`*^9, 
   3.80339485100404*^9}, 3.803397269400152*^9, 3.804343569032516*^9, {
   3.8043441779843903`*^9, 3.8043441785348186`*^9}, {3.804345528212033*^9, 
   3.8043455283191147`*^9}, {3.8043482483389072`*^9, 3.804348250335457*^9}, {
   3.804348999502578*^9, 3.8043489995996523`*^9}, {3.8043490925820007`*^9, 
   3.8043490927291145`*^9}, {3.80451933962536*^9, 3.804519339859774*^9}, {
   3.8045205567782145`*^9, 3.804520557247041*^9}, {3.804521073038145*^9, 
   3.8045210732569275`*^9}, {3.804521152663441*^9, 3.804521152757205*^9}, {
   3.804521464187267*^9, 3.8045214643279123`*^9}, {3.804545874319066*^9, 
   3.8045458744753385`*^9}, {3.8045460890897703`*^9, 
   3.8045460891835356`*^9}, {3.804546190142262*^9, 3.804546190595456*^9}, {
   3.8045868865938334`*^9, 3.8045868868282475`*^9}, {3.8045916336063304`*^9, 
   3.8045916336844664`*^9}, {3.804591811382941*^9, 3.804591811507962*^9}, 
   3.8048513408389482`*^9, {3.804858869583768*^9, 3.8048588697400417`*^9}, {
   3.8048672372703323`*^9, 3.8048672375047445`*^9}, 3.8048969343130455`*^9, {
   3.805017086905365*^9, 3.805017089015106*^9}, {3.805637808410037*^9, 
   3.8056378090038867`*^9}, {3.805637839479997*^9, 3.8056378395425076`*^9}, {
   3.805637928829769*^9, 3.805637935794962*^9}, {3.80563799728349*^9, 
   3.8056380004551644`*^9}, {3.80730701006466*^9, 3.80730702271651*^9}, {
   3.8073081627747116`*^9, 3.807308162920826*^9}, {3.807309188629385*^9, 
   3.807309188747476*^9}, {3.8078829149739237`*^9, 3.8078829151145725`*^9}, {
   3.807884048623297*^9, 3.8078840487952013`*^9}, {3.8078848575194664`*^9, 
   3.8078848576757417`*^9}, {3.8100444440565834`*^9, 3.810044444153659*^9}, {
   3.8124705114750643`*^9, 3.8124705225316668`*^9}, {3.813996834344035*^9, 
   3.813996836302557*^9}, {3.813996870752377*^9, 3.8139968713818655`*^9}, 
   3.81399966789194*^9, {3.8140268427045755`*^9, 3.8140268472431097`*^9}, {
   3.8140270190668716`*^9, 3.814027021250575*^9}, 3.825284853822337*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1444]:=",ExpressionUUID->"3570a921-8175-4c5b-ac71-ad5fa82485de"],

Cell[TextData[{
 StyleBox["Albacore: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of albacore"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}, {3.8252743225014563`*^9, 3.8252743303151894`*^9}, 
   3.8252839339687376`*^9, {3.8252848205032315`*^9, 3.825284826700097*^9}, {
   3.8252848582017193`*^9, 
   3.8252848656496153`*^9}},ExpressionUUID->"bb2b7b0d-5f40-49bc-9c52-\
bd9acea698b1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"repla", " ", "=", "  ", "0.50"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662885297171*^9}, {3.8016683902542915`*^9, 
   3.801668392194314*^9}, {3.801668476343513*^9, 3.8016684764529057`*^9}, {
   3.8016685159337964`*^9, 3.801668531426852*^9}, 3.801692415143248*^9, {
   3.8016926196184893`*^9, 3.801692619774764*^9}, {3.801780289233728*^9, 
   3.8017802906278515`*^9}, 3.8033028464480004`*^9, 3.8033032141861067`*^9, {
   3.80339474346602*^9, 3.803394743762943*^9}, {3.8033948509102745`*^9, 
   3.80339485100404*^9}, 3.803397269400152*^9, 3.804343569032516*^9, {
   3.8043441779843903`*^9, 3.8043441785348186`*^9}, {3.804345528212033*^9, 
   3.8043455283191147`*^9}, {3.8043482483389072`*^9, 3.804348250335457*^9}, {
   3.804348999502578*^9, 3.8043489995996523`*^9}, {3.8043490925820007`*^9, 
   3.8043490927291145`*^9}, {3.80451933962536*^9, 3.804519339859774*^9}, {
   3.8045205567782145`*^9, 3.804520557247041*^9}, {3.804521073038145*^9, 
   3.8045210732569275`*^9}, {3.804521152663441*^9, 3.804521152757205*^9}, {
   3.804521464187267*^9, 3.8045214643279123`*^9}, {3.804545874319066*^9, 
   3.8045458744753385`*^9}, {3.8045460890897703`*^9, 
   3.8045460891835356`*^9}, {3.804546190142262*^9, 3.804546190595456*^9}, {
   3.8045868865938334`*^9, 3.8045868868282475`*^9}, {3.8045916336063304`*^9, 
   3.8045916336844664`*^9}, {3.804591811382941*^9, 3.804591811507962*^9}, 
   3.8048513408389482`*^9, {3.804858869583768*^9, 3.8048588697400417`*^9}, {
   3.8048672372703323`*^9, 3.8048672375047445`*^9}, 3.8048969343130455`*^9, {
   3.805017086905365*^9, 3.805017089015106*^9}, {3.805637808410037*^9, 
   3.8056378090038867`*^9}, {3.805637843341254*^9, 3.8056378458573027`*^9}, 
   3.8056379494388447`*^9, 3.8056380018847294`*^9, {3.8073070139246683`*^9, 
   3.8073070256898212`*^9}, {3.8073081654828186`*^9, 3.807308165628934*^9}, {
   3.807309190757039*^9, 3.807309190923169*^9}, 3.8078828549289255`*^9, {
   3.8078829178493986`*^9, 3.807882917943164*^9}, {3.807884051313525*^9, 
   3.807884051469801*^9}, {3.8078848609286976`*^9, 3.8078848610537176`*^9}, {
   3.810044447197035*^9, 3.8100444473341417`*^9}, {3.812470527012166*^9, 
   3.812470527169289*^9}, {3.8139968385883403`*^9, 3.8139968404377766`*^9}, {
   3.813996873500513*^9, 3.813996874119995*^9}, 3.8139996648395615`*^9, {
   3.8140268498621454`*^9, 3.8140268528254547`*^9}, {3.814027024993485*^9, 
   3.8140270270600977`*^9}, {3.825284869048283*^9, 3.8252848711778803`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1445]:=",ExpressionUUID->"8084d100-1196-49fa-a6db-fe6657cbfd2a"],

Cell[TextData[{
 StyleBox["Bigeye: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of bigeye"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}, {3.8252743225014563`*^9, 3.8252743303151894`*^9}, 
   3.8252839339687376`*^9, {3.8252848205032315`*^9, 3.825284826700097*^9}, {
   3.8252848957070723`*^9, 
   3.8252849017237635`*^9}},ExpressionUUID->"97fd0de6-9d1f-4bff-b3cc-\
094d217cb0e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"replb", " ", "=", "0.30"}], " ", ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662885297171*^9}, {3.8016683902542915`*^9, 
   3.801668392194314*^9}, {3.801668476343513*^9, 3.8016684764529057`*^9}, {
   3.8016685159337964`*^9, 3.801668531426852*^9}, 3.801692415143248*^9, {
   3.8016926196184893`*^9, 3.801692619774764*^9}, {3.801780289233728*^9, 
   3.8017802906278515`*^9}, 3.8033028464480004`*^9, 3.8033032141861067`*^9, {
   3.80339474346602*^9, 3.803394743762943*^9}, {3.8033948509102745`*^9, 
   3.80339485100404*^9}, 3.803397269400152*^9, 3.804343569032516*^9, {
   3.8043441779843903`*^9, 3.8043441785348186`*^9}, {3.804345528212033*^9, 
   3.8043455283191147`*^9}, {3.8043482483389072`*^9, 3.804348250335457*^9}, {
   3.804348999502578*^9, 3.8043489995996523`*^9}, {3.8043490925820007`*^9, 
   3.8043490927291145`*^9}, {3.80451933962536*^9, 3.804519339859774*^9}, {
   3.8045205567782145`*^9, 3.804520557247041*^9}, {3.804521073038145*^9, 
   3.8045210732569275`*^9}, {3.804521152663441*^9, 3.804521152757205*^9}, {
   3.804521464187267*^9, 3.8045214643279123`*^9}, {3.804545874319066*^9, 
   3.8045458744753385`*^9}, {3.8045460890897703`*^9, 
   3.8045460891835356`*^9}, {3.804546190142262*^9, 3.804546190595456*^9}, {
   3.8045868865938334`*^9, 3.8045868868282475`*^9}, {3.8045916336063304`*^9, 
   3.8045916336844664`*^9}, {3.804591811382941*^9, 3.804591811507962*^9}, 
   3.8048513408389482`*^9, {3.804858869583768*^9, 3.8048588697400417`*^9}, {
   3.8048672372703323`*^9, 3.8048672375047445`*^9}, 3.8048969343130455`*^9, {
   3.805017086905365*^9, 3.805017089015106*^9}, {3.805637808410037*^9, 
   3.8056378090038867`*^9}, {3.80563784962342*^9, 3.805637850060994*^9}, {
   3.8056379572848544`*^9, 3.805637967093734*^9}, 3.8056380038482428`*^9, {
   3.8073070286551275`*^9, 3.807307029234577*^9}, {3.8073081687603703`*^9, 
   3.8073081689655294`*^9}, {3.807309193424114*^9, 3.807309193660299*^9}, 
   3.8078828756862574`*^9, {3.8078829211155696`*^9, 3.807882921224963*^9}, {
   3.807884054157751*^9, 3.807884054407793*^9}, {3.8078848647105556`*^9, 
   3.8078848648355756`*^9}, {3.8100444502694387`*^9, 3.8100444504756*^9}, {
   3.812470531255483*^9, 3.812470531432622*^9}, {3.8139968431468897`*^9, 
   3.813996844928274*^9}, {3.8139968763547373`*^9, 3.813996876896158*^9}, {
   3.813999645366426*^9, 3.813999660948556*^9}, {3.8140268554555006`*^9, 
   3.8140268584768534`*^9}, {3.8140270302806005`*^9, 3.814027032041976*^9}, {
   3.8252848740291576`*^9, 3.8252848742983384`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1446]:=",ExpressionUUID->"c1974cde-0bee-4337-89d4-4d8be79bede4"],

Cell[TextData[{
 StyleBox["Bluefin: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of bluefin"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}, {3.8252743225014563`*^9, 3.8252743303151894`*^9}, 
   3.8252839339687376`*^9, {3.8252848205032315`*^9, 3.825284826700097*^9}, {
   3.825284905396676*^9, 
   3.82528490975505*^9}},ExpressionUUID->"d3130cb4-ccc7-411c-95d4-\
c4e0d7d022cc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"replf", " ", "=", " ", "0.10"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662888928058*^9}, {3.8016683952885675`*^9, 
   3.8016683957417665`*^9}, {3.801668478875883*^9, 3.801668478985276*^9}, {
   3.8016685230652122`*^9, 3.8016685337553577`*^9}, 3.8016924179886847`*^9, {
   3.801692616946184*^9, 3.8016926170868325`*^9}, {3.801780293582797*^9, 
   3.8017802946923575`*^9}, 3.8033028505850444`*^9, {3.8033032081382475`*^9, 
   3.8033032184211392`*^9}, 3.80339474828187*^9, {3.803394853256654*^9, 
   3.8033948533973007`*^9}, 3.8033972714877625`*^9, {3.8043435722129936`*^9, 
   3.8043435734429483`*^9}, {3.8043441746958294`*^9, 
   3.8043441752562647`*^9}, {3.8043455309101295`*^9, 3.804345531017213*^9}, {
   3.80434825300554*^9, 3.8043482532307134`*^9}, {3.8043490017373157`*^9, 
   3.8043490018544083`*^9}, {3.8043490949148126`*^9, 
   3.8043490950228963`*^9}, {3.804519342578964*^9, 3.80451934279775*^9}, {
   3.804520559891337*^9, 3.80452056018826*^9}, {3.804521075397897*^9, 
   3.804521075741864*^9}, {3.804521154945324*^9, 3.804521155070345*^9}, {
   3.8045214667892885`*^9, 3.804521466896373*^9}, {3.804545877273263*^9, 
   3.804545877492049*^9}, {3.8045460915435076`*^9, 3.804546091652898*^9}, {
   3.8045461863758335`*^9, 3.8045461875168595`*^9}, {3.8045868894228296`*^9, 
   3.804586889625988*^9}, {3.8045916357474985`*^9, 3.804591635841265*^9}, {
   3.8045918139304185`*^9, 3.804591814102498*^9}, 3.8048513430267563`*^9, {
   3.804858875065585*^9, 3.804858875190604*^9}, {3.804867240348963*^9, 
   3.8048672406146297`*^9}, 3.804896936438388*^9, {3.805017091984372*^9, 
   3.805017093687793*^9}, {3.805637855297874*^9, 3.805637855782327*^9}, {
   3.805637981691862*^9, 3.8056380055232553`*^9}, {3.807307032370018*^9, 
   3.8073070328814154`*^9}, {3.807308171743693*^9, 3.807308171900815*^9}, {
   3.8073091964174447`*^9, 3.807309196545544*^9}, {3.807882898924378*^9, 
   3.807882923710372*^9}, {3.8078840572051353`*^9, 3.8078840573301563`*^9}, {
   3.8078848677266655`*^9, 3.8078848678360577`*^9}, {3.8100444535179806`*^9, 
   3.810044453715135*^9}, 3.8124705351155*^9, {3.8124714648855715`*^9, 
   3.812471467405529*^9}, {3.8139968484340057`*^9, 3.8139968793480663`*^9}, {
   3.8139996721842823`*^9, 3.8139996749994698`*^9}, {3.8140268615402412`*^9, 
   3.814026864443497*^9}, {3.8140270350062795`*^9, 3.8140270370238543`*^9}, 
   3.825284877419783*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1447]:=",ExpressionUUID->"8416828b-6e0d-4043-b421-691ce31c4cb1"],

Cell[TextData[{
 StyleBox["Other/NEI tuna: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of other/NEI tuna"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}, {3.8252743225014563`*^9, 3.8252743303151894`*^9}, 
   3.8252839339687376`*^9, {3.8252848205032315`*^9, 3.825284826700097*^9}, {
   3.825284912689377*^9, 
   3.825284919667821*^9}},ExpressionUUID->"18f9d4cc-f423-4f9b-bfde-\
cb646d233bfe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"replo", " ", "=", "0.30"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662888928058*^9}, {3.8016683952885675`*^9, 
   3.8016683957417665`*^9}, {3.801668478875883*^9, 3.801668478985276*^9}, {
   3.8016685230652122`*^9, 3.8016685337553577`*^9}, 3.8016924179886847`*^9, {
   3.801692616946184*^9, 3.8016926170868325`*^9}, {3.801780293582797*^9, 
   3.8017802946923575`*^9}, 3.8033028505850444`*^9, {3.8033032081382475`*^9, 
   3.8033032184211392`*^9}, 3.80339474828187*^9, {3.803394853256654*^9, 
   3.8033948533973007`*^9}, 3.8033972714877625`*^9, {3.8043435722129936`*^9, 
   3.8043435734429483`*^9}, {3.8043441746958294`*^9, 
   3.8043441752562647`*^9}, {3.8043455309101295`*^9, 3.804345531017213*^9}, {
   3.80434825300554*^9, 3.8043482532307134`*^9}, {3.8043490017373157`*^9, 
   3.8043490018544083`*^9}, {3.8043490949148126`*^9, 
   3.8043490950228963`*^9}, {3.804519342578964*^9, 3.80451934279775*^9}, {
   3.804520559891337*^9, 3.80452056018826*^9}, {3.804521075397897*^9, 
   3.804521075741864*^9}, {3.804521154945324*^9, 3.804521155070345*^9}, {
   3.8045214667892885`*^9, 3.804521466896373*^9}, {3.804545877273263*^9, 
   3.804545877492049*^9}, {3.8045460915435076`*^9, 3.804546091652898*^9}, {
   3.8045461863758335`*^9, 3.8045461875168595`*^9}, {3.8045868894228296`*^9, 
   3.804586889625988*^9}, {3.8045916357474985`*^9, 3.804591635841265*^9}, {
   3.8045918139304185`*^9, 3.804591814102498*^9}, 3.8048513430267563`*^9, {
   3.804858875065585*^9, 3.804858875190604*^9}, {3.804867240348963*^9, 
   3.8048672406146297`*^9}, 3.804896936438388*^9, {3.805017091984372*^9, 
   3.805017093687793*^9}, {3.805637855297874*^9, 3.8056378641787643`*^9}, {
   3.805637992675209*^9, 3.805638007096881*^9}, {3.807307036378137*^9, 
   3.807307038828045*^9}, {3.8073081747070003`*^9, 3.8073081748831367`*^9}, {
   3.807309198713234*^9, 3.8073091988393316`*^9}, {3.8078829265389643`*^9, 
   3.807882926695241*^9}, {3.807884060410119*^9, 3.8078840605038843`*^9}, {
   3.807884870742775*^9, 3.807884870820913*^9}, {3.8100444562351007`*^9, 
   3.810044456402231*^9}, 3.812470538896456*^9, {3.8139968530916257`*^9, 
   3.8139968825285425`*^9}, {3.8139996564690685`*^9, 
   3.8139996570695386`*^9}, {3.8140268671225863`*^9, 
   3.8140268699487824`*^9}, {3.814027040215335*^9, 3.814027042261932*^9}, {
   3.817026685690507*^9, 3.8170267111255007`*^9}, {3.825284881647073*^9, 
   3.82528488762577*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1448]:=",ExpressionUUID->"917179e3-d8df-4f69-a8d3-384801ef2ab8"],

Cell[TextData[{
 StyleBox["Bonito: ",
  FontWeight->"Bold"],
 "fraction of illegal imports replaced by legal imports of bonito"
}], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.7954528536190567`*^9, 
   3.7954528566213865`*^9}, {3.7954529012640867`*^9, 
   3.7954529059797497`*^9}, {3.801662811632952*^9, 3.8016628446158667`*^9}, {
   3.801662876842581*^9, 3.801662878499118*^9}, {3.805710411488573*^9, 
   3.8057104277897997`*^9}, {3.8057107370229836`*^9, 
   3.8057107373355346`*^9}, {3.8196722218093386`*^9, 3.819672237683111*^9}, {
   3.819672310875057*^9, 3.81967231317002*^9}, 3.8196725370855665`*^9, {
   3.8198159738040314`*^9, 3.8198159740712395`*^9}, {3.824980385672387*^9, 
   3.824980391298769*^9}, {3.8252743225014563`*^9, 3.8252743303151894`*^9}, 
   3.8252839339687376`*^9, {3.8252848205032315`*^9, 3.825284826700097*^9}, {
   3.8252849234007206`*^9, 
   3.825284927254754*^9}},ExpressionUUID->"4edb0494-743d-45cb-be98-\
609276a5f31e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"repln", " ", "=", "0.30"}], " ", ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528593685226`*^9, 3.795452864075181*^9}, {3.7954529087869353`*^9, 
   3.795452913148324*^9}, {3.7957772824282236`*^9, 3.7957772825052843`*^9}, {
   3.8016628486490526`*^9, 3.801662888928058*^9}, {3.8016683952885675`*^9, 
   3.8016683957417665`*^9}, {3.801668478875883*^9, 3.801668478985276*^9}, {
   3.8016685230652122`*^9, 3.8016685337553577`*^9}, 3.8016924179886847`*^9, {
   3.801692616946184*^9, 3.8016926170868325`*^9}, {3.801780293582797*^9, 
   3.8017802946923575`*^9}, 3.8033028505850444`*^9, {3.8033032081382475`*^9, 
   3.8033032184211392`*^9}, 3.80339474828187*^9, {3.803394853256654*^9, 
   3.8033948533973007`*^9}, 3.8033972714877625`*^9, {3.8043435722129936`*^9, 
   3.8043435734429483`*^9}, {3.8043441746958294`*^9, 
   3.8043441752562647`*^9}, {3.8043455309101295`*^9, 3.804345531017213*^9}, {
   3.80434825300554*^9, 3.8043482532307134`*^9}, {3.8043490017373157`*^9, 
   3.8043490018544083`*^9}, {3.8043490949148126`*^9, 
   3.8043490950228963`*^9}, {3.804519342578964*^9, 3.80451934279775*^9}, {
   3.804520559891337*^9, 3.80452056018826*^9}, {3.804521075397897*^9, 
   3.804521075741864*^9}, {3.804521154945324*^9, 3.804521155070345*^9}, {
   3.8045214667892885`*^9, 3.804521466896373*^9}, {3.804545877273263*^9, 
   3.804545877492049*^9}, {3.8045460915435076`*^9, 3.804546091652898*^9}, {
   3.8045461863758335`*^9, 3.8045461875168595`*^9}, {3.8045868894228296`*^9, 
   3.804586889625988*^9}, {3.8045916357474985`*^9, 3.804591635841265*^9}, {
   3.8045918139304185`*^9, 3.804591814102498*^9}, 3.8048513430267563`*^9, {
   3.804858875065585*^9, 3.804858875190604*^9}, {3.804867240348963*^9, 
   3.8048672406146297`*^9}, 3.804896936438388*^9, {3.805017091984372*^9, 
   3.805017093687793*^9}, {3.805637855297874*^9, 3.8056378641787643`*^9}, {
   3.805637992675209*^9, 3.805638007096881*^9}, {3.8056390201770725`*^9, 
   3.8056390368217773`*^9}, {3.8073070420295362`*^9, 3.807307044155188*^9}, {
   3.807308177607259*^9, 3.80730817776338*^9}, {3.807309201419341*^9, 
   3.807309201576463*^9}, {3.807882929601977*^9, 3.807882929680115*^9}, {
   3.807884064895274*^9, 3.8078840649890394`*^9}, {3.80788487351005*^9, 
   3.8078848736819525`*^9}, {3.8100444593465347`*^9, 3.8100444594646273`*^9}, 
   3.8124705419678545`*^9, {3.8139968588411055`*^9, 3.813996885422798*^9}, 
   3.8139996515762596`*^9, {3.814026872134488*^9, 3.8140268755011063`*^9}, {
   3.8140270452372437`*^9, 3.8140270477572093`*^9}, 3.8252848913907185`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1449]:=",ExpressionUUID->"9cb39eff-cb75-4584-a370-05a9a0eb76bd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.5 Price Elasticity of Supply", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, {
   3.8196719830576887`*^9, 3.81967198641488*^9}, {3.8196720938701487`*^9, 
   3.81967210605611*^9}, {3.81967219811668*^9, 3.819672213143815*^9}, {
   3.819672363407755*^9, 3.819672372555518*^9}, 3.8196725593450384`*^9, {
   3.8198143101346893`*^9, 3.8198143131120086`*^9}, {3.8198143634432487`*^9, 
   3.8198143660582876`*^9}, 
   3.8252839339697375`*^9},ExpressionUUID->"247b77ac-4517-4ce7-b8fd-\
80480d652892"],

Cell[TextData[StyleBox["Source: USITC Staff Estimate and Interviews with \
Industry Participants.",
 FontSize->12]], "Text",
 CellChangeTimes->{{3.8196717358656883`*^9, 3.81967174596994*^9}, {
   3.8196718275392156`*^9, 3.8196718783149896`*^9}, {3.8196719122029943`*^9, 
   3.8196719125283165`*^9}, {3.8196719906789083`*^9, 3.8196720182317753`*^9}, 
   3.8196725593450384`*^9, 3.8200124748939843`*^9, {3.8200126204719076`*^9, 
   3.820012620846199*^9}, 3.8252839339707084`*^9},
 FontSlant->"Italic",ExpressionUUID->"cb882b65-e83f-4d39-9f9f-3a71b35a4671"],

Cell[TextData[StyleBox["U.S. landings of yellowfin",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.8249805094257298`*^9, 3.8249805103694663`*^9}, {
   3.8252743961392064`*^9, 3.825274409012866*^9}, 3.8252839339707084`*^9, {
   3.8252849563645267`*^9, 
   3.8252849586463356`*^9}},ExpressionUUID->"946e3f97-19ba-4835-9754-\
6a3bc7578743"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eyu", " ", "=", "5.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, 3.8048513547315273`*^9, {
   3.8048597028089485`*^9, 3.8048597031058826`*^9}, 3.8050172286041574`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1450]:=",ExpressionUUID->"0e61cea0-3282-45a7-bd8e-9e8e785d69eb"],

Cell[TextData[StyleBox["U.S. landings of skipjack",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.8249805094257298`*^9, 3.8249805103694663`*^9}, {
   3.8252743961392064`*^9, 3.825274409012866*^9}, 3.8252839339707084`*^9, {
   3.8252849563645267`*^9, 3.8252849586463356`*^9}, {3.8252852423321896`*^9, 
   3.8252852433179812`*^9}},ExpressionUUID->"6a761702-15e0-4505-997b-\
cda1d7a880f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"esu", " ", "=", "5.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8048513547315273`*^9, 
   3.804851365641842*^9}, {3.8048597057626595`*^9, 3.804859706091468*^9}, 
   3.8050172421063824`*^9, {3.807278593567297*^9, 3.807278593723418*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1451]:=",ExpressionUUID->"daaf0596-c33a-4587-81b3-e028c2d51607"],

Cell[TextData[StyleBox["U.S. landings of albacore",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.8249805094257298`*^9, 3.8249805103694663`*^9}, {
   3.8252743961392064`*^9, 3.825274409012866*^9}, 3.8252839339707084`*^9, {
   3.8252849563645267`*^9, 3.8252849586463356`*^9}, {3.8252852493116617`*^9, 
   3.8252852502244062`*^9}},ExpressionUUID->"41e025eb-3bca-41ea-bf88-\
d4109d5be917"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eau", " ", "=", "5.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8048513547315273`*^9, 
   3.8048513680171757`*^9}, {3.804859708529451*^9, 3.8048597088263845`*^9}, {
   3.807278595506809*^9, 3.8072785956729383`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1452]:=",ExpressionUUID->"61c0c99e-cd47-4677-a666-19e1cd12c8f5"],

Cell[TextData[StyleBox["U.S. landings of bigeye",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.8249805094257298`*^9, 3.8249805103694663`*^9}, {
   3.8252743961392064`*^9, 3.825274409012866*^9}, 3.8252839339707084`*^9, {
   3.8252849563645267`*^9, 3.8252849586463356`*^9}, {3.825285254893056*^9, 
   3.8252852674678516`*^9}},ExpressionUUID->"8fda4d45-d175-4b46-918a-\
e2f53c2bb0c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ebu", " ", "=", "2.0"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8048513547315273`*^9, 
   3.8048513702674923`*^9}, {3.804859712264567*^9, 3.8048597125615005`*^9}, 
   3.8050172630810432`*^9, {3.8072785982539477`*^9, 3.807278598362032*^9}, {
   3.8100472491000433`*^9, 3.8100472492171345`*^9}, {3.810047334186076*^9, 
   3.8100473382602377`*^9}, 3.825284970792794*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1453]:=",ExpressionUUID->"c77200e6-564e-48a4-9d46-75e553d26040"],

Cell[TextData[StyleBox["U.S. landings of bluefin",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.8249805094257298`*^9, 3.8249805103694663`*^9}, {
   3.8252743961392064`*^9, 3.825274409012866*^9}, 3.8252839339707084`*^9, {
   3.8252849563645267`*^9, 3.8252849586463356`*^9}, {3.825285261361107*^9, 
   3.8252852634637423`*^9}},ExpressionUUID->"0594a634-5a80-47a5-b3c3-\
a9af9333c6c8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"efu", " ", "=", "2.0"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8048513547315273`*^9, 
   3.8048513702674923`*^9}, {3.804859712264567*^9, 3.8048597125615005`*^9}, {
   3.8050172630810432`*^9, 3.805017275067389*^9}, {3.8072786018577533`*^9, 
   3.807278602182005*^9}, {3.810047329379346*^9, 3.810047342357418*^9}, 
   3.825284973537939*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1454]:=",ExpressionUUID->"91ca236f-1de5-4270-b969-bd269e28ac56"],

Cell[TextData[StyleBox["U.S. landings of other/NEI tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.8249805094257298`*^9, 3.8249805103694663`*^9}, {
   3.8252743961392064`*^9, 3.825274409012866*^9}, 3.8252839339707084`*^9, {
   3.8252849563645267`*^9, 3.8252849586463356`*^9}, {3.82528527204043*^9, 
   3.8252852746634803`*^9}},ExpressionUUID->"3ce5464a-aa90-48d7-8b09-\
71e943c24616"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eou", " ", "=", "5.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8048513547315273`*^9, 
   3.8048513702674923`*^9}, {3.804859712264567*^9, 3.8048597125615005`*^9}, {
   3.8050172630810432`*^9, 3.8050172793315725`*^9}, {3.8072786040134273`*^9, 
   3.8072786041705494`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1455]:=",ExpressionUUID->"3e57279e-e33a-4cae-870a-123d34efdc5f"],

Cell[TextData[StyleBox["U.S. landings of bonito",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.791635004903948*^9, 3.7916350079863176`*^9}, {
   3.7916374051533175`*^9, 3.7916374074010534`*^9}, {3.791639954743683*^9, 
   3.7916399673924417`*^9}, {3.7916399989748077`*^9, 
   3.7916400007431717`*^9}, {3.7954520831018844`*^9, 3.795452119837143*^9}, {
   3.7954523619018683`*^9, 3.795452362542366*^9}, {3.795452818546794*^9, 
   3.795452827280582*^9}, {3.795864759428293*^9, 3.7958647601078205`*^9}, {
   3.7988096048422227`*^9, 3.798809605984623*^9}, {3.799790892189664*^9, 
   3.799790949165455*^9}, {3.805710496411161*^9, 3.805710498458372*^9}, 
   3.805710726364991*^9, {3.819672379615509*^9, 3.819672385976882*^9}, 
   3.8196725593450384`*^9, {3.8249805094257298`*^9, 3.8249805103694663`*^9}, {
   3.8252743961392064`*^9, 3.825274409012866*^9}, 3.8252839339707084`*^9, {
   3.8252849563645267`*^9, 3.8252849586463356`*^9}, {3.82528528006971*^9, 
   3.825285283365306*^9}},ExpressionUUID->"4d3bfae3-c892-471b-9ae9-\
9b61e1a1558f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"enu", " ", "=", "5.0"}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.7954528309434304`*^9, 3.7954528477204685`*^9}, 3.7954546632723*^9, {
   3.7958646670308933`*^9, 3.7958646671679997`*^9}, 3.7958647551159415`*^9, {
   3.7988099058524013`*^9, 3.7988099060782413`*^9}, {3.7990609527985573`*^9, 
   3.799060952917369*^9}, {3.799093946568883*^9, 3.7990939579397545`*^9}, {
   3.7990943651295524`*^9, 3.799094366270444*^9}, 3.799094756803099*^9, {
   3.799098845644702*^9, 3.7990988457227635`*^9}, {3.799099093692296*^9, 
   3.7990990937803645`*^9}, {3.7990993528549356`*^9, 
   3.7990993529820347`*^9}, {3.799408885346872*^9, 3.7994088854639645`*^9}, {
   3.79940901719479*^9, 3.799409017360919*^9}, {3.799409720975665*^9, 
   3.7994097210627017`*^9}, {3.7997908956433725`*^9, 3.799790895721511*^9}, 
   3.799790985760846*^9, {3.7997915952035685`*^9, 3.7997915952973337`*^9}, 
   3.799799213005015*^9, {3.7998571664756913`*^9, 3.7998571668195324`*^9}, {
   3.7998576510235624`*^9, 3.7998576511642094`*^9}, {3.8001421001816297`*^9, 
   3.8001421002972097`*^9}, {3.800171508481261*^9, 3.800171508577692*^9}, {
   3.80017154353423*^9, 3.8001715437394843`*^9}, 3.801663009265958*^9, {
   3.8017803275830135`*^9, 3.8017803277080355`*^9}, {3.801780408243921*^9, 
   3.8017804099785957`*^9}, {3.803392585270754*^9, 3.8033925853488913`*^9}, {
   3.8043435932633715`*^9, 3.804343593971922*^9}, 3.8043441708758554`*^9, {
   3.8043443841407824`*^9, 3.804344410833547*^9}, {3.8048513547315273`*^9, 
   3.8048513702674923`*^9}, {3.804859712264567*^9, 3.8048597125615005`*^9}, {
   3.8050172630810432`*^9, 3.8050172793315725`*^9}, {3.8056391300743694`*^9, 
   3.8056391301681356`*^9}, {3.8072786056587114`*^9, 3.8072786057748013`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1456]:=",ExpressionUUID->"964c7e7e-ddcb-4310-9a59-ed47f40d7af9"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2. Data Inputs",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.795452962713849*^9}, {
  3.8196715794204283`*^9, 3.8196715805723763`*^9}, {3.819672652231064*^9, 
  3.819672658049889*^9}},ExpressionUUID->"6c4dde34-c4f1-4c62-93c5-\
887546d1f4ff"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.1 U.S. Landings Quantities and Prices", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672709332239*^9}, 
   3.819814602882104*^9, 3.8249807397550435`*^9, 
   3.8252839339717245`*^9},ExpressionUUID->"7ed18dcf-dd31-41da-8f64-\
8738eabac76d"],

Cell[TextData[StyleBox["Source: National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries).\
\[NonBreakingSpace]Fisheries of the United States 2018. Current Fishery \
Statistics No. 2018. U.S. Department of Commerce. Silver Spring MD:\
\[NonBreakingSpace]NOAA,\[NonBreakingSpace]February 2020. \
https://www.fisheries.noaa.gov/resource/document/fisheries-united-states-2018-\
report.\[NonBreakingSpace]",
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, 
   3.819814602882104*^9, {3.8198155788251867`*^9, 3.8198155811910124`*^9}, 
   3.8249807397550435`*^9, 3.8252839339717245`*^9},
 FontSize->12,ExpressionUUID->"28d290be-5290-456a-a5b7-2cc9f92874b9"],

Cell[TextData[StyleBox["Yellowfin tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8252853315822973`*^9, 
  3.8252853337199664`*^9}},ExpressionUUID->"dc721d55-ea86-4677-9331-\
9b4436aa4166"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qydu0", " ", "=", "5843673.00"}], " ", ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.8048514547791586`*^9, {
   3.804858998862688*^9, 3.8048590002413826`*^9}, 3.8050173226703215`*^9, {
   3.8050221654427185`*^9, 3.8050221715374117`*^9}, {3.807287084512781*^9, 
   3.807287085043193*^9}, {3.813591963604884*^9, 3.813591995741906*^9}, {
   3.8139958701684074`*^9, 3.813995882003619*^9}, {3.8139959567958436`*^9, 
   3.813995971396208*^9}, 3.8252853389681096`*^9, {3.8252853716856694`*^9, 
   3.825285372829578*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1457]:=",ExpressionUUID->"400c8e39-93cb-4fef-a9fb-41930d195d3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pydu0", " ", "=", "6.1081"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, 
   3.8048516657287436`*^9, {3.804859289924417*^9, 3.804859293881085*^9}, 
   3.8050178536388817`*^9, {3.8050225182495184`*^9, 3.8050225241723566`*^9}, 
   3.8072860329245715`*^9, {3.8252855580661826`*^9, 3.825285559889612*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1458]:=",ExpressionUUID->"cfe43c25-be78-4227-bac0-674e47880d70"],

Cell[TextData[StyleBox["Skipjack tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8252853315822973`*^9, 3.8252853337199664`*^9}, {
  3.8252854021875253`*^9, 3.825285403162287*^9}, {3.825285555015797*^9, 
  3.8252855554971724`*^9}},ExpressionUUID->"0c142a9d-c94f-42aa-ba3b-\
c88cdc29bab3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdu0", " ", "=", "1448384.00"}], " ", ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.8048514568888445`*^9, {
   3.804859007321229*^9, 3.804859009274654*^9}, 3.8050173371426563`*^9, {
   3.805022177647732*^9, 3.8050221804450397`*^9}, {3.807287087850379*^9, 
   3.8072870883807926`*^9}, {3.8135919735005913`*^9, 
   3.8135919935071697`*^9}, {3.813995885951694*^9, 3.813995890037876*^9}, {
   3.81399597864285*^9, 3.813995979972884*^9}, 3.825285342283668*^9, 
   3.8252853773511095`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1459]:=",ExpressionUUID->"4ecde827-d0a5-44ad-8f2a-1ab84264d7b8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"psdu0", " ", "=", "1.4963"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.8048516736382985`*^9}, {3.8048592982724123`*^9, 
   3.80485930216366*^9}, 3.8050178642343397`*^9, {3.8050225293919544`*^9, 
   3.8050225352691364`*^9}, 3.8072860376602564`*^9, 3.8252855660984735`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1460]:=",ExpressionUUID->"fc8eb168-ab40-4abf-a2f7-a6c4a5fe0448"],

Cell[TextData[StyleBox["Albacore tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8252853315822973`*^9, 3.8252853337199664`*^9}, {
  3.8252854060625577`*^9, 
  3.8252854071534095`*^9}},ExpressionUUID->"ea2bcdfb-c99f-4c31-8987-\
54cb12f71abf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadu0", " ", "=", "8529946.00"}], " ", ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.8048514589516478`*^9, {
   3.8048590130252295`*^9, 3.804859016210842*^9}, {3.805022188118102*^9, 
   3.805022192057477*^9}, {3.80728709151323*^9, 3.807287091895526*^9}, {
   3.8135919833162365`*^9, 3.8135919885643215`*^9}, {3.8139958931983323`*^9, 
   3.8139958970093007`*^9}, {3.813995982620946*^9, 3.8139959838819284`*^9}, 
   3.8252853449007435`*^9, 3.825285378787229*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1461]:=",ExpressionUUID->"6682d775-94cf-4a53-8c9a-592c4584bd42"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"padu0", " ", "=", "3.5245"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.8048516760920506`*^9}, {3.804859306715953*^9, 
   3.804859310810358*^9}, {3.8050225406447134`*^9, 3.8050225457625327`*^9}, {
   3.8072860413331146`*^9, 3.8072860443164372`*^9}, 3.8252855675996447`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1462]:=",ExpressionUUID->"5c93ef97-317b-45bc-930c-7ed4a5083bcf"],

Cell[TextData[StyleBox["Bigeye tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8252853315822973`*^9, 3.8252853337199664`*^9}, {
  3.8252854099165716`*^9, 
  3.825285410587093*^9}},ExpressionUUID->"0112fdff-5a16-4d00-b5e1-\
58d3d225a468"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qbdu0", " ", "=", "8325596.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.804851461217606*^9, {
   3.8048590263373966`*^9, 3.8048590278376274`*^9}, 3.80501735923965*^9, {
   3.805022199245713*^9, 3.805022203090089*^9}, {3.8072870949408975`*^9, 
   3.8072870953031797`*^9}, {3.8110710487158346`*^9, 
   3.8110710647353935`*^9}, {3.8139430277723*^9, 3.813943031118907*^9}, {
   3.8139959005340443`*^9, 3.813995905112606*^9}, {3.813995936669177*^9, 
   3.813995937417758*^9}, 3.8252853476949253`*^9, 3.8252853801983232`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1463]:=",ExpressionUUID->"aba9680d-c0d7-4bcf-aed7-0787606061b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pbdu0", " ", "=", "9.0050"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.804851678024618*^9}, {3.804859329331564*^9, 
   3.8048593352231383`*^9}, {3.804859838203453*^9, 3.804859839094244*^9}, 
   3.805017872688827*^9, {3.8050225519510365`*^9, 3.8050225559089317`*^9}, 
   3.807286047684058*^9, 3.8252855691188354`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1464]:=",ExpressionUUID->"a81323c0-f581-4d29-94ee-cd5c44c14b81"],

Cell[TextData[StyleBox["Bluefin tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8252853315822973`*^9, 3.8252853337199664`*^9}, {
  3.825285413374277*^9, 
  3.825285414128886*^9}},ExpressionUUID->"e6e92c8c-da3d-4093-8cb2-\
2878fa5aa703"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qfdu0", " ", "=", "958000.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.804851461217606*^9, {
   3.8048590263373966`*^9, 3.8048590278376274`*^9}, {3.80501735923965*^9, 
   3.805017366961873*^9}, {3.8050222146072206`*^9, 3.805022216810708*^9}, {
   3.807287098268512*^9, 3.807287098621783*^9}, {3.813995908214022*^9, 
   3.813995941217713*^9}, 3.8252853501928563`*^9, 3.8252853816594696`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1465]:=",ExpressionUUID->"1f90fa36-e1a2-4518-ba97-444f0e6e14ef"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pfdu0", " ", "=", "11.9081"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.804851678024618*^9}, {3.804859329331564*^9, 
   3.8048593352231383`*^9}, {3.804859838203453*^9, 3.804859839094244*^9}, {
   3.805017872688827*^9, 3.80501788154963*^9}, {3.805022560685978*^9, 
   3.805022565829212*^9}, 3.8072860514349775`*^9, 3.8252855709012327`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1466]:=",ExpressionUUID->"39683c2b-cd55-4bab-afc2-f50ad5743fba"],

Cell[TextData[StyleBox["Other/NEI tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8252853315822973`*^9, 3.8252853337199664`*^9}, {
  3.8252854166758595`*^9, 
  3.8252854183741846`*^9}},ExpressionUUID->"db516c3a-2383-4a18-b0ae-\
cdf3bfcdf90d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qodu0", " ", "=", "256773.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.804851461217606*^9, {
   3.8048590263373966`*^9, 3.8048590278376274`*^9}, {3.80501735923965*^9, 
   3.8050173703386555`*^9}, {3.8050222214856396`*^9, 3.805022223720377*^9}, {
   3.807287101388917*^9, 3.807287101752199*^9}, {3.813995918936369*^9, 
   3.8139959233478036`*^9}, {3.8139959880761952`*^9, 3.813995989001915*^9}, 
   3.8252853532933345`*^9, 3.8252853836169977`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1467]:=",ExpressionUUID->"c3fb319a-7734-4450-9427-c60dc29e2cdb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"podu0", " ", "=", "2.2614"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.804851678024618*^9}, {3.804859329331564*^9, 
   3.8048593352231383`*^9}, {3.804859838203453*^9, 3.804859839094244*^9}, {
   3.805017872688827*^9, 3.805017884237563*^9}, {3.805018062809467*^9, 
   3.805018065512958*^9}, {3.805022569645549*^9, 3.8050225746075516`*^9}, {
   3.807286054634468*^9, 3.8072860588187275`*^9}, 3.825285572902796*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1468]:=",ExpressionUUID->"977552a6-aaf5-4f0f-b57e-a052f10a9db2"],

Cell[TextData[StyleBox["Bonito",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8252853315822973`*^9, 3.8252853337199664`*^9}, {
  3.825285422409342*^9, 
  3.82528542506842*^9}},ExpressionUUID->"f7f4d95d-36f3-45ef-94ff-\
c9078a0590fc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qndu0", " ", "=", "696000.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, 3.7997992260254607`*^9, {3.8016623959917994`*^9, 
   3.801662400833377*^9}, {3.80434361531853*^9, 3.804343642790904*^9}, {
   3.8045199061007853`*^9, 3.80451991538352*^9}, {3.8045456261254435`*^9, 
   3.804545628313345*^9}, 3.8045869095059967`*^9, 3.804851461217606*^9, {
   3.8048590263373966`*^9, 3.8048590278376274`*^9}, {3.80501735923965*^9, 
   3.8050173703386555`*^9}, {3.8050222214856396`*^9, 3.805022223720377*^9}, {
   3.8056391404207077`*^9, 3.8056391405457287`*^9}, {3.805645818533621*^9, 
   3.8056458195962996`*^9}, {3.8072871047185087`*^9, 
   3.8072871050818005`*^9}, {3.8139959264001827`*^9, 
   3.8139959303182297`*^9}, {3.8139959910104756`*^9, 
   3.8139959916900034`*^9}, {3.8252853558502846`*^9, 3.8252853860438986`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1469]:=",ExpressionUUID->"b1879f2c-a15e-4873-afdc-0b80bdeb3b6c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pndu0", " ", "=", "0.7888"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799797999314254*^9, 3.799798002242099*^9}, {3.79979813560623*^9, 
   3.7997981500594435`*^9}, 3.799799243547584*^9, {3.7998526200548897`*^9, 
   3.7998526348227315`*^9}, {3.7998549657124357`*^9, 3.79985497470359*^9}, {
   3.8016608829457183`*^9, 3.801660885289815*^9}, {3.801662607797329*^9, 
   3.80166260785984*^9}, {3.801662911897679*^9, 3.801662922211997*^9}, {
   3.8016672142437315`*^9, 3.80166724573563*^9}, {3.801692723187518*^9, 
   3.8016927283758764`*^9}, {3.801777983913335*^9, 3.801777985894841*^9}, {
   3.801778018822529*^9, 3.8017780219324207`*^9}, {3.80339208728214*^9, 
   3.8033920877978487`*^9}, {3.8033922027005806`*^9, 
   3.8033922106574497`*^9}, {3.8043438313317595`*^9, 3.804343831524908*^9}, {
   3.804343911237857*^9, 3.8043439131873713`*^9}, {3.80452076952404*^9, 
   3.804520773024602*^9}, {3.804587047312701*^9, 3.8045870691007304`*^9}, {
   3.8048516657287436`*^9, 3.804851678024618*^9}, {3.804859329331564*^9, 
   3.8048593352231383`*^9}, {3.804859838203453*^9, 3.804859839094244*^9}, {
   3.805017872688827*^9, 3.805017884237563*^9}, {3.805018062809467*^9, 
   3.805018065512958*^9}, {3.805022569645549*^9, 3.8050225746075516`*^9}, {
   3.8056395637745504`*^9, 3.805639564099233*^9}, {3.8056464299750767`*^9, 
   3.8056464323392377`*^9}, 3.807286062699747*^9, 3.825285575654954*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1470]:=",ExpressionUUID->"d203fae2-8213-4deb-b593-2dcc4473e4c1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.2 U.S. Processing Production Quantities and \
Prices", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672733348008*^9}, {
   3.8196727961837325`*^9, 3.8196728038250227`*^9}, 3.819814751753172*^9, 
   3.8249808810930777`*^9, 
   3.825283933977741*^9},ExpressionUUID->"e09c3dc8-b140-4b90-bf99-\
ef3e06a1c9c4"],

Cell[TextData[StyleBox["Sources:\n National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries).\
\[NonBreakingSpace]Fisheries of the United States 2018. Current Fishery \
Statistics No. 2018. U.S. Department of Commerce. Silver Spring MD:\
\[NonBreakingSpace]NOAA,\[NonBreakingSpace]February 2020. \
https://www.fisheries.noaa.gov/resource/document/fisheries-united-states-2018-\
report.\[NonBreakingSpace] \n\nNational Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries). NOAA \
Processed Products database. Accessed September 1, \
2020.https://www.fisheries.noaa.gov/foss/f?p=215:3:5412288074334::NO:::",
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, {
   3.819814602882104*^9, 3.819814670599902*^9}, {3.8198147375350885`*^9, 
   3.819814751753172*^9}, {3.8198155956591797`*^9, 3.8198155972494073`*^9}, 
   3.8249808810930777`*^9, 3.825283933977741*^9, 3.825416545653907*^9},
 FontSize->12,ExpressionUUID->"a63ef450-5c34-4c49-ae25-47beaa37a7c8"],

Cell[TextData[StyleBox["Processed Yellowfin",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9, {3.824980768462393*^9, 3.824980769184957*^9}, 
   3.8249808810930777`*^9, {3.8252748152865276`*^9, 3.825274816511503*^9}, 
   3.825283933977741*^9, {3.8252855945567474`*^9, 
   3.825285595652607*^9}},ExpressionUUID->"48711c42-2516-4e45-b84b-\
93f4c0b85e8b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qydp0", " ", "=", "18470202.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.80485147925504*^9, {3.8048590537865825`*^9, 3.8048590560213146`*^9}, 
   3.80501738938866*^9, 3.8050222301276703`*^9, {3.805022486126275*^9, 
   3.8050224886158657`*^9}, {3.805023204571621*^9, 3.805023236303412*^9}, {
   3.805645835267213*^9, 3.805645866025993*^9}, {3.807287108676591*^9, 
   3.807287109039876*^9}, {3.8139959491258707`*^9, 3.8139959535763364`*^9}, {
   3.825285600083074*^9, 3.8252856267919827`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1471]:=",ExpressionUUID->"24e0d001-9c3c-4664-b4e5-84955a14c169"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pydp0", " ", "=", "5.6637"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.804343942476156*^9, 3.804343949889929*^9}, {
   3.8045210306472683`*^9, 3.8045210368829145`*^9}, {3.804587081702225*^9, 
   3.8045870826558285`*^9}, 3.8048517570505433`*^9, 3.804865877652568*^9, 
   3.805018145205366*^9, {3.8050227847047715`*^9, 3.805022785329875*^9}, {
   3.8050232728873405`*^9, 3.80502328803021*^9}, {3.8056656016136923`*^9, 
   3.805665617298253*^9}, 3.8072860007665386`*^9, {3.825285743364297*^9, 
   3.82528574551493*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1472]:=",ExpressionUUID->"f518a895-fc64-4c1b-8016-df1a33c9f6f1"],

Cell[TextData[StyleBox["Processed Skipjack",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9, {3.824980768462393*^9, 3.824980769184957*^9}, 
   3.8249808810930777`*^9, {3.8252748152865276`*^9, 3.825274816511503*^9}, 
   3.825283933977741*^9, {3.8252855945567474`*^9, 3.825285595652607*^9}, {
   3.8252856544906673`*^9, 
   3.825285657948373*^9}},ExpressionUUID->"d9dbbeaf-c762-4a09-a777-\
925a2ade2183"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdp0", " ", "=", "74785963.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.804851484318285*^9, {3.8048590605689173`*^9, 3.8048590667730417`*^9}, 
   3.8050173975775113`*^9, 3.805022232784355*^9, 3.8050224930197735`*^9, {
   3.8050232180903654`*^9, 3.805023241085371*^9}, {3.805023632655447*^9, 
   3.8050236356424956`*^9}, 3.8056458386741605`*^9, {3.805645871183111*^9, 
   3.8056458757007465`*^9}, {3.807287111876079*^9, 3.8072871122203465`*^9}, 
   3.813996003280031*^9, {3.8252856033816586`*^9, 3.825285630723061*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1473]:=",ExpressionUUID->"6561412e-06fd-4c57-ae93-47270a6df98e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"psdp0", " ", "=", "4.2374"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.804343942476156*^9, 3.804343949889929*^9}, {
   3.8045210306472683`*^9, 3.8045210368829145`*^9}, {3.804587081702225*^9, 
   3.8045870826558285`*^9}, {3.804851759302089*^9, 3.8048517613180237`*^9}, 
   3.804865883950451*^9, 3.805018154986638*^9, 3.805022789736844*^9, {
   3.8050232745594635`*^9, 3.805023293624789*^9}, {3.80566562639616*^9, 
   3.8056656278964133`*^9}, 3.8072859969465656`*^9, 3.825285748809501*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1474]:=",ExpressionUUID->"09c8ff30-42fd-4efc-951c-d2cfbedd4dcc"],

Cell[TextData[StyleBox["Processed Albacore",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9, {3.824980768462393*^9, 3.824980769184957*^9}, 
   3.8249808810930777`*^9, {3.8252748152865276`*^9, 3.825274816511503*^9}, 
   3.825283933977741*^9, {3.8252855945567474`*^9, 3.825285595652607*^9}, {
   3.825285660600451*^9, 
   3.8252856616092424`*^9}},ExpressionUUID->"b1963b6b-e39f-4658-9673-\
3eccc76f66c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadp0", " ", "=", "67028892.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.804851485974779*^9, {3.8048590710549765`*^9, 3.804859073899182*^9}, 
   3.80502223606614*^9, 3.805022494144955*^9, {3.8050232199500046`*^9, 
   3.8050232477426076`*^9}, 3.805645842097738*^9, {3.805645882358735*^9, 
   3.8056458856249104`*^9}, {3.807287115095586*^9, 3.8072871154498625`*^9}, 
   3.8139960044209175`*^9, {3.8252856062989464`*^9, 3.825285632347332*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1475]:=",ExpressionUUID->"abd93098-806c-4525-be8c-4d88e9e76f05"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"padp0", " ", "=", "6.0944"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.804343942476156*^9, 3.804343949889929*^9}, {
   3.8045210306472683`*^9, 3.8045210368829145`*^9}, {3.804587081702225*^9, 
   3.8045870826558285`*^9}, 3.8048517637402706`*^9, 3.804865889483494*^9, 
   3.8050227919715805`*^9, {3.8050232755596113`*^9, 3.805023302613583*^9}, {
   3.8056656376059666`*^9, 3.8056656387233295`*^9}, 3.807285993815127*^9, 
   3.825285751022269*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1476]:=",ExpressionUUID->"c11b0971-44f2-457e-a56f-d2e8e07d9df7"],

Cell[TextData[StyleBox["Processed Bigeye",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9, {3.824980768462393*^9, 3.824980769184957*^9}, 
   3.8249808810930777`*^9, {3.8252748152865276`*^9, 3.825274816511503*^9}, 
   3.825283933977741*^9, {3.8252855945567474`*^9, 3.825285595652607*^9}, {
   3.8252856651980495`*^9, 
   3.825285666734254*^9}},ExpressionUUID->"c8c70d6c-84d7-4491-a4ad-\
3b7e6cff5294"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qbdp0", " ", "=", "1595096.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.8048514880219545`*^9, {3.8048590780406504`*^9, 3.8048590807442083`*^9}, 
   3.8050174161586895`*^9, 3.805022239350669*^9, 3.8050224952701406`*^9, 
   3.8050232217002525`*^9, {3.8050232521651382`*^9, 3.805023254618627*^9}, 
   3.805645845237493*^9, {3.805645891750942*^9, 3.8056458939388103`*^9}, {
   3.807287117863742*^9, 3.8072871182170153`*^9}, 3.813996005415691*^9, {
   3.825285609227252*^9, 3.8252856337674456`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1477]:=",ExpressionUUID->"99c6e44e-061a-4ff5-961c-12a04ff14f1d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pbdp0", " ", "=", "24.7219"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.804343942476156*^9, 3.804343949889929*^9}, {
   3.8045210306472683`*^9, 3.8045210368829145`*^9}, {3.804587081702225*^9, 
   3.8045870826558285`*^9}, 3.804851766084381*^9, 3.804865895093766*^9, 
   3.805018163879826*^9, 3.8050227942063227`*^9, 3.805023277466144*^9, {
   3.805023307715171*^9, 3.8050233123404217`*^9}, {3.8056656472163677`*^9, 
   3.8056656478883595`*^9}, {3.807285987178963*^9, 3.807285988251796*^9}, 
   3.8252857520690565`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1478]:=",ExpressionUUID->"b2da8702-0316-46b8-9356-5aa032c6c832"],

Cell[TextData[StyleBox["Processed Bluefin",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9, {3.824980768462393*^9, 3.824980769184957*^9}, 
   3.8249808810930777`*^9, {3.8252748152865276`*^9, 3.825274816511503*^9}, 
   3.825283933977741*^9, {3.8252855945567474`*^9, 3.825285595652607*^9}, {
   3.825285670097885*^9, 
   3.8252856708534775`*^9}},ExpressionUUID->"d49fdc00-6dd6-4870-a223-\
211f32fdc395"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qfdp0", " ", "=", "714906.00"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.8048514880219545`*^9, {3.8048590780406504`*^9, 3.8048590807442083`*^9}, {
   3.8050174161586895`*^9, 3.8050174244881883`*^9}, 3.8050222430108185`*^9, 
   3.8050224962546763`*^9, 3.805023223403619*^9, {3.8050232587911205`*^9, 
   3.8050232611677017`*^9}, 3.8056458488251038`*^9, {3.805645899512662*^9, 
   3.80564590198705*^9}, {3.8072871215355988`*^9, 3.807287121878865*^9}, 
   3.813996006371434*^9, {3.8252856119423594`*^9, 3.8252856359861794`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1479]:=",ExpressionUUID->"afc8f065-ee22-4e37-948b-934b709956c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pfdp0", " ", "=", "28.9190"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.804343942476156*^9, 3.804343949889929*^9}, {
   3.8045210306472683`*^9, 3.8045210368829145`*^9}, {3.804587081702225*^9, 
   3.8045870826558285`*^9}, 3.804851766084381*^9, 3.804865895093766*^9, {
   3.805018163879826*^9, 3.8050181722248125`*^9}, 3.805022796644215*^9, 
   3.8050232786225653`*^9, {3.8050233174491405`*^9, 3.8050233230437202`*^9}, {
   3.805665655545946*^9, 3.8056656574837837`*^9}, 3.8072859828365784`*^9, 
   3.825285754516977*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1480]:=",ExpressionUUID->"bffbf241-e5a3-4e32-be55-4013deb3732d"],

Cell[TextData[StyleBox["Processed Other/NEI tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610004655204`*^9, 3.7990610135612383`*^9}, {
   3.7997911313445854`*^9, 3.799791147003186*^9}, {3.799791202733632*^9, 
   3.799791203936952*^9}, {3.7997922204200535`*^9, 3.799792263084735*^9}, {
   3.7998023713196135`*^9, 3.7998023910849323`*^9}, 3.7998808786079793`*^9, {
   3.799881079140381*^9, 3.799881100502863*^9}, {3.805710525367653*^9, 
   3.8057105285712976`*^9}, {3.8057105981709957`*^9, 
   3.8057106004526224`*^9}, {3.8057106807164984`*^9, 
   3.8057106809821663`*^9}, {3.819814682681319*^9, 3.8198146921346903`*^9}, 
   3.819814751753172*^9, {3.824980768462393*^9, 3.824980769184957*^9}, 
   3.8249808810930777`*^9, {3.8252748152865276`*^9, 3.825274816511503*^9}, 
   3.825283933977741*^9, {3.8252855945567474`*^9, 3.825285595652607*^9}, {
   3.825285673839814*^9, 
   3.825285675747308*^9}},ExpressionUUID->"a91c91e4-620c-485b-a666-\
91eb8e1a799d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qodp0", " ", "=", "1086.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, 3.7997992277757783`*^9, {3.80166240933113*^9, 
   3.8016624114721084`*^9}, {3.8043436227142825`*^9, 3.804343650165639*^9}, {
   3.8043478194526515`*^9, 3.804347821046896*^9}, {3.804347922719031*^9, 
   3.8043479243332844`*^9}, {3.804586936094033*^9, 3.8045869722273607`*^9}, 
   3.8048514880219545`*^9, {3.8048590780406504`*^9, 3.8048590807442083`*^9}, {
   3.8050174161586895`*^9, 3.805017426879205*^9}, 3.8050222461675797`*^9, 
   3.8050224971767*^9, 3.805023225716447*^9, {3.8050236382210197`*^9, 
   3.8050236393305664`*^9}, 3.8056458523944626`*^9, 3.805645906628456*^9, {
   3.80564596119252*^9, 3.805646008123979*^9}, {3.8056460581507945`*^9, 
   3.805646059976446*^9}, {3.807287124498906*^9, 3.8072871248231583`*^9}, 
   3.8139960073952312`*^9, {3.825285614867663*^9, 3.8252856375213823`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1481]:=",ExpressionUUID->"e1ddfe9a-548c-4dc9-bd0f-2b29fc1ca0ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"podp0", " ", "=", "1.1543"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997912215499964`*^9, 
   3.7997912368809423`*^9}, {3.7997915104766955`*^9, 3.799791511008032*^9}, {
   3.799791913299527*^9, 3.799791913471428*^9}, {3.799791969851351*^9, 
   3.799791970351426*^9}, 3.799799246720034*^9, {3.801662624987032*^9, 
   3.8016626251589375`*^9}, {3.8033922321138678`*^9, 
   3.8033922322857714`*^9}, {3.804343942476156*^9, 3.804343949889929*^9}, {
   3.8045210306472683`*^9, 3.8045210368829145`*^9}, {3.804587081702225*^9, 
   3.8045870826558285`*^9}, 3.804851766084381*^9, 3.804865895093766*^9, {
   3.805018163879826*^9, 3.8050181759909954`*^9}, {3.8050230081841908`*^9, 
   3.8050230092155676`*^9}, 3.805023279888378*^9, {3.805665665469347*^9, 
   3.805665666078829*^9}, 3.807285980001371*^9, 3.82528575597415*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1482]:=",ExpressionUUID->"ecb360a1-d972-4160-8e9f-525353ea954d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.3 Import Quantities and Prices", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672733348008*^9}, {
   3.819672809477676*^9, 3.8196728096938534`*^9}, 3.8198152044580364`*^9, 
   3.8249830230169973`*^9, 3.8252827698425417`*^9, 
   3.8252828702591667`*^9},ExpressionUUID->"24bc1583-a9ae-4346-bc8b-\
b41eef6a8229"],

Cell[TextData[StyleBox["Source: IUU Estimate Database as described in Chapter \
3 of the report. ",
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, 
   3.819814602882104*^9, {3.8198147741606445`*^9, 3.8198147935287457`*^9}, 
   3.8198152044580364`*^9, 3.820012478192554*^9, {3.8208559831037273`*^9, 
   3.8208560402321887`*^9}, 3.824980895304139*^9, 3.8249830230169973`*^9, 
   3.825282769843543*^9, 3.825282870260154*^9},
 FontSize->12,ExpressionUUID->"823d90d3-c0ab-4612-a986-7fb16fe609fc"],

Cell[TextData[StyleBox["Yellowfin",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.82498135149479*^9, 3.824981353015973*^9}, 3.8249814426737957`*^9, 
   3.8249830230169973`*^9, {3.8252749315381975`*^9, 3.8252749323147917`*^9}, 
   3.825282769843543*^9, 3.825282870260154*^9, {3.8252858273930244`*^9, 
   3.8252858286450853`*^9}},ExpressionUUID->"0bf8ee30-2366-4a46-937b-\
dcce0f4b07bd"],

Cell["Total unprocessed imports", "Text",
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814453368645`*^9, 3.8249814468960824`*^9}, 
   3.8249830230169973`*^9, 3.825282769843543*^9, 
   3.825282870260154*^9},ExpressionUUID->"4833965b-09d4-4d61-ba29-\
576776789caf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qytu0", " ", "=", 
    StyleBox["7277295",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.8048514991738663`*^9, {
   3.8048590916512775`*^9, 3.8048590942923245`*^9}, 3.805017449790481*^9, {
   3.8050222550283995`*^9, 3.805022258888447*^9}, {3.8056461502065105`*^9, 
   3.8056461519460487`*^9}, {3.8072871280736885`*^9, 
   3.8072871284569874`*^9}, {3.8124706620246544`*^9, 
   3.8124706655974464`*^9}, {3.8139960310256276`*^9, 3.813996039503229*^9}, {
   3.8170267513962555`*^9, 3.8170267561807013`*^9}, {3.81702678646284*^9, 
   3.817026788522355*^9}, {3.8187996510336695`*^9, 3.8187996518713255`*^9}, 
   3.825285787015414*^9, {3.825285837299809*^9, 3.8252858386118665`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1483]:=",ExpressionUUID->"ae10a51e-203c-49fc-b34c-3bab85f2f593"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pytu0", " ", "=", "6.10622"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851738717746*^9, {3.8048593644040937`*^9, 
   3.804859369373639*^9}, 3.8050180911508274`*^9, {3.805022589673736*^9, 
   3.8050225937212696`*^9}, {3.8056655234742956`*^9, 3.8056655242087946`*^9}, 
   3.8072860283560123`*^9, {3.812471001995841*^9, 3.8124710037962484`*^9}, {
   3.8139962057916765`*^9, 3.813996208095474*^9}, {3.8170310457145967`*^9, 
   3.8170310509618754`*^9}, {3.8170316519772673`*^9, 
   3.8170316526056647`*^9}, {3.818800451254632*^9, 3.818800459803276*^9}, {
   3.825285847970174*^9, 3.8252858645411577`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1484]:=",ExpressionUUID->"bbe25b2d-bbf5-45c8-98c1-b268a76c3c79"],

Cell["Total processed imports", "Text",
 CellChangeTimes->{{3.825286395115486*^9, 
  3.8252863987273245`*^9}},ExpressionUUID->"1e6fa944-248c-42ea-9f68-\
d8c262e947b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qytp0", " ", "=", 
    StyleBox["52839763",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.8048515168380613`*^9, {3.8048591480713325`*^9, 
   3.804859151134322*^9}, 3.805017502641066*^9, {3.8050223114300685`*^9, 
   3.805022316447248*^9}, {3.8056462154235764`*^9, 3.8056462194300847`*^9}, {
   3.8072871522555094`*^9, 3.8072871525897713`*^9}, {3.812470725483238*^9, 
   3.812470730168902*^9}, {3.8170270796601934`*^9, 3.8170270834812407`*^9}, {
   3.8170271462308426`*^9, 3.8170271565834293`*^9}, {3.818799862615045*^9, 
   3.8187998696665583`*^9}, 3.8252862663166304`*^9, {3.8252863703010607`*^9, 
   3.8252863718812747`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1485]:=",ExpressionUUID->"9485f714-e9cc-42a5-989a-eec3da2d3d9d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pytp0", " ", "=", "8.04508"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.8048517763987885`*^9, {
   3.8048594197297783`*^9, 3.80485942321471*^9}, {3.804859460017418*^9, 
   3.804859464424373*^9}, {3.804865902826519*^9, 3.80486590501756*^9}, 
   3.8050182696736803`*^9, {3.805023020546306*^9, 3.8050230248593616`*^9}, {
   3.805665716479865*^9, 3.805665716933069*^9}, 3.807285975235664*^9, {
   3.8124710815818105`*^9, 3.8124710841898365`*^9}, {3.8170311013467064`*^9, 
   3.817031105395082*^9}, {3.8170318963465643`*^9, 3.817031898866809*^9}, {
   3.8188008174889092`*^9, 3.818800826989335*^9}, {3.8252865318432903`*^9, 
   3.825286558569063*^9}, {3.8252865976554565`*^9, 3.8252866013633523`*^9}, {
   3.8252866456738076`*^9, 3.825286647513279*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1486]:=",ExpressionUUID->"780be44e-d362-41c6-bc75-eb26841e8c10"],

Cell["Illegal imports", "Text",
 CellChangeTimes->{{3.825286959123578*^9, 
  3.8252869609440002`*^9}},ExpressionUUID->"b810cbd4-8a2b-4e92-b4f6-\
2f8f241d689b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qyiu0", " ", "=", "990308"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.8048515369847345`*^9, {3.804859197487756*^9, 
   3.8048592001756873`*^9}, 3.8050175725603075`*^9, {3.8050223915991592`*^9, 
   3.805022394208959*^9}, {3.8056463094236813`*^9, 3.80564631193972*^9}, {
   3.8072871753154593`*^9, 3.8072871759149294`*^9}, {3.8124707911575503`*^9, 
   3.812470792810842*^9}, {3.8139961295343122`*^9, 3.8139961462022924`*^9}, {
   3.81702731162739*^9, 3.8170273166307974`*^9}, {3.8170273752790356`*^9, 
   3.8170274171940055`*^9}, {3.817030601981617*^9, 3.8170306716792746`*^9}, {
   3.818800074536688*^9, 3.818800076763429*^9}, 3.825286733216867*^9, {
   3.8252868266805525`*^9, 3.8252868287421784`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1487]:=",ExpressionUUID->"ef17bc6d-a4c5-40a9-85a0-e1e90d4683ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qyip0", " ", "=", "7064729"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515541907682`*^9, {3.8048592345130177`*^9, 3.804859239029372*^9}, 
   3.805017636828994*^9, {3.8050224411970854`*^9, 3.805022443760002*^9}, {
   3.805646360660723*^9, 3.8056463640519037`*^9}, {3.8072871986906548`*^9, 
   3.807287199052935*^9}, {3.8124708448485026`*^9, 3.812470848293194*^9}, {
   3.817030837669922*^9, 3.8170308454022145`*^9}, {3.8170309011398506`*^9, 
   3.817030905826638*^9}, {3.818800267180568*^9, 3.8188002674818025`*^9}, 
   3.8252868475568056`*^9, 3.8252869378070045`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1488]:=",ExpressionUUID->"5869e936-4b85-417d-9535-9acd134d3627"],

Cell[TextData[StyleBox["Skipjack",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.82498135149479*^9, 3.824981353015973*^9}, 3.8249814426737957`*^9, 
   3.8249830230169973`*^9, {3.8252749315381975`*^9, 3.8252749323147917`*^9}, 
   3.825282769843543*^9, 3.825282870260154*^9, {3.8252858273930244`*^9, 
   3.8252858286450853`*^9}, {3.8252858870026903`*^9, 
   3.8252858882816973`*^9}},ExpressionUUID->"2a63f4da-eb85-4c6b-a533-\
22b5c1dddd8b"],

Cell["Total unprocessed imports", "Text",
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814453368645`*^9, 3.8249814468960824`*^9}, 
   3.8249830230169973`*^9, 3.825282769843543*^9, 
   3.825282870260154*^9},ExpressionUUID->"5ebdd3af-807f-46ba-907f-\
369f547773cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qstu0", " ", "=", 
    StyleBox["28952079",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.8048515018675895`*^9, {
   3.8048590980585527`*^9, 3.8048591016372504`*^9}, 3.8050174603390923`*^9, {
   3.80502226377987*^9, 3.8050222653269944`*^9}, {3.805646157032232*^9, 
   3.8056461604749346`*^9}, {3.807287131244157*^9, 3.8072871315774155`*^9}, {
   3.8124706702160573`*^9, 3.812470673592696*^9}, {3.8139960472422504`*^9, 
   3.8139960525093503`*^9}, {3.817026799880369*^9, 3.8170268196172047`*^9}, {
   3.8187996718759575`*^9, 3.818799672155176*^9}, 3.82528579189423*^9, 
   3.8252860367639694`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1489]:=",ExpressionUUID->"4f31d8a3-142a-4e41-9984-1a88a6f968f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pstu0", " ", "=", "5.7198"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851741390031*^9, {3.8048593749382596`*^9, 
   3.8048593807364388`*^9}, 3.805018101074109*^9, {3.8050226014569044`*^9, 
   3.805022607145331*^9}, {3.805665532444476*^9, 3.805665533897846*^9}, 
   3.807286023846504*^9, {3.812471009340581*^9, 3.81247101104291*^9}, {
   3.813996222924016*^9, 3.813996226517811*^9}, {3.8170310539901476`*^9, 
   3.817031057554384*^9}, {3.8170316741801405`*^9, 3.8170316766575317`*^9}, {
   3.818800488400502*^9, 3.8188004952738447`*^9}, {3.8252860496530333`*^9, 
   3.8252860650380893`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1490]:=",ExpressionUUID->"3ff847f8-e519-4d22-a466-267ec672c9ff"],

Cell["Total processed imports", "Text",
 CellChangeTimes->{{3.825286410832776*^9, 
  3.8252864144986935`*^9}},ExpressionUUID->"3c70026f-6cbc-4bb3-8069-\
6d167beb218b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qstp0", " ", "=", 
    StyleBox["97739443",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.804851519404023*^9, {3.8048591560917697`*^9, 
   3.8048591592391844`*^9}, 3.805017512752103*^9, {3.805022335809778*^9, 
   3.805022340044843*^9}, {3.805646222735584*^9, 3.805646229362497*^9}, {
   3.807287155327902*^9, 3.8072871557112017`*^9}, {3.812470735230854*^9, 
   3.8124707378979363`*^9}, {3.8170270896378555`*^9, 3.817027093115483*^9}, {
   3.8170271693205433`*^9, 3.8170271716763983`*^9}, {3.818799900834919*^9, 
   3.8187999045898557`*^9}, {3.8252862762804623`*^9, 3.8252862766878014`*^9}, 
   3.825286375261944*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1491]:=",ExpressionUUID->"29350a81-3a4a-4b4b-a909-8f3dc67795fb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pstp0", " ", "=", "4.70128"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.8048517788079557`*^9, {
   3.8048594276529274`*^9, 3.8048594301064444`*^9}, {3.8048594705997667`*^9, 
   3.8048594745222692`*^9}, {3.804865909505168*^9, 3.8048659121618433`*^9}, 
   3.805018278393769*^9, {3.8050230298017282`*^9, 3.805023034771118*^9}, {
   3.805665725529579*^9, 3.80566572662352*^9}, 3.8072859714447136`*^9, {
   3.8124710875284305`*^9, 3.8124710898512344`*^9}, {3.817031108438241*^9, 
   3.817031111571967*^9}, {3.817031928502398*^9, 3.817031929537632*^9}, {
   3.818800868178522*^9, 3.818800879723544*^9}, {3.825286534817594*^9, 
   3.8252865615914183`*^9}, {3.8252866055355835`*^9, 3.8252866088951955`*^9}, 
   3.8252866514642982`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1492]:=",ExpressionUUID->"6af3a0db-6bd1-4bd8-b13c-06058f2aad81"],

Cell["Illegal imports", "Text",
 CellChangeTimes->{{3.825286978011262*^9, 
  3.825286981567995*^9}},ExpressionUUID->"a56c7ed1-8d22-43ab-b414-\
6e87c5d3693c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsiu0", " ", "=", "2630579"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.8048515390631647`*^9, {3.8048592061610203`*^9, 
   3.804859208024148*^9}, 3.805017589247558*^9, {3.80502240255534*^9, 
   3.8050224042587395`*^9}, {3.805646316597954*^9, 3.8056463194890537`*^9}, {
   3.807287178584004*^9, 3.8072871789673014`*^9}, {3.8124707969961123`*^9, 
   3.812470799189829*^9}, {3.8139961282833395`*^9, 3.8139961603913345`*^9}, {
   3.8170273205235744`*^9, 3.8170273243689384`*^9}, {3.8170306939551735`*^9, 
   3.8170306989099092`*^9}, {3.8188001070481014`*^9, 3.8188001074133863`*^9}, 
   3.825286744347522*^9, 3.825286832929424*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1493]:=",ExpressionUUID->"49bbfc31-81e6-46c1-a11b-7bf50613d980"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsip0", " ", "=", "10177644"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515567692885`*^9, {3.8048592431706595`*^9, 3.8048592455772943`*^9}, 
   3.805017646330557*^9, {3.8050224491983905`*^9, 3.8050224526520786`*^9}, {
   3.805646368460105*^9, 3.8056463708980045`*^9}, {3.8072872016339464`*^9, 
   3.8072872019972277`*^9}, {3.812470852853757*^9, 3.8124708559241543`*^9}, {
   3.817030849062209*^9, 3.817030853560207*^9}, {3.8170309187162714`*^9, 
   3.8170309207248964`*^9}, {3.818800289146641*^9, 3.8188002949761715`*^9}, 
   3.825286851756051*^9, 3.8252869391089783`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1494]:=",ExpressionUUID->"21327809-8401-4b20-ae5b-310e4df12604"],

Cell[TextData[StyleBox["Albacore",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.82498135149479*^9, 3.824981353015973*^9}, 3.8249814426737957`*^9, 
   3.8249830230169973`*^9, {3.8252749315381975`*^9, 3.8252749323147917`*^9}, 
   3.825282769843543*^9, 3.825282870260154*^9, {3.8252858273930244`*^9, 
   3.8252858286450853`*^9}, {3.8252858929773817`*^9, 
   3.8252858938900766`*^9}},ExpressionUUID->"57d9ff1a-ea87-44cc-a887-\
0d6d017211d4"],

Cell["Total unprocessed imports", "Text",
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814453368645`*^9, 3.8249814468960824`*^9}, 
   3.8249830230169973`*^9, 3.825282769843543*^9, 
   3.825282870260154*^9},ExpressionUUID->"ddc87626-191a-4861-8414-\
1a700a9cabd5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qatu0", " ", "=", 
    StyleBox["10825988",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.804851503993678*^9, {
   3.804859106546692*^9, 3.8048591085313845`*^9}, {3.8050222716874075`*^9, 
   3.805022273656476*^9}, {3.805646165378788*^9, 3.8056461681735787`*^9}, {
   3.80728713527129*^9, 3.807287135624566*^9}, {3.8124706796494274`*^9, 
   3.8124706827588563`*^9}, {3.8139430805834107`*^9, 3.813943096887103*^9}, {
   3.817026834547948*^9, 3.8170268520094194`*^9}, {3.8187996944846296`*^9, 
   3.818799699093235*^9}, 3.825285795391984*^9, 3.8252860345682116`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1495]:=",ExpressionUUID->"8ccfd944-c19b-49ca-bd97-ae7982c4c14d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"patu0", " ", "=", "5.96477"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851745095583*^9, {3.8048593855964956`*^9, 
   3.804859389253332*^9}, {3.8050226314772887`*^9, 3.8050226372125945`*^9}, {
   3.8056655461121254`*^9, 3.805665546643465*^9}, 3.8072860200945845`*^9, {
   3.8124710177501493`*^9, 3.812471019972889*^9}, {3.8139962470477934`*^9, 
   3.81399624909439*^9}, {3.817031064413453*^9, 3.8170310685705233`*^9}, {
   3.8170317069989786`*^9, 3.817031711040077*^9}, {3.8188005238980913`*^9, 
   3.8188005357823277`*^9}, {3.8252860809175196`*^9, 3.8252860982060547`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1496]:=",ExpressionUUID->"8b465579-3011-4468-9c89-a2f6795256be"],

Cell["Total processed imports", "Text",
 CellChangeTimes->{{3.8252864235046854`*^9, 
  3.8252864270434723`*^9}},ExpressionUUID->"b84af873-ac36-4ec3-868a-\
1ffaad1bbaba"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qatp0", " ", "=", 
    StyleBox["36456957",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.8048515215605907`*^9, {3.804859164699379*^9, 
   3.804859168700019*^9}, {3.805022345295699*^9, 3.8050223485306015`*^9}, {
   3.805646237247239*^9, 3.805646241247918*^9}, {3.8072871585173845`*^9, 
   3.8072871588706584`*^9}, {3.8124707447913227`*^9, 
   3.8124707487684317`*^9}, {3.817027096613226*^9, 3.817027103663125*^9}, {
   3.817027206765975*^9, 3.8170272102391467`*^9}, {3.81879991954154*^9, 
   3.8187999235696907`*^9}, {3.825286280161522*^9, 3.825286280680889*^9}, 
   3.8252863774396267`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1497]:=",ExpressionUUID->"e01165ce-f1d5-466c-bd97-2cfeb5fb52a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"patp0", " ", "=", "6.27589"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.804851781495868*^9, {
   3.8048594347165575`*^9, 3.8048594421552544`*^9}, {3.8048594788678904`*^9, 
   3.804859482930971*^9}, {3.8048659166313086`*^9, 3.8048659239918613`*^9}, {
   3.805023039568612*^9, 3.805023045366234*^9}, {3.805665734128354*^9, 
   3.805665735003507*^9}, 3.8072859681771703`*^9, {3.8124710971188803`*^9, 
   3.812471100878801*^9}, {3.8170311143298845`*^9, 3.81703111760369*^9}, {
   3.817032144216039*^9, 3.8170321451648455`*^9}, {3.818800903715294*^9, 
   3.818800912065819*^9}, {3.825286540082718*^9, 3.825286565415386*^9}, {
   3.8252866129983873`*^9, 3.8252866172076645`*^9}, 3.825286652792343*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1498]:=",ExpressionUUID->"cf846bbd-4358-4ded-a3bd-51431faf16f0"],

Cell["Illegal imports", "Text",
 CellChangeTimes->{{3.8252869958140907`*^9, 
  3.825286997582435*^9}},ExpressionUUID->"f2be6bbb-96fd-4dbc-8a3c-\
7a8c9d5303e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qaiu0", " ", "=", "1649831"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.804851541954215*^9, {3.804859212477992*^9, 
   3.804859214822117*^9}, {3.805022408853236*^9, 3.805022410087814*^9}, {
   3.8056463242097116`*^9, 3.8056463265851*^9}, {3.807287181824526*^9, 
   3.8072871821868076`*^9}, {3.8124708036322956`*^9, 3.812470806555579*^9}, {
   3.8139431246226964`*^9, 3.813943138369398*^9}, {3.817027329093926*^9, 
   3.817027332921517*^9}, {3.81703071672717*^9, 3.8170307204724984`*^9}, {
   3.8188001308556156`*^9, 3.8188001382713795`*^9}, 3.82528675385898*^9, 
   3.825286834139417*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1499]:=",ExpressionUUID->"adf09bb8-ba09-42d4-8fa1-3851ed8f03f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qaip0", " ", "=", "5185988"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.80485155892587*^9, {3.8048592504999576`*^9, 3.8048592528905926`*^9}, {
   3.805022457746656*^9, 3.8050224597157245`*^9}, {3.805646375867463*^9, 
   3.8056463782597036`*^9}, {3.8072872044301233`*^9, 
   3.8072872047833977`*^9}, {3.812470861518526*^9, 3.812470864597933*^9}, {
   3.8170308568525343`*^9, 3.8170308640123835`*^9}, {3.8170309404387817`*^9, 
   3.8170309440483613`*^9}, {3.8188003099217873`*^9, 
   3.8188003176828194`*^9}, {3.825286855602067*^9, 3.8252868564757195`*^9}, 
   3.8252869402168283`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1500]:=",ExpressionUUID->"eecac173-9bd3-4c06-b1be-e9c182499ee0"],

Cell[TextData[StyleBox["Bigeye",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.82498135149479*^9, 3.824981353015973*^9}, 3.8249814426737957`*^9, 
   3.8249830230169973`*^9, {3.8252749315381975`*^9, 3.8252749323147917`*^9}, 
   3.825282769843543*^9, 3.825282870260154*^9, {3.8252858273930244`*^9, 
   3.8252858286450853`*^9}, {3.82528589820047*^9, 
   3.825285898867016*^9}},ExpressionUUID->"e03dd20a-f0ad-4f2a-a960-\
e82685438b09"],

Cell["Total unprocessed imports", "Text",
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814453368645`*^9, 3.8249814468960824`*^9}, 
   3.8249830230169973`*^9, 3.825282769843543*^9, 
   3.825282870260154*^9},ExpressionUUID->"3ca59a7a-92d7-4ee5-a3a1-\
70ddbd3d7a5e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qbtu0", " ", 
    StyleBox["=",
     FontColor->GrayLevel[0]], 
    StyleBox["7562019",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.804851506634692*^9, {
   3.8048591212377567`*^9, 3.8048591249079113`*^9}, 3.8050174723254375`*^9, {
   3.8050222788917065`*^9, 3.805022281860938*^9}, {3.8056461739322014`*^9, 
   3.805646177617194*^9}, {3.8072871390522375`*^9, 3.80728713941552*^9}, {
   3.8124706871913223`*^9, 3.8124706908231564`*^9}, {3.8139960571369543`*^9, 
   3.813996071275962*^9}, {3.8170268635823975`*^9, 3.8170269262026024`*^9}, {
   3.818799719562233*^9, 3.8187997294179344`*^9}, 3.8252857986405134`*^9, {
   3.8252859365204744`*^9, 3.8252859435859823`*^9}, 3.8252860324205666`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1501]:=",ExpressionUUID->"371d9049-7ce7-40f7-b41b-29c4bc91fb4b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pbtu0", " ", "=", "7.38661"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851748049161*^9, {3.8048593936292486`*^9, 
   3.804859397458267*^9}, 3.805018113388355*^9, {3.8050226422134104`*^9, 
   3.8050226466203794`*^9}, {3.8056655591158066`*^9, 3.805665559787795*^9}, 
   3.807286017504567*^9, {3.8124710258524823`*^9, 3.8124710265310125`*^9}, {
   3.8170310713789687`*^9, 3.8170310751238317`*^9}, {3.8170317283925557`*^9, 
   3.817031762641839*^9}, {3.818800578137246*^9, 3.818800613587799*^9}, {
   3.8252862082181644`*^9, 3.82528623058273*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1502]:=",ExpressionUUID->"aac04036-7655-40bb-aad7-1dc7991d1003"],

Cell["Total processed imports", "Text",
 CellChangeTimes->{{3.8252864340009093`*^9, 
  3.825286437352582*^9}},ExpressionUUID->"63d56b7a-c375-443d-94af-\
b937d9617e22"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qbtp0", " ", "=", 
    StyleBox["8165080",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.804851523748412*^9, {3.8048591766858854`*^9, 
   3.80485918053025*^9}, 3.805017523488247*^9, {3.8050223529375687`*^9, 
   3.8050223554223504`*^9}, {3.80564624818703*^9, 3.805646251328046*^9}, {
   3.807287161303554*^9, 3.8072871616478214`*^9}, {3.8124707569608307`*^9, 
   3.8124707592346106`*^9}, {3.817027106498041*^9, 3.8170271098016253`*^9}, {
   3.817027226424262*^9, 3.81702723235335*^9}, {3.818799938416293*^9, 
   3.8187999432580795`*^9}, 3.825286284714108*^9, 3.8252863788617487`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1503]:=",ExpressionUUID->"fc53ee63-8e40-4683-b321-8821e0a01696"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pbtp0", " ", "=", "8.66838"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.804851783996252*^9, {
   3.8048594463590517`*^9, 3.8048594494689245`*^9}, {3.804859487327943*^9, 
   3.8048594931426477`*^9}, {3.8048659293832474`*^9, 3.8048659328369255`*^9}, 
   3.8050182854886165`*^9, {3.8050230503825045`*^9, 3.8050230545861716`*^9}, {
   3.805665743000533*^9, 3.8056657436142235`*^9}, 3.807285963302374*^9, {
   3.8124711044445715`*^9, 3.8124711067173367`*^9}, {3.8170311205330467`*^9, 
   3.817031123804088*^9}, {3.8170321595537567`*^9, 3.8170321606300926`*^9}, {
   3.818800931881302*^9, 3.8188009403248997`*^9}, {3.8252865423845053`*^9, 
   3.8252865682566085`*^9}, {3.825286621165737*^9, 3.8252866240840664`*^9}, 
   3.8252866541353893`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1504]:=",ExpressionUUID->"a19c8c06-1203-453b-97b9-81d7697dca09"],

Cell["Illegal imports", "Text",
 CellChangeTimes->{{3.825287010218315*^9, 
  3.8252870118945656`*^9}},ExpressionUUID->"fd59724b-d4d7-48f5-94e7-\
da3322d79cb4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qbiu0", " ", "=", " ", "1165447"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.804851544345194*^9, {3.804859222792143*^9, 
   3.8048592281838903`*^9}, 3.805017601499572*^9, {3.805022415979398*^9, 
   3.805022417932844*^9}, {3.8056463334000163`*^9, 3.8056463354941115`*^9}, {
   3.8072871848168564`*^9, 3.807287185140107*^9}, {3.812470812099916*^9, 
   3.8124708159489193`*^9}, {3.817027336278945*^9, 3.8170273397815933`*^9}, {
   3.8170307389027505`*^9, 3.8170307538396864`*^9}, {3.8188001604526186`*^9, 
   3.818800166915642*^9}, {3.825286763662555*^9, 3.825286772798671*^9}, 
   3.825286835330274*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1505]:=",ExpressionUUID->"7d33a6af-ed15-4356-8e81-ee1b51ecb618"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qbip0", " ", "=", "1393667"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515613793716`*^9, {3.804859261769577*^9, 3.8048592662859316`*^9}, 
   3.8050176541599693`*^9, {3.8050224656385655`*^9, 3.8050224672325726`*^9}, {
   3.805646383822101*^9, 3.80564638584033*^9}, {3.807287208241089*^9, 
   3.807287208554332*^9}, {3.8124708697979937`*^9, 3.8124708722288914`*^9}, {
   3.8170308668605547`*^9, 3.8170308708010283`*^9}, {3.81703095618285*^9, 
   3.817030957763472*^9}, {3.8188003396088605`*^9, 3.818800339881072*^9}, 
   3.825286859170827*^9, 3.825286941174591*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1506]:=",ExpressionUUID->"35bf12f1-9497-43a8-93f9-a343c7e57c0a"],

Cell[TextData[StyleBox["Bluefin",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.82498135149479*^9, 3.824981353015973*^9}, 3.8249814426737957`*^9, 
   3.8249830230169973`*^9, {3.8252749315381975`*^9, 3.8252749323147917`*^9}, 
   3.825282769843543*^9, 3.825282870260154*^9, {3.8252858273930244`*^9, 
   3.8252858286450853`*^9}, {3.825285902626979*^9, 
   3.8252859056593685`*^9}},ExpressionUUID->"9ac45ad9-bf21-4008-a758-\
786c7ed6b0fa"],

Cell["Total unprocessed imports", "Text",
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814453368645`*^9, 3.8249814468960824`*^9}, 
   3.8249830230169973`*^9, 3.825282769843543*^9, 
   3.825282870260154*^9},ExpressionUUID->"ffe82adc-fd6a-424b-bf03-\
086e92c0fa26"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qftu0", " ", "=", 
    StyleBox["2326232",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.804851506634692*^9, {
   3.8048591212377567`*^9, 3.8048591249079113`*^9}, {3.8050174723254375`*^9, 
   3.8050174834066176`*^9}, {3.8050222868930087`*^9, 3.805022290552119*^9}, {
   3.8056461840458636`*^9, 3.80564618843721*^9}, 3.8072853285732417`*^9, {
   3.8072871428922243`*^9, 3.8072871432455006`*^9}, {3.8124706954227505`*^9, 
   3.812470699320797*^9}, {3.8139960740921507`*^9, 3.8139960808173904`*^9}, {
   3.8170269400573797`*^9, 3.817026971353592*^9}, {3.8187997486869965`*^9, 
   3.8187997564951024`*^9}, 3.8252858028008223`*^9, {3.8252859627009473`*^9, 
   3.8252859715238576`*^9}, 3.825286029867527*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1507]:=",ExpressionUUID->"e3583c1c-0b7d-498c-9dc9-be43612a7e2d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pftu0", " ", "=", "21.2879"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851748049161*^9, {3.8048593936292486`*^9, 
   3.804859397458267*^9}, {3.805018113388355*^9, 3.805018121905187*^9}, {
   3.8050226512323885`*^9, 3.8050226559050236`*^9}, 3.8072860133993692`*^9, {
   3.8124710329320145`*^9, 3.8124710336295595`*^9}, {3.8170310779522963`*^9, 
   3.8170310814452767`*^9}, {3.8170317950122576`*^9, 3.817031820986454*^9}, {
   3.8188006421409903`*^9, 3.818800690817913*^9}, {3.8252861791103945`*^9, 
   3.825286197844082*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1508]:=",ExpressionUUID->"8abd3c2c-fa5f-4fa9-b775-f67376897e53"],

Cell["Total processed imports", "Text",
 CellChangeTimes->{{3.825286444872414*^9, 
  3.8252864557299194`*^9}},ExpressionUUID->"f6c7bd60-e494-47f6-9024-\
c6db127d3f58"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qftp0", " ", "=", 
    StyleBox["201152",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.804851523748412*^9, {3.8048591766858854`*^9, 
   3.80485918053025*^9}, {3.805017523488247*^9, 3.8050175307081823`*^9}, {
   3.8050223611106586`*^9, 3.8050223632985163`*^9}, {3.805646256795086*^9, 
   3.805646259346697*^9}, {3.8072871643559303`*^9, 3.8072871646801825`*^9}, {
   3.8124707645527635`*^9, 3.8124707661069803`*^9}, {3.8170271135955095`*^9, 
   3.817027116893659*^9}, {3.817027252679825*^9, 3.8170272632006483`*^9}, {
   3.818799960090233*^9, 3.818799972865218*^9}, {3.8252862879486017`*^9, 
   3.8252863222754483`*^9}, 3.8252863809964237`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1509]:=",ExpressionUUID->"aaf62327-53e1-464d-9269-855cd6a8d47e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pftp0", " ", "=", "13.509"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.804851783996252*^9, {
   3.8048594463590517`*^9, 3.8048594494689245`*^9}, {3.804859487327943*^9, 
   3.8048594931426477`*^9}, {3.8048659293832474`*^9, 
   3.8048659328369255`*^9}, {3.8050182854886165`*^9, 
   3.8050182941251855`*^9}, {3.805023059946237*^9, 3.8050230631497755`*^9}, {
   3.8056657522159815`*^9, 3.805665753372402*^9}, 3.807285958614726*^9, {
   3.8124711105493135`*^9, 3.8124711129311633`*^9}, {3.817031126826954*^9, 
   3.817031129947338*^9}, {3.817032174004941*^9, 3.8170322107620726`*^9}, {
   3.818800970537512*^9, 3.818800994794469*^9}, {3.8252865452337003`*^9, 
   3.825286571136911*^9}, {3.8252866280521092`*^9, 3.8252866554403996`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1510]:=",ExpressionUUID->"830979a0-2024-4f7e-94ef-e6fd5d545f12"],

Cell["Illegal imports", "Text",
 CellChangeTimes->{{3.825287024203146*^9, 
  3.8252870263408203`*^9}},ExpressionUUID->"402de0e1-f804-4c84-9030-\
4cc90722e61c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qfiu0", " ", "=", " ", "1108413"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.804851544345194*^9, {3.804859222792143*^9, 
   3.8048592281838903`*^9}, {3.805017601499572*^9, 3.8050176145309644`*^9}, {
   3.8050224245056534`*^9, 3.80502242658412*^9}, {3.805646340307399*^9, 
   3.8056463430450153`*^9}, {3.807287188529745*^9, 3.8072871888529963`*^9}, {
   3.8124708225270615`*^9, 3.812470825991767*^9}, {3.81702734289427*^9, 
   3.817027346571784*^9}, {3.8170307699254923`*^9, 3.8170307827900524`*^9}, {
   3.818800196098323*^9, 3.8188001983730907`*^9}, {3.825286777096019*^9, 
   3.8252867864423037`*^9}, 3.825286836709371*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1511]:=",ExpressionUUID->"d335b394-b7ba-460c-8916-2bfed61ddef4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qfip0", " ", "=", "52704"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515613793716`*^9, {3.804859261769577*^9, 3.8048592662859316`*^9}, {
   3.8050176541599693`*^9, 3.8050176622706776`*^9}, {3.8050224736086135`*^9, 
   3.805022474483754*^9}, {3.807287210968213*^9, 3.8072872113014717`*^9}, {
   3.812470876543264*^9, 3.812470879003186*^9}, {3.8170308736352663`*^9, 
   3.8170308774964*^9}, {3.8170309720031996`*^9, 3.8170309765101337`*^9}, {
   3.8188003626587753`*^9, 3.818800363047076*^9}, {3.825286862835658*^9, 
   3.825286868988441*^9}, 3.825286942846877*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1512]:=",ExpressionUUID->"5c57897c-e6e0-4547-adec-f264f983fc1c"],

Cell[TextData[StyleBox["Other/NEI tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.82498135149479*^9, 3.824981353015973*^9}, 3.8249814426737957`*^9, 
   3.8249830230169973`*^9, {3.8252749315381975`*^9, 3.8252749323147917`*^9}, 
   3.825282769843543*^9, 3.825282870260154*^9, {3.8252858273930244`*^9, 
   3.8252858286450853`*^9}, {3.82528591117762*^9, 
   3.8252859130831013`*^9}},ExpressionUUID->"068f0a4b-0c8d-4f61-b575-\
95776c4129e2"],

Cell["Total unprocessed imports", "Text",
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814453368645`*^9, 3.8249814468960824`*^9}, 
   3.8249830230169973`*^9, 3.825282769843543*^9, 
   3.825282870260154*^9},ExpressionUUID->"4aceaba7-6a60-4554-863d-\
dd84089e35c2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qotu0", 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox["=",
     FontColor->GrayLevel[0]], 
    StyleBox["259286",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.804851506634692*^9, {
   3.8048591212377567`*^9, 3.8048591249079113`*^9}, {3.8050174723254375`*^9, 
   3.805017486142664*^9}, {3.805022295146616*^9, 3.8050222988034616`*^9}, {
   3.8056461958459024`*^9, 3.8056461989581876`*^9}, {3.8072871459436*^9, 
   3.807287146306884*^9}, {3.8124707048851423`*^9, 3.8124707071188917`*^9}, {
   3.817026985694618*^9, 3.817026994199976*^9}, {3.817027027538821*^9, 
   3.8170270292904625`*^9}, {3.825285986836858*^9, 3.8252859874363413`*^9}, 
   3.825286028281313*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1513]:=",ExpressionUUID->"9e84867b-f9b9-42cf-9eed-4e824f4a1706"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"potu0", " ", "=", "5.78741"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851748049161*^9, {3.8048593936292486`*^9, 
   3.804859397458267*^9}, {3.805018113388355*^9, 3.805018124311778*^9}, {
   3.805022660421383*^9, 3.8050226647658396`*^9}, 3.807286008446515*^9, {
   3.8124710396672497`*^9, 3.8124710408571744`*^9}, {3.817031084297268*^9, 
   3.817031088997329*^9}, {3.817031857302637*^9, 3.817031861179042*^9}, {
   3.818800731623802*^9, 3.818800744542898*^9}, {3.825286146680996*^9, 
   3.8252861590937386`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1514]:=",ExpressionUUID->"98eaeb8e-715e-43ab-ab2b-514540ca6fbe"],

Cell["Total processed imports", "Text",
 CellChangeTimes->{{3.825286475626487*^9, 
  3.8252864798908243`*^9}},ExpressionUUID->"1567bd46-d040-4da0-b773-\
798f28cbadeb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qotp0", " ", "=", 
    StyleBox["981188",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.804851523748412*^9, {3.8048591766858854`*^9, 
   3.80485918053025*^9}, {3.805017523488247*^9, 3.805017533396126*^9}, {
   3.805022368064474*^9, 3.8050223716740403`*^9}, {3.805646264750458*^9, 
   3.8056462705795403`*^9}, {3.807287168846424*^9, 3.8072871692187123`*^9}, {
   3.812470771819442*^9, 3.8124707738860545`*^9}, {3.817027120175207*^9, 
   3.8170271267858734`*^9}, {3.8170272789158387`*^9, 3.8170272803518395`*^9}, 
   3.8188000062923484`*^9, 3.825286291298212*^9, 3.8252863823665257`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1515]:=",ExpressionUUID->"d0c9dc2b-643a-4c85-b86d-881765c9c441"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"potp0", " ", "=", "8.0845"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.804851783996252*^9, {
   3.8048594463590517`*^9, 3.8048594494689245`*^9}, {3.804859487327943*^9, 
   3.8048594931426477`*^9}, {3.8048659293832474`*^9, 
   3.8048659328369255`*^9}, {3.8050182854886165`*^9, 
   3.8050182968443565`*^9}, {3.8050230672908416`*^9, 3.805023070853801*^9}, 
   3.807285955327167*^9, {3.812471122403522*^9, 3.8124711246372566`*^9}, {
   3.8170311338547955`*^9, 3.81703113771802*^9}, {3.8170322851629524`*^9, 
   3.817032288211093*^9}, {3.818801013341965*^9, 3.818801022904436*^9}, {
   3.8252865501405334`*^9, 3.8252865736528587`*^9}, {3.825286634279956*^9, 
   3.8252866566363297`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1516]:=",ExpressionUUID->"97a149fc-08a4-4fe9-88c3-c69289bd6ca6"],

Cell["Illegal imports", "Text",
 CellChangeTimes->{{3.825287037928815*^9, 
  3.825287039755228*^9}},ExpressionUUID->"4b79b523-99b6-43b1-bb28-\
30c46d43bab0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qoiu0", " ", "=", "46462"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.804851544345194*^9, {3.804859222792143*^9, 
   3.8048592281838903`*^9}, {3.805017601499572*^9, 3.8050176172501593`*^9}, {
   3.805022431367359*^9, 3.805022433055135*^9}, {3.805646347764537*^9, 
   3.805646349983653*^9}, {3.8072871916101437`*^9, 3.807287192052487*^9}, {
   3.812470831171816*^9, 3.812470833002245*^9}, {3.817027349257557*^9, 
   3.8170273531283236`*^9}, {3.817030806492116*^9, 3.817030808682965*^9}, {
   3.818800227010348*^9, 3.8188002293701825`*^9}, {3.825286790511427*^9, 
   3.825286792914287*^9}, 3.8252868380834723`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1517]:=",ExpressionUUID->"43dbadf4-e672-4f76-9011-c2105e6d5cee"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qoip0", " ", "=", "278737"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515613793716`*^9, {3.804859261769577*^9, 3.8048592662859316`*^9}, {
   3.8050176541599693`*^9, 3.805017664872533*^9}, {3.8050224793751793`*^9, 
   3.805022481297365*^9}, {3.807287213834445*^9, 3.8072872141667023`*^9}, {
   3.8124708831204023`*^9, 3.8124708844284267`*^9}, {3.81703088031153*^9, 
   3.817030883999052*^9}, {3.8170309999363403`*^9, 3.817031001109849*^9}, {
   3.8188003861700478`*^9, 3.8188003864912977`*^9}, 3.825286872089853*^9, 
   3.825286943909753*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1518]:=",ExpressionUUID->"deeacab3-4398-4bbd-8b8a-420ec18f72de"],

Cell[TextData[StyleBox["Bonito",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7990610156303186`*^9, 3.7990610445251637`*^9}, {
   3.7997912961634583`*^9, 3.799791305350816*^9}, 3.80460555302131*^9, {
   3.8057106111430745`*^9, 3.8057106141435614`*^9}, {3.805710669667836*^9, 
   3.8057106699334855`*^9}, {3.8198147993913155`*^9, 3.819814801895269*^9}, {
   3.8198150235080533`*^9, 3.819815029741912*^9}, 3.8198152044580364`*^9, {
   3.8249809000438323`*^9, 3.824980900790411*^9}, 3.824981043854788*^9, {
   3.82498135149479*^9, 3.824981353015973*^9}, 3.8249814426737957`*^9, 
   3.8249830230169973`*^9, {3.8252749315381975`*^9, 3.8252749323147917`*^9}, 
   3.825282769843543*^9, 3.825282870260154*^9, {3.8252858273930244`*^9, 
   3.8252858286450853`*^9}, {3.8252859175766315`*^9, 
   3.825285918229213*^9}},ExpressionUUID->"741a7d08-dd5e-44d5-816a-\
9860128f4512"],

Cell["Total unprocessed imports", "Text",
 CellChangeTimes->{{3.8198150361799293`*^9, 3.8198150377071247`*^9}, 
   3.8198152044580364`*^9, {3.8249814453368645`*^9, 3.8249814468960824`*^9}, 
   3.8249830230169973`*^9, 3.825282769843543*^9, 
   3.825282870260154*^9},ExpressionUUID->"80679306-7315-447f-8853-\
cb9a606afce3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qntu0", " ", "=", 
    StyleBox["68877",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, 3.7997923408078775`*^9, {3.8016626780701056`*^9, 
   3.801662681430084*^9}, {3.8043436823736987`*^9, 3.804343685415067*^9}, {
   3.8043438497681026`*^9, 3.8043438518156967`*^9}, {3.8045194008492875`*^9, 
   3.8045194150604362`*^9}, {3.8045456430295744`*^9, 3.804545645217409*^9}, {
   3.804586953551327*^9, 3.804586957583432*^9}, 3.804851506634692*^9, {
   3.8048591212377567`*^9, 3.8048591249079113`*^9}, {3.8050174723254375`*^9, 
   3.805017486142664*^9}, {3.805022295146616*^9, 3.8050222988034616`*^9}, {
   3.8056391592118626`*^9, 3.805639159336881*^9}, {3.805646203099519*^9, 
   3.8056462062341137`*^9}, {3.8072871490159926`*^9, 
   3.8072871493402457`*^9}, {3.812470711531336*^9, 3.812470713134591*^9}, {
   3.8170270442098465`*^9, 3.8170270573388834`*^9}, {3.8252860119235077`*^9, 
   3.825286023910865*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1519]:=",ExpressionUUID->"4478c4b2-9dca-4c70-9a3e-09d649c678a6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pntu0", " ", "=", "3.2723"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, 3.799799245204134*^9, {
   3.801662615235279*^9, 3.8016626171106157`*^9}, {3.8033922236809115`*^9, 
   3.8033922241497374`*^9}, {3.8043439166010265`*^9, 
   3.8043439299514136`*^9}, {3.804519813021881*^9, 3.804519826152172*^9}, {
   3.8045206495059085`*^9, 3.8045206577890797`*^9}, {3.8045870600676985`*^9, 
   3.804587072501094*^9}, 3.804851748049161*^9, {3.8048593936292486`*^9, 
   3.804859397458267*^9}, {3.805018113388355*^9, 3.805018124311778*^9}, {
   3.805022660421383*^9, 3.8050226647658396`*^9}, {3.805639573588688*^9, 
   3.805639573854355*^9}, {3.805646445181013*^9, 3.8056464467919188`*^9}, 
   3.8072860048537188`*^9, {3.8124710471991005`*^9, 3.81247104807378*^9}, {
   3.817031091659253*^9, 3.817031094937298*^9}, {3.8170316006616583`*^9, 
   3.8170316248405743`*^9}, {3.81703187441805*^9, 3.8170318751355524`*^9}, {
   3.8188007825526047`*^9, 3.818800793637269*^9}, {3.825286125065095*^9, 
   3.825286142789962*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1520]:=",ExpressionUUID->"59e87d4e-a875-4e1f-973d-449d82a95dd9"],

Cell["Total processed imports", "Text",
 CellChangeTimes->{{3.825286463311845*^9, 
  3.8252864684839334`*^9}},ExpressionUUID->"730c05e4-fbd5-45c9-a667-\
9fa4c34cb3e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qntp0", " ", "=", 
    StyleBox["291758",
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->GrayLevel[0]]}], 
  StyleBox[
   RowBox[{"(*", "kg", "*)"}],
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, 
   3.799792290761775*^9, {3.801662688837666*^9, 3.801662692682107*^9}, {
   3.8043436886055465`*^9, 3.8043436926326804`*^9}, {3.804343864547529*^9, 
   3.804343869165122*^9}, {3.8043478240612392`*^9, 3.8043478245616274`*^9}, {
   3.8043479104715033`*^9, 3.8043479116223974`*^9}, {3.804586986559531*^9, 
   3.8045869906788425`*^9}, 3.804851523748412*^9, {3.8048591766858854`*^9, 
   3.80485918053025*^9}, {3.805017523488247*^9, 3.805017533396126*^9}, {
   3.805022368064474*^9, 3.8050223716740403`*^9}, {3.8056391702000093`*^9, 
   3.8056391702781477`*^9}, {3.8056462747989845`*^9, 3.80564627658125*^9}, {
   3.8072871719188156`*^9, 3.8072871723011127`*^9}, {3.8124707771456017`*^9, 
   3.8124707787398496`*^9}, {3.817027129898817*^9, 3.8170271337197084`*^9}, {
   3.8170272933909826`*^9, 3.817027294360754*^9}, 3.817033469405682*^9, {
   3.818800037712908*^9, 3.8188000381002116`*^9}, 3.825286294609796*^9, 
   3.8252863844971523`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1521]:=",ExpressionUUID->"67db23b1-1ee2-4480-abd2-735099b48a51"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pntp0", " ", "=", "5.6819"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"$", "/", "kg"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997912303014293`*^9, 3.799791240709296*^9}, {
   3.7997919155967455`*^9, 3.7997919159718013`*^9}, {3.799791975211526*^9, 
   3.7997919757897377`*^9}, 3.7997992482671895`*^9, {3.8016626305518*^9, 
   3.8016626306143107`*^9}, {3.8033922370765524`*^9, 3.80339223759093*^9}, {
   3.8043439559656544`*^9, 3.8043439736974487`*^9}, 3.8045198314970336`*^9, {
   3.8045870910166917`*^9, 3.8045870917664704`*^9}, 3.804851783996252*^9, {
   3.8048594463590517`*^9, 3.8048594494689245`*^9}, {3.804859487327943*^9, 
   3.8048594931426477`*^9}, {3.8048659293832474`*^9, 
   3.8048659328369255`*^9}, {3.8050182854886165`*^9, 
   3.8050182968443565`*^9}, {3.8050230672908416`*^9, 3.805023070853801*^9}, {
   3.80563958846546*^9, 3.805639588749045*^9}, {3.8056657662612505`*^9, 
   3.8056657673708196`*^9}, 3.807285951300034*^9, {3.8124711288925624`*^9, 
   3.8124711310572443`*^9}, {3.817031140320038*^9, 3.817031143671297*^9}, {
   3.817032308308015*^9, 3.8170323182860837`*^9}, {3.8188010402890253`*^9, 
   3.8188010512716074`*^9}, {3.825286554083594*^9, 3.825286576293852*^9}, {
   3.8252866399043293`*^9, 3.8252866577622156`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1522]:=",ExpressionUUID->"4f385778-3f43-40ed-921c-7c0e04fb9a01"],

Cell["Illegal imports", "Text",
 CellChangeTimes->{{3.825287042639509*^9, 
  3.825287044350828*^9}},ExpressionUUID->"3a58bab2-ea6a-4da8-9acd-\
f8f1973f108e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qniu0", " ", "=", "17160"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997916455119476`*^9, 3.7997916466996403`*^9}, {3.801662291673366*^9, 
   3.8016622943144274`*^9}, {3.80434370800364*^9, 3.80434370943075*^9}, {
   3.804343880379847*^9, 3.804343881590788*^9}, {3.8045197955968304`*^9, 
   3.804519797581732*^9}, {3.8045457056779346`*^9, 3.8045457083272967`*^9}, 
   3.804587021479476*^9, 3.804851544345194*^9, {3.804859222792143*^9, 
   3.8048592281838903`*^9}, {3.805017601499572*^9, 3.8050176172501593`*^9}, {
   3.805022431367359*^9, 3.805022433055135*^9}, {3.805639177044874*^9, 
   3.8056391771386395`*^9}, {3.805646353109165*^9, 3.805646354484394*^9}, {
   3.807287194928727*^9, 3.8072871952820015`*^9}, {3.8124708367151446`*^9, 
   3.812470838486531*^9}, {3.817027355979813*^9, 3.8170273593452334`*^9}, {
   3.8170308206442385`*^9, 3.8170308222843156`*^9}, {3.8188002415066147`*^9, 
   3.8188002430057797`*^9}, {3.8252867956254354`*^9, 3.825286796217864*^9}, 
   3.8252868393644085`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1523]:=",ExpressionUUID->"b4652dbd-baa0-483b-80d4-bed59ea1e685"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qnip0", " ", "=", "72084"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.798809687598858*^9, 3.798809696772917*^9}, {
   3.7988105077139387`*^9, 3.7988105144527636`*^9}, {3.799060996386744*^9, 
   3.7990609971368637`*^9}, {3.799094690735475*^9, 3.7990946933144903`*^9}, {
   3.7994089202223353`*^9, 3.799408922535157*^9}, {3.7994094838296933`*^9, 
   3.799409494058672*^9}, {3.7997913745459175`*^9, 3.7997913761555543`*^9}, {
   3.7997914118373547`*^9, 3.799791412290553*^9}, {3.79979168333277*^9, 
   3.799791684957667*^9}, {3.7998574035488396`*^9, 3.7998574038926435`*^9}, {
   3.7998575105714703`*^9, 3.799857511587253*^9}, {3.8016622758195224`*^9, 
   3.8016622793878593`*^9}, {3.8043437130735855`*^9, 
   3.8043437147078543`*^9}, {3.8043438917126637`*^9, 
   3.8043438948140774`*^9}, {3.8043478273688145`*^9, 3.804347828893999*^9}, {
   3.804347884112952*^9, 3.804347885804266*^9}, 3.804587032747341*^9, 
   3.8048515613793716`*^9, {3.804859261769577*^9, 3.8048592662859316`*^9}, {
   3.8050176541599693`*^9, 3.805017664872533*^9}, {3.8050224793751793`*^9, 
   3.805022481297365*^9}, {3.8056391851716747`*^9, 3.80563918526544*^9}, {
   3.805646396734899*^9, 3.80564639985824*^9}, {3.807287217190057*^9, 
   3.807287217504301*^9}, {3.812470888772176*^9, 3.8124708902283196`*^9}, {
   3.8170308874410143`*^9, 3.8170308908911667`*^9}, {3.817031013279088*^9, 
   3.8170310144617667`*^9}, {3.818800399482394*^9, 3.818800402678879*^9}, {
   3.825286874695879*^9, 3.8252868750712085`*^9}, 3.8252869449725432`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1524]:=",ExpressionUUID->"71c82659-8137-4bc9-8885-d62034d062ab"],

Cell["Calculation of legal imports ", "Text",
 CellChangeTimes->{{3.799061046869288*^9, 3.799061055183115*^9}, {
   3.799791360292451*^9, 3.7997914000229187`*^9}, {3.799791698056525*^9, 
   3.7997916983378224`*^9}, {3.7997917503203683`*^9, 3.799791755353649*^9}, {
   3.800692812549324*^9, 3.800692822846528*^9}, 
   3.825285459757553*^9},ExpressionUUID->"cd6f868f-52a1-4b7d-bdd8-\
1e0c25075729"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qylu0", " ", "=", " ", 
   RowBox[{"qytu0", "-", "qyiu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516193628035`*^9}, 
   3.8050174498061085`*^9, 3.8050175725603075`*^9, 3.805017684173834*^9, 
   3.8252854561217136`*^9},
 CellLabel->
  "In[1525]:=",ExpressionUUID->"411685ec-4e7e-4e82-ae79-6c9d904a1b83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qylp0", " ", "=", " ", 
   RowBox[{"qytp0", "-", "qyip0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516228761787`*^9}, 3.805017502641066*^9, 3.805017636828994*^9, {
   3.8050177316792107`*^9, 3.8050177321949186`*^9}, 3.825285454893753*^9},
 CellLabel->
  "In[1526]:=",ExpressionUUID->"34e10a13-0897-4126-a042-cb29ac11441b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qslu0", " ", "=", " ", 
   RowBox[{"qstu0", "-", "qsiu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516271213703`*^9}, 
   3.8050174603547196`*^9, 3.805017589247558*^9, 3.8050176968766108`*^9, 
   3.8252854535006604`*^9},
 CellLabel->
  "In[1527]:=",ExpressionUUID->"6db908f8-9ec3-41b6-8085-74a4b5f16e26"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qslp0", " ", "=", " ", 
   RowBox[{"qstp0", "-", "qsip0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516321373944`*^9}, 3.805017512752103*^9, 3.805017646330557*^9, {
   3.8050177436811852`*^9, 3.8050177437905784`*^9}, 3.8252854522426777`*^9},
 CellLabel->
  "In[1528]:=",ExpressionUUID->"47372b87-46e4-4e84-abb6-b4b18d167dd3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qalu0", " ", "=", " ", 
   RowBox[{"qatu0", "-", "qaiu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516376071844`*^9}, 
   3.825285449041175*^9},
 CellLabel->
  "In[1529]:=",ExpressionUUID->"5cef1721-b569-43ee-b7b4-73bb1e65ec8f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qalp0", " ", "=", " ", 
   RowBox[{"qatp0", "-", "qaip0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516080308895`*^9}, {3.804851639935667*^9, 3.8048516418820176`*^9}, 
   3.8252854474589367`*^9},
 CellLabel->
  "In[1530]:=",ExpressionUUID->"72241c77-9f0f-489b-8a81-f6b0d3b357f1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qblu0", " ", "=", " ", 
   RowBox[{"qbtu0", "-", "qbiu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516110447454`*^9}, {
   3.804851645028388*^9, 3.8048516486545525`*^9}, 3.8050174723254375`*^9, 
   3.805017601499572*^9, 3.805017705706191*^9, 3.8252854461979475`*^9},
 CellLabel->
  "In[1531]:=",ExpressionUUID->"7642a00a-7e5c-4224-8711-9ffc11e1be68"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qblp0", " ", "=", " ", 
   RowBox[{"qbtp0", "-", "qbip0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516144799304`*^9}, {3.8048516517171288`*^9, 3.804851653045458*^9}, 
   3.805017523503875*^9, 3.8050176541599693`*^9, {3.8050177690133715`*^9, 
   3.80501776909151*^9}, 3.825285444729803*^9},
 CellLabel->
  "In[1532]:=",ExpressionUUID->"912b37a4-b188-4750-8262-c62c624d05cf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qflu0", " ", "=", " ", 
   RowBox[{"qftu0", "-", "qfiu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516110447454`*^9}, {
   3.804851645028388*^9, 3.8048516486545525`*^9}, 3.8050174723254375`*^9, 
   3.805017601499572*^9, 3.805017705706191*^9, {3.805017779297551*^9, 
   3.8050177851734924`*^9}, 3.8252854430654984`*^9},
 CellLabel->
  "In[1533]:=",ExpressionUUID->"b2292b82-0665-4f04-80e1-a2dee86e9765"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qflp0", " ", "=", " ", 
   RowBox[{"qftp0", "-", "qfip0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516144799304`*^9}, {3.8048516517171288`*^9, 3.804851653045458*^9}, 
   3.805017523503875*^9, 3.8050176541599693`*^9, {3.8050177690133715`*^9, 
   3.805017793223928*^9}, 3.825285441611395*^9},
 CellLabel->
  "In[1534]:=",ExpressionUUID->"2f08f5a1-311d-43ce-870b-fb2dfac7f219"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qolu0", " ", "=", " ", 
   RowBox[{"qotu0", "-", "qoiu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516110447454`*^9}, {
   3.804851645028388*^9, 3.8048516486545525`*^9}, 3.8050174723254375`*^9, 
   3.805017601499572*^9, 3.805017705706191*^9, {3.8050177978316727`*^9, 
   3.8050178023792987`*^9}, 3.825285440153221*^9},
 CellLabel->
  "In[1535]:=",ExpressionUUID->"b10de096-9726-4741-8e0d-30b85301d56f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qolp0", " ", "=", " ", 
   RowBox[{"qotp0", "-", "qoip0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516144799304`*^9}, {3.8048516517171288`*^9, 3.804851653045458*^9}, 
   3.805017523503875*^9, 3.8050176541599693`*^9, {3.8050177690133715`*^9, 
   3.80501776909151*^9}, {3.8050178052247257`*^9, 3.8050178102724323`*^9}, 
   3.8252854384528904`*^9},
 CellLabel->
  "In[1536]:=",ExpressionUUID->"fc71cdd8-ff97-488c-8f54-4ec2ef85e7be"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qnlu0", " ", "=", " ", 
   RowBox[{"qntu0", "-", "qniu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7958653827403708`*^9, 3.7958653924669275`*^9}, 
   3.7958654473786063`*^9, {3.798809826150194*^9, 3.798809845808265*^9}, {
   3.7988104809364376`*^9, 3.798810489213653*^9}, {3.799791759291794*^9, 
   3.799791779125046*^9}, 3.799792298002516*^9, 3.8006928096496553`*^9, 
   3.8017798610663214`*^9, 3.803120619103281*^9, {3.8043437364187465`*^9, 
   3.804343749109624*^9}, {3.8048515691461897`*^9, 3.8048516110447454`*^9}, {
   3.804851645028388*^9, 3.8048516486545525`*^9}, 3.8050174723254375`*^9, 
   3.805017601499572*^9, 3.805017705706191*^9, {3.8050177978316727`*^9, 
   3.8050178023792987`*^9}, {3.805639542737355*^9, 3.8056395466442127`*^9}, 
   3.825285437003791*^9},
 CellLabel->
  "In[1537]:=",ExpressionUUID->"f7595b6e-ef48-47d8-acbf-73a66b10338d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qnlp0", " ", "=", " ", 
   RowBox[{"qntp0", "-", "qnip0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799791835172965*^9, 3.799791848018551*^9}, 
   3.799792302331315*^9, 3.8006928261666946`*^9, 3.8017798633166904`*^9, 
   3.8031206213490334`*^9, {3.8043437545748763`*^9, 3.8043437702891035`*^9}, {
   3.8043440516360874`*^9, 3.804344072252125*^9}, {3.8048515721819506`*^9, 
   3.8048516144799304`*^9}, {3.8048516517171288`*^9, 3.804851653045458*^9}, 
   3.805017523503875*^9, 3.8050176541599693`*^9, {3.8050177690133715`*^9, 
   3.80501776909151*^9}, {3.8050178052247257`*^9, 3.8050178102724323`*^9}, {
   3.8056395492397213`*^9, 3.8056395529434223`*^9}, {3.8252854323180914`*^9, 
   3.8252854353344526`*^9}},
 CellLabel->
  "In[1538]:=",ExpressionUUID->"10a406bd-eaec-4da3-ae56-d57cd82e65f3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.4 Export Quantities", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672744603273*^9}, {
   3.8196728121258554`*^9, 3.8196728122829847`*^9}, {3.819815211108224*^9, 
   3.8198152128205585`*^9}, 3.81981526037964*^9, 3.825007774600871*^9, 
   3.8252828702791944`*^9},ExpressionUUID->"5c4b7dbf-3a8e-45b2-9b5e-\
e78045930657"],

Cell[TextData[StyleBox["Source:National Oceanic and Atmospheric \
Administration. National Marine Fisheries Service (NOAA Fisheries). NOAA US \
Trade in Fishery Products database. Accessed September 1, 2020. \
https://foss.nmfs.noaa.gov/apexfoss/f?p=215:2:14884747663545::NO",
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.8198144502389154`*^9, 3.819814498857001*^9}, 
   3.819814602882104*^9, {3.8198147741606445`*^9, 3.8198147935287457`*^9}, {
   3.819815219280593*^9, 3.81981526037964*^9}, {3.819815772355571*^9, 
   3.8198157737996855`*^9}, 3.825007774600871*^9, 3.8252828702791944`*^9},
 FontSize->12,ExpressionUUID->"dd88b4bf-a98e-4046-be0f-da118062aa96"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qydue0", " ", "=", "1474827.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.8048518506428456`*^9}, 3.805018387688871*^9, {
   3.805023130413168*^9, 3.8050231336479807`*^9}, {3.8072862558220773`*^9, 
   3.8072862563034544`*^9}, {3.8252871020756874`*^9, 3.82528710355384*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1539]:=",ExpressionUUID->"d36c758b-7ed8-4713-92ae-51ee7315a7bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qydpe0", " ", "=", "  ", "0"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.80485185308072*^9}, 
   3.80501840391133*^9, 3.825287107094591*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1540]:=",ExpressionUUID->"f5a00f2e-1382-4412-b39c-d22462e02472"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdue0", " ", "=", "666890.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.8048518633108516`*^9}, {3.804859565020601*^9, 
   3.8048595675211444`*^9}, 3.8050184291651025`*^9, 3.805018466468952*^9, {
   3.8050231373516073`*^9, 3.805023140305151*^9}, {3.807286252305337*^9, 
   3.807286252718661*^9}, 3.825287107980321*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1541]:=",ExpressionUUID->"ebbcdefa-e8b4-418d-bbcc-8a1406b8ea24"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdpe0", " ", "=", "  ", "0"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.804851865652524*^9}, {
   3.8048595759473476`*^9, 3.8048595789792566`*^9}, 3.8050184188980236`*^9, 
   3.805018469422534*^9, 3.825287108898054*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1542]:=",ExpressionUUID->"3302594c-3311-486c-975d-02c4f6420f26"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadue0", " ", "=", "6859332.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.804851867681604*^9}, {3.8048595877155313`*^9, 
   3.804859590950609*^9}, 3.8050184722360744`*^9, {3.805023149337344*^9, 
   3.805023152290888*^9}, {3.8072862490367928`*^9, 3.807286249499153*^9}, 
   3.825287109738665*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1543]:=",ExpressionUUID->"1673fb4d-d680-490d-a146-b94de2c1ce9e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadpe0", " ", "=", "  ", "0"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.8048518697629004`*^9}, {
   3.8048595996715755`*^9, 3.804859601859536*^9}, 3.805018474955246*^9, 
   3.8252871106263423`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1544]:=",ExpressionUUID->"6a1cb2bd-9ccd-4c6e-a7ca-0c0cc8e3fd86"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qbdue0", " ", "=", "164478.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.804851871981992*^9}, {3.804859615581441*^9, 
   3.804859619692989*^9}, 3.805018443417308*^9, 3.8050184782526307`*^9, {
   3.805023157744404*^9, 3.8050231603693323`*^9}, {3.8072862459263754`*^9, 
   3.807286246377728*^9}, 3.8252871115531073`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1545]:=",ExpressionUUID->"778b1d34-2b16-4641-afe4-958ffaa66eba"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qbdpe0", " ", "=", "  ", "0"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.8048518740604353`*^9}, {
   3.8048596312446957`*^9, 3.8048596325730925`*^9}, {3.8050184579051275`*^9, 
   3.8050184808624096`*^9}, 3.8252871125138035`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1546]:=",ExpressionUUID->"17bf2afb-74a4-4899-a403-1ee2cb2495d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qfdue0", " ", "=", "548749.00"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.804851871981992*^9}, {3.804859615581441*^9, 
   3.804859619692989*^9}, 3.805018443417308*^9, {3.8050184782526307`*^9, 
   3.8050184905223784`*^9}, {3.805023165776619*^9, 3.8050231684957542`*^9}, 
   3.8050238288230305`*^9, 3.80728548376904*^9, {3.807286242253513*^9, 
   3.8072862427549105`*^9}, 3.8252871134175196`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1547]:=",ExpressionUUID->"7f003a9b-1f8b-4d9e-a4a9-1aca2619de06"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qfdpe0", " ", "=", "  ", "0"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.8048518740604353`*^9}, {
   3.8048596312446957`*^9, 3.8048596325730925`*^9}, {3.8050184579051275`*^9, 
   3.805018494757408*^9}, 3.8252871153140516`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1548]:=",ExpressionUUID->"37bb7d17-06ad-414f-a3a0-68314fec7d91"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qodue0", " ", "=", "0"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.804851871981992*^9}, {3.804859615581441*^9, 
   3.804859619692989*^9}, 3.805018443417308*^9, {3.8050184782526307`*^9, 
   3.805018498367342*^9}, 3.8050231725588303`*^9, 3.8252871163407793`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1549]:=",ExpressionUUID->"e1812860-5f1c-4169-94a1-19394261051f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qodpe0", " ", "=", "  ", "0"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928482519035`*^9, 3.7997928619931197`*^9}, {
   3.799792932904928*^9, 3.7997929338206606`*^9}, 3.7997931378597746`*^9, {
   3.799793389601818*^9, 3.799793396587142*^9}, {3.804344105039635*^9, 
   3.804344123209774*^9}, {3.804851844159994*^9, 3.8048518740604353`*^9}, {
   3.8048596312446957`*^9, 3.8048596325730925`*^9}, {3.8050184579051275`*^9, 
   3.8050185027117643`*^9}, 3.8252871181241913`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1550]:=",ExpressionUUID->"afaa7c76-91eb-4a00-b049-87075744925a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qndue0", " ", "=", "0"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7997928038620005`*^9, 3.799792837218154*^9}, {
   3.799792924069019*^9, 3.799792929726248*^9}, {3.799793121678907*^9, 
   3.799793144001396*^9}, {3.79979337071767*^9, 3.799793399228195*^9}, {
   3.799799265568861*^9, 3.7997992676473627`*^9}, {3.8043440943363066`*^9, 
   3.804344119187645*^9}, 3.804587132657447*^9, {3.804587294575024*^9, 
   3.804587295246994*^9}, {3.8045904375239677`*^9, 3.8045904408058047`*^9}, {
   3.804851847754297*^9, 3.804851871981992*^9}, {3.804859615581441*^9, 
   3.804859619692989*^9}, 3.805018443417308*^9, {3.8050184782526307`*^9, 
   3.805018498367342*^9}, 3.8050231725588303`*^9, {3.8056396456454935`*^9, 
   3.8056396457937593`*^9}, 3.825287119931579*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1551]:=",ExpressionUUID->"69d4f5bc-3302-4d76-83a8-e6b4cab670f2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.5 Catch Limits", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8196716206413603`*^9, 3.8196716573155355`*^9}, 
   3.819672507377739*^9, {3.8196726657212505`*^9, 3.819672709332239*^9}, {
   3.819672747951029*^9, 3.819672752938134*^9}, {3.819672814932173*^9, 
   3.8196728150802965`*^9}, 3.8198153194016666`*^9, 3.8250241781979237`*^9, 
   3.8252829616523466`*^9, 
   3.825283063327988*^9},ExpressionUUID->"c16170aa-44a3-4c71-a07e-\
95c8ef6a135c"],

Cell[TextData[StyleBox["Yellowfin tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.825287139143584*^9, 
  3.825287142543166*^9}},ExpressionUUID->"252f8968-7724-41d3-aa7c-\
1192b882b8c2"],

Cell[TextData[StyleBox["No aggregate ACL available, inserted arbitrarily high \
limit so it doesn\[CloseCurlyQuote]t affect calculation. ",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934406567`*^9, 3.8250232599285984`*^9, 3.8250234385889854`*^9, {
   3.8250235568550773`*^9, 3.825023721715456*^9}, {3.8250241515651827`*^9, 
   3.825024178198924*^9}, 3.8252829616523466`*^9, 
   3.825283063327988*^9},ExpressionUUID->"5c4f00af-1b9c-424c-bca5-\
ccdf8213e40f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qydcap", " ", "=", "400000000"}], ";"}], " ", 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.804851796545054*^9, 
   3.8048952007649207`*^9, {3.804895250483545*^9, 3.8048952544374237`*^9}, {
   3.8050183281629877`*^9, 3.805018342993407*^9}, {3.805023083589896*^9, 
   3.8050230976888266`*^9}, {3.805665773734192*^9, 3.80566577395298*^9}, {
   3.8140278907864637`*^9, 3.8140278930692415`*^9}, 3.825287167051273*^9, {
   3.8252873724829593`*^9, 3.8252873735077634`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1552]:=",ExpressionUUID->"802c6b9b-1962-431d-b17b-a621193520c7"],

Cell[TextData[StyleBox["Skipjack tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.825287139143584*^9, 
  3.8252871557634726`*^9}},ExpressionUUID->"744d9f40-2552-4822-8e73-\
7184611bd5a6"],

Cell[TextData[StyleBox["No aggregate ACL available, inserted arbitrarily high \
limit so it doesn\[CloseCurlyQuote]t affect calculation. ",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934406567`*^9, 3.8250232599285984`*^9, 3.8250234385889854`*^9, {
   3.8250235568550773`*^9, 3.825023721715456*^9}, {3.8250241515651827`*^9, 
   3.825024178198924*^9}, 3.8252829616523466`*^9, 
   3.825283063327988*^9},ExpressionUUID->"da8032ca-080c-4486-b6d1-\
c13f60b65389"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qsdcap", " ", "=", "400000000"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.8048517992485948`*^9, {
   3.8048952270850687`*^9, 3.8048952446230383`*^9}, {3.805018338242672*^9, 
   3.8050183454469113`*^9}, 3.8050231013143167`*^9, {3.8056657763909063`*^9, 
   3.805665776531555*^9}, 3.8140278982612834`*^9, 3.825287169929531*^9, 
   3.8252873778161345`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1553]:=",ExpressionUUID->"cb959750-59dd-405b-8ff0-098877582c11"],

Cell[TextData[StyleBox["Albacore tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.825287139143584*^9, 
  3.8252871639628863`*^9}},ExpressionUUID->"0212caa3-1cbe-4b2c-a8b1-\
fd9e031ae510"],

Cell[TextData[StyleBox["No aggregate ACL available, inserted arbitrarily high \
limit so it doesn\[CloseCurlyQuote]t affect calculation. ",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934406567`*^9, 3.8250232599285984`*^9, 3.8250234385889854`*^9, {
   3.8250235568550773`*^9, 3.825023721715456*^9}, {3.8250241515651827`*^9, 
   3.825024178198924*^9}, 3.8252829616523466`*^9, 
   3.825283063327988*^9},ExpressionUUID->"b910205f-395a-47e4-911a-\
4e3c4f7e50e9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qadcap", " ", "=", "400000000"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.8048518024053288`*^9, 
   3.8048952209520655`*^9, 3.8048952578286753`*^9, {3.805023085762065*^9, 
   3.8050231025488586`*^9}, {3.805665779407057*^9, 3.8056657795320787`*^9}, 
   3.8140279011255145`*^9, 3.82528717321611*^9, 3.8252873794113812`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1554]:=",ExpressionUUID->"63bde8db-8dca-4231-b99b-9dc06652c0ae"],

Cell[TextData[StyleBox["Bigeye tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.825287139143584*^9, 3.825287142543166*^9}, {
  3.8252871781939735`*^9, 
  3.8252871795630493`*^9}},ExpressionUUID->"4ce19111-9aa0-48c9-9d17-\
047166ecea6c"],

Cell[TextData[StyleBox["Sources:\nInternational Commission for the \
Conservation of Atlantic Tunas, \[OpenCurlyDoubleQuote]Tropical Tuna Fishery \
Management Plans,\[CloseCurlyDoubleQuote] 2018, \
https://www.iccat.int/com2018/ENG/PA1_501_ENG.pdf.\n\n\
\[OpenCurlyDoubleQuote]Electronic Code of Federal Regulations: Longline \
Fishing Restrictions,\[CloseCurlyDoubleQuote] Text, Electronic Code of \
Federal Regulations (eCFR), accessed October 27, 2020, \
https://www.ecfr.gov/cgi-bin/text-idx?c=ecfr&SID=\
c4a02d52df72fb2c44dab04d0a6684a7&rgn=div8&view=text&node=50:11.0.2.11.1.15.21.\
15&idno=50.\n\nNOAA Fisheries, \[OpenCurlyDoubleQuote]Longline Bigeye Tuna \
Catch Limits in the Pacific,\[CloseCurlyDoubleQuote] NOAA, August 13, 2019, \
Pacific Islands, International, \
https://www.fisheries.noaa.gov/pacific-islands/sustainable-fisheries/longline-\
bigeye-tuna-catch-limits-pacific.\n\n\[OpenCurlyDoubleQuote]Pacific Island \
Pelagic Fisheries; 2018 U.S. Territorial Longline Bigeye Tuna Catch Limits,\
\[CloseCurlyDoubleQuote] Federal Register, October 23, 2018, \
https://www.federalregister.gov/documents/2018/10/23/2018-23080/pacific-\
island-pelagic-fisheries-2018-us-territorial-longline-bigeye-tuna-catch-\
limits.",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934406567`*^9, 3.8250232599285984`*^9, 3.8250234385889854`*^9, {
   3.8250235568550773`*^9, 3.825023721715456*^9}, {3.8250241515651827`*^9, 
   3.825024178198924*^9}, 3.8252829616523466`*^9, 3.825283063327988*^9, {
   3.825287182366289*^9, 
   3.8252872625509768`*^9}},ExpressionUUID->"6414f3cf-0fb4-4612-ad56-\
bfff509d639e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qbdcap", " ", "=", "11879000"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.804851805171688*^9, {
   3.8048961193381124`*^9, 3.804896138325565*^9}, {3.8050183495569224`*^9, 
   3.8050183601989946`*^9}, {3.8050230886843357`*^9, 
   3.8050231036583843`*^9}, {3.8056657816756353`*^9, 3.805665781800657*^9}, {
   3.8100468335295324`*^9, 3.810046836491831*^9}, 3.8140278846416807`*^9, 
   3.8252873818072567`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1555]:=",ExpressionUUID->"fc85e40d-813d-4459-9fa3-8bef78a8fce4"],

Cell[TextData[StyleBox["Bluefin tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.825287139143584*^9, 3.825287142543166*^9}, {
  3.8252871781939735`*^9, 3.8252871795630493`*^9}, {3.8252872906309257`*^9, 
  3.8252872913895206`*^9}},ExpressionUUID->"e6a985b5-a2fc-4e0c-b2c6-\
02cdb4a64566"],

Cell[TextData[StyleBox["Sources:\nNational Marine Fisheries Service, \
\[OpenCurlyDoubleQuote]National Marine Fisheries Service Pacific Bluefin \
Stakeholder Meeting,\[CloseCurlyDoubleQuote] May 19, 2020, \
https://www.pcouncil.org/documents/2020/06/d-1-a-supplemental-nmfs-report-3.\
pdf/.\n\nFisheries, \[OpenCurlyDoubleQuote]Atlantic Bluefin Tuna and Northern \
Albacore Quotas and Minor Change in Atlantic Tuna Size Limit,\
\[CloseCurlyDoubleQuote] NOAA, August 10, 2020, New England/Mid-Atlantic, \
Southeast, \
https://www.fisheries.noaa.gov/bulletin/atlantic-bluefin-tuna-and-northern-\
albacore-quotas-and-minor-change-atlantic-tuna-size.",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934406567`*^9, 3.8250232599285984`*^9, 3.8250234385889854`*^9, {
   3.8250235568550773`*^9, 3.825023721715456*^9}, {3.8250241515651827`*^9, 
   3.825024178198924*^9}, 3.8252829616523466`*^9, 3.825283063327988*^9, {
   3.825287182366289*^9, 
   3.8252873211578083`*^9}},ExpressionUUID->"862ed9af-b18f-4dcb-b850-\
008a4cefc1be"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qfdcap", " ", "=", "1878000"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.804851805171688*^9, {
   3.8048961193381124`*^9, 3.804896138325565*^9}, {3.8050183495569224`*^9, 
   3.8050183601989946`*^9}, {3.805019563577289*^9, 3.805019563702309*^9}, {
   3.8050230912784367`*^9, 3.805023104830418*^9}, {3.805665784176071*^9, 
   3.805665784316721*^9}, {3.810046841317577*^9, 3.8100468432500763`*^9}, 
   3.8140278879502563`*^9, 3.82528738435625*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1556]:=",ExpressionUUID->"422e32a6-79a0-4a83-9eca-a130a7bfd0fe"],

Cell[TextData[StyleBox["Other/NEI tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.825287139143584*^9, 3.8252871639628863`*^9}, {
  3.825287344713238*^9, 
  3.8252873465056367`*^9}},ExpressionUUID->"94271768-293d-486c-9851-\
1796d0c241bc"],

Cell[TextData[StyleBox["No aggregate ACL available, inserted arbitrarily high \
limit so it doesn\[CloseCurlyQuote]t affect calculation. ",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934406567`*^9, 3.8250232599285984`*^9, 3.8250234385889854`*^9, {
   3.8250235568550773`*^9, 3.825023721715456*^9}, {3.8250241515651827`*^9, 
   3.825024178198924*^9}, 3.8252829616523466`*^9, 
   3.825283063327988*^9},ExpressionUUID->"a05273ab-4645-4f43-a5e8-\
6c11b8a01e71"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qodcap", " ", "=", "400000000"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.804851805171688*^9, {
   3.8048961193381124`*^9, 3.804896138325565*^9}, {3.8050183495569224`*^9, 
   3.8050183601989946`*^9}, {3.8050195666402893`*^9, 3.805019566843447*^9}, {
   3.8050230933255887`*^9, 3.805023105830553*^9}, {3.805665786724717*^9, 
   3.8056657868341284`*^9}, 3.814027904769348*^9, 3.8252873497191496`*^9, 
   3.8252873861966896`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1557]:=",ExpressionUUID->"8a6ec7a1-47a4-4e5f-837b-ec8dc5daca28"],

Cell[TextData[StyleBox["Bonito",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.825287139143584*^9, 3.8252871639628863`*^9}, {
  3.825287341724901*^9, 
  3.8252873423373775`*^9}},ExpressionUUID->"dff70f9d-5747-4325-9939-\
2385c520a77f"],

Cell[TextData[StyleBox["No aggregate ACL available, inserted arbitrarily high \
limit so it doesn\[CloseCurlyQuote]t affect calculation. ",
 FontSize->12,
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.819815515075979*^9, 3.819815519811634*^9}, 
   3.8198156934406567`*^9, 3.8250232599285984`*^9, 3.8250234385889854`*^9, {
   3.8250235568550773`*^9, 3.825023721715456*^9}, {3.8250241515651827`*^9, 
   3.825024178198924*^9}, 3.8252829616523466`*^9, 
   3.825283063327988*^9},ExpressionUUID->"3c253ed7-03fb-4278-b739-\
5661b9c265fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qndcap", " ", "=", "400000000"}], ";"}], 
  RowBox[{"(*", "kg", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7965672860137568`*^9, 3.7965673075117826`*^9}, 
   3.7965673619429517`*^9, {3.796567392504822*^9, 3.79656741209855*^9}, {
   3.796570703086454*^9, 3.796570704493722*^9}, 3.796570890730534*^9, {
   3.796571284528157*^9, 3.796571285147747*^9}, {3.796571407851569*^9, 
   3.796571421624565*^9}, {3.7965714847103662`*^9, 3.796571485082275*^9}, {
   3.7965715273255405`*^9, 3.796571527489255*^9}, {3.7988096339555655`*^9, 
   3.7988096462074347`*^9}, 3.798809767381409*^9, {3.7990611171350017`*^9, 
   3.799061120229245*^9}, {3.7990947115107083`*^9, 3.7990947143849545`*^9}, {
   3.7997920583575363`*^9, 3.799792065655161*^9}, {3.799792134713421*^9, 
   3.799792138135829*^9}, {3.8043439954383636`*^9, 3.8043440311741695`*^9}, {
   3.8043477385857477`*^9, 3.804347739087138*^9}, 3.804851805171688*^9, {
   3.8048961193381124`*^9, 3.804896138325565*^9}, {3.8050183495569224`*^9, 
   3.8050183601989946`*^9}, {3.8050195666402893`*^9, 3.805019566843447*^9}, {
   3.8050230933255887`*^9, 3.805023105830553*^9}, {3.8056395965444593`*^9, 
   3.805639596669479*^9}, {3.805665788928226*^9, 3.805665789053248*^9}, 
   3.8140279066298*^9, 3.8252873376747327`*^9, 3.825287387924041*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[1558]:=",ExpressionUUID->"ea8d8b41-c0db-4621-8a2a-96bd5e38c84b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.6 Import Market Share Statistics", "Subsection",
 FontSize->18]], "Subsubsection",
 CellChangeTimes->{{3.8199018381766195`*^9, 3.8199018609792204`*^9}, 
   3.819901901056156*^9, 3.8199024672872863`*^9, 3.825024287532875*^9, 
   3.8252830633299837`*^9},ExpressionUUID->"11ce761c-6bc0-4ca5-9f3f-\
a2d2d30f962c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qatu0", "/", 
   RowBox[{"(", 
    RowBox[{"qatu0", "+", "qadu0", "-", "qadue0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.812670427969713*^9, 3.8126704560626554`*^9}},
 CellLabel->
  "In[1559]:=",ExpressionUUID->"65c383af-0e3a-41f5-8344-899c12a2520c"],

Cell[BoxData["0.8663145389442666`"], "Output",
 CellChangeTimes->{3.812670458097247*^9, 3.812736044956642*^9, 
  3.812821570388451*^9, 3.8129696056247697`*^9, 3.8129703759905453`*^9, 
  3.812971091498503*^9, 3.8129761332314777`*^9, 3.8129765108018045`*^9, 
  3.8139962925612245`*^9, 3.813996895317497*^9, 3.813997815787465*^9, 
  3.8139981301004314`*^9, 3.8139984993989315`*^9, 3.813998930036333*^9, 
  3.813999686008039*^9, 3.8140261508603516`*^9, 3.81402688590921*^9, 
  3.8140270573386693`*^9, 3.8148302766138997`*^9, 3.815477458419841*^9, 
  3.815477765838646*^9, 3.815478324961543*^9, 3.8154785829511576`*^9, 
  3.815775359797075*^9, 3.817033444840873*^9, 3.81703347705834*^9, 
  3.8188010760429616`*^9, 3.825287054662829*^9, 3.825287412663392*^9, 
  3.8252878313014336`*^9, 3.825416599813219*^9},
 CellLabel->
  "Out[1559]=",ExpressionUUID->"326087ce-2f60-4c51-bfc6-a4d27b5ab246"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qbtu0", "/", 
   RowBox[{"(", 
    RowBox[{"qbtu0", "+", "qbdu0", "-", "qbdue0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.812670427969713*^9, 3.812670478205954*^9}},
 CellLabel->
  "In[1560]:=",ExpressionUUID->"c426af25-e96e-4958-9fee-83f26408e112"],

Cell[BoxData["0.48094849011364593`"], "Output",
 CellChangeTimes->{3.812670458097247*^9, 3.812670504117197*^9, 
  3.812736045137766*^9, 3.8128215705836024`*^9, 3.812969606015456*^9, 
  3.8129703762250395`*^9, 3.81297109171729*^9, 3.8129761335016336`*^9, 
  3.8129765110999217`*^9, 3.8139962927763915`*^9, 3.813996895532666*^9, 
  3.813997816019647*^9, 3.8139981304587097`*^9, 3.8139984997552075`*^9, 
  3.8139989302424927`*^9, 3.813999686217202*^9, 3.814026151095535*^9, 
  3.814026886131385*^9, 3.8140270575608416`*^9, 3.8148302768370676`*^9, 
  3.8154774587167664`*^9, 3.815477766088688*^9, 3.815478325227212*^9, 
  3.8154785832011995`*^9, 3.8157753600752525`*^9, 3.817033444851881*^9, 
  3.817033477070349*^9, 3.818801076055972*^9, 3.8252870551261835`*^9, 
  3.825287412881562*^9, 3.825287831444518*^9, 3.8254166000884356`*^9},
 CellLabel->
  "Out[1560]=",ExpressionUUID->"df002371-bd5c-4724-8896-3bb749161c78"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qftu0", "/", 
   RowBox[{"(", 
    RowBox[{"qftu0", "+", "qfdu0", "-", "qfdue0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.812670427969713*^9, 3.812670488229786*^9}},
 CellLabel->
  "In[1561]:=",ExpressionUUID->"732c0ddb-fdad-48f7-94f5-56a73e10b068"],

Cell[BoxData["0.8503916858558435`"], "Output",
 CellChangeTimes->{3.812670458097247*^9, 3.8126705064700575`*^9, 
  3.812736045316906*^9, 3.8128215707847586`*^9, 3.8129696063748865`*^9, 
  3.8129703764437647`*^9, 3.812971091951705*^9, 3.812976133752198*^9, 
  3.812976511412445*^9, 3.8139962929895573`*^9, 3.813996895739828*^9, 
  3.8139978162658386`*^9, 3.813998130816989*^9, 3.813998500058444*^9, 
  3.813998930445651*^9, 3.813999686437372*^9, 3.81402615134673*^9, 
  3.814026886351557*^9, 3.8140270577760086`*^9, 3.8148302770352216`*^9, 
  3.8154774589824343`*^9, 3.815477766323101*^9, 3.8154783254616256`*^9, 
  3.8154785834668684`*^9, 3.815775360381491*^9, 3.8170334448648915`*^9, 
  3.8170334770833592`*^9, 3.818801076068982*^9, 3.8252870553283606`*^9, 
  3.8252874129806395`*^9, 3.8252878315646114`*^9, 3.825416600393689*^9},
 CellLabel->
  "Out[1561]=",ExpressionUUID->"85952ffd-90c3-4a3d-9c58-66b08ca16776"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qstu0", "/", 
   RowBox[{"(", 
    RowBox[{"qstu0", "+", "qsdu0", "-", "qsdue0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.812670427969713*^9, 3.8126704560626554`*^9}, {
  3.81267049266125*^9, 3.8126705014140863`*^9}},
 CellLabel->
  "In[1562]:=",ExpressionUUID->"47edc215-7f91-4a09-8d92-d251aff27f2c"],

Cell[BoxData["0.9737167813636121`"], "Output",
 CellChangeTimes->{3.812670458097247*^9, 3.812670508449584*^9, 
  3.812736045491042*^9, 3.8128215709769464`*^9, 3.8129696066405535`*^9, 
  3.812970376678188*^9, 3.8129710921704917`*^9, 3.8129761340122013`*^9, 
  3.8129765117250032`*^9, 3.813996293203724*^9, 3.813996895946991*^9, 
  3.8139978165180345`*^9, 3.8139981312042894`*^9, 3.813998500371687*^9, 
  3.8139989306488085`*^9, 3.813999686643533*^9, 3.8140261515749083`*^9, 
  3.8140268865637217`*^9, 3.814027058001184*^9, 3.814830277248391*^9, 
  3.815477459248103*^9, 3.815477766573143*^9, 3.8154783257116685`*^9, 
  3.8154785837325373`*^9, 3.8157753606537004`*^9, 3.817033444877406*^9, 
  3.817033477098393*^9, 3.8188010760809917`*^9, 3.8252870555225067`*^9, 
  3.825287413078717*^9, 3.8252878317778087`*^9, 3.8254166006348658`*^9},
 CellLabel->
  "Out[1562]=",ExpressionUUID->"1aa178e7-154f-42f3-9828-4778a0da8c62"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qytu0", "/", 
   RowBox[{"(", 
    RowBox[{"qytu0", "+", "qydu0", "-", "qydue0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.812670427969713*^9, 3.8126704560626554`*^9}, {
  3.812670514647424*^9, 3.8126705214307256`*^9}},
 CellLabel->
  "In[1563]:=",ExpressionUUID->"7dbb8992-dd6e-4107-9b77-adfe7650b76e"],

Cell[BoxData["0.6248674990282188`"], "Output",
 CellChangeTimes->{3.812670458097247*^9, 3.8126705235133505`*^9, 
  3.8127360456631775`*^9, 3.8128215711650543`*^9, 3.81296960690622*^9, 
  3.8129703768969836`*^9, 3.812971092420534*^9, 3.812976134301428*^9, 
  3.812976512068801*^9, 3.8139962934459133`*^9, 3.8139968961601562`*^9, 
  3.813997816742208*^9, 3.813998131561571*^9, 3.8139985007459784`*^9, 
  3.81399893086898*^9, 3.813999686855698*^9, 3.814026151803087*^9, 
  3.814026886789898*^9, 3.81402705821235*^9, 3.814830277447542*^9, 
  3.815477459513773*^9, 3.8154777668231845`*^9, 3.815478325961709*^9, 
  3.81547858399822*^9, 3.8157753609649725`*^9, 3.817033444890986*^9, 
  3.8170334771164255`*^9, 3.818801076095002*^9, 3.825287055717657*^9, 
  3.8252874131848*^9, 3.8252878319829364`*^9, 3.8254166008921137`*^9},
 CellLabel->
  "Out[1563]=",ExpressionUUID->"baf2af1e-f805-4832-aa31-a46332b7f41e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qntu0", "/", 
   RowBox[{"(", 
    RowBox[{"qntu0", "+", "qndu0", "-", "qndue0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.812670427969713*^9, 3.8126704560626554`*^9}, {
  3.812670527900778*^9, 3.8126705358850164`*^9}},
 CellLabel->
  "In[1564]:=",ExpressionUUID->"9eaa2753-1be0-43c2-935b-9544a2ace27d"],

Cell[BoxData["0.09004977270855313`"], "Output",
 CellChangeTimes->{3.812670458097247*^9, 3.812670537830533*^9, 
  3.8127360458343115`*^9, 3.8128215713552017`*^9, 3.812969607250023*^9, 
  3.812970377131445*^9, 3.812971092654948*^9, 3.812976134576644*^9, 
  3.81297651239701*^9, 3.813996293681097*^9, 3.8139968963623133`*^9, 
  3.8139978169713864`*^9, 3.8139981319158473`*^9, 3.8139985010832405`*^9, 
  3.8139989310751405`*^9, 3.8139996870608587`*^9, 3.8140261520322666`*^9, 
  3.814026887003063*^9, 3.814027058424513*^9, 3.8148302776797585`*^9, 
  3.8154774598106966`*^9, 3.815477767073226*^9, 3.8154783261961226`*^9, 
  3.815478584279501*^9, 3.8157753612601795`*^9, 3.817033444903159*^9, 
  3.817033477133398*^9, 3.81880107610902*^9, 3.825287055910815*^9, 
  3.82528741335093*^9, 3.8252878321680803`*^9, 3.825416601150266*^9},
 CellLabel->
  "Out[1564]=",ExpressionUUID->"4405fcc1-7ac5-44cc-a3fb-bdde98a82932"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qatp0", "/", 
   RowBox[{"(", 
    RowBox[{"qatp0", "+", "qadp0", "-", "qadpe0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.812670427969713*^9, 3.8126704560626554`*^9}, {
  3.8126705427583847`*^9, 3.812670549639762*^9}},
 CellLabel->
  "In[1565]:=",ExpressionUUID->"38d65750-b852-42a0-bb25-7482c68f75cc"],

Cell[BoxData["0.35228929706128226`"], "Output",
 CellChangeTimes->{3.812670458097247*^9, 3.812670551043857*^9, 
  3.8127360460054455`*^9, 3.812821571540346*^9, 3.8129696076719637`*^9, 
  3.812970377350202*^9, 3.8129710928737354`*^9, 3.8129761348558626`*^9, 
  3.812976512709566*^9, 3.8139962939132795`*^9, 3.8139968965654707`*^9, 
  3.813997817184552*^9, 3.8139981322871375`*^9, 3.813998501424505*^9, 
  3.813998931287307*^9, 3.8139996872700224`*^9, 3.8140261522694526`*^9, 
  3.8140268872152276`*^9, 3.8140270586366777`*^9, 3.814830277976999*^9, 
  3.8154774600763664`*^9, 3.815477767307643*^9, 3.815478326446165*^9, 
  3.8154785845607963`*^9, 3.8157753615524373`*^9, 3.8170334449141674`*^9, 
  3.817033477146453*^9, 3.818801076124025*^9, 3.825287056480235*^9, 
  3.825287413444003*^9, 3.8252878323522854`*^9, 3.825416601429499*^9},
 CellLabel->
  "Out[1565]=",ExpressionUUID->"e025ec69-ffbe-4aa0-aba9-dde83841c55a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qbtp0", "/", 
   RowBox[{"(", 
    RowBox[{"qbtp0", "+", "qbdp0", "-", "qbdpe0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.812670427969713*^9, 3.8126704560626554`*^9}, {
  3.8126705427583847`*^9, 3.812670549639762*^9}, {3.812670709257454*^9, 
  3.812670715676469*^9}},
 CellLabel->
  "In[1566]:=",ExpressionUUID->"05511a5f-0a7e-45c1-bf3d-c37a2cc52924"],

Cell[BoxData["0.8365709798675761`"], "Output",
 CellChangeTimes->{3.812670458097247*^9, 3.812670551043857*^9, 
  3.812670717405818*^9, 3.8127360461855865`*^9, 3.8128215717595177`*^9, 
  3.8129696080626497`*^9, 3.812970377584626*^9, 3.81297109310815*^9, 
  3.812976135144575*^9, 3.8129765130377474`*^9, 3.8139962941444607`*^9, 
  3.8139968967696495`*^9, 3.813997817406725*^9, 3.8139981326404123`*^9, 
  3.813998501761781*^9, 3.813998931497471*^9, 3.8139996874802203`*^9, 
  3.814026152499633*^9, 3.8140268874313955`*^9, 3.8140270588558483`*^9, 
  3.814830278309229*^9, 3.8154774603420353`*^9, 3.8154777675576816`*^9, 
  3.815478326711834*^9, 3.8154785848264637`*^9, 3.8157753618126*^9, 
  3.817033444925176*^9, 3.817033477159525*^9, 3.818801076139036*^9, 
  3.8252870570747504`*^9, 3.82528741354208*^9, 3.8252878325363736`*^9, 
  3.8254166017117577`*^9},
 CellLabel->
  "Out[1566]=",ExpressionUUID->"33c8c216-fe08-43d8-b1e2-9514e25d9eb6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qftp0", "/", 
   RowBox[{"(", 
    RowBox[{"qftp0", "+", "qfdp0", "-", "qfdpe0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.812670427969713*^9, 3.8126704560626554`*^9}, {
  3.8126705427583847`*^9, 3.812670549639762*^9}, {3.812670709257454*^9, 
  3.8126707376825905`*^9}},
 CellLabel->
  "In[1567]:=",ExpressionUUID->"ebc2b054-f985-4e96-9b60-8e2dec5952c8"],

Cell[BoxData["0.21958434946258862`"], "Output",
 CellChangeTimes->{
  3.812670458097247*^9, 3.812670551043857*^9, {3.812670717405818*^9, 
   3.81267073925381*^9}, 3.812736046369731*^9, 3.8128215719886975`*^9, 
   3.812969608453336*^9, 3.8129703778034215`*^9, 3.8129710933269367`*^9, 
   3.812976135519636*^9, 3.812976513365917*^9, 3.813996294376642*^9, 
   3.813996896974789*^9, 3.813997817672994*^9, 3.813998132991685*^9, 
   3.813998502098029*^9, 3.8139989317016315`*^9, 3.8139996876883507`*^9, 
   3.8140261527448225`*^9, 3.81402688764256*^9, 3.8140270590890293`*^9, 
   3.8148302786394806`*^9, 3.81547746063896*^9, 3.815477767807723*^9, 
   3.815478326961875*^9, 3.815478585092132*^9, 3.8157753620758066`*^9, 
   3.8170334449371853`*^9, 3.8170334771725636`*^9, 3.8188010761530476`*^9, 
   3.82528705727089*^9, 3.8252874137092113`*^9, 3.825287832716527*^9, 
   3.825416601955947*^9},
 CellLabel->
  "Out[1567]=",ExpressionUUID->"616d42cc-05e6-435a-906e-057bb121a26d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qstp0", "/", 
   RowBox[{"(", 
    RowBox[{"qstp0", "+", "qsdp0", "-", "qsdpe0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.812670427969713*^9, 3.8126704560626554`*^9}, {
  3.8126705427583847`*^9, 3.812670549639762*^9}, {3.812670709257454*^9, 
  3.812670775186723*^9}},
 CellLabel->
  "In[1568]:=",ExpressionUUID->"51f69870-456a-4e85-a6be-8d6a3c74cbbe"],

Cell[BoxData["0.5665220286454506`"], "Output",
 CellChangeTimes->{
  3.812670458097247*^9, 3.812670551043857*^9, {3.812670717405818*^9, 
   3.81267073925381*^9}, 3.812670777014146*^9, 3.812736046543867*^9, 
   3.812821572216876*^9, 3.8129696088752766`*^9, 3.8129703780378523`*^9, 
   3.8129710935613513`*^9, 3.8129761358165593`*^9, 3.8129765136784434`*^9, 
   3.8139962946068206`*^9, 3.813996897192959*^9, 3.81399781790213*^9, 
   3.8139981333639746`*^9, 3.8139985024352913`*^9, 3.813998931920803*^9, 
   3.8139996879085226`*^9, 3.8140261529810066`*^9, 3.814026887866734*^9, 
   3.81402705930921*^9, 3.8148302789427075`*^9, 3.8154774609671392`*^9, 
   3.815477768057765*^9, 3.815478327196289*^9, 3.815478585342177*^9, 
   3.815775362356048*^9, 3.817033444948194*^9, 3.817033477184544*^9, 
   3.8188010761670585`*^9, 3.8252870574930553`*^9, 3.825287413801283*^9, 
   3.8252878329126987`*^9, 3.825416602216097*^9},
 CellLabel->
  "Out[1568]=",ExpressionUUID->"921e98f3-0476-426a-8ce3-6d1c9665d269"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"qytp0", "/", 
   RowBox[{"(", 
    RowBox[{"qytp0", "+", "qydp0", "-", "qydpe0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.812670427969713*^9, 3.8126704560626554`*^9}, {
  3.8126705427583847`*^9, 3.812670549639762*^9}, {3.812670709257454*^9, 
  3.8126707376825905`*^9}, {3.812670787751484*^9, 3.8126707965132904`*^9}},
 CellLabel->
  "In[1569]:=",ExpressionUUID->"95ef8fe1-5218-4f52-a9c4-d2cfc1066f0e"],

Cell[BoxData["0.7409870836425175`"], "Output",
 CellChangeTimes->{
  3.812670458097247*^9, 3.812670551043857*^9, {3.812670717405818*^9, 
   3.81267073925381*^9}, 3.8126707982416334`*^9, 3.812736046715001*^9, 
   3.8128215724040227`*^9, 3.8129696092659626`*^9, 3.81297037825664*^9, 
   3.812971093795766*^9, 3.8129761360822277`*^9, 3.812976513990996*^9, 
   3.8139962948329964`*^9, 3.813996897395116*^9, 3.8139978181292872`*^9, 
   3.813998133712245*^9, 3.8139985027885656`*^9, 3.813998932123962*^9, 
   3.8139996881136827`*^9, 3.8140261532171907`*^9, 3.8140268880779014`*^9, 
   3.814027059530372*^9, 3.8148302792599826`*^9, 3.815477461264064*^9, 
   3.8154777683078065`*^9, 3.8154783274463305`*^9, 3.8154785856390977`*^9, 
   3.8157753626482553`*^9, 3.8170334449602027`*^9, 3.817033477197554*^9, 
   3.8188010761810694`*^9, 3.825287057688195*^9, 3.825287413895357*^9, 
   3.8252878331238766`*^9, 3.8254166025023465`*^9},
 CellLabel->
  "Out[1569]=",ExpressionUUID->"cad18d76-b14a-4120-8c5d-0fc4bbf86e00"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3. Calibration",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.7954529786642447`*^9}, {
  3.79545386036082*^9, 3.7954538618860044`*^9}, {3.819900448697421*^9, 
  3.8199004491007357`*^9}},ExpressionUUID->"030c91d2-5273-48bd-b7f2-\
94f6c286661c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vytu0", "=", 
   RowBox[{"qytu0", " ", "pytu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.8048519125993204`*^9, 3.804851917644553*^9}, 
   3.8050174498061085`*^9, 3.8050180911508274`*^9, 3.805018527654379*^9},
 CellLabel->
  "In[1570]:=",ExpressionUUID->"9d5a52cf-3316-4cb2-80ab-9c9bede1d617"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vytp0", "=", 
   RowBox[{"qytp0", " ", "pytp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519143027067`*^9, 3.804851921426384*^9}, 3.805017502641066*^9, 
   3.8050182696736803`*^9, 3.805018537499652*^9},
 CellLabel->
  "In[1571]:=",ExpressionUUID->"563be225-6049-49ee-806a-d676b042abd2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vstu0", "=", 
   RowBox[{"qstu0", " ", "pstu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851926580485*^9, 3.8048519296747103`*^9}, 
   3.8050174603547196`*^9, 3.805018101074109*^9, 3.8050185566621103`*^9},
 CellLabel->
  "In[1572]:=",ExpressionUUID->"586a9c09-4290-443b-bf7d-c0d9a9d73e0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vstp0", "=", 
   RowBox[{"qstp0", " ", "pstp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519311436853`*^9, 3.804851933990306*^9}, 3.805017512752103*^9, 
   3.805018278393769*^9, 3.805018548673256*^9},
 CellLabel->
  "In[1573]:=",ExpressionUUID->"64e92a99-a9c8-424b-ad08-340b3749b512"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vatu0", "=", 
   RowBox[{"qatu0", " ", "patu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851936162515*^9, 3.8048519393476534`*^9}},
 CellLabel->
  "In[1574]:=",ExpressionUUID->"d41b583f-dae0-48e9-b4c3-be318f3fd670"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vatp0", "=", 
   RowBox[{"qatp0", " ", "patp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519407330923`*^9, 3.8048519441135435`*^9}},
 CellLabel->
  "In[1575]:=",ExpressionUUID->"4ff425df-281f-4ea5-98ba-80b9dac98a0d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vbtu0", "=", 
   RowBox[{"qbtu0", " ", "pbtu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851948303916*^9, 3.804851950926388*^9}, 
   3.8050174723410645`*^9, 3.805018113403982*^9, 3.8050185702579627`*^9},
 CellLabel->
  "In[1576]:=",ExpressionUUID->"bcd1b8c2-12df-4a34-b46e-55c2ab4cc24e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vbtp0", "=", 
   RowBox[{"qbtp0", " ", "pbtp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519523417597`*^9, 3.804851955436349*^9}, 3.805017523503875*^9, 
   3.8050182854886165`*^9, 3.805018578479169*^9},
 CellLabel->
  "In[1577]:=",ExpressionUUID->"7ba43ca5-42d7-4dd1-9e4d-54130dec78d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vftu0", "=", 
   RowBox[{"qftu0", " ", "pftu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851948303916*^9, 3.804851950926388*^9}, 
   3.8050174723410645`*^9, 3.805018113403982*^9, {3.8050185702579627`*^9, 
   3.8050186149235363`*^9}},
 CellLabel->
  "In[1578]:=",ExpressionUUID->"a670896e-3a79-4021-8343-54a5ece8d061"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vftp0", "=", 
   RowBox[{"qftp0", " ", "pftp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519523417597`*^9, 3.804851955436349*^9}, 3.805017523503875*^9, 
   3.8050182854886165`*^9, {3.805018578479169*^9, 3.8050186102353115`*^9}},
 CellLabel->
  "In[1579]:=",ExpressionUUID->"e277d6ca-3f55-4be1-9d33-c1ff6a01c5a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"votu0", "=", 
   RowBox[{"qotu0", " ", "potu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851948303916*^9, 3.804851950926388*^9}, 
   3.8050174723410645`*^9, 3.805018113403982*^9, {3.8050185702579627`*^9, 
   3.805018604889504*^9}},
 CellLabel->
  "In[1580]:=",ExpressionUUID->"d10dcd0c-1bec-4815-805a-88cd35a2b449"],

Cell[BoxData[
 RowBox[{
  RowBox[{"votp0", "=", 
   RowBox[{"qotp0", " ", "potp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519523417597`*^9, 3.804851955436349*^9}, 3.805017523503875*^9, 
   3.8050182854886165`*^9, {3.805018578479169*^9, 3.8050185989979677`*^9}},
 CellLabel->
  "In[1581]:=",ExpressionUUID->"53646c65-6bf2-44ab-80e9-9a7f3d2e9934"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vntu0", "=", 
   RowBox[{"qntu0", " ", "pntu0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.7997919972317624`*^9, 
   3.7997920207225666`*^9}, {3.799792428946842*^9, 3.7997924321813593`*^9}, {
   3.799793523562995*^9, 3.7997935237335167`*^9}, {3.7997935976721745`*^9, 
   3.7997936036729813`*^9}, 3.803118485480049*^9, {3.8043442228923273`*^9, 
   3.804344259923139*^9}, {3.804851948303916*^9, 3.804851950926388*^9}, 
   3.8050174723410645`*^9, 3.805018113403982*^9, {3.8050185702579627`*^9, 
   3.805018604889504*^9}, {3.8056396586085687`*^9, 3.8056396627737474`*^9}},
 CellLabel->
  "In[1582]:=",ExpressionUUID->"78d80331-eb25-4316-8bfc-a56ea14d3fe2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vntp0", "=", 
   RowBox[{"qntp0", " ", "pntp0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988096728031516`*^9, 3.7988096932885838`*^9}, {
   3.798810476181714*^9, 3.7988104993747444`*^9}, {3.7990609810992455`*^9, 
   3.7990609823963275`*^9}, {3.799094682100728*^9, 3.799094683527843*^9}, {
   3.799408912039892*^9, 3.7994089159189463`*^9}, {3.799791309664023*^9, 
   3.7997913231736326`*^9}, {3.799791467498536*^9, 3.799791489910027*^9}, {
   3.7997920012027044`*^9, 3.799792001390234*^9}, {3.7997920398846292`*^9, 
   3.799792040353452*^9}, 3.799792435791297*^9, {3.799793526749631*^9, 
   3.799793528365549*^9}, {3.7997936336427937`*^9, 3.7997936383922815`*^9}, 
   3.8031184854870543`*^9, {3.8043442407532225`*^9, 3.8043442680654707`*^9}, {
   3.8048519523417597`*^9, 3.804851955436349*^9}, 3.805017523503875*^9, 
   3.8050182854886165`*^9, {3.805018578479169*^9, 3.8050185989979677`*^9}, {
   3.805639664953207*^9, 3.805639669055869*^9}},
 CellLabel->
  "In[1583]:=",ExpressionUUID->"447b75a5-cd59-441a-a64d-140c9dd7fec3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vydu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qydu0", "-", "qydue0"}], ")"}], " ", "pydu0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.8048519638260803`*^9, 3.8048519716484485`*^9}, {
   3.8048598918387938`*^9, 3.804859912733159*^9}, {3.804860064780347*^9, 
   3.804860071891223*^9}, 3.8048664223456783`*^9, 3.805017322685949*^9, 
   3.80501738938866*^9, 3.8050178536388817`*^9, 3.805018387688871*^9, 
   3.805018727270131*^9, {3.805025120899139*^9, 3.8050251367937717`*^9}, 
   3.8050252580605593`*^9, 3.805665863356492*^9, 3.807277249097739*^9, 
   3.825285063803553*^9},
 CellLabel->
  "In[1584]:=",ExpressionUUID->"a3ab304f-2aee-4fbd-bfd7-6f5a12f02f88"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vydp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qydp0", "-", "qydpe0"}], ")"}], " ", "pydp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.804851974426258*^9, 3.80485197968615*^9}, 3.80501738938866*^9, 
   3.805018145205366*^9, 3.80501840391133*^9, 3.8050187353351493`*^9, 
   3.80566588742692*^9, 3.825285065444852*^9},
 CellLabel->
  "In[1585]:=",ExpressionUUID->"3f3f71a9-fce2-4be4-b505-60d2d9a2083c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vsdu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qsdu0", "-", "qsdue0"}], ")"}], " ", "psdu0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.8048519828841496`*^9, 3.804851990206542*^9}, {
   3.8048598935265956`*^9, 3.8048599148897953`*^9}, {3.8048600789598665`*^9, 
   3.804860083476311*^9}, 3.804866425674345*^9, 3.805017337158284*^9, 
   3.8050173975775113`*^9, 3.8050178642343397`*^9, 3.8050184291651025`*^9, {
   3.8050187442272134`*^9, 3.8050187632601604`*^9}, {3.805025141075765*^9, 
   3.805025155558032*^9}, 3.8050252619518375`*^9, 3.8056658649505205`*^9, {
   3.807277252326253*^9, 3.8072772526204815`*^9}, 3.825285067021062*^9},
 CellLabel->
  "In[1586]:=",ExpressionUUID->"719d6bd9-ab83-433d-bc57-a6b508965f6b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vsdp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qsdp0", "-", "qsdpe0"}], ")"}], " ", "psdp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.804851992378751*^9, 3.8048520018629837`*^9}, 3.8050173975775113`*^9, 
   3.805018154986638*^9, 3.805018413272153*^9, 3.805018840007553*^9, 
   3.8056658858328915`*^9, 3.825285068326084*^9},
 CellLabel->
  "In[1587]:=",ExpressionUUID->"ca4a1562-a6dc-469b-905d-0d39aef96b5a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vadu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qadu0", "-", "qadue0"}], ")"}], " ", "padu0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.804852007460396*^9, 3.804852013220827*^9}, {
   3.80485989505812*^9, 3.8048599170464315`*^9}, {3.8048600866018105`*^9, 
   3.8048600916988807`*^9}, 3.8048664286460667`*^9, {3.805025158428979*^9, 
   3.8050251700740337`*^9}, 3.8050252659837627`*^9, 3.805665866717702*^9, 
   3.8072772571219826`*^9, 3.8252850699533787`*^9},
 CellLabel->
  "In[1588]:=",ExpressionUUID->"12c30e9d-754a-45e0-8c39-1b72a9f6c4ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vadp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qadp0", "-", "qadpe0"}], ")"}], " ", "padp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.8048520162475986`*^9, 3.8048520205763884`*^9}, 3.8056658839419365`*^9, 
   3.8252850714796047`*^9},
 CellLabel->
  "In[1589]:=",ExpressionUUID->"288ea92c-c9be-4ba0-82d7-1acdbbeb49ee"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vbdu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qbdu0", "-", "qbdue0"}], " ", ")"}], " ", "pbdu0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.804852022920974*^9, 3.804852030499457*^9}, {
   3.804859896652155*^9, 3.804859921734771*^9}, {3.8048600950900917`*^9, 
   3.8048600972310853`*^9}, 3.804866433404766*^9, 3.80501735923965*^9, 
   3.8050174161586895`*^9, 3.805017872688827*^9, 3.805018443417308*^9, 
   3.805018858088605*^9, {3.8050251727620006`*^9, 3.8050251792318745`*^9}, 
   3.8050252695468607`*^9, 3.805665869264631*^9, 3.8072772599671984`*^9, 
   3.8252850727195735`*^9},
 CellLabel->
  "In[1590]:=",ExpressionUUID->"b2ccd627-d7eb-4881-8b69-b0a9aa854d3c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vbdp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qbdp0", "-", "qbdpe0"}], ")"}], " ", "pbdp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.8048520323591175`*^9, 3.804852037110026*^9}, 3.8050174161743164`*^9, 
   3.805018163879826*^9, 3.8050184579051275`*^9, 3.805018865715522*^9, 
   3.805665881923529*^9, {3.825285073955515*^9, 3.8252850767847157`*^9}},
 CellLabel->
  "In[1591]:=",ExpressionUUID->"07cb80e4-b70d-4a54-9c85-400d2cb9ea9b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vfdu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qfdu0", "-", "qfdue0"}], ")"}], " ", "pfdu0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.804852022920974*^9, 3.804852030499457*^9}, {
   3.804859896652155*^9, 3.804859921734771*^9}, {3.8048600950900917`*^9, 
   3.8048600972310853`*^9}, 3.804866433404766*^9, 3.80501735923965*^9, 
   3.8050174161586895`*^9, 3.805017872688827*^9, 3.805018443417308*^9, {
   3.805018858088605*^9, 3.80501889274378*^9}, {3.805023754012517*^9, 
   3.8050237635049405`*^9}, 3.8050250545222626`*^9, {3.8050251892456903`*^9, 
   3.8050251953572793`*^9}, {3.8050252724379697`*^9, 3.805025272875543*^9}, 
   3.8056658711243305`*^9, 3.807277264269552*^9, 3.8252850797550464`*^9},
 CellLabel->
  "In[1592]:=",ExpressionUUID->"c58f1e24-fc21-48b5-a52b-8ef5b76fd29a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vfdp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qfdp0", "-", "qfdpe0"}], ")"}], " ", "pfdp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.8048520323591175`*^9, 3.804852037110026*^9}, 3.8050174161743164`*^9, 
   3.805018163879826*^9, 3.8050184579051275`*^9, 3.805018865715522*^9, {
   3.805018895994308*^9, 3.8050189056064577`*^9}, 3.805665879876297*^9, 
   3.825285083252757*^9},
 CellLabel->
  "In[1593]:=",ExpressionUUID->"58ea194b-8382-4059-9a56-4bd3f7863104"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vodu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qodu0", "-", "qodue0"}], ")"}], " ", "podu0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.804852022920974*^9, 3.804852030499457*^9}, {
   3.804859896652155*^9, 3.804859921734771*^9}, {3.8048600950900917`*^9, 
   3.8048600972310853`*^9}, 3.804866433404766*^9, 3.80501735923965*^9, 
   3.8050174161586895`*^9, 3.805017872688827*^9, 3.805018443417308*^9, 
   3.805018858088605*^9, {3.8050189086090927`*^9, 3.8050189207964573`*^9}, {
   3.805025198060874*^9, 3.805025202280357*^9}, 3.8050252760635777`*^9, 
   3.805665872969016*^9, {3.8072772674210052`*^9, 3.8072772676161566`*^9}, 
   3.8252850847429233`*^9},
 CellLabel->
  "In[1594]:=",ExpressionUUID->"452c9f24-2134-4294-98c5-98d220bcf96c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vodp0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qodp0", "-", "qodpe0"}], ")"}], " ", "podp0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911915513325`*^9}, {3.7997919112836013`*^9, 3.799791911455502*^9}, {
   3.7997919449185266`*^9, 3.799791945730766*^9}, {3.7997935180608344`*^9, 
   3.7997935182171097`*^9}, {3.7997935587157516`*^9, 
   3.7997935638103285`*^9}, {3.7997993042378016`*^9, 
   3.7997993081761866`*^9}, {3.801667647389421*^9, 3.80166768129465*^9}, {
   3.801667742587038*^9, 3.8016677494160843`*^9}, {3.801668151905736*^9, 
   3.8016681571409187`*^9}, {3.801688578840159*^9, 3.8016885832371025`*^9}, 
   3.8031185033750157`*^9, {3.8043442949463854`*^9, 3.8043443072139287`*^9}, {
   3.8048520323591175`*^9, 3.804852037110026*^9}, 3.8050174161743164`*^9, 
   3.805018163879826*^9, 3.8050184579051275`*^9, 3.805018865715522*^9, {
   3.805018922906186*^9, 3.80501893122008*^9}, 3.8056658784229183`*^9, 
   3.825285086347191*^9},
 CellLabel->
  "In[1595]:=",ExpressionUUID->"ebbbcfd0-9681-4755-aac2-3374db013fbe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vndu0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qndu0", "-", "qndue0"}], ")"}], " ", "pndu0"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798809657361961*^9, 3.7988096699555407`*^9}, {
   3.7988104465457516`*^9, 3.798810465799652*^9}, {3.798810502176505*^9, 
   3.798810503574647*^9}, {3.7990609698725395`*^9, 3.799060972665097*^9}, {
   3.799094671269264*^9, 3.7990946763102036`*^9}, {3.799791159585913*^9, 
   3.7997911689540596`*^9}, {3.7997919092644377`*^9, 
   3.7997919094050846`*^9}, {3.7997919406053815`*^9, 3.799791941167966*^9}, {
   3.799793516013627*^9, 3.799793553386464*^9}, {3.7997992983617744`*^9, 
   3.7997993018623867`*^9}, {3.8016676171324716`*^9, 
   3.8016676445764694`*^9}, {3.801667731198634*^9, 3.8016677358869586`*^9}, {
   3.8016681389014945`*^9, 3.8016681497625465`*^9}, {3.8016885683384705`*^9, 
   3.8016885738080997`*^9}, {3.8017810523130617`*^9, 3.801781054782216*^9}, 
   3.803118503369011*^9, {3.804344273787924*^9, 3.804344289264965*^9}, {
   3.804348220542281*^9, 3.804348225543173*^9}, {3.8045457442070265`*^9, 
   3.804545745019652*^9}, {3.804852022920974*^9, 3.804852030499457*^9}, {
   3.804859896652155*^9, 3.804859921734771*^9}, {3.8048600950900917`*^9, 
   3.8048600972310853`*^9}, 3.804866433404766*^9, 3.80501735923965*^9, 
   3.8050174161586895`*^9, 3.805017872688827*^9, 3.805018443417308*^9, 
   3.805018858088605*^9, {3.8050189086090927`*^9, 3.8050189207964573`*^9}, {
   3.805025198060874*^9, 3.805025202280357*^9}, 3.8050252760635777`*^9, {
   3.8056396792953224`*^9, 3.8056396871898513`*^9}, 3.8056658754534435`*^9, 
   3.8072733198026342`*^9, 3.825285087549138*^9},
 CellLabel->
  "In[1596]:=",ExpressionUUID->"151f7240-9f23-4bf6-aab8-426e1b4f1a4c"],

Cell[CellGroupData[{

Cell["3.1 Supply Parameters", "Subsubsection",
 CellChangeTimes->{{3.819902497376732*^9, 3.819902510893259*^9}, 
   3.8250246051964817`*^9},
 CellLabel->
  "In[207]:=",ExpressionUUID->"f8be89da-e224-495e-93d3-82ef70496628"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eydu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"eyu", " ", 
     FractionBox["qydu0", 
      RowBox[{"(", 
       RowBox[{"qydcap", "-", "qydu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.804852083303175*^9, 3.804852090898363*^9}, {
   3.805017228666668*^9, 3.805017228666668*^9}, {3.805017322685949*^9, 
   3.805017322685949*^9}, 3.8050183281629877`*^9, {3.8072777430621724`*^9, 
   3.8072777461225553`*^9}, {3.8072787023302307`*^9, 3.8072787025063686`*^9}, 
   3.825285090248228*^9},
 CellLabel->
  "In[1597]:=",ExpressionUUID->"251b4ab0-22c0-46e3-b8e5-e9aa3e6836c2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aydu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qydcap", "-", "qydu0"}], ")"}], " ", 
    SuperscriptBox["pydu0", "eydu"]}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048520933987694`*^9, 
   3.804852099759162*^9}, 3.805017228682296*^9, 3.805017322685949*^9, 
   3.8050178536388817`*^9, 3.8050183281629877`*^9, 3.805018972205937*^9, 
   3.807278714532398*^9, 3.8252850914902*^9},
 CellLabel->
  "In[1598]:=",ExpressionUUID->"84a21240-2395-4207-a627-0bd1de0b1bd2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"esdu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"esu", " ", 
     FractionBox["qsdu0", 
      RowBox[{"(", 
       RowBox[{"qsdcap", "-", "qsdu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.8048521093589597`*^9, 3.804852115828997*^9}, {
   3.80501724212201*^9, 3.80501724212201*^9}, {3.805017337158284*^9, 
   3.805017337158284*^9}, 3.805018338242672*^9, {3.807277748418344*^9, 
   3.807277748986786*^9}, 3.8252850933266773`*^9},
 CellLabel->
  "In[1599]:=",ExpressionUUID->"ddefb4fb-ed0b-41c9-b34f-815fdb269d09"],

Cell[BoxData[
 RowBox[{
  RowBox[{"asdu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qsdcap", "-", "qsdu0"}], ")"}], " ", 
    SuperscriptBox["psdu0", "esdu"]}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521184231625`*^9, 
   3.8048521249554644`*^9}, 3.80501724212201*^9, 3.805017337158284*^9, 
   3.8050178642343397`*^9, 3.805018338258299*^9, 3.8050189849580746`*^9, 
   3.82528509661722*^9},
 CellLabel->
  "In[1600]:=",ExpressionUUID->"9804a220-ad8a-4ea2-b0a3-d983552dacc8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eadu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"eau", " ", 
     FractionBox["qadu0", 
      RowBox[{"(", 
       RowBox[{"qadcap", "-", "qadu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.8048521327848425`*^9, 3.8048521396333513`*^9}, {
   3.8072777513326106`*^9, 3.807277751478725*^9}, 3.8252850977781563`*^9},
 CellLabel->
  "In[1601]:=",ExpressionUUID->"f305acde-6487-41d5-8850-a22925249eb5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aadu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qadcap", "-", "qadu0"}], ")"}], " ", 
    SuperscriptBox["padu0", "eadu"]}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521436041384`*^9, 
   3.8048521498553686`*^9}, 3.8252850993484087`*^9},
 CellLabel->
  "In[1602]:=",ExpressionUUID->"f5232fbe-62d7-4e00-986d-f2c32840b136"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ebdu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"ebu", " ", 
     FractionBox["qbdu0", 
      RowBox[{"(", 
       RowBox[{"qbdcap", "-", "qbdu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.8048521589190774`*^9, 3.804852165998335*^9}, {
   3.8050172630810432`*^9, 3.8050172630810432`*^9}, {3.80501735923965*^9, 
   3.8050173592553644`*^9}, 3.8050183601989946`*^9, {3.8072777540197015`*^9, 
   3.807277754136793*^9}, 3.8252851011848307`*^9},
 CellLabel->
  "In[1603]:=",ExpressionUUID->"ac224861-1ffc-4908-a6d4-f00c1b91f388"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abdu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qbdcap", "-", "qbdu0"}], ")"}], " ", 
    SuperscriptBox["pbdu0", "ebdu"]}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521687650814`*^9, 
   3.8048521751254616`*^9}, 3.8050172630966716`*^9, 3.8050173592553644`*^9, 
   3.805017872688827*^9, 3.8050183601989946`*^9, 3.8050194297527933`*^9, 
   3.825285102796051*^9},
 CellLabel->
  "In[1604]:=",ExpressionUUID->"22c1ee31-aa92-4f38-bac8-c199f7968ae9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"efdu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"efu", " ", 
     FractionBox["qfdu0", 
      RowBox[{"(", 
       RowBox[{"qfdcap", "-", "qfdu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.8048521589190774`*^9, 3.804852165998335*^9}, {
   3.8050172630810432`*^9, 3.8050172630810432`*^9}, {3.80501735923965*^9, 
   3.8050173592553644`*^9}, 3.8050183601989946`*^9, {3.8050194862238812`*^9, 
   3.805019495709798*^9}, {3.8072777575544558`*^9, 3.8072777578086543`*^9}, 
   3.825285104793653*^9},
 CellLabel->
  "In[1605]:=",ExpressionUUID->"2c6e2342-421a-4708-b8b8-5c667135aa12"],

Cell[BoxData[
 RowBox[{
  RowBox[{"afdu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qfdcap", "-", "qfdu0"}], ")"}], " ", 
    SuperscriptBox["pfdu0", "efdu"]}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521687650814`*^9, 
   3.8048521751254616`*^9}, 3.8050172630966716`*^9, 3.8050173592553644`*^9, 
   3.805017872688827*^9, 3.8050183601989946`*^9, 3.8050194297527933`*^9, {
   3.8050195018045397`*^9, 3.8050195102746644`*^9}, 3.825285106263771*^9},
 CellLabel->
  "In[1606]:=",ExpressionUUID->"e4a181ee-069f-4237-bdb1-e29ece128f2d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eodu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"eou", " ", 
     FractionBox["qodu0", 
      RowBox[{"(", 
       RowBox[{"qodcap", "-", "qodu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.8048521589190774`*^9, 3.804852165998335*^9}, {
   3.8050172630810432`*^9, 3.8050172630810432`*^9}, {3.80501735923965*^9, 
   3.8050173592553644`*^9}, 3.8050183601989946`*^9, {3.8050195139940205`*^9, 
   3.8050195356237755`*^9}, {3.8072777610812016`*^9, 3.8072777618167734`*^9}, 
   3.825285108061163*^9},
 CellLabel->
  "In[1607]:=",ExpressionUUID->"745d2426-5f4e-4ea4-8d95-2cd7241500ec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aodu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qodcap", "-", "qodu0"}], ")"}], " ", 
    SuperscriptBox["podu0", "eodu"]}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521687650814`*^9, 
   3.8048521751254616`*^9}, 3.8050172630966716`*^9, 3.8050173592553644`*^9, 
   3.805017872688827*^9, 3.8050183601989946`*^9, 3.8050194297527933`*^9, {
   3.8050195390618343`*^9, 3.805019548651763*^9}, 3.8252851096964865`*^9},
 CellLabel->
  "In[1608]:=",ExpressionUUID->"94b6edbf-8c1e-4ac1-9ae1-85e6f5b9f009"],

Cell[BoxData[
 RowBox[{
  RowBox[{"endu", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"enu", " ", 
     FractionBox["qndu0", 
      RowBox[{"(", 
       RowBox[{"qndcap", "-", "qndu0"}], ")"}]]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7990975812788644`*^9, 3.799097619150687*^9}, 
   3.7990988395699186`*^9, 3.7997943068448796`*^9, {3.7997944525311923`*^9, 
   3.799794495227602*^9}, {3.799799342677128*^9, 3.7997993468028483`*^9}, 
   3.799857686752442*^9, {3.801663068857303*^9, 3.8016630773954597`*^9}, {
   3.8016631601623044`*^9, 3.801663162568957*^9}, {3.8043443478105164`*^9, 
   3.804344406649295*^9}, {3.8048521589190774`*^9, 3.804852165998335*^9}, {
   3.8050172630810432`*^9, 3.8050172630810432`*^9}, {3.80501735923965*^9, 
   3.8050173592553644`*^9}, 3.8050183601989946`*^9, {3.8050195139940205`*^9, 
   3.8050195356237755`*^9}, {3.805639707717786*^9, 3.805639717375868*^9}, {
   3.8072777654606085`*^9, 3.8072777655586853`*^9}, 3.8252851111225567`*^9},
 CellLabel->
  "In[1609]:=",ExpressionUUID->"41deddaa-e5e1-4a31-984a-bf30677cca86"],

Cell[BoxData[
 RowBox[{
  RowBox[{"andu", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"qndcap", "-", "qndu0"}], ")"}], " ", 
    SuperscriptBox["pndu0", "endu"]}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7954545827847443`*^9, 3.795454592500293*^9}, {
   3.7954546335261803`*^9, 3.795454649811839*^9}, {3.795454708947795*^9, 
   3.7954547093901405`*^9}, 3.7954548974533033`*^9, 3.7954554797098083`*^9, 
   3.795456748307864*^9, {3.7954567794810934`*^9, 3.7954567969676867`*^9}, {
   3.7955250220002375`*^9, 3.7955250220062428`*^9}, 3.7955257981109056`*^9, 
   3.7955332163560486`*^9, {3.795777431902437*^9, 3.7957774849756527`*^9}, 
   3.7957775608382626`*^9, 3.7957781874878297`*^9, 3.795778274225032*^9, {
   3.795864643422542*^9, 3.7958646599704065`*^9}, 3.795864803204052*^9, {
   3.796567755738987*^9, 3.796567771150817*^9}, {3.7988098860260515`*^9, 
   3.7988098997406187`*^9}, {3.798809982357664*^9, 3.7988099831405764`*^9}, 
   3.7990943730267167`*^9, {3.7990944233008614`*^9, 3.7990944289392304`*^9}, {
   3.7990948421818137`*^9, 3.7990948690397997`*^9}, {3.799097230370245*^9, 
   3.7990972418311677`*^9}, 3.799097370737106*^9, 3.7990976161963606`*^9, 
   3.7994471080696898`*^9, 3.7997943086576853`*^9, {3.7997945738201075`*^9, 
   3.799794595901208*^9}, {3.799799371788849*^9, 3.799799393791478*^9}, {
   3.8016630893767166`*^9, 3.801663089564248*^9}, 3.803114052260586*^9, {
   3.8043443950802913`*^9, 3.804344427208288*^9}, {3.8048521687650814`*^9, 
   3.8048521751254616`*^9}, 3.8050172630966716`*^9, 3.8050173592553644`*^9, 
   3.805017872688827*^9, 3.8050183601989946`*^9, 3.8050194297527933`*^9, {
   3.8050195390618343`*^9, 3.805019548651763*^9}, {3.8056397203138247`*^9, 
   3.8056397284424424`*^9}, 3.8252851136635857`*^9},
 CellLabel->
  "In[1610]:=",ExpressionUUID->"ce02a34d-707c-477f-b9f3-80a7e49f1cfc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2 Demand Parameters", "Subsubsection",
 CellChangeTimes->{{3.819902497376732*^9, 3.819902510893259*^9}, 
   3.8250246051964817`*^9, {3.825283986924929*^9, 
   3.825283990682822*^9}},ExpressionUUID->"d43bc1bc-6db0-47cd-9c1e-\
e695e7782ff4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bytu", " ", "=", 
   RowBox[{
    FractionBox["vytu0", "vydu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pytu0", "pydu0"], ")"}], 
     RowBox[{"sigmayu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852908773026*^9}, 
   3.804954429860744*^9, 3.8050178536388817`*^9, 3.8050180911508274`*^9, 
   3.805018527670006*^9, 3.805018727270131*^9, 3.8050196031952763`*^9, 
   3.825285114927554*^9},
 CellLabel->
  "In[1611]:=",ExpressionUUID->"1bd69a31-8d5e-4be7-ac7b-526a6a7dc4b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pyu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pydu0", 
       RowBox[{"1", "-", "sigmayu"}]], "+", 
      RowBox[{"bytu", " ", 
       SuperscriptBox["pytu0", 
        RowBox[{"1", "-", "sigmayu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmayu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8049544298763714`*^9, 3.8049544298763714`*^9}, 
   3.8050178536545095`*^9, 3.8050180911664543`*^9, {3.8050196031952763`*^9, 
   3.805019614619006*^9}, 3.825285117167321*^9},
 CellLabel->
  "In[1612]:=",ExpressionUUID->"bfe09279-c02a-4e14-b37a-2ead85213dd7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bstu", " ", "=", 
   RowBox[{
    FractionBox["vstu0", "vsdu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pstu0", "psdu0"], ")"}], 
     RowBox[{"sigmasu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.8048529305003295`*^9}, 
   3.80495448906104*^9, 3.805017864249967*^9, 3.805018101074109*^9, 
   3.8050185566621103`*^9, 3.8050187442272134`*^9, {3.80501878270205*^9, 
   3.8050187879997787`*^9}, 3.805019635911148*^9, 3.8252851196622877`*^9},
 CellLabel->
  "In[1613]:=",ExpressionUUID->"d2ca5df3-78b6-49e1-b854-f20b9894de8a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdu0", 
       RowBox[{"1", "-", "sigmasu"}]], "+", 
      RowBox[{"bstu", " ", 
       SuperscriptBox["pstu0", 
        RowBox[{"1", "-", "sigmasu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.80495448906104*^9, 
   3.8049544890767255`*^9}, 3.805017864249967*^9, 3.8050181010897365`*^9, {
   3.805019635911148*^9, 3.8050196452264185`*^9}, 3.8252851209742875`*^9},
 CellLabel->
  "In[1614]:=",ExpressionUUID->"e9996e19-c9e2-4bad-80d6-e5d1f107f50b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"batu", " ", "=", 
   RowBox[{
    FractionBox["vatu0", "vadu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["patu0", "padu0"], ")"}], 
     RowBox[{"sigmaau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, 
   3.8252851222082386`*^9},
 CellLabel->
  "In[1615]:=",ExpressionUUID->"385ca98f-830d-4059-a353-b4dd92eaff40"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pau0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padu0", 
       RowBox[{"1", "-", "sigmaau"}]], "+", 
      RowBox[{"batu", " ", 
       SuperscriptBox["patu0", 
        RowBox[{"1", "-", "sigmaau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, 3.8252851237054462`*^9},
 CellLabel->
  "In[1616]:=",ExpressionUUID->"11633740-7877-4529-9267-5101c3b28f3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bbtu", " ", "=", 
   RowBox[{
    FractionBox["vbtu0", "vbdu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pbtu0", "pbdu0"], ")"}], 
     RowBox[{"sigmabu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.804853007174381*^9, 3.8048530190200768`*^9}, 3.8049546266952868`*^9, 
   3.805017872688827*^9, 3.805018113403982*^9, 3.8050185702579627`*^9, 
   3.805018858088605*^9, 3.80501967075628*^9, 3.82528512572701*^9},
 CellLabel->
  "In[1617]:=",ExpressionUUID->"387dcf33-3dbb-4670-99ab-85ffff228603"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pbu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pbdu0", 
       RowBox[{"1", "-", "sigmabu"}]], "+", 
      RowBox[{"bbtu", " ", 
       SuperscriptBox["pbtu0", 
        RowBox[{"1", "-", "sigmabu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmabu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8049546267109137`*^9, 3.8049546267109137`*^9}, 
   3.805017872688827*^9, 3.805018113403982*^9, {3.80501967075628*^9, 
   3.8050196847698293`*^9}, 3.825285127240186*^9},
 CellLabel->
  "In[1618]:=",ExpressionUUID->"764696a7-2ccb-4e84-8698-455b1318fc9e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bftu", " ", "=", 
   RowBox[{
    FractionBox["vftu0", "vfdu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pftu0", "pfdu0"], ")"}], 
     RowBox[{"sigmafu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.804853007174381*^9, 3.8048530190200768`*^9}, 3.8049546266952868`*^9, 
   3.805017872688827*^9, 3.805018113403982*^9, 3.8050185702579627`*^9, 
   3.805018858088605*^9, 3.80501967075628*^9, {3.805019702949969*^9, 
   3.8050197141705465`*^9}, 3.825285128445146*^9},
 CellLabel->
  "In[1619]:=",ExpressionUUID->"7e8bc4a9-59b5-4213-a12b-64692d4817e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pfu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pfdu0", 
       RowBox[{"1", "-", "sigmafu"}]], "+", 
      RowBox[{"bftu", " ", 
       SuperscriptBox["pftu0", 
        RowBox[{"1", "-", "sigmafu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmafu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8049546267109137`*^9, 3.8049546267109137`*^9}, 
   3.805017872688827*^9, 3.805018113403982*^9, {3.80501967075628*^9, 
   3.8050196847698293`*^9}, {3.8050197183743553`*^9, 3.805019732064079*^9}, 
   3.8252851302655644`*^9},
 CellLabel->
  "In[1620]:=",ExpressionUUID->"6881808e-6ee8-4fbf-a097-67964535b9e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"botu", " ", "=", 
   RowBox[{
    FractionBox["votu0", "vodu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["potu0", "podu0"], ")"}], 
     RowBox[{"sigmaou", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.804853007174381*^9, 3.8048530190200768`*^9}, 3.8049546266952868`*^9, 
   3.805017872688827*^9, 3.805018113403982*^9, 3.8050185702579627`*^9, 
   3.805018858088605*^9, 3.80501967075628*^9, {3.8050197383932323`*^9, 
   3.805019751506009*^9}, 3.8252851315705643`*^9},
 CellLabel->
  "In[1621]:=",ExpressionUUID->"973e0b37-8182-4fda-9e0f-5a79f4428a28"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pou0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["podu0", 
       RowBox[{"1", "-", "sigmaou"}]], "+", 
      RowBox[{"botu", " ", 
       SuperscriptBox["potu0", 
        RowBox[{"1", "-", "sigmaou"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaou"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8049546267109137`*^9, 3.8049546267109137`*^9}, 
   3.805017872688827*^9, 3.805018113403982*^9, {3.80501967075628*^9, 
   3.8050196847698293`*^9}, {3.8050197560536213`*^9, 3.8050197733327894`*^9}, 
   3.8252851336992483`*^9},
 CellLabel->
  "In[1622]:=",ExpressionUUID->"47fa4eb1-e757-4dc0-863e-a3881a527a94"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bntu", " ", "=", 
   RowBox[{
    FractionBox["vntu0", "vndu0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pntu0", "pndu0"], ")"}], 
     RowBox[{"sigmanu", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.804853007174381*^9, 3.8048530190200768`*^9}, 3.8049546266952868`*^9, 
   3.805017872688827*^9, 3.805018113403982*^9, 3.8050185702579627`*^9, 
   3.805018858088605*^9, 3.80501967075628*^9, {3.8050197383932323`*^9, 
   3.805019751506009*^9}, {3.80563999535212*^9, 3.8056400073706765`*^9}, 
   3.825285134856145*^9},
 CellLabel->
  "In[1623]:=",ExpressionUUID->"6f5e7dc2-ad0f-4179-ae72-c51b53d6c9bd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pnu0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pndu0", 
       RowBox[{"1", "-", "sigmanu"}]], "+", 
      RowBox[{"bntu", " ", 
       SuperscriptBox["pntu0", 
        RowBox[{"1", "-", "sigmanu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmanu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8049546267109137`*^9, 3.8049546267109137`*^9}, 
   3.805017872688827*^9, 3.805018113403982*^9, {3.80501967075628*^9, 
   3.8050196847698293`*^9}, {3.8050197560536213`*^9, 
   3.8050197733327894`*^9}, {3.805640010418045*^9, 3.8056400283975616`*^9}, 
   3.8252851362382064`*^9},
 CellLabel->
  "In[1624]:=",ExpressionUUID->"b90f7656-9533-4e23-8b30-fff3e1d43867"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsu", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vsdu0", "+", "vstu0"}], 
     RowBox[{"vydu0", "+", "vytu0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Psu0", "Pyu0"], ")"}], 
     RowBox[{"betau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.805018527670006*^9, 3.8050185566621103`*^9}, {3.805018727285775*^9, 
   3.8050187442272134`*^9}, {3.8050187967043133`*^9, 3.8050187992359776`*^9}, 
   3.805019614619006*^9, 3.8050196452264185`*^9, 3.805019802540661*^9, 
   3.8252851425762043`*^9},
 CellLabel->
  "In[1625]:=",ExpressionUUID->"62eabe97-1954-43ae-855a-7d2c54b35cbd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bau", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vadu0", "+", "vatu0"}], 
     RowBox[{"vydu0", "+", "vytu0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pau0", "Pyu0"], ")"}], 
     RowBox[{"betau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.804853293988452*^9}, 
   3.805018527670006*^9, 3.805018727285775*^9, 3.8050196146346335`*^9, 
   3.8252851446327696`*^9},
 CellLabel->
  "In[1626]:=",ExpressionUUID->"4d9b0a1f-c966-472a-b552-6af5401f68b8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bou", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vodu0", "+", "votu0"}], 
     RowBox[{"vydu0", "+", "vytu0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pou0", "Pyu0"], ")"}], 
     RowBox[{"betau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.8048532815960116`*^9, 3.8048533048189335`*^9}, 3.8050185276856337`*^9, 
   3.8050185702579627`*^9, 3.805018727285775*^9, 3.805018858088605*^9, 
   3.8050196146346335`*^9, 3.8050196847698293`*^9, 3.805019812682934*^9, {
   3.8050198805950856`*^9, 3.8050198891156464`*^9}, 3.8252851461369457`*^9},
 CellLabel->
  "In[1627]:=",ExpressionUUID->"f941036b-720f-480c-b55f-675c0c274d1d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bnu", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vndu0", "+", "vntu0"}], 
     RowBox[{"vydu0", "+", "vytu0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pnu0", "Pyu0"], ")"}], 
     RowBox[{"betau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.8048532815960116`*^9, 3.8048533048189335`*^9}, 3.8050185276856337`*^9, 
   3.8050185702579627`*^9, 3.805018727285775*^9, 3.805018858088605*^9, 
   3.8050196146346335`*^9, 3.8050196847698293`*^9, 3.805019812682934*^9, {
   3.8050198805950856`*^9, 3.8050198891156464`*^9}, {3.805640045777953*^9, 
   3.8056400536164417`*^9}, 3.825285147441966*^9},
 CellLabel->
  "In[1628]:=",ExpressionUUID->"9f1ce122-1da6-4467-859b-c911e0fbf274"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bfu", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vfdu0", "+", "vftu0"}], 
     RowBox[{"vbdu0", "+", "vbtu0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pfu0", "Pbu0"], ")"}], 
     RowBox[{"betau", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.8048532815960116`*^9, 3.8048533048189335`*^9}, 3.8050185276856337`*^9, 
   3.8050185702579627`*^9, 3.805018727285775*^9, 3.805018858088605*^9, 
   3.8050196146346335`*^9, 3.8050196847698293`*^9, 3.805019812682934*^9, {
   3.8050198659677114`*^9, 3.8050198748597784`*^9}, {3.813997040829769*^9, 
   3.813997046223968*^9}, 3.825285149318445*^9},
 CellLabel->
  "In[1629]:=",ExpressionUUID->"2bd131a2-c9c0-49aa-a8ac-c0ffda5dda8c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P1u0", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pyu0", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bsu", " ", 
       SuperscriptBox["Psu0", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bau", " ", 
       SuperscriptBox["Pau0", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bou", " ", 
       SuperscriptBox["Pou0", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bnu", " ", 
       SuperscriptBox["Pnu0", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, 3.8050196146346335`*^9, 
   3.8050196452264185`*^9, 3.8050196847698293`*^9, {3.805019802540661*^9, 
   3.8050198551991177`*^9}, {3.805640058914117*^9, 3.805640067666767*^9}, {
   3.8139970954222636`*^9, 3.813997103563604*^9}, {3.8139971588256187`*^9, 
   3.8139971589827414`*^9}, {3.8139974489814854`*^9, 3.813997449561937*^9}, 
   3.8252851510237694`*^9},
 CellLabel->
  "In[1630]:=",ExpressionUUID->"e6724399-0426-4abd-bb4b-27370550b482"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P2u0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pbu0", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bfu", " ", 
       SuperscriptBox["Pfu0", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.813997108085124*^9, 3.813997156413744*^9}, {
   3.8139974456438866`*^9, 3.813997446174302*^9}, 3.8139974987732444`*^9, 
   3.825285152333838*^9},
 CellLabel->
  "In[1631]:=",ExpressionUUID->"27fb513c-94bf-41fe-917f-d84a14538a41"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bytp", " ", "=", 
   RowBox[{
    FractionBox["vytp0", "vydp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pytp0", "pydp0"], ")"}], 
     RowBox[{"sigmayp", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852908773026*^9}, {
   3.8048533814497547`*^9, 3.8048533850606613`*^9}, 3.8049544666958017`*^9, 
   3.805018145205366*^9, 3.8050182696736803`*^9, 3.805018537499652*^9, 
   3.8050187353507767`*^9, 3.8050199344667687`*^9, 3.8252851584185953`*^9},
 CellLabel->
  "In[1632]:=",ExpressionUUID->"379bd8ba-b8f0-4369-b43e-b6613eb75c99"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pyp0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pydp0", 
       RowBox[{"1", "-", "sigmayp"}]], "+", 
      RowBox[{"bytp", " ", 
       SuperscriptBox["pytp0", 
        RowBox[{"1", "-", "sigmayp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmayp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048533855138645`*^9, 3.804853387764236*^9}, {
   3.804954466711429*^9, 3.804954466711429*^9}, 3.805018145220993*^9, 
   3.8050182696736803`*^9, 3.8050199344667687`*^9, 3.8050199698348083`*^9, 
   3.8252851600978827`*^9},
 CellLabel->
  "In[1633]:=",ExpressionUUID->"1ed764e9-1c8e-4b4d-9273-7c8f56f9b844"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bstp", " ", "=", 
   RowBox[{
    FractionBox["vstp0", "vsdp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pstp0", "psdp0"], ")"}], 
     RowBox[{"sigmasp", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.8048529305003295`*^9}, {
   3.8048533881740723`*^9, 3.804853389939992*^9}, 3.8049545102161703`*^9, 
   3.805018154986638*^9, 3.805018278393769*^9, 3.8050185486888833`*^9, 
   3.805018840007553*^9, 3.80501994403093*^9, 3.8252851613728933`*^9},
 CellLabel->
  "In[1634]:=",ExpressionUUID->"29fbc036-d510-40fe-8daf-9600259594f0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psp0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdp0", 
       RowBox[{"1", "-", "sigmasp"}]], "+", 
      RowBox[{"bstp", " ", 
       SuperscriptBox["pstp0", 
        RowBox[{"1", "-", "sigmasp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.8048533906588616`*^9, 
   3.804853392674816*^9}, {3.8049545102317977`*^9, 3.8049545102317977`*^9}, 
   3.805018154986638*^9, 3.805018278409396*^9, 3.805019944046558*^9, 
   3.8050199843385897`*^9, 3.8252851632453394`*^9},
 CellLabel->
  "In[1635]:=",ExpressionUUID->"d597280d-cf66-4efd-a4df-e8e3cfc822e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"batp", " ", "=", 
   RowBox[{
    FractionBox["vatp0", "vadp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["patp0", "padp0"], ")"}], 
     RowBox[{"sigmaap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.8048533930967607`*^9, 3.804853394675149*^9}, 3.82528516444027*^9},
 CellLabel->
  "In[1636]:=",ExpressionUUID->"046a6855-34da-4a95-a501-75e89b292345"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pap0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padp0", 
       RowBox[{"1", "-", "sigmaap"}]], "+", 
      RowBox[{"batp", " ", 
       SuperscriptBox["patp0", 
        RowBox[{"1", "-", "sigmaap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048533952064857`*^9, 
   3.8048533971443033`*^9}, 3.825285165697246*^9},
 CellLabel->
  "In[1637]:=",ExpressionUUID->"d22c127a-b4b1-4a89-8bd5-9291c05be00a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bbtp", " ", "=", 
   RowBox[{
    FractionBox["vbtp0", "vbdp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pbtp0", "pbdp0"], ")"}], 
     RowBox[{"sigmabp", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.804853007174381*^9, 3.8048530190200768`*^9}, {3.8048533974568553`*^9, 
   3.804853398894594*^9}, 3.8049546404935093`*^9, 3.805018163895453*^9, 
   3.8050182854886165`*^9, 3.805018578494796*^9, 3.805018865715522*^9, 
   3.8050199536901255`*^9, 3.8252851678379765`*^9},
 CellLabel->
  "In[1638]:=",ExpressionUUID->"93b2d3b9-f4dc-4bec-b540-3dc836afe09b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pbp0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pbdp0", 
       RowBox[{"1", "-", "sigmabp"}]], "+", 
      RowBox[{"bbtp", " ", 
       SuperscriptBox["pbtp0", 
        RowBox[{"1", "-", "sigmabp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmabp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.804954640509137*^9, 3.804954640509137*^9}, 3.805018163895453*^9, 
   3.8050182855042944`*^9, 3.8050199537057533`*^9, 3.805020008092595*^9, 
   3.825285169136962*^9},
 CellLabel->
  "In[1639]:=",ExpressionUUID->"ad032d2a-ff52-44d7-8d69-ecdf737d464c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bftp", " ", "=", 
   RowBox[{
    FractionBox["vftp0", "vfdp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pftp0", "pfdp0"], ")"}], 
     RowBox[{"sigmafp", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.804853007174381*^9, 3.8048530190200768`*^9}, {3.8048533974568553`*^9, 
   3.804853398894594*^9}, 3.8049546404935093`*^9, 3.805018163895453*^9, 
   3.8050182854886165`*^9, 3.805018578494796*^9, 3.805018865715522*^9, 
   3.8050199536901255`*^9, {3.8050200349746237`*^9, 3.8050200456795435`*^9}, 
   3.825285170479*^9},
 CellLabel->
  "In[1640]:=",ExpressionUUID->"d89a45b1-455b-4c84-bfb2-4d419410a0cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pfp0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pfdp0", 
       RowBox[{"1", "-", "sigmafp"}]], "+", 
      RowBox[{"bftp", " ", 
       SuperscriptBox["pftp0", 
        RowBox[{"1", "-", "sigmafp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmafp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.804954640509137*^9, 3.804954640509137*^9}, 3.805018163895453*^9, 
   3.8050182855042944`*^9, 3.8050199537057533`*^9, 3.805020008092595*^9, {
   3.8050200498208623`*^9, 3.805020066793394*^9}, 3.8252851723834763`*^9},
 CellLabel->
  "In[1641]:=",ExpressionUUID->"e0dfef6b-9095-46bd-b1db-493e8ded06e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"botp", " ", "=", 
   RowBox[{
    FractionBox["votp0", "vodp0"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["potp0", "podp0"], ")"}], 
     RowBox[{"sigmaop", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7916349666731367`*^9, 3.791634969924673*^9}, 
   3.791635376286104*^9, {3.791639960640232*^9, 3.791639963232232*^9}, {
   3.7916400423602796`*^9, 3.7916400630112123`*^9}, {3.7916403663392324`*^9, 
   3.7916403664022813`*^9}, {3.7916404664274673`*^9, 3.791640466501509*^9}, {
   3.7916409078907127`*^9, 3.791640932258882*^9}, 3.791642141310727*^9, {
   3.791642175815278*^9, 3.791642178040009*^9}, {3.7916450914996047`*^9, 
   3.791645091818857*^9}, {3.795452153608122*^9, 3.795452156571401*^9}, {
   3.79545305025589*^9, 3.7954530542239747`*^9}, {3.79545316247342*^9, 
   3.795453169394801*^9}, {3.7954533462122264`*^9, 3.7954533464193897`*^9}, 
   3.795453760366103*^9, {3.7954538082843437`*^9, 3.7954538111785946`*^9}, 
   3.795454332079898*^9, {3.7954554865220633`*^9, 3.795455486778262*^9}, {
   3.79545624651688*^9, 3.795456273301695*^9}, {3.795456421024506*^9, 
   3.79545642751355*^9}, {3.795525022030261*^9, 3.7955250220362673`*^9}, 
   3.795525218193719*^9, 3.7955257059357996`*^9, {3.795533281006304*^9, 
   3.7955332841867723`*^9}, 3.7957772430185943`*^9, 3.7957775608412657`*^9, {
   3.7957780719089956`*^9, 3.795778071909996*^9}, {3.7957781628246593`*^9, 
   3.795778187489831*^9}, {3.795864844154768*^9, 3.7958649073558893`*^9}, {
   3.7958650679567113`*^9, 3.795865068114834*^9}, {3.7958669859005384`*^9, 
   3.795866987839042*^9}, {3.7961197288516083`*^9, 3.796119736633658*^9}, {
   3.798809951231065*^9, 3.798809968981861*^9}, {3.7997953450434823`*^9, 
   3.7997953753317633`*^9}, {3.7997956299618196`*^9, 3.799795640166177*^9}, {
   3.7997960295840774`*^9, 3.7997960500698004`*^9}, {3.799797110519265*^9, 
   3.7997971156190743`*^9}, {3.799799416603014*^9, 3.79979944071797*^9}, {
   3.7998564860436697`*^9, 3.7998564869344573`*^9}, 3.799856619219349*^9, {
   3.8004555664169536`*^9, 3.80045556662957*^9}, 3.800635749587065*^9, 
   3.8017785131107388`*^9, 3.8031140475308523`*^9, {3.804344509778531*^9, 
   3.804344524827236*^9}, {3.804852900036868*^9, 3.804852970866297*^9}, {
   3.804853007174381*^9, 3.8048530190200768`*^9}, {3.8048533974568553`*^9, 
   3.804853398894594*^9}, 3.8049546404935093`*^9, 3.805018163895453*^9, 
   3.8050182854886165`*^9, 3.805018578494796*^9, 3.805018865715522*^9, 
   3.8050199536901255`*^9, {3.805020071591073*^9, 3.805020083710909*^9}, 
   3.825285175141697*^9},
 CellLabel->
  "In[1642]:=",ExpressionUUID->"251ab582-9b64-4b8f-8f2a-b01aa1edb46b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pop0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["podp0", 
       RowBox[{"1", "-", "sigmaop"}]], "+", 
      RowBox[{"botp", " ", 
       SuperscriptBox["potp0", 
        RowBox[{"1", "-", "sigmaop"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaop"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.804954640509137*^9, 3.804954640509137*^9}, 3.805018163895453*^9, 
   3.8050182855042944`*^9, 3.8050199537057533`*^9, 3.805020008092595*^9, {
   3.805020086773922*^9, 3.8050201036517515`*^9}, 3.825285177502511*^9},
 CellLabel->
  "In[1643]:=",ExpressionUUID->"10c092d2-c064-4dbd-b087-f6d73fab8a94"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsp", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vsdp0", "+", "vstp0"}], 
     RowBox[{"vydp0", "+", "vytp0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Psp0", "Pyp0"], ")"}], 
     RowBox[{"betap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.804853425853657*^9, 3.804853428010266*^9}, {3.805018537499652*^9, 
   3.8050185486888833`*^9}, 3.8050187353507767`*^9, 3.805018840007553*^9, {
   3.8050199698348083`*^9, 3.8050199843385897`*^9}, 3.8050201228280954`*^9, 
   3.8252851845079746`*^9},
 CellLabel->
  "In[1644]:=",ExpressionUUID->"8305e50c-adba-4ce2-96df-65790eba427b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bap", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vadp0", "+", "vatp0"}], 
     RowBox[{"vydp0", "+", "vytp0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pap0", "Pyp0"], ")"}], 
     RowBox[{"betap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.804853293988452*^9}, {
   3.8048534284009533`*^9, 3.80485342996371*^9}, 3.805018537515279*^9, 
   3.8050187353507767`*^9, 3.8050199698348083`*^9, 3.825285186680731*^9},
 CellLabel->
  "In[1645]:=",ExpressionUUID->"54f686b0-44db-4784-8a4e-7cfac2c72f32"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bop", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vodp0", "+", "votp0"}], 
     RowBox[{"vydp0", "+", "vytp0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pop0", "Pyp0"], ")"}], 
     RowBox[{"betap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.8048532815960116`*^9, 3.8048533048189335`*^9}, {3.804853430260635*^9, 
   3.8048534318233943`*^9}, 3.805018537515279*^9, 3.805018578494796*^9, 
   3.8050187353507767`*^9, 3.805018865715522*^9, 3.8050199698348083`*^9, 
   3.805020008092595*^9, 3.8050201313295197`*^9, {3.805020189086344*^9, 
   3.8050201971189404`*^9}, 3.825285188899398*^9},
 CellLabel->
  "In[1646]:=",ExpressionUUID->"f8f4cffc-2e08-4013-8cd5-e151588c3e2e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bnp", "=", 
   RowBox[{
    FractionBox["vntp0", 
     RowBox[{"vydp0", "+", "vytp0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["pntp0", "Pyp0"], ")"}], 
     RowBox[{"betap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.8048532815960116`*^9, 3.8048533048189335`*^9}, {3.804853430260635*^9, 
   3.8048534318233943`*^9}, 3.805018537515279*^9, 3.805018578494796*^9, 
   3.8050187353507767`*^9, 3.805018865715522*^9, 3.8050199698348083`*^9, 
   3.805020008092595*^9, 3.8050201313295197`*^9, {3.805020189086344*^9, 
   3.8050201971189404`*^9}, {3.8056401178664365`*^9, 
   3.8056401253688564`*^9}, {3.807273357720145*^9, 3.807273363834903*^9}, 
   3.825285191688635*^9},
 CellLabel->
  "In[1647]:=",ExpressionUUID->"19f80ec7-4361-4557-abb4-76d7665e3fd6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bfp", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"vfdp0", "+", "vftp0"}], 
     RowBox[{"vbdp0", "+", "vbtp0"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["Pfp0", "Pbp0"], ")"}], 
     RowBox[{"betap", "-", "1"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8006360721904936`*^9, 3.8006361553652325`*^9}, {
   3.8006573541937003`*^9, 3.8006573677893033`*^9}, 3.8017784770582275`*^9, 
   3.803114009021455*^9, {3.804853150966774*^9, 3.8048532499973593`*^9}, {
   3.8048532815960116`*^9, 3.8048533048189335`*^9}, {3.804853430260635*^9, 
   3.8048534318233943`*^9}, 3.805018537515279*^9, 3.805018578494796*^9, 
   3.8050187353507767`*^9, 3.805018865715522*^9, 3.8050199698348083`*^9, 
   3.805020008092595*^9, 3.8050201313295197`*^9, {3.8050201748795977`*^9, 
   3.805020183272869*^9}, {3.807306456579997*^9, 3.807306457002326*^9}, {
   3.813997203115099*^9, 3.8139972124673758`*^9}, 3.825285194016398*^9},
 CellLabel->
  "In[1648]:=",ExpressionUUID->"d45e55d8-cf88-4b9a-97a8-b5feb88adfba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P1p0", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pyp0", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bsp", " ", 
       SuperscriptBox["Psp0", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bap", " ", 
       SuperscriptBox["Pap0", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bop", " ", 
       SuperscriptBox["Pop0", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bnp", " ", 
       SuperscriptBox["pntp0", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048534322140846`*^9, 
   3.8048534358553085`*^9}, {3.805019969866063*^9, 3.805020008092595*^9}, {
   3.8050201228437223`*^9, 3.8050201668938847`*^9}, {3.8056401304009275`*^9, 
   3.805640139998988*^9}, {3.807273372617741*^9, 3.8072733778748293`*^9}, {
   3.8072774339896793`*^9, 3.8072774461091146`*^9}, {3.8139972182979126`*^9, 
   3.8139972249130664`*^9}, {3.8139974402476845`*^9, 3.8139974409072003`*^9}, 
   3.8252851967425632`*^9},
 CellLabel->
  "In[1649]:=",ExpressionUUID->"a4a909b7-206c-40c9-bf6f-7340e63204b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P2p0", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pbp0", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bfp", " ", 
       SuperscriptBox["Pfp0", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.8139972300360546`*^9, 3.813997258883507*^9}, {
   3.8139974374314957`*^9, 3.813997438150055*^9}, 3.8252851988742304`*^9},
 CellLabel->
  "In[1650]:=",ExpressionUUID->"df2f5467-8409-48bb-9ef1-7c6e5b1ee99f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ku1", "=", 
   FractionBox[
    RowBox[{"qytu0", " ", 
     SuperscriptBox["P1u0", 
      RowBox[{
       RowBox[{"-", "etau"}], "-", "betau", " "}]], 
     SuperscriptBox["Pyu0", 
      RowBox[{"betau", "-", "sigmayu"}]], 
     SuperscriptBox["pytu0", "sigmayu"]}], "bytu"]}], ";"}]], "Input",
 CellChangeTimes->{{3.800140454488206*^9, 3.800140523176643*^9}, {
   3.800455058428173*^9, 3.800455063959334*^9}, {3.8006362513154964`*^9, 
   3.800636260384779*^9}, 3.8006363054963803`*^9, 3.800647348889147*^9, 
   3.8006960898303185`*^9, 3.800804256877533*^9, {3.8008043645295997`*^9, 
   3.800804364685875*^9}, {3.8008068728494596`*^9, 3.800806875974489*^9}, {
   3.8016604841908655`*^9, 3.8016604867536297`*^9}, {3.801663391117081*^9, 
   3.801663391882834*^9}, 3.801664413638791*^9, {3.8016647577403903`*^9, 
   3.801664759459405*^9}, {3.8016648404783707`*^9, 3.8016648805396347`*^9}, {
   3.801665135307444*^9, 3.801665211909813*^9}, 3.8016653900835795`*^9, {
   3.8016670898715615`*^9, 3.8016670989043036`*^9}, {3.80168887262052*^9, 
   3.8016888744489493`*^9}, {3.8016889608852425`*^9, 3.801689010426876*^9}, {
   3.8017784454569283`*^9, 3.801778458163327*^9}, 3.801778528743101*^9, {
   3.8017814934521255`*^9, 3.8017814938740683`*^9}, {3.8031140023071547`*^9, 
   3.803114014512789*^9}, {3.8031260626605997`*^9, 3.8031261061075296`*^9}, {
   3.804344640574292*^9, 3.804344672830389*^9}, {3.8048534574220657`*^9, 
   3.8048535141640887`*^9}, {3.804954429923254*^9, 3.804954429923254*^9}, 
   3.8050174498061085`*^9, 3.8050180911664543`*^9, {3.8050196031952763`*^9, 
   3.8050196146346335`*^9}, {3.807287931462183*^9, 3.8072879666545725`*^9}, {
   3.8139972889939485`*^9, 3.813997291424837*^9}, {3.813997420260131*^9, 
   3.8139974209686813`*^9}, 3.8252852014021835`*^9},
 CellLabel->
  "In[1651]:=",ExpressionUUID->"0f3e7553-f6e2-4c16-ad42-a622b32f2bcb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ku2", " ", "=", " ", 
   FractionBox[
    RowBox[{"qbtu0", " ", 
     SuperscriptBox["P2u0", 
      RowBox[{
       RowBox[{"-", "etau"}], "-", "betau"}]], 
     SuperscriptBox["Pbu0", 
      RowBox[{"betau", "-", "sigmabu"}]], 
     SuperscriptBox["pbtu0", "sigmabu"]}], "bbtu"]}], ";"}]], "Input",
 CellChangeTimes->{{3.8139973017378654`*^9, 3.813997344850428*^9}, {
   3.813997423519664*^9, 3.813997425557255*^9}, 3.813998916000405*^9, {
   3.8139992184158325`*^9, 3.813999232474778*^9}, 3.8252852034558115`*^9},
 CellLabel->
  "In[1652]:=",ExpressionUUID->"c419041f-0db1-4067-a99f-0107c1d5fb81"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kp1", "=", 
   FractionBox[
    RowBox[{"qytp0", " ", 
     SuperscriptBox["P1p0", 
      RowBox[{
       RowBox[{"-", "etap"}], "-", "betap"}]], " ", 
     SuperscriptBox["Pyp0", 
      RowBox[{"betap", "-", "sigmayp"}]], 
     SuperscriptBox["pytp0", "sigmayp"]}], "bytp"]}], ";"}]], "Input",
 CellChangeTimes->{{3.801689038848219*^9, 3.8016890477090626`*^9}, 
   3.80177853075905*^9, 3.8031139983340187`*^9, {3.8031261513407984`*^9, 
   3.80312624801073*^9}, {3.8031284224239283`*^9, 3.8031284235638275`*^9}, {
   3.804344676926572*^9, 3.8043446965778627`*^9}, {3.80485352319683*^9, 
   3.8048535706159515`*^9}, {3.8049544667270565`*^9, 3.8049544667270565`*^9}, 
   3.8050175026566935`*^9, 3.8050182696893077`*^9, 3.8050199344667687`*^9, 
   3.805019969866063*^9, {3.813997348604349*^9, 3.813997351791833*^9}, {
   3.8139974288658257`*^9, 3.813997429466293*^9}, 3.825285205607506*^9},
 CellLabel->
  "In[1653]:=",ExpressionUUID->"3ef16ad7-9288-471b-b407-adece8171bc8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kp2", " ", "=", 
   FractionBox[
    RowBox[{"qbtp0", " ", 
     SuperscriptBox["P2p0", 
      RowBox[{
       RowBox[{"-", "etap"}], "-", "betap"}]], " ", 
     SuperscriptBox["Pbp0", 
      RowBox[{"betap", "-", "sigmabp"}]], 
     SuperscriptBox["pbtp0", "sigmabp"]}], "bbtp"]}], " ", ";"}]], "Input",
 CellChangeTimes->{{3.813997358987432*^9, 3.813997393242099*^9}, {
   3.813997432665786*^9, 3.813997433542467*^9}, {3.8139991689583282`*^9, 
   3.813999191041523*^9}, 3.825285208344643*^9},
 CellLabel->
  "In[1654]:=",ExpressionUUID->"7b4f3f13-cb36-44aa-add5-05e9e2122d1a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4. New Equilibrium Calculation",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.7954529786642447`*^9}, {
  3.79545386036082*^9, 3.7954538618860044`*^9}, {3.795525436722562*^9, 
  3.795525448873003*^9}, {3.819900451316465*^9, 
  3.819900451678748*^9}},ExpressionUUID->"5033ec64-9fb0-47a7-80a9-\
2acecbefbedd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pyu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pydu", 
       RowBox[{"1", "-", "sigmayu"}]], "+", 
      RowBox[{"bytu", " ", 
       SuperscriptBox["pytu", 
        RowBox[{"1", "-", "sigmayu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmayu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048537407717743`*^9, 3.804853751697942*^9}, {
   3.804954429923254*^9, 3.804954429938881*^9}, {3.8050196031952763`*^9, 
   3.8050196146346335`*^9}, {3.8050202419412766`*^9, 3.805020254318351*^9}},
 CellLabel->
  "In[1655]:=",ExpressionUUID->"ef893d96-bd08-4069-9c34-459925ad7abd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdu", 
       RowBox[{"1", "-", "sigmasu"}]], "+", 
      RowBox[{"bstu", " ", 
       SuperscriptBox["pstu", 
        RowBox[{"1", "-", "sigmasu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.804853754104593*^9, 
   3.8048537632655916`*^9}, {3.8049544890767255`*^9, 
   3.8049544890767255`*^9}, {3.805019635911148*^9, 3.8050196452420464`*^9}, {
   3.805020269508397*^9, 3.805020277728525*^9}},
 CellLabel->
  "In[1656]:=",ExpressionUUID->"8ed78591-642f-4073-ae37-f3504a3aa756"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pau", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padu", 
       RowBox[{"1", "-", "sigmaau"}]], "+", 
      RowBox[{"batu", " ", 
       SuperscriptBox["patu", 
        RowBox[{"1", "-", "sigmaau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048537655159597`*^9, 
   3.8048537724008365`*^9}},
 CellLabel->
  "In[1657]:=",ExpressionUUID->"ce99f432-061e-4019-ad09-c149f12ad464"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pbu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pbdu", 
       RowBox[{"1", "-", "sigmabu"}]], "+", 
      RowBox[{"bbtu", " ", 
       SuperscriptBox["pbtu", 
        RowBox[{"1", "-", "sigmabu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmabu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}, {
   3.8049546267109137`*^9, 3.8049546267265406`*^9}, {3.80501967075628*^9, 
   3.8050196847698293`*^9}, {3.8050202878564696`*^9, 3.8050202964360323`*^9}},
 CellLabel->
  "In[1658]:=",ExpressionUUID->"885540a3-c558-4d46-8645-7a9b84d95c48"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pfu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pfdu", 
       RowBox[{"1", "-", "sigmafu"}]], "+", 
      RowBox[{"bftu", " ", 
       SuperscriptBox["pftu", 
        RowBox[{"1", "-", "sigmafu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmafu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}, {
   3.8049546267109137`*^9, 3.8049546267265406`*^9}, {3.80501967075628*^9, 
   3.8050196847698293`*^9}, {3.8050202878564696`*^9, 
   3.8050202964360323`*^9}, {3.8050203416174593`*^9, 3.8050203570617857`*^9}},
 CellLabel->
  "In[1659]:=",ExpressionUUID->"26e7f073-06b1-4e5a-8eff-d9badcd29a3b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pou", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["podu", 
       RowBox[{"1", "-", "sigmaou"}]], "+", 
      RowBox[{"botu", " ", 
       SuperscriptBox["potu", 
        RowBox[{"1", "-", "sigmaou"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaou"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}, {
   3.8049546267109137`*^9, 3.8049546267265406`*^9}, {3.80501967075628*^9, 
   3.8050196847698293`*^9}, {3.8050202878564696`*^9, 
   3.8050202964360323`*^9}, {3.805020361828209*^9, 3.805020377674616*^9}},
 CellLabel->
  "In[1660]:=",ExpressionUUID->"46b47e41-b29a-438d-a4f1-ca328fe5a8e2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pnu", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pndu", 
       RowBox[{"1", "-", "sigmanu"}]], "+", 
      RowBox[{"bntu", " ", 
       SuperscriptBox["pntu", 
        RowBox[{"1", "-", "sigmanu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmanu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}, {
   3.8049546267109137`*^9, 3.8049546267265406`*^9}, {3.80501967075628*^9, 
   3.8050196847698293`*^9}, {3.8050202878564696`*^9, 
   3.8050202964360323`*^9}, {3.805020361828209*^9, 3.805020377674616*^9}, {
   3.805640301663845*^9, 3.8056403150842867`*^9}},
 CellLabel->
  "In[1661]:=",ExpressionUUID->"c57bda11-d8d5-4640-b6e9-81ea62f804c0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P1u", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pyu", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bsu", " ", 
       SuperscriptBox["Psu", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bau", " ", 
       SuperscriptBox["Pau", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bou", " ", 
       SuperscriptBox["Pou", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bnu", " ", 
       SuperscriptBox["Pnu", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048536729130955`*^9, 
   3.804853693916567*^9}, 3.805019614650261*^9, 3.8050196452420464`*^9, 
   3.8050196847698293`*^9, {3.805019802540661*^9, 3.805019812682934*^9}, {
   3.8050203129401875`*^9, 3.805020330818774*^9}, {3.8050205921461425`*^9, 
   3.8050205922399073`*^9}, {3.805640322587119*^9, 3.8056403333666506`*^9}, {
   3.81399740495922*^9, 3.8139974156615505`*^9}, 3.813997465178093*^9},
 CellLabel->
  "In[1662]:=",ExpressionUUID->"fcad075f-b133-4c8a-bbfe-1247200c7621"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P2u", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pbu", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bfu", " ", 
       SuperscriptBox["Pfu", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.8139974684796658`*^9, 3.8139975172736473`*^9}},
 CellLabel->
  "In[1663]:=",ExpressionUUID->"99823b00-635f-49cc-9e3d-c2e6132f7bbb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pydp", " ", "=", " ", 
   RowBox[{"Pyu", " ", 
    FractionBox["pydp0", "Pyu0"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.814026118622264*^9, 3.814026136844446*^9}, {
  3.8140264929472895`*^9, 3.8140264934186563`*^9}, {3.8140265962707243`*^9, 
  3.8140265985545034`*^9}},
 CellLabel->
  "In[1664]:=",ExpressionUUID->"da0aff7c-7b14-4aa8-b92e-a0eed3b6c7f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psdp", " ", "=", " ", 
   RowBox[{"Psu", " ", 
    FractionBox["psdp0", "Psu0"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.814026268039674*^9, 3.814026283925037*^9}, {
  3.814026603095039*^9, 3.814026608026879*^9}},
 CellLabel->
  "In[1665]:=",ExpressionUUID->"119302ff-62d4-4ee6-b157-93f9af95b567"],

Cell[BoxData[
 RowBox[{
  RowBox[{"padp", " ", "=", " ", 
   RowBox[{"Pau", " ", 
    FractionBox["padp0", "Pau0"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8140263004404187`*^9, 3.8140263128430786`*^9}, {
  3.8140266120259933`*^9, 3.814026616869763*^9}},
 CellLabel->
  "In[1666]:=",ExpressionUUID->"595b2566-2755-435c-b60f-85d1074d0b10"],

Cell[BoxData[
 RowBox[{
  RowBox[{"podp", " ", "=", " ", 
   RowBox[{"Pou", " ", 
    FractionBox["podp0", "Pou0"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8140263233512583`*^9, 3.81402633627732*^9}, {
  3.8140266218726587`*^9, 3.8140266303592615`*^9}},
 CellLabel->
  "In[1667]:=",ExpressionUUID->"a637258c-e1d7-4776-97e4-1054436d77b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pbdp", " ", "=", " ", 
   RowBox[{"Pbu", " ", 
    FractionBox["pbdp0", "Pbu0"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.815477650435968*^9, 3.815477678112421*^9}},
 CellLabel->
  "In[1668]:=",ExpressionUUID->"328f6603-63df-4175-8a38-3d6f30379a3e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pfdp", " ", "=", " ", 
   RowBox[{"Pfu", " ", 
    FractionBox["pfdp0", "Pfu0"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.815477684222804*^9, 3.8154776893330283`*^9}},
 CellLabel->
  "In[1669]:=",ExpressionUUID->"eee623c3-a5d5-4047-9310-aee616ffb0c9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pyp", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pydp", 
       RowBox[{"1", "-", "sigmayp"}]], "+", 
      RowBox[{"bytp", " ", 
       SuperscriptBox["pytp", 
        RowBox[{"1", "-", "sigmayp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmayp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048533855138645`*^9, 3.804853387764236*^9}, {
   3.804853813462556*^9, 3.804853819838611*^9}, 3.8048540877282963`*^9, {
   3.8049544667270565`*^9, 3.8049544667270565`*^9}, 3.8050199344667687`*^9, 
   3.805019969866063*^9, 3.8050206098365355`*^9, 3.8050206555345936`*^9},
 CellLabel->
  "In[1670]:=",ExpressionUUID->"9d050bb0-c02a-4827-8832-d05de9cd5771"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psp", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdp", 
       RowBox[{"1", "-", "sigmasp"}]], "+", 
      RowBox[{"bstp", " ", 
       SuperscriptBox["pstp", 
        RowBox[{"1", "-", "sigmasp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.8048533906588616`*^9, 
   3.804853392674816*^9}, {3.8048538223073983`*^9, 3.8048538261666756`*^9}, 
   3.8048540893066835`*^9, {3.8049545102317977`*^9, 3.8049545102317977`*^9}, 
   3.805019944046558*^9, 3.8050199843385897`*^9, 3.8050206231222305`*^9, 
   3.8050206633483715`*^9},
 CellLabel->
  "In[1671]:=",ExpressionUUID->"a48f174d-0b4e-4016-89cb-12950409eed7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pap", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padp", 
       RowBox[{"1", "-", "sigmaap"}]], "+", 
      RowBox[{"batp", " ", 
       SuperscriptBox["patp", 
        RowBox[{"1", "-", "sigmaap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048533952064857`*^9, 
   3.8048533971443033`*^9}, {3.8048538294184713`*^9, 3.8048538335596733`*^9}, 
   3.8048540912601304`*^9},
 CellLabel->
  "In[1672]:=",ExpressionUUID->"d25cd3d4-d9b3-4009-ac7e-4fadd097d429"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pbp", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pbdp", 
       RowBox[{"1", "-", "sigmabp"}]], "+", 
      RowBox[{"bbtp", " ", 
       SuperscriptBox["pbtp", 
        RowBox[{"1", "-", "sigmabp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmabp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.8048538356537657`*^9, 3.804853840279529*^9}, 3.804854093104184*^9, {
   3.804954640509137*^9, 3.804954640509137*^9}, 3.8050199537057533`*^9, 
   3.805020008092595*^9, 3.8050206310766573`*^9, 3.8050206707245793`*^9},
 CellLabel->
  "In[1673]:=",ExpressionUUID->"32ef4bb7-8042-4bd0-bd2d-98b82f2e0275"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pfp", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pfdp", 
       RowBox[{"1", "-", "sigmafp"}]], "+", 
      RowBox[{"bftp", " ", 
       SuperscriptBox["pftp", 
        RowBox[{"1", "-", "sigmafp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmafp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.8048538356537657`*^9, 3.804853840279529*^9}, 3.804854093104184*^9, {
   3.804954640509137*^9, 3.804954640509137*^9}, 3.8050199537057533`*^9, 
   3.805020008092595*^9, 3.8050206310766573`*^9, 3.8050206707245793`*^9, {
   3.805020734720484*^9, 3.8050207497491813`*^9}},
 CellLabel->
  "In[1674]:=",ExpressionUUID->"08466a49-25b4-495a-aed9-6e7b567f6770"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pop", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["podp", 
       RowBox[{"1", "-", "sigmaop"}]], "+", 
      RowBox[{"botp", " ", 
       SuperscriptBox["potp", 
        RowBox[{"1", "-", "sigmaop"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaop"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.8048538356537657`*^9, 3.804853840279529*^9}, 3.804854093104184*^9, {
   3.804954640509137*^9, 3.804954640509137*^9}, 3.8050199537057533`*^9, 
   3.805020008092595*^9, 3.8050206310766573`*^9, 3.8050206707245793`*^9, {
   3.8050207543196583`*^9, 3.8050207705410624`*^9}},
 CellLabel->
  "In[1675]:=",ExpressionUUID->"4534289d-cc08-4831-a2b9-f2744c2fce2a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P1p", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pyp", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bsp", " ", 
       SuperscriptBox["Psp", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bap", " ", 
       SuperscriptBox["Pap", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bop", " ", 
       SuperscriptBox["Pop", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bnp", " ", 
       SuperscriptBox["pntp", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048534322140846`*^9, 
   3.8048534358553085`*^9}, {3.8048536992339973`*^9, 3.8048537091388454`*^9}, 
   3.8048540746935024`*^9, {3.805019969866063*^9, 3.805020008092595*^9}, {
   3.8050201228437223`*^9, 3.8050201313295197`*^9}, {3.805020781011525*^9, 
   3.805020802171235*^9}, {3.805640379370714*^9, 3.805640384222707*^9}, {
   3.80727748582003*^9, 3.8072774878576155`*^9}, {3.813997520258972*^9, 
   3.8139975266309323`*^9}},
 CellLabel->
  "In[1676]:=",ExpressionUUID->"f0685b32-fed0-4748-827d-4b13ae9f2b4c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P2p", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", " ", 
     RowBox[{
      SuperscriptBox["Pbp", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bfp", " ", 
       SuperscriptBox["Pfp", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.8139975291909213`*^9, 3.813997542893591*^9}, 
   3.813997964917837*^9},
 CellLabel->
  "In[1677]:=",ExpressionUUID->"666f492e-57b8-4ad9-9d7c-03dd39cfe112"],

Cell[TextData[StyleBox["Equilibrium equations",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.825287925387567*^9, 
  3.8252879296669016`*^9}},ExpressionUUID->"b2546a53-d4ee-4a9e-b3a4-\
5655bc44c153"],

Cell["\<\
Total supply (landings) of wild caught = exports + consumer demand \
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800413034212*^9}, 3.799855091636346*^9, {
   3.799884003726459*^9, 3.7998840232612796`*^9}, {3.800099320730234*^9, 
   3.800099324730491*^9}, {3.804344834713479*^9, 3.8043448352639103`*^9}, 
   3.813998789608014*^9, 
   3.825287936724382*^9},ExpressionUUID->"a73e3fe0-db97-486d-b715-\
1d3b31d8449a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E1", "=", 
   RowBox[{
    RowBox[{"qydcap", "-", 
     RowBox[{"aydu", " ", 
      SuperscriptBox["pydu", 
       RowBox[{"-", "eydu"}]]}]}], "\[Equal]", 
    RowBox[{"qydue0", "+", 
     RowBox[{"ku1", " ", 
      SuperscriptBox["P1u", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Pyu", 
       RowBox[{"sigmayu", "-", "betau"}]], " ", 
      SuperscriptBox["pydu", 
       RowBox[{"-", "sigmayu"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.804854416639573*^9, 3.8048544212964177`*^9}, {
   3.8048603517476826`*^9, 3.8048603524352975`*^9}, {3.804954429938881*^9, 
   3.804954429938881*^9}, {3.8049544667270565`*^9, 3.8049544667270565`*^9}, 
   3.8050172287448063`*^9, 3.8050183281629877`*^9, {3.805018387688871*^9, 
   3.8050183990668306`*^9}, 3.805018972205937*^9, 3.805019614650261*^9, 
   3.805019969866063*^9, {3.8050202419412766`*^9, 3.8050202419412766`*^9}, 
   3.805020609852163*^9, 3.8072787145424056`*^9, {3.8072790806023884`*^9, 
   3.807279089690464*^9}, 3.8072798240237083`*^9, 3.8139975580513916`*^9, 
   3.813997977303482*^9},
 CellLabel->
  "In[1678]:=",ExpressionUUID->"7054bfa1-6724-4536-94f8-428722fa9818"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E2", "=", 
   RowBox[{
    RowBox[{"qsdcap", "-", 
     RowBox[{"asdu", " ", 
      SuperscriptBox["psdu", 
       RowBox[{"-", "esdu"}]]}]}], "\[Equal]", 
    RowBox[{"qsdue0", "+", 
     RowBox[{"ku1", " ", "bsu", " ", 
      SuperscriptBox["P1u", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Psu", 
       RowBox[{"sigmasu", "-", "betau"}]], " ", 
      SuperscriptBox["psdu", 
       RowBox[{"-", "sigmasu"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541255705385`*^9, 3.8048541651264515`*^9}, {
   3.8048544272849865`*^9, 3.8048544302820015`*^9}, {3.8048546142370343`*^9, 
   3.804854615080909*^9}, {3.8048603568579025`*^9, 3.804860357420493*^9}, {
   3.8048606311455*^9, 3.804860631911248*^9}, {3.8049544890767255`*^9, 
   3.804954510247425*^9}, 3.80501724212201*^9, 3.805018338258299*^9, {
   3.805018413272153*^9, 3.8050184291651025`*^9}, 3.8050189849580746`*^9, 
   3.8050196452420464`*^9, 3.805019802540661*^9, 3.8050199843542175`*^9, 
   3.8050201228437223`*^9, {3.805020269508397*^9, 3.805020269508397*^9}, 
   3.8050206231222305`*^9, 3.8072791275989757`*^9, 3.8072798211784925`*^9, 
   3.8139975610116916`*^9, 3.813997979469166*^9},
 CellLabel->
  "In[1679]:=",ExpressionUUID->"8d9a5d54-6195-4864-9379-ebaa47dda552"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E3", "=", 
   RowBox[{
    RowBox[{"qadcap", "-", 
     RowBox[{"aadu", " ", 
      SuperscriptBox["padu", 
       RowBox[{"-", "eadu"}]]}]}], "\[Equal]", 
    RowBox[{"qadue0", "+", 
     RowBox[{"ku1", " ", "bau", " ", 
      SuperscriptBox["P1u", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Pau", 
       RowBox[{"sigmaau", "-", "betau"}]], " ", 
      SuperscriptBox["padu", 
       RowBox[{"-", "sigmaau"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541278209124`*^9, 3.804854127961561*^9}, {
   3.804854173974129*^9, 3.8048542013069344`*^9}, {3.8048544347821636`*^9, 
   3.804854437822094*^9}, {3.8048546184876595`*^9, 3.804854619268606*^9}, {
   3.804860360530382*^9, 3.804860361030465*^9}, {3.8048606435537367`*^9, 
   3.8048606448664465`*^9}, 3.8072791564484367`*^9, 3.8072798186385145`*^9, 
   3.813997563020435*^9, 3.813997981084421*^9},
 CellLabel->
  "In[1680]:=",ExpressionUUID->"b0114ba0-c557-4d16-ae5b-21ff20f003b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E4", "=", 
   RowBox[{
    RowBox[{"qbdcap", "-", 
     RowBox[{"abdu", " ", 
      SuperscriptBox["pbdu", 
       RowBox[{"-", "ebdu"}]]}]}], "\[Equal]", 
    RowBox[{"qbdue0", "+", 
     RowBox[{"ku2", " ", 
      SuperscriptBox["P2u", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Pbu", 
       RowBox[{"sigmabu", "-", "betau"}]], " ", 
      SuperscriptBox["pbdu", 
       RowBox[{"-", "sigmabu"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541303369503`*^9, 3.8048541304619713`*^9}, {
   3.8048542078548927`*^9, 3.8048542473983154`*^9}, {3.8048544408381042`*^9, 
   3.8048544472919245`*^9}, {3.8048546221752834`*^9, 
   3.8048546230035305`*^9}, {3.804860163075424*^9, 3.804860163434861*^9}, {
   3.804860364468531*^9, 3.8048603661250505`*^9}, {3.8048606546180067`*^9, 
   3.8048606554618917`*^9}, {3.8049546267265406`*^9, 3.804954640509137*^9}, 
   3.8050172630966716`*^9, 3.805018360214622*^9, {3.805018443417308*^9, 
   3.8050184579051275`*^9}, 3.8050194297527933`*^9, 3.805019684785465*^9, 
   3.805019812682934*^9, 3.805020008092595*^9, 3.8050201313295197`*^9, {
   3.8050202878564696`*^9, 3.8050202878564696`*^9}, 3.8050206310766573`*^9, 
   3.807279568965589*^9, 3.8072798155761304`*^9, 3.813997567215698*^9, 
   3.8139976770684676`*^9, 3.8139979831520343`*^9},
 CellLabel->
  "In[1681]:=",ExpressionUUID->"b96827f8-268f-402a-b86f-72a53198ccf1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E5", "=", 
   RowBox[{
    RowBox[{"qfdcap", "-", 
     RowBox[{"afdu", " ", 
      SuperscriptBox["pfdu", 
       RowBox[{"-", "efdu"}]]}]}], "\[Equal]", 
    RowBox[{"qfdue0", "+", 
     RowBox[{"ku2", " ", "bfu", " ", 
      SuperscriptBox["P2u", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Pfu", 
       RowBox[{"sigmafu", "-", "betau"}]], " ", 
      SuperscriptBox["pfdu", 
       RowBox[{"-", "sigmafu"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541303369503`*^9, 3.8048541304619713`*^9}, {
   3.8048542078548927`*^9, 3.8048542473983154`*^9}, {3.8048544408381042`*^9, 
   3.8048544472919245`*^9}, {3.8048546221752834`*^9, 
   3.8048546230035305`*^9}, {3.804860163075424*^9, 3.804860163434861*^9}, {
   3.804860364468531*^9, 3.8048603661250505`*^9}, {3.8048606546180067`*^9, 
   3.8048606554618917`*^9}, {3.8049546267265406`*^9, 3.804954640509137*^9}, 
   3.8050172630966716`*^9, 3.805018360214622*^9, {3.805018443417308*^9, 
   3.8050184579051275`*^9}, 3.8050194297527933`*^9, 3.805019684785465*^9, 
   3.805019812682934*^9, 3.805020008092595*^9, 3.8050201313295197`*^9, {
   3.8050202878564696`*^9, 3.8050202878564696`*^9}, 3.8050206310766573`*^9, {
   3.805020861123869*^9, 3.805020912948207*^9}, 3.807279607336462*^9, 
   3.807279812562784*^9, 3.813997569420418*^9, 3.813997985180611*^9},
 CellLabel->
  "In[1682]:=",ExpressionUUID->"0968519c-053b-4dae-becf-1dda4af898b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E6", "=", 
   RowBox[{
    RowBox[{"qodcap", "-", 
     RowBox[{"aodu", " ", 
      SuperscriptBox["podu", 
       RowBox[{"-", "eodu"}]]}]}], "\[Equal]", 
    RowBox[{"qodue0", "+", 
     RowBox[{"ku1", " ", "bou", " ", 
      SuperscriptBox["P1u", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Pou", 
       RowBox[{"sigmaou", "-", "betau"}]], " ", 
      SuperscriptBox["podu", 
       RowBox[{"-", "sigmaou"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541303369503`*^9, 3.8048541304619713`*^9}, {
   3.8048542078548927`*^9, 3.8048542473983154`*^9}, {3.8048544408381042`*^9, 
   3.8048544472919245`*^9}, {3.8048546221752834`*^9, 
   3.8048546230035305`*^9}, {3.804860163075424*^9, 3.804860163434861*^9}, {
   3.804860364468531*^9, 3.8048603661250505`*^9}, {3.8048606546180067`*^9, 
   3.8048606554618917`*^9}, {3.8049546267265406`*^9, 3.804954640509137*^9}, 
   3.8050172630966716`*^9, 3.805018360214622*^9, {3.805018443417308*^9, 
   3.8050184579051275`*^9}, 3.8050194297527933`*^9, 3.805019684785465*^9, 
   3.805019812682934*^9, 3.805020008092595*^9, 3.8050201313295197`*^9, {
   3.8050202878564696`*^9, 3.8050202878564696`*^9}, 3.8050206310766573`*^9, {
   3.8050208652351437`*^9, 3.8050208655164404`*^9}, {3.8050209307173986`*^9, 
   3.8050209595502567`*^9}, 3.8072796357595897`*^9, 3.807279809599477*^9, 
   3.8139975708185043`*^9, 3.813997988164937*^9},
 CellLabel->
  "In[1683]:=",ExpressionUUID->"c2996b52-8c55-4eee-9698-15dc1c36aea2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E19", "=", 
   RowBox[{
    RowBox[{"qndcap", "-", 
     RowBox[{"andu", " ", 
      SuperscriptBox["pndu", 
       RowBox[{"-", "endu"}]]}]}], "\[Equal]", 
    RowBox[{"qndue0", "+", 
     RowBox[{"ku1", " ", "bnu", " ", 
      SuperscriptBox["P1u", 
       RowBox[{"etau", "+", "betau"}]], 
      SuperscriptBox["Pnu", 
       RowBox[{"sigmanu", "-", "betau"}]], " ", 
      SuperscriptBox["pndu", 
       RowBox[{"-", "sigmanu"}]]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80311071699988*^9, 3.803110828843034*^9}, 
   3.8031136321951523`*^9, {3.803114133058365*^9, 3.8031141367052436`*^9}, {
   3.803114182974989*^9, 3.8031141867099032`*^9}, {3.8031255933312693`*^9, 
   3.803125596914029*^9}, {3.8043448596348677`*^9, 3.804344934149843*^9}, {
   3.8045457780792418`*^9, 3.8045457785951977`*^9}, {3.8048539531658134`*^9, 
   3.804854061206873*^9}, {3.8048541303369503`*^9, 3.8048541304619713`*^9}, {
   3.8048542078548927`*^9, 3.8048542473983154`*^9}, {3.8048544408381042`*^9, 
   3.8048544472919245`*^9}, {3.8048546221752834`*^9, 
   3.8048546230035305`*^9}, {3.804860163075424*^9, 3.804860163434861*^9}, {
   3.804860364468531*^9, 3.8048603661250505`*^9}, {3.8048606546180067`*^9, 
   3.8048606554618917`*^9}, {3.8049546267265406`*^9, 3.804954640509137*^9}, 
   3.8050172630966716`*^9, 3.805018360214622*^9, {3.805018443417308*^9, 
   3.8050184579051275`*^9}, 3.8050194297527933`*^9, 3.805019684785465*^9, 
   3.805019812682934*^9, 3.805020008092595*^9, 3.8050201313295197`*^9, {
   3.8050202878564696`*^9, 3.8050202878564696`*^9}, 3.8050206310766573`*^9, {
   3.8050208652351437`*^9, 3.8050208655164404`*^9}, {3.8050209307173986`*^9, 
   3.8050209595502567`*^9}, {3.8056403963743753`*^9, 3.8056404515265226`*^9}, 
   3.8072775786563034`*^9, 3.807279803120435*^9, 3.813997572344691*^9, 
   3.813997989927307*^9},
 CellLabel->
  "In[1684]:=",ExpressionUUID->"5a095dd6-2bc6-48a6-afb7-e9e725444647"],

Cell["\<\
Supply of imported unprocessed product = Demand for imported unprocessed \
product\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.7998012380597954`*^9}, {3.804854223408702*^9, 
  3.804854223455584*^9}, {3.80485425494967*^9, 3.8048542550121794`*^9}, {
  3.804854289806265*^9, 3.8048542955259604`*^9}, {3.8048543266944003`*^9, 
  3.804854326803794*^9}},ExpressionUUID->"f2222292-c02a-4dff-bfb0-\
5253e658f6aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E7", "=", 
   RowBox[{
    RowBox[{"qylu0", "+", 
     RowBox[{"reply", " ", "qyiu0"}]}], "\[Equal]", 
    RowBox[{"ku1", " ", "bytu", " ", 
     SuperscriptBox["P1u", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Pyu", 
      RowBox[{"sigmayu", "-", "betau"}]], "  ", 
     SuperscriptBox["pytu", 
      RowBox[{"-", "sigmayu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854469219143*^9}, {3.8049544299545083`*^9, 
   3.8049544299545083`*^9}, 3.8050175725759478`*^9, 3.8050176841894617`*^9, {
   3.805019603210904*^9, 3.805019614650261*^9}, 3.805020254318351*^9, {
   3.8050209691455855`*^9, 3.805020969286234*^9}, {3.8056380321600294`*^9, 
   3.8056380324725823`*^9}, 3.8139975810094376`*^9, 3.8139979932248764`*^9},
 CellLabel->
  "In[1685]:=",ExpressionUUID->"791f993f-332f-45c9-b74d-5610bfc47b08"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E8", "=", 
   RowBox[{
    RowBox[{"qslu0", "+", 
     RowBox[{"repls", " ", "qsiu0"}]}], "\[Equal]", 
    RowBox[{"ku1", " ", "bstu", " ", "bsu", " ", 
     SuperscriptBox["P1u", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Psu", 
      RowBox[{"sigmasu", "-", "betau"}]], "  ", 
     SuperscriptBox["pstu", 
      RowBox[{"-", "sigmasu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.8048545129788523`*^9}, {3.804860514608667*^9, 
   3.8048605154838066`*^9}, {3.8049544890767255`*^9, 3.8049544890767255`*^9}, 
   3.805017589247558*^9, 3.8050176968766108`*^9, {3.805019635926775*^9, 
   3.8050196452420464`*^9}, 3.805019802540661*^9, 3.805020277728525*^9, {
   3.8050209719898124`*^9, 3.805020972114833*^9}, {3.805638036066558*^9, 
   3.805638036240765*^9}, 3.8139975841008453`*^9, 3.813997994997254*^9},
 CellLabel->
  "In[1686]:=",ExpressionUUID->"e0970f00-5295-4a08-929a-eb9fdaf290f2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E9", "=", 
   RowBox[{
    RowBox[{"qalu0", "+", 
     RowBox[{"repla", " ", "qaiu0"}]}], "\[Equal]", 
    RowBox[{"ku1", " ", "batu", " ", "bau", " ", 
     SuperscriptBox["P1u", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Pau", 
      RowBox[{"sigmaau", "-", "betau"}]], "  ", 
     SuperscriptBox["patu", 
      RowBox[{"-", "sigmaau"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854535651602*^9}, {3.804860518781827*^9, 
   3.8048605197034464`*^9}, {3.805020974568369*^9, 3.8050209747090178`*^9}, {
   3.8056380391773567`*^9, 3.805638039489907*^9}, 3.8139975864546766`*^9, 
   3.8139979963953424`*^9},
 CellLabel->
  "In[1687]:=",ExpressionUUID->"ff7b668f-42fc-496d-9711-68ef3214bd65"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E10", "=", 
   RowBox[{
    RowBox[{"qblu0", "+", 
     RowBox[{"replb", " ", "qbiu0"}]}], "\[Equal]", 
    RowBox[{"ku2", " ", "bbtu", " ", 
     SuperscriptBox["P2u", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Pbu", 
      RowBox[{"sigmabu", "-", "betau"}]], "  ", 
     SuperscriptBox["pbtu", 
      RowBox[{"-", "sigmabu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854492241708*^9}, {3.8048545380175877`*^9, 
   3.8048545527071533`*^9}, {3.8048605221100817`*^9, 
   3.8048605232990365`*^9}, {3.8049546267265406`*^9, 3.8049546267265406`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805019670771908*^9, 
   3.805019684785465*^9}, 3.8050198126985607`*^9, 3.8050202964360323`*^9, {
   3.805020977131299*^9, 3.8050209774125957`*^9}, {3.805638042536155*^9, 
   3.8056380426924305`*^9}, 3.813997592175129*^9, 3.813997672154642*^9, {
   3.8139979981487093`*^9, 3.8139979994176955`*^9}},
 CellLabel->
  "In[1688]:=",ExpressionUUID->"d16e2950-660f-43e2-895a-44af17fb0b6a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E11", "=", 
   RowBox[{
    RowBox[{"qflu0", "+", 
     RowBox[{"replf", " ", "qfiu0"}]}], "\[Equal]", 
    RowBox[{"ku2", " ", "bftu", " ", "bfu", " ", 
     SuperscriptBox["P2u", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Pfu", 
      RowBox[{"sigmafu", "-", "betau"}]], "  ", 
     SuperscriptBox["pftu", 
      RowBox[{"-", "sigmafu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854492241708*^9}, {3.8048545380175877`*^9, 
   3.8048545527071533`*^9}, {3.8048605221100817`*^9, 
   3.8048605232990365`*^9}, {3.8049546267265406`*^9, 3.8049546267265406`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805019670771908*^9, 
   3.805019684785465*^9}, 3.8050198126985607`*^9, 3.8050202964360323`*^9, {
   3.805020977131299*^9, 3.805021024420715*^9}, {3.8056380458491983`*^9, 
   3.805638046021101*^9}, 3.813997593937498*^9, 3.813998002815343*^9},
 CellLabel->
  "In[1689]:=",ExpressionUUID->"cfe54ccf-0db7-4801-88fa-6007d3fcd471"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E12", "=", 
   RowBox[{
    RowBox[{"qolu0", "+", 
     RowBox[{"replo", " ", "qoiu0"}]}], "\[Equal]", 
    RowBox[{"ku1", " ", "botu", " ", "bou", " ", 
     SuperscriptBox["P1u", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Pou", 
      RowBox[{"sigmaou", "-", "betau"}]], "  ", 
     SuperscriptBox["potu", 
      RowBox[{"-", "sigmaou"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854492241708*^9}, {3.8048545380175877`*^9, 
   3.8048545527071533`*^9}, {3.8048605221100817`*^9, 
   3.8048605232990365`*^9}, {3.8049546267265406`*^9, 3.8049546267265406`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805019670771908*^9, 
   3.805019684785465*^9}, 3.8050198126985607`*^9, 3.8050202964360323`*^9, {
   3.805020977131299*^9, 3.805020990602307*^9}, {3.805021027311825*^9, 
   3.8050210469393115`*^9}, {3.8056380485550127`*^9, 3.8056380493363886`*^9}, 
   3.813997595818968*^9, 3.813998005316287*^9},
 CellLabel->
  "In[1690]:=",ExpressionUUID->"63d14fc8-2bcf-4006-bdcb-7b8b710e0c35"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E20", "=", 
   RowBox[{
    RowBox[{"qnlu0", "+", 
     RowBox[{"repln", " ", "qniu0"}]}], "\[Equal]", 
    RowBox[{"ku1", " ", "bntu", " ", "bnu", " ", 
     SuperscriptBox["P1u", 
      RowBox[{"etau", "+", "betau"}]], 
     SuperscriptBox["Pnu", 
      RowBox[{"sigmanu", "-", "betau"}]], "  ", 
     SuperscriptBox["pntu", 
      RowBox[{"-", "sigmanu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031134953565693`*^9, 3.8031135488052015`*^9}, 
   3.803113641968768*^9, 3.8031186962845826`*^9, {3.804344959120267*^9, 
   3.8043450068043685`*^9}, {3.8048542235337224`*^9, 
   3.8048542235337224`*^9}, {3.8048542550903163`*^9, 
   3.8048542551059437`*^9}, {3.804854333180173*^9, 3.804854367327508*^9}, {
   3.8048544625607567`*^9, 3.804854492241708*^9}, {3.8048545380175877`*^9, 
   3.8048545527071533`*^9}, {3.8048605221100817`*^9, 
   3.8048605232990365`*^9}, {3.8049546267265406`*^9, 3.8049546267265406`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805019670771908*^9, 
   3.805019684785465*^9}, 3.8050198126985607`*^9, 3.8050202964360323`*^9, {
   3.805020977131299*^9, 3.805020990602307*^9}, {3.805021027311825*^9, 
   3.8050210469393115`*^9}, {3.8056380485550127`*^9, 
   3.8056380493363886`*^9}, {3.805640454417622*^9, 3.8056404752987947`*^9}, 
   3.8139975973441525`*^9, 3.813998006744401*^9},
 CellLabel->
  "In[1691]:=",ExpressionUUID->"5d990e3e-9816-4f52-bc72-4ce73d582557"],

Cell["\<\
Supply of imported processed product = Demand for imported processed product\
\>", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.7998012380597954`*^9}, {3.799884418200181*^9, 
  3.799884420684106*^9}, {3.8048542235337224`*^9, 3.8048542235649776`*^9}, {
  3.8048542551059437`*^9, 3.804854255152827*^9}, {3.8048543063260717`*^9, 
  3.804854311392005*^9}, {3.8048546319736*^9, 
  3.8048546323799095`*^9}},ExpressionUUID->"aee4aa60-9cad-4f3f-8312-\
69ed87061370"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E13", "=", 
   RowBox[{
    RowBox[{"qylp0", "+", 
     RowBox[{"reply", " ", "qyip0"}]}], "\[Equal]", 
    RowBox[{"kp1", " ", "bytp", " ", 
     SuperscriptBox["P1p", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pyp", 
      RowBox[{"sigmayp", "-", "betap"}]], " ", 
     SuperscriptBox["pytp", 
      RowBox[{"-", "sigmayp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
   3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
   3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
   3.8048546364093094`*^9, 3.8048546757308216`*^9}, {3.8049544667426844`*^9, 
   3.8049544667426844`*^9}, 3.805017636828994*^9, 3.8050199344667687`*^9, 
   3.805019969866063*^9, 3.8050206555502205`*^9, {3.8050210534247737`*^9, 
   3.8050210719588156`*^9}, {3.805638052243109*^9, 3.805638052446267*^9}, 
   3.813997601470366*^9, 3.8139980097477374`*^9},
 CellLabel->
  "In[1692]:=",ExpressionUUID->"dc442f99-2bf6-4cb3-b474-ca34a001692e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E14", "=", 
   RowBox[{
    RowBox[{"qslp0", "+", 
     RowBox[{"repls", " ", "qsip0"}]}], "\[Equal]", 
    RowBox[{"kp1", " ", "bstp", " ", "bsp", " ", 
     SuperscriptBox["P1p", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Psp", 
      RowBox[{"sigmasp", "-", "betap"}]], " ", 
     SuperscriptBox["pstp", 
      RowBox[{"-", "sigmasp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
   3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
   3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
   3.8048546364093094`*^9, 3.8048547075084224`*^9}, {3.804860454860574*^9, 
   3.804860461533553*^9}, {3.804954510247425*^9, 3.804954510247425*^9}, 
   3.805017646330557*^9, 3.805019944046558*^9, 3.8050199843542175`*^9, 
   3.8050201228437223`*^9, 3.8050206633483715`*^9, {3.805021056300256*^9, 
   3.8050210762098417`*^9}, {3.8056380554623804`*^9, 3.8056380555717735`*^9}, 
   3.813997602995551*^9, 3.8139980116272016`*^9},
 CellLabel->
  "In[1693]:=",ExpressionUUID->"8fd0c066-a41d-4bb3-8941-1c1ea14cc382"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E15", "=", 
   RowBox[{
    RowBox[{"qalp0", "+", 
     RowBox[{"repla", " ", "qaip0"}]}], "\[Equal]", 
    RowBox[{"kp1", " ", "batp", " ", "bap", " ", 
     SuperscriptBox["P1p", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pap", 
      RowBox[{"sigmaap", "-", "betap"}]], " ", 
     SuperscriptBox["patp", 
      RowBox[{"-", "sigmaap"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
   3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
   3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
   3.8048546364093094`*^9, 3.804854724823798*^9}, {3.804860465050977*^9, 
   3.804860465769847*^9}, {3.805021058753792*^9, 3.805021058972579*^9}, {
   3.8056380585410113`*^9, 3.805638058884816*^9}, 3.813997606147007*^9, 
   3.813998013055315*^9},
 CellLabel->
  "In[1694]:=",ExpressionUUID->"97c8f4b3-e25d-4002-9d3d-bf446eb05265"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E16", "=", 
   RowBox[{
    RowBox[{"qblp0", "+", 
     RowBox[{"replb", " ", "qbip0"}]}], "\[Equal]", 
    RowBox[{"kp2", " ", "bbtp", " ", 
     SuperscriptBox["P2p", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pbp", 
      RowBox[{"sigmabp", "-", "betap"}]], " ", 
     SuperscriptBox["pbtp", 
      RowBox[{"-", "sigmabp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
   3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
   3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
   3.8048546364093094`*^9, 3.804854691797214*^9}, {3.804854727667985*^9, 
   3.8048547417515974`*^9}, {3.804860470270588*^9, 3.8048604712707496`*^9}, {
   3.804954640509137*^9, 3.804954640524764*^9}, 3.8050176541599693`*^9, 
   3.8050199537057533`*^9, 3.8050200081082225`*^9, 3.805020131345148*^9, 
   3.8050206707245793`*^9, {3.805021060755541*^9, 3.8050210902671776`*^9}, {
   3.8056380617710304`*^9, 3.8056380622641325`*^9}, 3.813997608047485*^9, 
   3.8139976583839197`*^9, {3.813998014630539*^9, 3.813998019169072*^9}},
 CellLabel->
  "In[1695]:=",ExpressionUUID->"0940c008-f167-45b0-8f67-f75f70a7d4aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E17", "=", 
   RowBox[{
    RowBox[{"qflp0", "+", 
     RowBox[{"replf", " ", "qfip0"}]}], "\[Equal]", 
    RowBox[{"kp2", " ", "bftp", " ", "bfp", " ", 
     SuperscriptBox["P2p", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pfp", 
      RowBox[{"sigmafp", "-", "betap"}]], " ", 
     SuperscriptBox["pftp", 
      RowBox[{"-", "sigmafp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
   3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
   3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
   3.8048546364093094`*^9, 3.8048546757308216`*^9}, {3.8049544667426844`*^9, 
   3.8049544667426844`*^9}, 3.805017636828994*^9, 3.8050199344667687`*^9, 
   3.805019969866063*^9, 3.8050206555502205`*^9, {3.8050210534247737`*^9, 
   3.8050210719588156`*^9}, {3.805021114427477*^9, 3.8050211350415163`*^9}, {
   3.8056380697113733`*^9, 3.805638069878157*^9}, {3.8072797775995708`*^9, 
   3.807279778435221*^9}, 3.8139976099379535`*^9, 3.8139980213757896`*^9},
 CellLabel->
  "In[1696]:=",ExpressionUUID->"4a6d51bc-ab93-4cda-be00-59be19085ebe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E18", "=", 
   RowBox[{
    RowBox[{"qolp0", "+", 
     RowBox[{"replo", " ", "qoip0"}]}], "\[Equal]", 
    RowBox[{"kp1", " ", "botp", " ", "bop", " ", 
     SuperscriptBox["P1p", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pop", 
      RowBox[{"sigmaop", "-", "betap"}]], " ", 
     SuperscriptBox["potp", 
      RowBox[{"-", "sigmaop"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
   3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
   3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
   3.8048546364093094`*^9, 3.8048546757308216`*^9}, {3.8049544667426844`*^9, 
   3.8049544667426844`*^9}, 3.805017636828994*^9, 3.8050199344667687`*^9, 
   3.805019969866063*^9, 3.8050206555502205`*^9, {3.8050210534247737`*^9, 
   3.8050210719588156`*^9}, {3.8050211188813486`*^9, 
   3.8050211455120215`*^9}, {3.805638072172863*^9, 3.8056380723393145`*^9}, {
   3.8072797931166477`*^9, 3.8072797937361326`*^9}, 3.813997611680314*^9, 
   3.8139980240138445`*^9},
 CellLabel->
  "In[1697]:=",ExpressionUUID->"0f1f16ba-f3a9-433f-bc3f-db13778a6b2c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"E21", "=", 
   RowBox[{
    RowBox[{"qnlp0", "+", 
     RowBox[{"repln", " ", "qnip0"}]}], "\[Equal]", 
    RowBox[{"kp1", " ", "bnp", "  ", 
     SuperscriptBox["P1p", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["pntp", 
      RowBox[{"-", "betap"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8031137088798847`*^9, 3.8031137515072517`*^9}, {
   3.8043450314895763`*^9, 3.804345065522052*^9}, {3.8048542235806046`*^9, 
   3.8048542235806046`*^9}, {3.804854255168454*^9, 3.804854255168454*^9}, {
   3.8048546364093094`*^9, 3.8048546757308216`*^9}, {3.8049544667426844`*^9, 
   3.8049544667426844`*^9}, 3.805017636828994*^9, 3.8050199344667687`*^9, 
   3.805019969866063*^9, 3.8050206555502205`*^9, {3.8050210534247737`*^9, 
   3.8050210719588156`*^9}, {3.8050211188813486`*^9, 
   3.8050211455120215`*^9}, {3.805638072172863*^9, 3.8056380723393145`*^9}, {
   3.8056404842109137`*^9, 3.805640510334753*^9}, {3.8072776295809946`*^9, 
   3.807277634898158*^9}, {3.8072797678920155`*^9, 3.80727978960091*^9}, 
   3.813997613729143*^9, 3.8139980258452682`*^9},
 CellLabel->
  "In[1698]:=",ExpressionUUID->"4ee84eba-03d6-4839-abf7-1d5dedd77b46"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "E1", ",", "E2", ",", "E3", ",", " ", "E4", ",", " ", "E5", ",", " ", 
     "E6", ",", "E7", ",", "E8", ",", "E9", ",", "E10", ",", "E11", ",", 
     "E12", ",", " ", "E13", ",", " ", "E14", ",", " ", "E15", ",", " ", 
     "E16", ",", " ", "E17", ",", " ", "E18", ",", "E19", ",", "E20", ",", 
     "E21"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pydu", ",", "pydu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pytu", ",", "pytu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"psdu", ",", "psdu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pstu", ",", "pstu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"padu", ",", "padu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"patu", ",", "patu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pbdu", ",", "pbdu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pbtu", ",", "pbtu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pytp", ",", "pytp0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pstp", ",", "pstp0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"patp", ",", "patp0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pbtp", ",", "pbtp0"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"pfdu", ",", "pfdu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pftu", ",", "pftu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pftp", ",", "pftp0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"podu", ",", "podu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"potu", ",", "potu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"potp", ",", "potp0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pndu", ",", "pndu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pntu", ",", "pntu0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pntp", ",", "pntp0"}], "}"}], ",", 
   RowBox[{"AccuracyGoal", "\[Rule]", "7"}], ",", " ", 
   RowBox[{"PrecisionGoal", "\[Rule]", "7"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799801050741409*^9, 3.7998010802456255`*^9}, {
   3.799801592828159*^9, 3.799801634478999*^9}, {3.7998017203390927`*^9, 
   3.799801763344025*^9}, 3.7998021088038597`*^9, {3.799855159502365*^9, 
   3.799855165706504*^9}, {3.801692496821689*^9, 3.801692518577862*^9}, {
   3.801780123825697*^9, 3.8017801628874054`*^9}, {3.80178020897694*^9, 
   3.8017802303410735`*^9}, {3.804345075920143*^9, 3.8043451100366836`*^9}, {
   3.8048547484844165`*^9, 3.8048549152697835`*^9}, {3.8050178536701374`*^9, 
   3.805017872704455*^9}, {3.8050180911664543`*^9, 3.805018113403982*^9}, {
   3.8050182696893077`*^9, 3.8050182855042944`*^9}, {3.8050202419569035`*^9, 
   3.8050202964360323`*^9}, {3.8050206555502205`*^9, 
   3.8050206707245793`*^9}, {3.8050211495951157`*^9, 
   3.8050212640550547`*^9}, {3.805640520045041*^9, 3.8056405549869733`*^9}, 
   3.8056410453683844`*^9, {3.807279663398108*^9, 3.80727974305568*^9}, {
   3.807280690468972*^9, 3.807280724761815*^9}, {3.8072858337385387`*^9, 
   3.8072858466256275`*^9}, {3.807286985290553*^9, 3.807286985820998*^9}, {
   3.807287043933196*^9, 3.8072870639978137`*^9}, {3.807306171035367*^9, 
   3.8073061878224363`*^9}, {3.807306519442914*^9, 3.807306530173261*^9}, {
   3.813999279049034*^9, 3.813999281922268*^9}, {3.814026435812806*^9, 
   3.8140264769188128`*^9}, {3.815477824207671*^9, 3.8154778370848036`*^9}},
 CellLabel->
  "In[1699]:=",ExpressionUUID->"6340c5ef-1fdf-4a1b-8913-8de97b421861"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"pydu", "\[Rule]", "6.168142262847031`"}], ",", 
   RowBox[{"pytu", "\[Rule]", "6.527004274382824`"}], ",", 
   RowBox[{"psdu", "\[Rule]", "1.5280030856837585`"}], ",", 
   RowBox[{"pstu", "\[Rule]", "5.997903679119734`"}], ",", 
   RowBox[{"padu", "\[Rule]", "3.5299794282461034`"}], ",", 
   RowBox[{"patu", "\[Rule]", "6.336433477286378`"}], ",", 
   RowBox[{"pbdu", "\[Rule]", "9.437434312440114`"}], ",", 
   RowBox[{"pbtu", "\[Rule]", "8.353974514213736`"}], ",", 
   RowBox[{"pytp", "\[Rule]", "8.640099032299927`"}], ",", 
   RowBox[{"pstp", "\[Rule]", "4.954054705583637`"}], ",", 
   RowBox[{"patp", "\[Rule]", "6.697470608137142`"}], ",", 
   RowBox[{"pbtp", "\[Rule]", "9.890758720988554`"}], ",", 
   RowBox[{"pfdu", "\[Rule]", "13.116760219521101`"}], ",", 
   RowBox[{"pftu", "\[Rule]", "27.2299307247436`"}], ",", 
   RowBox[{"pftp", "\[Rule]", "16.504714938947007`"}], ",", 
   RowBox[{"podu", "\[Rule]", "2.2730451308005883`"}], ",", 
   RowBox[{"potu", "\[Rule]", "6.2982340997963835`"}], ",", 
   RowBox[{"potp", "\[Rule]", "9.045160985589884`"}], ",", 
   RowBox[{"pndu", "\[Rule]", "0.8036731628078742`"}], ",", 
   RowBox[{"pntu", "\[Rule]", "3.446701784605092`"}], ",", 
   RowBox[{"pntp", "\[Rule]", "6.289960120612147`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8072800367833257`*^9, 3.8072801831342497`*^9, 3.8072802173018456`*^9, {
   3.807280700370719*^9, 3.807280725951782*^9}, 3.8072857755421414`*^9, 
   3.8072858387844887`*^9, 3.8072861035375357`*^9, {3.8072870142500906`*^9, 
   3.8072870650586376`*^9}, 3.80728755114637*^9, 3.8072875872714868`*^9, {
   3.8073061812192936`*^9, 3.807306190812764*^9}, 3.8073064875931287`*^9, {
   3.807306531193055*^9, 3.8073065364821725`*^9}, 3.807307069647044*^9, 
   3.807308205129673*^9, 3.807309224121013*^9, 3.8078829522542696`*^9, 
   3.807884096669301*^9, 3.8078849043923273`*^9, 3.810047120911561*^9, 
   3.81004727426057*^9, 3.8100473665261745`*^9, 3.811071102706309*^9, 
   3.8124706051141872`*^9, 3.8124709285014157`*^9, 3.812471178965461*^9, 
   3.8124715402184105`*^9, 3.812736061499569*^9, 3.812821587779987*^9, 
   3.8129696293628445`*^9, 3.8129703960683813`*^9, 3.8129711117078657`*^9, 
   3.8129761564788246`*^9, 3.8129765398646464`*^9, 3.8139963136146135`*^9, 
   3.81399691388297*^9, 3.813997836944935*^9, 3.8139985415187187`*^9, 
   3.81399894933836*^9, 3.813999240751273*^9, 3.813999287110306*^9, 
   3.813999705317072*^9, 3.8140263814665003`*^9, 3.814026702425369*^9, 
   3.814026906115943*^9, 3.8140270777545624`*^9, 3.814830301855589*^9, 
   3.81547748353337*^9, 3.8154777889674683`*^9, 3.815477841257365*^9, 
   3.81547815649687*^9, 3.8154786048922825`*^9, 3.8157753851633725`*^9, 
   3.817033446501229*^9, 3.8170334786883698`*^9, 3.818801077806342*^9, 
   3.825416604307741*^9},
 CellLabel->
  "Out[1699]=",ExpressionUUID->"5b6dbb66-7a0c-4475-8df5-c300c0adb493"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pydu1", " ", "=", " ", 
   RowBox[{"pydu", "/.", "%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549276482487`*^9}, {3.8050202419725313`*^9, 3.8050202419725313`*^9}},
 CellLabel->
  "In[1700]:=",ExpressionUUID->"946f9cfe-6f47-48dd-8266-de1998056519"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pytu1", " ", "=", " ", 
   RowBox[{"pytu", "/.", "%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549332913156`*^9}, {3.8050202543339787`*^9, 3.8050202543339787`*^9}},
 CellLabel->
  "In[1701]:=",ExpressionUUID->"43559586-6a2c-42e9-a31e-8d54a991c323"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pytp1", " ", "=", " ", 
   RowBox[{"pytp", "/.", "%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.80485493651056*^9}, {3.8050206555502205`*^9, 3.805020655565849*^9}},
 CellLabel->
  "In[1702]:=",ExpressionUUID->"fe6319c4-183f-4cb1-8921-13252519ec27"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psdu1", " ", "=", " ", 
   RowBox[{"psdu", "/.", "%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549495621114`*^9}, {3.804854982786557*^9, 3.804854983239752*^9}, {
  3.8050202695240245`*^9, 3.8050202695240245`*^9}},
 CellLabel->
  "In[1703]:=",ExpressionUUID->"9dc9d079-0605-42cf-9fae-d970b8bf9b15"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pstu1", " ", "=", " ", 
   RowBox[{"pstu", "/.", "%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549504059906`*^9}, {3.8048549864902515`*^9, 3.804854986960324*^9}, {
  3.805020277728525*^9, 3.805020277744152*^9}},
 CellLabel->
  "In[1704]:=",ExpressionUUID->"52280ee1-ca06-46e2-8fd2-1ee3bf86a7bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pstp1", " ", "=", " ", 
   RowBox[{"pstp", "/.", "%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.8048549519374757`*^9}, {3.8048549888981214`*^9, 3.804854989429453*^9}, {
  3.8050206633639984`*^9, 3.8050206633639984`*^9}},
 CellLabel->
  "In[1705]:=",ExpressionUUID->"16577354-fa8c-4ba9-a552-6e3f71acfce3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"padu1", " ", "=", " ", 
   RowBox[{"padu", "/.", "%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549948209057`*^9}},
 CellLabel->
  "In[1706]:=",ExpressionUUID->"d8dba8ef-0920-4505-bdb4-adc27f532b87"],

Cell[BoxData[
 RowBox[{
  RowBox[{"patu1", " ", "=", " ", 
   RowBox[{"patu", "/.", "%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549332913156`*^9}, {3.8048549687687798`*^9, 3.8048549977743783`*^9}},
 CellLabel->
  "In[1707]:=",ExpressionUUID->"bd09eadf-153e-4b02-a931-f9871574b095"],

Cell[BoxData[
 RowBox[{
  RowBox[{"patp1", " ", "=", " ", 
   RowBox[{"patp", "/.", "%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.80485493651056*^9}, {3.804854969784561*^9, 3.8048550007148633`*^9}},
 CellLabel->
  "In[1708]:=",ExpressionUUID->"dbbea929-f638-498e-b75b-52c8fc05722d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pbdu1", " ", "=", " ", 
   RowBox[{"pbdu", "/.", "%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549276482487`*^9}, {3.804854975285405*^9, 3.804855007481864*^9}, {
  3.805020287872097*^9, 3.805020287872097*^9}},
 CellLabel->
  "In[1709]:=",ExpressionUUID->"ec51b3fd-7e7d-4c61-9972-2d851b2142ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pbtu1", " ", "=", " ", 
   RowBox[{"pbtu", "/.", "%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549332913156`*^9}, {3.804854976394951*^9, 3.8048549767231264`*^9}, {
  3.8048550098412547`*^9, 3.804855011638406*^9}, {3.80502029645166*^9, 
  3.80502029645166*^9}},
 CellLabel->
  "In[1710]:=",ExpressionUUID->"2d72f4c8-4704-4135-89b4-ae65638945c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pbtp1", " ", "=", " ", 
   RowBox[{"pbtp", "/.", "%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.80485493651056*^9}, {3.804854977160694*^9, 3.804854978739061*^9}, {
  3.8048550132320137`*^9, 3.8048550149197726`*^9}, {3.8050206707402067`*^9, 
  3.8050206707402067`*^9}},
 CellLabel->
  "In[1711]:=",ExpressionUUID->"e4ae86d0-0ecf-4d01-9a43-638ff4316501"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pfdu1", " ", "=", " ", 
   RowBox[{"pfdu", "/.", "%%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549276482487`*^9}, {3.804854975285405*^9, 3.804855007481864*^9}, {
  3.805020287872097*^9, 3.805020287872097*^9}, {3.805021283198599*^9, 
  3.805021290567246*^9}},
 CellLabel->
  "In[1712]:=",ExpressionUUID->"363b0dc2-9fe4-4ac6-8270-075099442dc1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pftu1", " ", "=", " ", 
   RowBox[{"pftu", "/.", "%%%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549332913156`*^9}, {3.804854976394951*^9, 3.8048549767231264`*^9}, {
  3.8048550098412547`*^9, 3.804855011638406*^9}, {3.80502029645166*^9, 
  3.80502029645166*^9}, {3.805021293223941*^9, 3.8050212992860556`*^9}},
 CellLabel->
  "In[1713]:=",ExpressionUUID->"f468faf8-f8bd-4c10-ac7a-f2bb158e1dcd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pftp1", " ", "=", " ", 
   RowBox[{"pftp", "/.", "%%%%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.80485493651056*^9}, {3.804854977160694*^9, 3.804854978739061*^9}, {
  3.8048550132320137`*^9, 3.8048550149197726`*^9}, {3.8050206707402067`*^9, 
  3.8050206707402067`*^9}, {3.8050213014895496`*^9, 3.805021306836628*^9}},
 CellLabel->
  "In[1714]:=",ExpressionUUID->"cea7b54e-c772-47bd-897d-57c5f521d92a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"podu1", " ", "=", " ", 
   RowBox[{"podu", "/.", "%%%%%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549276482487`*^9}, {3.804854975285405*^9, 3.804855007481864*^9}, {
  3.805020287872097*^9, 3.805020287872097*^9}, {3.805021309212026*^9, 
  3.805021316136299*^9}},
 CellLabel->
  "In[1715]:=",ExpressionUUID->"ed362b77-6bc1-4448-880e-83a403e1ad8b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"potu1", " ", "=", " ", 
   RowBox[{"potu", "/.", "%%%%%%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549332913156`*^9}, {3.804854976394951*^9, 3.8048549767231264`*^9}, {
  3.8048550098412547`*^9, 3.804855011638406*^9}, {3.80502029645166*^9, 
  3.80502029645166*^9}, {3.8050213184023037`*^9, 3.805021324747714*^9}},
 CellLabel->
  "In[1716]:=",ExpressionUUID->"2d3ae847-e6b2-47f7-9486-932bdc12b0a0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"potp1", " ", "=", " ", 
   RowBox[{"potp", "/.", "%%%%%%%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.80485493651056*^9}, {3.804854977160694*^9, 3.804854978739061*^9}, {
  3.8048550132320137`*^9, 3.8048550149197726`*^9}, {3.8050206707402067`*^9, 
  3.8050206707402067`*^9}, {3.8050213273106437`*^9, 3.8050213333107805`*^9}},
 CellLabel->
  "In[1717]:=",ExpressionUUID->"693b0175-b716-4b97-b073-d664939f0ede"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pndu1", " ", "=", " ", 
   RowBox[{"pndu", "/.", "%%%%%%%%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485317827997`*^9, 3.7998485378585787`*^9}, {
  3.8043451144961543`*^9, 3.804345117815737*^9}, {3.8048549258198433`*^9, 
  3.8048549276482487`*^9}, {3.804854975285405*^9, 3.804855007481864*^9}, {
  3.805020287872097*^9, 3.805020287872097*^9}, {3.805021309212026*^9, 
  3.805021316136299*^9}, {3.8056405718719873`*^9, 3.805640587754229*^9}},
 CellLabel->
  "In[1718]:=",ExpressionUUID->"891700e6-5502-4e18-85da-fb1626e937b3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pntu1", " ", "=", " ", 
   RowBox[{"pntu", "/.", "%%%%%%%%%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485404215107`*^9, 3.7998485501542273`*^9}, {
  3.8043451216767387`*^9, 3.804345124639048*^9}, {3.804854930742814*^9, 
  3.8048549332913156`*^9}, {3.804854976394951*^9, 3.8048549767231264`*^9}, {
  3.8048550098412547`*^9, 3.804855011638406*^9}, {3.80502029645166*^9, 
  3.80502029645166*^9}, {3.8050213184023037`*^9, 3.805021324747714*^9}, {
  3.8056405767167215`*^9, 3.8056405918693995`*^9}},
 CellLabel->
  "In[1719]:=",ExpressionUUID->"70ea8773-9cf2-413c-82f5-942bb4cd6084"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pntp1", " ", "=", " ", 
   RowBox[{"pntp", "/.", "%%%%%%%%%%%%%%%%%%%%%"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7998485533422656`*^9, 3.7998485589528217`*^9}, {
  3.8043451288243003`*^9, 3.80434513282141*^9}, {3.804854935182231*^9, 
  3.80485493651056*^9}, {3.804854977160694*^9, 3.804854978739061*^9}, {
  3.8048550132320137`*^9, 3.8048550149197726`*^9}, {3.8050206707402067`*^9, 
  3.8050206707402067`*^9}, {3.8050213273106437`*^9, 3.8050213333107805`*^9}, {
  3.8056405810780835`*^9, 3.805640595561248*^9}},
 CellLabel->
  "In[1720]:=",ExpressionUUID->"001d8a12-b4b4-44d8-9731-59bdec8b5ca0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pyu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pydu1", 
       RowBox[{"1", "-", "sigmayu"}]], "+", 
      RowBox[{"bytu", " ", 
       SuperscriptBox["pytu1", 
        RowBox[{"1", "-", "sigmayu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmayu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048537407717743`*^9, 3.804853751697942*^9}, {
   3.804858232034235*^9, 3.8048582371444397`*^9}, {3.8049544299701357`*^9, 
   3.8049544299701357`*^9}, {3.805019603210904*^9, 3.805019614650261*^9}, {
   3.8050202419725313`*^9, 3.8050202543339787`*^9}},
 CellLabel->
  "In[1721]:=",ExpressionUUID->"827b48b7-cd55-4505-a89a-8bea05d601f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdu1", 
       RowBox[{"1", "-", "sigmasu"}]], "+", 
      RowBox[{"bstu", " ", 
       SuperscriptBox["pstu1", 
        RowBox[{"1", "-", "sigmasu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.804853754104593*^9, 
   3.8048537632655916`*^9}, {3.8048582389728565`*^9, 
   3.8048582512496104`*^9}, {3.8049544890922947`*^9, 
   3.8049544890922947`*^9}, {3.805019635926775*^9, 3.8050196452420464`*^9}, {
   3.805020269539652*^9, 3.805020277744152*^9}},
 CellLabel->
  "In[1722]:=",ExpressionUUID->"10e0a844-12f0-4717-ae97-7bb0e70d876c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pau1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padu1", 
       RowBox[{"1", "-", "sigmaau"}]], "+", 
      RowBox[{"batu", " ", 
       SuperscriptBox["patu1", 
        RowBox[{"1", "-", "sigmaau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048537655159597`*^9, 
   3.8048537724008365`*^9}, {3.804858241066943*^9, 3.804858253249933*^9}},
 CellLabel->
  "In[1723]:=",ExpressionUUID->"88b75a07-2f21-4492-b2d3-ed45dee10998"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pbu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pbdu1", 
       RowBox[{"1", "-", "sigmabu"}]], "+", 
      RowBox[{"bbtu", " ", 
       SuperscriptBox["pbtu1", 
        RowBox[{"1", "-", "sigmabu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmabu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}, {
   3.804858242871995*^9, 3.8048582551252365`*^9}, {3.8049546267265406`*^9, 
   3.8049546267265406`*^9}, {3.805019670771908*^9, 3.805019684785465*^9}, {
   3.805020287872097*^9, 3.80502029645166*^9}},
 CellLabel->
  "In[1724]:=",ExpressionUUID->"36baead3-72a4-46ae-9e7b-357bd3170f22"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pfu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pfdu1", 
       RowBox[{"1", "-", "sigmafu"}]], "+", 
      RowBox[{"bftu", " ", 
       SuperscriptBox["pftu1", 
        RowBox[{"1", "-", "sigmafu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmafu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}, {
   3.804858242871995*^9, 3.8048582551252365`*^9}, {3.8049546267265406`*^9, 
   3.8049546267265406`*^9}, {3.805019670771908*^9, 3.805019684785465*^9}, {
   3.805020287872097*^9, 3.80502029645166*^9}, {3.8050213870187244`*^9, 
   3.8050214029147677`*^9}},
 CellLabel->
  "In[1725]:=",ExpressionUUID->"0571bbc8-e10f-4994-b3a9-b9907a4032d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pou1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["podu1", 
       RowBox[{"1", "-", "sigmaou"}]], "+", 
      RowBox[{"botu", " ", 
       SuperscriptBox["potu1", 
        RowBox[{"1", "-", "sigmaou"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaou"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}, {
   3.804858242871995*^9, 3.8048582551252365`*^9}, {3.8049546267265406`*^9, 
   3.8049546267265406`*^9}, {3.805019670771908*^9, 3.805019684785465*^9}, {
   3.805020287872097*^9, 3.80502029645166*^9}, {3.8050214048541455`*^9, 
   3.8050214206570406`*^9}},
 CellLabel->
  "In[1726]:=",ExpressionUUID->"25c9e9ad-6c6b-4a6e-badf-d81bcb918d0d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pnu1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pndu1", 
       RowBox[{"1", "-", "sigmanu"}]], "+", 
      RowBox[{"bntu", " ", 
       SuperscriptBox["pntu1", 
        RowBox[{"1", "-", "sigmanu"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmanu"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048537753460503`*^9, 3.804853783378973*^9}, {
   3.804858242871995*^9, 3.8048582551252365`*^9}, {3.8049546267265406`*^9, 
   3.8049546267265406`*^9}, {3.805019670771908*^9, 3.805019684785465*^9}, {
   3.805020287872097*^9, 3.80502029645166*^9}, {3.8050214048541455`*^9, 
   3.8050214206570406`*^9}, {3.805640618572982*^9, 3.8056406327008715`*^9}},
 CellLabel->
  "In[1727]:=",ExpressionUUID->"393bc706-f2d6-4c09-8627-1d1a4ef1aa2b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P1u1", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pyu1", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bsu", " ", 
       SuperscriptBox["Psu1", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bau", " ", 
       SuperscriptBox["Pau1", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bou", " ", 
       SuperscriptBox["Pou1", 
        RowBox[{"1", "-", "betau"}]]}], "+", 
      RowBox[{"bnu", " ", 
       SuperscriptBox["Pnu1", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048536729130955`*^9, 
   3.804853693916567*^9}, {3.804858258172606*^9, 3.804858267559837*^9}, 
   3.805019614650261*^9, 3.8050196452420464`*^9, 3.805019684785465*^9, {
   3.8050198025562887`*^9, 3.8050198126985607`*^9}, {3.8050214303144875`*^9, 
   3.8050214551064477`*^9}, {3.8056406364927936`*^9, 
   3.8056406441226745`*^9}, {3.8139977026754065`*^9, 3.8139977075542045`*^9}},
 CellLabel->
  "In[1728]:=",ExpressionUUID->"2cf42da1-537d-47cf-a868-6ac8425005fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P2u1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", " ", 
     RowBox[{
      SuperscriptBox["Pbu1", 
       RowBox[{"1", "-", "betau"}]], "+", 
      RowBox[{"bfu", " ", 
       SuperscriptBox["Pfu1", 
        RowBox[{"1", "-", "betau"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betau"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.8139977100871744`*^9, 3.813997731223633*^9}},
 CellLabel->
  "In[1729]:=",ExpressionUUID->"4ee6446c-deec-472a-a7f0-b874c8cab3a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pyp1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pydp1", 
       RowBox[{"1", "-", "sigmayp"}]], "+", 
      RowBox[{"bytp", " ", 
       SuperscriptBox["pytp1", 
        RowBox[{"1", "-", "sigmayp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmayp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, {3.8048528703729815`*^9, 
   3.8048528968638077`*^9}, {3.8048533855138645`*^9, 3.804853387764236*^9}, {
   3.804853813462556*^9, 3.804853819838611*^9}, 3.8048540877282963`*^9, {
   3.804858269903962*^9, 3.804858273639639*^9}, {3.8049544667426844`*^9, 
   3.8049544667426844`*^9}, 3.8050199344667687`*^9, 3.805019969881691*^9, 
   3.805020609852163*^9, 3.805020655565849*^9},
 CellLabel->
  "In[1730]:=",ExpressionUUID->"6968501f-a00f-4eb4-b7de-e4b7523cd5a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psp1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["psdp1", 
       RowBox[{"1", "-", "sigmasp"}]], "+", 
      RowBox[{"bstp", " ", 
       SuperscriptBox["pstp1", 
        RowBox[{"1", "-", "sigmasp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmasp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529340478163`*^9, 3.8048529473629103`*^9}, {3.8048533906588616`*^9, 
   3.804853392674816*^9}, {3.8048538223073983`*^9, 3.8048538261666756`*^9}, 
   3.8048540893066835`*^9, {3.8048582767495184`*^9, 3.8048582802344575`*^9}, {
   3.804954510247425*^9, 3.804954510247425*^9}, 3.805019944046558*^9, 
   3.8050199843542175`*^9, 3.8050206231222305`*^9, 3.8050206633639984`*^9},
 CellLabel->
  "In[1731]:=",ExpressionUUID->"50b2217b-a0f5-4ef2-a665-089b684d852b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pap1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["padp1", 
       RowBox[{"1", "-", "sigmaap"}]], "+", 
      RowBox[{"batp", " ", 
       SuperscriptBox["patp1", 
        RowBox[{"1", "-", "sigmaap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048533952064857`*^9, 
   3.8048533971443033`*^9}, {3.8048538294184713`*^9, 3.8048538335596733`*^9}, 
   3.8048540912601304`*^9, {3.804858282906767*^9, 3.8048582862510543`*^9}},
 CellLabel->
  "In[1732]:=",ExpressionUUID->"ca99b36d-0784-4f5c-abb4-899421699bbc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pbp1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pbdp1", 
       RowBox[{"1", "-", "sigmabp"}]], "+", 
      RowBox[{"bbtp", " ", 
       SuperscriptBox["pbtp1", 
        RowBox[{"1", "-", "sigmabp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmabp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.8048538356537657`*^9, 3.804853840279529*^9}, 3.804854093104184*^9, {
   3.8048582887367105`*^9, 3.8048582922681465`*^9}, {3.804954640524764*^9, 
   3.804954640524764*^9}, 3.8050199537057533`*^9, 3.8050200081082225`*^9, 
   3.805020631092285*^9, 3.8050206707402067`*^9},
 CellLabel->
  "In[1733]:=",ExpressionUUID->"cd104c3f-d515-420d-85d0-6d5fe0acf9eb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pfp1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["pfdp1", 
       RowBox[{"1", "-", "sigmafp"}]], "+", 
      RowBox[{"bftp", " ", 
       SuperscriptBox["pftp1", 
        RowBox[{"1", "-", "sigmafp"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmafp"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.8048538356537657`*^9, 3.804853840279529*^9}, 3.804854093104184*^9, {
   3.8048582887367105`*^9, 3.8048582922681465`*^9}, {3.804954640524764*^9, 
   3.804954640524764*^9}, 3.8050199537057533`*^9, 3.8050200081082225`*^9, 
   3.805020631092285*^9, 3.8050206707402067`*^9, {3.805021467544857*^9, 
   3.805021480687713*^9}},
 CellLabel->
  "In[1734]:=",ExpressionUUID->"b91acc9e-d0f7-4343-901b-85eb5f9b4f67"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pop1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["podp1", 
       RowBox[{"1", "-", "sigmaop"}]], "+", 
      RowBox[{"botp", " ", 
       SuperscriptBox["potp1", 
        RowBox[{"1", "-", "sigmaop"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "sigmaop"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799795696092383*^9, 3.7997957663947954`*^9}, {
   3.7997970130203295`*^9, 3.799797015989379*^9}, {3.799799457483681*^9, 
   3.799799466116406*^9}, {3.8006357748995314`*^9, 3.8006357789459352`*^9}, 
   3.801665262463134*^9, 3.801778509000703*^9, 3.8031140435947456`*^9, {
   3.804344480623844*^9, 3.80434450518996*^9}, 3.8048528703729815`*^9, {
   3.8048529736827435`*^9, 3.804852985120942*^9}, {3.8048530220830803`*^9, 
   3.80485303991685*^9}, {3.8048533991915193`*^9, 3.804853403349728*^9}, {
   3.8048538356537657`*^9, 3.804853840279529*^9}, 3.804854093104184*^9, {
   3.8048582887367105`*^9, 3.8048582922681465`*^9}, {3.804954640524764*^9, 
   3.804954640524764*^9}, 3.8050199537057533`*^9, 3.8050200081082225`*^9, 
   3.805020631092285*^9, 3.8050206707402067`*^9, {3.80502148262545*^9, 
   3.8050215032861767`*^9}},
 CellLabel->
  "In[1735]:=",ExpressionUUID->"f6513031-5cad-4928-be8c-84291667fb4f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P1p1", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pyp1", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bsp", " ", 
       SuperscriptBox["Psp1", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bap", " ", 
       SuperscriptBox["Pap1", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bop", " ", 
       SuperscriptBox["Pop1", 
        RowBox[{"1", "-", "betap"}]]}], "+", 
      RowBox[{"bnp", " ", 
       SuperscriptBox["pntp1", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997956493407707`*^9, 3.799795693591977*^9}, {
   3.7997958259222507`*^9, 3.7997958691564445`*^9}, {3.7998824950462866`*^9, 
   3.7998825043579335`*^9}, {3.8006360216422567`*^9, 3.800636023723892*^9}, 
   3.8006362338215733`*^9, 3.800647328042477*^9, {3.8006473681776924`*^9, 
   3.800647368421081*^9}, 3.8017784795273743`*^9, 3.803114005629777*^9, {
   3.8048533088039646`*^9, 3.8048533491396923`*^9}, {3.8048534322140846`*^9, 
   3.8048534358553085`*^9}, {3.8048536992339973`*^9, 3.8048537091388454`*^9}, 
   3.8048540746935024`*^9, {3.8048582965623837`*^9, 3.8048583071734004`*^9}, {
   3.805019969881691*^9, 3.8050200081082225`*^9}, {3.8050201228437223`*^9, 
   3.805020131345148*^9}, {3.805021510756152*^9, 3.8050215301499543`*^9}, {
   3.805640668944806*^9, 3.805640674181842*^9}, {3.807280019631976*^9, 
   3.807280025332411*^9}, {3.813997735586028*^9, 3.8139977404237933`*^9}},
 CellLabel->
  "In[1736]:=",ExpressionUUID->"cf3a49b1-b3f6-48a3-98f1-2b28e692992d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P2p1", " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Pbp1", 
       RowBox[{"1", "-", "betap"}]], "+", 
      RowBox[{"bfp", " ", 
       SuperscriptBox["Pfp1", 
        RowBox[{"1", "-", "betap"}]]}]}], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", "betap"}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.813997745313599*^9, 3.813997759096328*^9}},
 CellLabel->
  "In[1737]:=",ExpressionUUID->"9d2e5d99-8e49-4609-836e-375792498d54"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pydp1", " ", "=", " ", 
   RowBox[{"Pyu1", " ", 
    FractionBox["pydp0", "Pyu0"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.814026118622264*^9, 3.814026136844446*^9}, {
  3.8140264929472895`*^9, 3.8140264934186563`*^9}, {3.8140265962707243`*^9, 
  3.8140265985545034`*^9}, {3.8140266858424597`*^9, 3.8140266897314835`*^9}},
 CellLabel->
  "In[1738]:=",ExpressionUUID->"06d36353-dfc7-4d1c-8143-aa54104266a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psdp1", " ", "=", " ", 
   RowBox[{"Psu1", " ", 
    FractionBox["psdp0", "Psu0"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.814026268039674*^9, 3.814026283925037*^9}, {
  3.814026603095039*^9, 3.814026608026879*^9}, {3.8140266908543615`*^9, 
  3.814026692224427*^9}},
 CellLabel->
  "In[1739]:=",ExpressionUUID->"9f53e977-679b-4ef3-9e59-bf6aa0ba9873"],

Cell[BoxData[
 RowBox[{
  RowBox[{"padp1", " ", "=", " ", 
   RowBox[{"Pau1", " ", 
    FractionBox["padp0", "Pau0"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8140263004404187`*^9, 3.8140263128430786`*^9}, {
  3.8140266120259933`*^9, 3.814026616869763*^9}, {3.814026693375322*^9, 
  3.814026696023386*^9}},
 CellLabel->
  "In[1740]:=",ExpressionUUID->"dae049e8-3b29-4344-a004-4d713b364504"],

Cell[BoxData[
 RowBox[{
  RowBox[{"podp1", " ", "=", " ", 
   RowBox[{"Pou1", " ", 
    FractionBox["podp0", "Pou0"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8140263233512583`*^9, 3.81402633627732*^9}, {
  3.8140266218726587`*^9, 3.8140266303592615`*^9}, {3.814026694566248*^9, 
  3.8140266970481825`*^9}},
 CellLabel->
  "In[1741]:=",ExpressionUUID->"211d406d-7e71-4e2b-bd2c-464cd41305c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pbdp1", " ", "=", " ", 
   RowBox[{"Pbu1", " ", 
    FractionBox["pbdp0", "Pbu0"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.814026118622264*^9, 3.814026136844446*^9}, {
  3.8140264929472895`*^9, 3.8140264934186563`*^9}, {3.8140265962707243`*^9, 
  3.8140265985545034`*^9}, {3.8140266858424597`*^9, 3.8140266897314835`*^9}, {
  3.815477736130605*^9, 3.815477741412733*^9}},
 CellLabel->
  "In[1742]:=",ExpressionUUID->"166ed68f-39a4-4ea5-874e-b306310def3d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pfdp1", " ", "=", " ", 
   RowBox[{"Pfu1", " ", 
    FractionBox["pfdp0", "Pfu0"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.814026118622264*^9, 3.814026136844446*^9}, {
  3.8140264929472895`*^9, 3.8140264934186563`*^9}, {3.8140265962707243`*^9, 
  3.8140265985545034`*^9}, {3.8140266858424597`*^9, 3.8140266897314835`*^9}, {
  3.815477744100678*^9, 3.8154777495390763`*^9}},
 CellLabel->
  "In[1743]:=",ExpressionUUID->"5e05c1c6-59cc-451a-bbbe-4e3cc433f17f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qydu1", "=", 
   RowBox[{"qydcap", "-", 
    RowBox[{"aydu", " ", 
     SuperscriptBox["pydu1", 
      RowBox[{"-", "eydu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
   3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
   3.804858318066416*^9}, 3.805017228776061*^9, 3.805018328178615*^9, 
   3.805018972205937*^9, 3.805020241988159*^9, {3.8050215414955635`*^9, 
   3.8050215416205845`*^9}, 3.8072787145594187`*^9},
 CellLabel->
  "In[1744]:=",ExpressionUUID->"da2c9595-e3fc-4efc-8340-7fcfa41ee32f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qytu1", " ", "=", " ", 
   RowBox[{"qylu0", "+", 
    RowBox[{"reply", " ", "qyiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, 3.8050175725759478`*^9, 3.8050176841894617`*^9, {
   3.8050215471852226`*^9, 3.8050215473414974`*^9}, {3.805638131820239*^9, 
   3.8056381321796722`*^9}},
 CellLabel->
  "In[1745]:=",ExpressionUUID->"968cd914-3f2c-4fc0-8be1-87db76fa5032"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qytp1", "=", 
   RowBox[{"qylp0", "+", 
    RowBox[{"reply", " ", "qyip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
   3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
   3.8048583295083256`*^9}, 3.805017636828994*^9, {3.805021561592044*^9, 
   3.805021564471135*^9}, {3.805638135757964*^9, 3.8056381359142394`*^9}},
 CellLabel->
  "In[1746]:=",ExpressionUUID->"5d201a59-15f3-4a9f-b1d9-6ab7b8e60249"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qydp1", " ", "=", " ", 
   RowBox[{"qydpe0", "+", 
    RowBox[{"kp1", " ", 
     SuperscriptBox["P1p1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pyp1", 
      RowBox[{"sigmayp", "-", "betap"}]], " ", 
     SuperscriptBox["pydp1", 
      RowBox[{"-", "sigmayp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
   3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
   3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
   3.804858331686155*^9, 3.8048583574115205`*^9}, {3.8049544667426844`*^9, 
   3.8049544667426844`*^9}, 3.8050183990668306`*^9, 3.805019969881691*^9, 
   3.805020609852163*^9, {3.8050215822396755`*^9, 3.8050215825991087`*^9}, 
   3.813997763842023*^9, 3.8139980830127764`*^9},
 CellLabel->
  "In[1747]:=",ExpressionUUID->"c5d80009-058b-43b9-95a0-97be06ff345a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qsdu1", "=", 
   RowBox[{"qsdcap", "-", 
    RowBox[{"asdu", " ", 
     SuperscriptBox["psdu1", 
      RowBox[{"-", "esdu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
   3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
   3.804858318066416*^9}, {3.8048583709925175`*^9, 3.8048583807603416`*^9}, 
   3.80501724212201*^9, 3.805018338258299*^9, 3.8050189849580746`*^9, 
   3.805020269539652*^9, {3.805021595591544*^9, 3.805021596091627*^9}},
 CellLabel->
  "In[1748]:=",ExpressionUUID->"3e642ed7-8a2a-4a7c-84b1-61256cf803c8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qstu1", " ", "=", " ", 
   RowBox[{"qslu0", "+", 
    RowBox[{"repls", " ", "qsiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, {3.804858383088846*^9, 3.804858391482087*^9}, 
   3.805017589247558*^9, 3.8050176939254065`*^9, {3.8050216031396575`*^9, 
   3.8050216036397414`*^9}, {3.8056381411939945`*^9, 3.80563814135027*^9}},
 CellLabel->
  "In[1749]:=",ExpressionUUID->"14ae33cb-8dc4-47b0-bd6d-02367efb45db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qstp1", "=", 
   RowBox[{"qslp0", "+", 
    RowBox[{"repls", " ", "qsip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
   3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
   3.8048583295083256`*^9}, {3.8048583919821677`*^9, 3.8048583929823275`*^9}, 
   3.805017646330557*^9, {3.80502160743724*^9, 3.80502161089093*^9}, {
   3.805638144147893*^9, 3.805638144288541*^9}},
 CellLabel->
  "In[1750]:=",ExpressionUUID->"9653b559-0a51-4e27-a205-737b01a7f79d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qsdp1", " ", "=", " ", 
   RowBox[{"qsdpe0", "+", 
    RowBox[{"kp1", " ", "bsp", " ", 
     SuperscriptBox["P1p1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Psp1", 
      RowBox[{"sigmasp", "-", "betap"}]], " ", 
     SuperscriptBox["psdp1", 
      RowBox[{"-", "sigmasp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
   3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
   3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
   3.804858331686155*^9, 3.8048583574115205`*^9}, {3.8048583936074276`*^9, 
   3.804858404171567*^9}, {3.804860786055422*^9, 3.8048607864617367`*^9}, {
   3.804954510247425*^9, 3.804954510247425*^9}, 3.805018413272153*^9, 
   3.8050199843542175`*^9, 3.8050201228437223`*^9, 3.8050206231378593`*^9, {
   3.805021615341569*^9, 3.805021615904162*^9}, 3.813997769051078*^9, 
   3.8139980886151376`*^9},
 CellLabel->
  "In[1751]:=",ExpressionUUID->"c8f582d1-1442-4d78-8704-4de7307105c1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qadu1", "=", 
   RowBox[{"qadcap", "-", 
    RowBox[{"aadu", " ", 
     SuperscriptBox["padu1", 
      RowBox[{"-", "eadu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
  3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
  3.804858318066416*^9}, {3.804858412220029*^9, 3.804858415017352*^9}},
 CellLabel->
  "In[1752]:=",ExpressionUUID->"f9613ae5-8b16-4e0c-b27c-4a183e59636d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qatu1", " ", "=", " ", 
   RowBox[{"qalu0", "+", 
    RowBox[{"repla", " ", "qaiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
  3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
  3.804858323051596*^9}, {3.8048584155486903`*^9, 3.8048584170020504`*^9}, {
  3.8056381467420683`*^9, 3.8056381472602715`*^9}},
 CellLabel->
  "In[1753]:=",ExpressionUUID->"11243cd2-b796-4e01-8542-850f98f840aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qatp1", "=", 
   RowBox[{"qalp0", "+", 
    RowBox[{"repla", " ", "qaip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
  3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
  3.8048583295083256`*^9}, {3.8048584174083652`*^9, 3.804858418330388*^9}, {
  3.8056381504455824`*^9, 3.8056381505549755`*^9}},
 CellLabel->
  "In[1754]:=",ExpressionUUID->"b63af19c-402b-4a43-8c33-41d4f5396395"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qadp1", " ", "=", " ", 
   RowBox[{"qadpe0", "+", 
    RowBox[{"kp1", " ", "bap", " ", 
     SuperscriptBox["P1p1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pap1", 
      RowBox[{"sigmaap", "-", "betap"}]], " ", 
     SuperscriptBox["padp1", 
      RowBox[{"-", "sigmaap"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
   3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
   3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
   3.804858331686155*^9, 3.8048583574115205`*^9}, {3.804858419221157*^9, 
   3.804858427725051*^9}, {3.8048607895672665`*^9, 3.8048607922437763`*^9}, 
   3.813997771877281*^9, 3.8139980935379696`*^9},
 CellLabel->
  "In[1755]:=",ExpressionUUID->"7ee696d2-f285-433f-80dc-784d4d3d5c14"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qbdu1", "=", 
   RowBox[{"qbdcap", "-", 
    RowBox[{"abdu", " ", 
     SuperscriptBox["pbdu1", 
      RowBox[{"-", "ebdu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
   3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
   3.804858318066416*^9}, {3.8048584341925*^9, 3.804858435911532*^9}, 
   3.8050172582821474`*^9, 3.805018360214622*^9, 3.8050194297527933`*^9, 
   3.805020287872097*^9, {3.8050216372392516`*^9, 3.805021637583057*^9}},
 CellLabel->
  "In[1756]:=",ExpressionUUID->"888e3a2d-d307-4c7b-a13a-f42ecd52ab55"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qbtu1", " ", "=", " ", 
   RowBox[{"qblu0", "+", 
    RowBox[{"replb", " ", "qbiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, {3.804858436286592*^9, 3.8048584368960643`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805021641771245*^9, 
   3.80502164192752*^9}, {3.8056381535739665`*^9, 3.805638153777124*^9}},
 CellLabel->
  "In[1757]:=",ExpressionUUID->"78166c8f-0a9e-4e78-90eb-12cf3e75d5d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qbtp1", "=", 
   RowBox[{"qblp0", "+", 
    RowBox[{"replb", " ", "qbip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
   3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
   3.8048583295083256`*^9}, {3.804858437239869*^9, 3.804858437911852*^9}, 
   3.8050176541599693`*^9, {3.8050216449136066`*^9, 3.805021647273368*^9}, {
   3.8056381566994724`*^9, 3.8056381568244925`*^9}},
 CellLabel->
  "In[1758]:=",ExpressionUUID->"bff7468d-1892-44a1-ab13-c7d9e1e5d3b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qbdp1", " ", "=", " ", 
   RowBox[{"qbdpe0", "+", 
    RowBox[{"kp2", " ", 
     SuperscriptBox["P2p1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pbp1", 
      RowBox[{"sigmabp", "-", "betap"}]], " ", 
     SuperscriptBox["pbdp1", 
      RowBox[{"-", "sigmabp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
   3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
   3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
   3.804858331686155*^9, 3.8048583574115205`*^9}, {3.8048584383181667`*^9, 
   3.804858445621817*^9}, {3.804860795771513*^9, 3.8048607983031683`*^9}, {
   3.804954640524764*^9, 3.804954640524764*^9}, 3.805018457920755*^9, 
   3.8050200081082225`*^9, 3.805020131345148*^9, 3.805020631092285*^9, {
   3.805021650523903*^9, 3.805021650617668*^9}, {3.8139977771934195`*^9, 
   3.813997780293831*^9}, 3.813998102251755*^9},
 CellLabel->
  "In[1759]:=",ExpressionUUID->"e5ee9f38-34c7-48ba-a642-b690f9fd2ef6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qfdu1", "=", 
   RowBox[{"qfdcap", "-", 
    RowBox[{"afdu", " ", 
     SuperscriptBox["pfdu1", 
      RowBox[{"-", "efdu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
   3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
   3.804858318066416*^9}, {3.8048584341925*^9, 3.804858435911532*^9}, 
   3.8050172582821474`*^9, 3.805018360214622*^9, 3.8050194297527933`*^9, 
   3.805020287872097*^9, {3.8050216372392516`*^9, 3.805021637583057*^9}, {
   3.805021668340543*^9, 3.8050216815614605`*^9}},
 CellLabel->
  "In[1760]:=",ExpressionUUID->"9ee139f8-dd61-49ba-9e44-ef070c835f9e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qftu1", " ", "=", " ", 
   RowBox[{"qflu0", "+", 
    RowBox[{"replf", " ", "qfiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, {3.804858436286592*^9, 3.8048584368960643`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805021641771245*^9, 
   3.80502164192752*^9}, {3.8050216824366035`*^9, 3.8050216835617847`*^9}, {
   3.8056381594655485`*^9, 3.8056381596843357`*^9}},
 CellLabel->
  "In[1761]:=",ExpressionUUID->"a3abd642-d5c4-4b76-b2bc-df6d735ad759"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qftp1", "=", 
   RowBox[{"qflp0", "+", 
    RowBox[{"replf", " ", "qfip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
   3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
   3.8048583295083256`*^9}, {3.804858437239869*^9, 3.804858437911852*^9}, 
   3.8050176541599693`*^9, {3.8050216449136066`*^9, 3.805021647273368*^9}, {
   3.8050216840306115`*^9, 3.805021684905758*^9}, {3.80563816318122*^9, 
   3.8056381632782955`*^9}},
 CellLabel->
  "In[1762]:=",ExpressionUUID->"2b79f586-f40a-4ad1-9e25-ed319fec9286"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qfdp1", " ", "=", " ", 
   RowBox[{"qfdpe0", "+", 
    RowBox[{"kp2", " ", "bfp", " ", 
     SuperscriptBox["P2p1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pfp1", 
      RowBox[{"sigmafp", "-", "betap"}]], " ", 
     SuperscriptBox["pfdp1", 
      RowBox[{"-", "sigmafp"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
   3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
   3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
   3.804858331686155*^9, 3.8048583574115205`*^9}, {3.8048584383181667`*^9, 
   3.804858445621817*^9}, {3.804860795771513*^9, 3.8048607983031683`*^9}, {
   3.804954640524764*^9, 3.804954640524764*^9}, 3.805018457920755*^9, 
   3.8050200081082225`*^9, 3.805020131345148*^9, 3.805020631092285*^9, {
   3.805021650523903*^9, 3.805021650617668*^9}, {3.805021685860292*^9, 
   3.8050216989683647`*^9}, 3.813997783181079*^9, 3.813998109212171*^9},
 CellLabel->
  "In[1763]:=",ExpressionUUID->"d1c876fb-bac7-4a69-a62f-408a82bf20b3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qodu1", "=", 
   RowBox[{"qodcap", "-", 
    RowBox[{"aodu", " ", 
     SuperscriptBox["podu1", 
      RowBox[{"-", "eodu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
   3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
   3.804858318066416*^9}, {3.8048584341925*^9, 3.804858435911532*^9}, 
   3.8050172582821474`*^9, 3.805018360214622*^9, 3.8050194297527933`*^9, 
   3.805020287872097*^9, {3.8050216372392516`*^9, 3.805021637583057*^9}, {
   3.8050216997966228`*^9, 3.805021715239889*^9}},
 CellLabel->
  "In[1764]:=",ExpressionUUID->"5663a682-3868-430c-b51e-543109457dcf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qotu1", " ", "=", " ", 
   RowBox[{"qolu0", "+", 
    RowBox[{"replo", " ", "qoiu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, {3.804858436286592*^9, 3.8048584368960643`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805021641771245*^9, 
   3.80502164192752*^9}, {3.805021722397313*^9, 3.805021724006952*^9}, {
   3.8056381660156755`*^9, 3.805638166328226*^9}},
 CellLabel->
  "In[1765]:=",ExpressionUUID->"9e71b931-d617-428a-9a63-c9b1b171e286"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qotp1", "=", 
   RowBox[{"qolp0", "+", 
    RowBox[{"replo", " ", "qoip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
   3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
   3.8048583295083256`*^9}, {3.804858437239869*^9, 3.804858437911852*^9}, 
   3.8050176541599693`*^9, {3.8050216449136066`*^9, 3.805021647273368*^9}, {
   3.805021725788495*^9, 3.8050217265855026`*^9}, {3.805638169362621*^9, 
   3.8056381695657787`*^9}},
 CellLabel->
  "In[1766]:=",ExpressionUUID->"a86a308e-d31b-4462-92c0-2bbe06ed4ed8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qodp1", " ", "=", " ", 
   RowBox[{"qodpe0", "+", 
    RowBox[{"kp1", " ", "bop", " ", 
     SuperscriptBox["P1p1", 
      RowBox[{"etap", "+", "betap"}]], 
     SuperscriptBox["Pop1", 
      RowBox[{"sigmaop", "-", "betap"}]], " ", 
     SuperscriptBox["podp1", 
      RowBox[{"-", "sigmaop"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941975267897`*^9, 3.8033942159701834`*^9}, {
   3.804345251142467*^9, 3.80434527768712*^9}, {3.804854223596233*^9, 
   3.804854223596233*^9}, {3.8048542551840816`*^9, 3.804854255199709*^9}, {
   3.804858331686155*^9, 3.8048583574115205`*^9}, {3.8048584383181667`*^9, 
   3.804858445621817*^9}, {3.804860795771513*^9, 3.8048607983031683`*^9}, {
   3.804954640524764*^9, 3.804954640524764*^9}, 3.805018457920755*^9, 
   3.8050200081082225`*^9, 3.805020131345148*^9, 3.805020631092285*^9, {
   3.805021650523903*^9, 3.805021650617668*^9}, {3.805021727273115*^9, 
   3.8050217388700185`*^9}, 3.8139977892357917`*^9, 3.81399811144691*^9},
 CellLabel->
  "In[1767]:=",ExpressionUUID->"b5432474-f281-45eb-9d5c-d18a453cd9e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qndu1", "=", 
   RowBox[{"qndcap", "-", 
    RowBox[{"andu", " ", 
     SuperscriptBox["pndu1", 
      RowBox[{"-", "endu"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803393997683539*^9, 3.8033940262570944`*^9}, {
   3.8043451883536158`*^9, 3.8043452006311703`*^9}, {3.804858311846034*^9, 
   3.804858318066416*^9}, {3.8048584341925*^9, 3.804858435911532*^9}, 
   3.8050172582821474`*^9, 3.805018360214622*^9, 3.8050194297527933`*^9, 
   3.805020287872097*^9, {3.8050216372392516`*^9, 3.805021637583057*^9}, {
   3.8050216997966228`*^9, 3.805021715239889*^9}, {3.805640684481781*^9, 
   3.805640692436912*^9}},
 CellLabel->
  "In[1768]:=",ExpressionUUID->"662f2a76-02c9-4540-8bca-997f98d98216"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qntu1", " ", "=", " ", 
   RowBox[{"qnlu0", "+", 
    RowBox[{"repln", " ", "qniu0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.803394083100375*^9, 3.803394088429737*^9}, {
   3.8043452137964115`*^9, 3.8043452288211007`*^9}, {3.8048583193478737`*^9, 
   3.804858323051596*^9}, {3.804858436286592*^9, 3.8048584368960643`*^9}, 
   3.805017601515199*^9, 3.805017705706191*^9, {3.805021641771245*^9, 
   3.80502164192752*^9}, {3.805021722397313*^9, 3.805021724006952*^9}, {
   3.8056381660156755`*^9, 3.805638166328226*^9}, {3.8056406942202864`*^9, 
   3.805640700303976*^9}},
 CellLabel->
  "In[1769]:=",ExpressionUUID->"6c412690-e9a1-4070-b320-5ff264b7d718"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qntp1", "=", 
   RowBox[{"qnlp0", "+", 
    RowBox[{"repln", " ", "qnip0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8033941039517093`*^9, 3.8033941078431787`*^9}, {
   3.8043452324939604`*^9, 3.8043452421624794`*^9}, {3.8048583253357763`*^9, 
   3.8048583295083256`*^9}, {3.804858437239869*^9, 3.804858437911852*^9}, 
   3.8050176541599693`*^9, {3.8050216449136066`*^9, 3.805021647273368*^9}, {
   3.805021725788495*^9, 3.8050217265855026`*^9}, {3.805638169362621*^9, 
   3.8056381695657787`*^9}, {3.80564070208635*^9, 3.8056407091758137`*^9}},
 CellLabel->
  "In[1770]:=",ExpressionUUID->"3c62f9d9-0709-4c50-8aa7-ab005e09122d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5. Results",
 FontSize->24]], "Section",
 CellChangeTimes->{{3.7912044888395996`*^9, 3.791204494140644*^9}, {
  3.7916283606052637`*^9, 3.7916283624927197`*^9}, {3.7916287086177945`*^9, 
  3.791628711832301*^9}, {3.795452961580968*^9, 3.7954529786642447`*^9}, {
  3.79545386036082*^9, 3.7954538618860044`*^9}, {3.795525436722562*^9, 
  3.795525448873003*^9}, {3.7998486591642857`*^9, 3.799848659976923*^9}, {
  3.8199004535482035`*^9, 
  3.8199004539735346`*^9}},ExpressionUUID->"f7f455d9-0fe1-41b8-9366-\
995ae7cc18de"],

Cell[TextData[StyleBox["Albacore Tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, {3.804858665201766*^9, 3.804858666686369*^9}, {
   3.805021883590415*^9, 3.8050218860908213`*^9}, 
   3.825287968356987*^9},ExpressionUUID->"0ba7f740-1ccf-4c0a-8976-\
8f2466cded3a"],

Cell["Percent change in price of unprocessed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}, {3.8140275517515464`*^9, 
  3.814027557807259*^9}},ExpressionUUID->"3d66264f-629c-44c5-9dbd-\
5d67f5927cbd"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"padu1", "-", "padu0"}], ")"}], "100"}], "padu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
  3.8048585992018385`*^9}, {3.8048587385491753`*^9, 3.8048587395967627`*^9}},
 CellLabel->
  "In[1771]:=",ExpressionUUID->"2a02d074-8b67-4ef2-97ac-70841c84a99d"],

Cell[BoxData["0.15546682497101025`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.8048588459827404`*^9, 3.8048588890674353`*^9, 
   3.8048596656690836`*^9, 3.804859752041461*^9, 3.80485996621189*^9, 
   3.8048601131836357`*^9, 3.8048603824870806`*^9, 3.804860539504755*^9, 
   3.804860671438266*^9, 3.8048614914695363`*^9, 3.8048659517951965`*^9, 
   3.804866275497053*^9, 3.8048664461030483`*^9, 3.8048672525232573`*^9, 
   3.8048811927855315`*^9, 3.8048952711748304`*^9, 3.8048961505619116`*^9, 
   3.8048969481434*^9, 3.8050220316633987`*^9, 3.8050234712493286`*^9, 
   3.8050236844798255`*^9, 3.8050238491447835`*^9, 3.805025223548292*^9, 
   3.8056381005132513`*^9, 3.805638196540518*^9, 3.805638618680574*^9, 
   3.8056408794150257`*^9, 3.8056410664043665`*^9, 3.8056658292193384`*^9, 
   3.807280221636265*^9, 3.8072857802648163`*^9, 3.8072861083442755`*^9, 
   3.8072875972032175`*^9, 3.807306492070613*^9, 3.8073065489828978`*^9, 
   3.8073070743436794`*^9, 3.807308210021482*^9, 3.807309224921638*^9, 
   3.807882953129416*^9, 3.8078840974506817`*^9, 3.8078849052674675`*^9, 
   3.810047121689164*^9, 3.810047275009151*^9, 3.810047367274755*^9, 
   3.811071103530958*^9, 3.8124706059368315`*^9, 3.8124709293010426`*^9, 
   3.812471179751071*^9, 3.812471541027072*^9, 3.8127360623202076`*^9, 
   3.812821588606629*^9, 3.812969630222353*^9, 3.812970396927928*^9, 
   3.8129711125517592`*^9, 3.8129761573539686`*^9, 3.812976541317942*^9, 
   3.81399631461942*^9, 3.813996914720601*^9, 3.813998562984428*^9, 
   3.8139989501770124`*^9, 3.8139992478127184`*^9, 3.8139997061437144`*^9, 
   3.8140267154745255`*^9, 3.814026907017644*^9, 3.814027078593214*^9, 
   3.814830302866376*^9, 3.8154774846116714`*^9, 3.8154777897488484`*^9, 
   3.8154778516653376`*^9, 3.815478605720546*^9, 3.815775386426358*^9, 
   3.817033447102559*^9, 3.8170334792805796`*^9, 3.8188010784178514`*^9, 
   3.8254166054886866`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1771]=",ExpressionUUID->"4af06576-122d-47b7-9d15-61fe68e44f1e"]
}, Open  ]],

Cell["Percent change in quantity of landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.807308034831148*^9},ExpressionUUID->"0fe098be-b29f-4ce6-bab0-\
f04522167f30"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qadu1", "-", "qadu0"}], ")"}], "100"}], "qadu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.804858781717317*^9, 3.80485878271747*^9}},
 CellLabel->
  "In[1772]:=",ExpressionUUID->"7d4c9a37-f057-46db-b5c4-4cfdb1bc79f0"],

Cell[BoxData["0.7766647765444049`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.8048588461233864`*^9, 3.804858889208082*^9, 
   3.8048596658097377`*^9, 3.8048597521977406`*^9, 3.804859966359081*^9, 
   3.8048601133242846`*^9, 3.804860382643334*^9, 3.8048605396610303`*^9, 
   3.8048606715945415`*^9, 3.804861491578929*^9, 3.8048659519045897`*^9, 
   3.8048662756220727`*^9, 3.804866446228069*^9, 3.804867252632651*^9, 
   3.804881192894924*^9, 3.804895271284257*^9, 3.8048961506713037`*^9, 
   3.8048969482527924`*^9, 3.8050220318665547`*^9, 3.8050234744998317`*^9, 
   3.805023684729825*^9, 3.805023849339243*^9, 3.805025223782708*^9, 
   3.8056381006695275`*^9, 3.8056381966811657`*^9, 3.8056386188524776`*^9, 
   3.8056408796522083`*^9, 3.8056410666928825`*^9, 3.805665829453754*^9, 
   3.8072802217653227`*^9, 3.8072857804729776`*^9, 3.807286108545433*^9, 
   3.807287597380355*^9, 3.807306492265766*^9, 3.8073065491740465`*^9, 
   3.807307074538831*^9, 3.8073082102556653`*^9, 3.8073092250497384`*^9, 
   3.8078829533025913`*^9, 3.8078840977476063`*^9, 3.807884905470626*^9, 
   3.8100471218162994`*^9, 3.810047275218313*^9, 3.8100473674839177`*^9, 
   3.8110711036620617`*^9, 3.81247060611598*^9, 3.8124709295122447`*^9, 
   3.81247117996824*^9, 3.8124715412382083`*^9, 3.8127360624523106`*^9, 
   3.8128215888037815`*^9, 3.812969630472392*^9, 3.8129703971936255`*^9, 
   3.8129711128174276`*^9, 3.8129761575102453`*^9, 3.8129765416617565`*^9, 
   3.813996314830562*^9, 3.813996914919796*^9, 3.81399856314155*^9, 
   3.8139989504131956`*^9, 3.8139992480689173`*^9, 3.81399970639491*^9, 
   3.8140267156326494`*^9, 3.814026907231811*^9, 3.8140270788324003`*^9, 
   3.814830303008487*^9, 3.8154774848617134`*^9, 3.8154777900301447`*^9, 
   3.8154778519154024`*^9, 3.8154786058768215`*^9, 3.815775386693575*^9, 
   3.817033447115569*^9, 3.8170334792935896`*^9, 3.818801078433833*^9, 
   3.825416605747882*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1772]=",ExpressionUUID->"53916a7a-e430-41e6-b331-569482a3f830"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 
  3.80485427153401*^9}},ExpressionUUID->"7de371d5-81f7-476d-9f31-\
0363bd80cce3"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"padp1", "-", "padp0"}], ")"}], "100"}], "padp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
  3.8048586124851284`*^9}, {3.804858740206231*^9, 3.804858741003228*^9}},
 CellLabel->
  "In[1773]:=",ExpressionUUID->"505233e9-3de1-4a29-9d0e-86ea14ae24b7"],

Cell[BoxData["5.695118312692114`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.804858846279661*^9, 3.804858889348729*^9, 
   3.8048596659503913`*^9, 3.804859752338393*^9, 3.80485996649973*^9, 
   3.8048601134805613`*^9, 3.804860382783988*^9, 3.804860539801677*^9, 
   3.8048606717351885`*^9, 3.8048614916726947`*^9, 3.8048659520296097`*^9, 
   3.8048662757314653`*^9, 3.8048664463218336`*^9, 3.8048672527420435`*^9, 
   3.8048811929886894`*^9, 3.80489527139362*^9, 3.804896150780697*^9, 
   3.8048969483621855`*^9, 3.8050220320384564`*^9, 3.8050234777659616`*^9, 
   3.8050236849486156`*^9, 3.805023849490115*^9, 3.8050252239702854`*^9, 
   3.8056381008113737`*^9, 3.8056381968530684`*^9, 3.8056386190712643`*^9, 
   3.805640879907406*^9, 3.8056410669585505`*^9, 3.8056658296413093`*^9, 
   3.807280221893422*^9, 3.8072857806721325`*^9, 3.807286108738584*^9, 
   3.8072875975574927`*^9, 3.807306492438902*^9, 3.8073065493651953`*^9, 
   3.8073070747309804`*^9, 3.8073082104518185`*^9, 3.8073092251608253`*^9, 
   3.807882953458867*^9, 3.8078840979507923`*^9, 3.807884905689041*^9, 
   3.8100471219383574`*^9, 3.81004727542047*^9, 3.8100473676820717`*^9, 
   3.8110711037971687`*^9, 3.8124706062841034`*^9, 3.812470929712364*^9, 
   3.8124711801713977`*^9, 3.8124715414393663`*^9, 3.8127360625784082`*^9, 
   3.8128215889999347`*^9, 3.812969630706804*^9, 3.812970397428028*^9, 
   3.812971113114353*^9, 3.8129761576667943`*^9, 3.8129765420211687`*^9, 
   3.81399631503272*^9, 3.8139969151599417`*^9, 3.8139985632796574`*^9, 
   3.8139989506403723`*^9, 3.813999248297095*^9, 3.8139997066220865`*^9, 
   3.81402671585585*^9, 3.81402690750102*^9, 3.8140270790645804`*^9, 
   3.814830303146596*^9, 3.81547748514301*^9, 3.815477790311442*^9, 
   3.815477852181048*^9, 3.8154786060330973`*^9, 3.8157753870338316`*^9, 
   3.8170334471275787`*^9, 3.8170334793076005`*^9, 3.8188010784488444`*^9, 
   3.8254166059620333`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1773]=",ExpressionUUID->"bf94bd58-d152-4fb4-b1b0-44d2951063e8"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
  3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
  3.804854255481004*^9, 
  3.8048542778511686`*^9}},ExpressionUUID->"8ae1ed5b-0ea8-45f8-946d-\
944ec7d06db1"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qadp1", "-", "qadp0"}], ")"}], "100"}], "qadp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}, {
  3.8048587831862926`*^9, 3.804858783952036*^9}},
 CellLabel->
  "In[1774]:=",ExpressionUUID->"5fd82f32-b684-4fbb-930c-804e026d4a08"],

Cell[BoxData[
 RowBox[{"-", "5.301255644348953`"}]], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.804858846420307*^9, 3.8048588894893756`*^9, 
   3.804859666091045*^9, 3.804859752494673*^9, 3.8048599666403804`*^9, 
   3.8048601136212463`*^9, 3.804860382940258*^9, 3.8048605399579525`*^9, 
   3.804860671907091*^9, 3.8048614917664604`*^9, 3.804865952139002*^9, 
   3.804866275856485*^9, 3.804866446446854*^9, 3.8048672528514366`*^9, 
   3.8048811930980816`*^9, 3.8048952714873867`*^9, 3.8048961508900895`*^9, 
   3.8048969484715776`*^9, 3.8050220322103577`*^9, 3.805023478187902*^9, 
   3.8050236851517644`*^9, 3.8050238496873655`*^9, 3.805025224142146*^9, 
   3.8056381009832764`*^9, 3.8056381971031094`*^9, 3.805638619274424*^9, 
   3.8056408802266517`*^9, 3.8056410672085915`*^9, 3.805665829840061*^9, 
   3.807280222025525*^9, 3.807285780865282*^9, 3.8072861089377403`*^9, 
   3.8072875977296276`*^9, 3.8073064926090345`*^9, 3.807306549559346*^9, 
   3.8073070749631605`*^9, 3.807308210645992*^9, 3.8073092253229523`*^9, 
   3.8078829536308265`*^9, 3.8078840981539326`*^9, 3.8078849058921986`*^9, 
   3.8100471221074886`*^9, 3.8100472756326375`*^9, 3.810047367885229*^9, 
   3.811071103971305*^9, 3.8124706064562387`*^9, 3.8124709299235296`*^9, 
   3.812471180373554*^9, 3.812471541640524*^9, 3.8127360627735605`*^9, 
   3.812821589183077*^9, 3.8129696309255877`*^9, 3.8129703976780787`*^9, 
   3.812971113380023*^9, 3.812976157901209*^9, 3.8129765423493843`*^9, 
   3.8139963152368793`*^9, 3.813996915399128*^9, 3.813998563479813*^9, 
   3.813998950865547*^9, 3.813999248524271*^9, 3.813999706849262*^9, 
   3.814026716101046*^9, 3.814026907744212*^9, 3.814027079292775*^9, 
   3.8148303033537583`*^9, 3.8154774854086795`*^9, 3.815477790561483*^9, 
   3.8154778524467173`*^9, 3.8154786062675114`*^9, 3.8157753873721*^9, 
   3.8170334471395874`*^9, 3.81703347932061*^9, 3.8188010784628553`*^9, 
   3.825416606184244*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1774]=",ExpressionUUID->"3cef5a96-011e-4323-a3ec-f5920da5eec4"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.805638279440954*^9}, 3.8073075506103206`*^9, {3.825288276808649*^9, 
   3.82528827825077*^9}},ExpressionUUID->"f7c8ac24-1772-44a2-8fd4-\
34926eabe768"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmaau"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"padu1", " ", 
     RowBox[{"(", 
      RowBox[{"qadu1", "-", "qadue0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"padu0", " ", 
     RowBox[{"(", 
      RowBox[{"qadu0", "-", "qadue0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.805638382813442*^9, 3.8056383904499063`*^9}, {3.805638490231865*^9, 
  3.805638492576459*^9}, {3.8056412032132607`*^9, 3.805641206526474*^9}, {
  3.8128215475746965`*^9, 3.8128215601464815`*^9}, {3.8252882836860223`*^9, 
  3.8252882852993145`*^9}},
 CellLabel->
  "In[1775]:=",ExpressionUUID->"f59586ff-0f98-4466-8cbf-e8037d2facd9"],

Cell[BoxData["121133.23324238986`"], "Output",
 CellChangeTimes->CompressedData["
1:eJwVxUsoA2AcAPBtTHJw2FgKB4oirOVVO8hnDmxc5qBowzRvtrDIYXOirJlt
WrmMRHltkraDkQNpsjXDDhaa10KfyNjFI///4dcvS6GSKpkMBqMUeF9OAvYm
SsKTebd46/HEN/5kFfA2YZPDVIjrL8MVePLDa7UbdhnCer+Mkuze3aozWG7Y
68XrhMGcc3gk39FyBe98BjrwZoluBeeEmsqu4Xwr34lPbwovv+SUlLyKu2Iw
3yDy4ZxQjZnXTgnbNraMj7pZW7jIEz+TpKREzb14dnbCvyKOC15sMAvw5Lcd
OS4bvpks76KEa1wXt8FHtohlFRZu70XxqbzS+jWY3Xh4sAFH7MEonrGvurf1
UOJlDRfNw9I5zQ8+W3tfsACvxaVJ8cpBhR7PTdG77fDfiO4c166/P+ED2o/0
sj5KKlKcmYP9lCSOhkT4o8Qqwb3G01XctaSxxA1Qknr3cNWtpiTB/hLGtVX+
mGeIEjHTV9w5Tsk/KwviyA==
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1775]=",ExpressionUUID->"3221fdcc-4fcd-44d2-93d2-b67da0a4e6bc"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.8056382995792217`*^9}, 3.8073075741496387`*^9, 
   3.825288287858329*^9},ExpressionUUID->"dcbbb31f-19e7-44bd-a931-\
55852205923a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmaap"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"padp1", " ", 
     RowBox[{"(", 
      RowBox[{"qadp1", "-", "qadpe0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"padp0", " ", 
     RowBox[{"(", 
      RowBox[{"qadp0", "-", "qadpe0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.805638311659393*^9, 3.805638322630473*^9}, {3.805638393085109*^9, 
  3.8056384022321267`*^9}, {3.8056384953269224`*^9, 3.805638497874226*^9}, {
  3.805641209558215*^9, 3.8056412124349337`*^9}, {3.8128216099392333`*^9, 
  3.812821622430957*^9}, {3.825288290358241*^9, 3.825288292206683*^9}},
 CellLabel->
  "In[1776]:=",ExpressionUUID->"c8061686-4796-4f70-a3b4-31ba8b7b2d73"],

Cell[BoxData["187231.93652751832`"], "Output",
 CellChangeTimes->CompressedData["
1:eJwVz0soA3AcB/BJEXnl4OKxHMiB1aJRw/yRwzBZHCiEhplXxIU80ozm4JWW
DGFlMvPaLuOAlMeETZimlkdef6/GzKP4/Q7fPpdv3/qGltQKRS4MBiMWYnzY
O9LkU7KrbzxBc3qnbejkTu8Puj3EDdCCvlplFDohUfJQwd9HqgF87r6VHxRQ
wu3fSDaBXsZNCbprPA8zgythuiIraHo7LUMTxdIZNIJRzLkAWz5jdOiWlmf5
KKRE/iSscIAN3vx9dLhKMBBQCr3wDhXaJfVYRNkSzz5PESUOleVeV06JtJHv
rwezDAo2mqNYL0R94q5lsRWww1/kF4OT7VSAhjBfBtXg9PKWHXVMJWTOgrmn
e5tzYBrLZkffTU1XY5Xwt7+ZNQ7Ovzb/ou5lD5ETYGsSU4hqxsRyNM86YNCA
btkyM7o06rxDpxTfgZwqSkaG1oLrqykROS9T0PiM8XQ0yO9Mja4v9Ay61lDy
Zb6xiuvgT+ejDbUwDx3bDZSsth1Hl7dT8g/r+/LO
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1776]=",ExpressionUUID->"67aeff48-cff3-49ff-a9c0-8323e0c9b80d"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"595cd19d-1187-4444-8116-\
3c5f95c9094e"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"patu1", "-", "patu0"}], ")"}], "100"}], "patu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
  3.8048586228946285`*^9}, {3.8048587414876785`*^9, 3.8048587423628125`*^9}},
 CellLabel->
  "In[1777]:=",ExpressionUUID->"54ef8831-e826-4661-bf9d-4173471e7600"],

Cell[BoxData["6.230977511058739`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.8048588465765815`*^9, 3.804858889630022*^9, 
   3.8048596662473273`*^9, 3.8048597526353245`*^9, 3.8048599667810307`*^9, 
   3.8048601137774878`*^9, 3.804860383112162*^9, 3.8048605401142273`*^9, 
   3.804860672047739*^9, 3.8048614918758535`*^9, 3.804865952232767*^9, 
   3.8048662759658775`*^9, 3.8048664465406685`*^9, 3.80486725296095*^9, 
   3.804881193191847*^9, 3.804895271581153*^9, 3.80489615101511*^9, 
   3.8048969485809703`*^9, 3.8050220323822594`*^9, 3.805023481297758*^9, 
   3.805023685401803*^9, 3.8050238498436394`*^9, 3.80502522431405*^9, 
   3.805638101139552*^9, 3.805638197275014*^9, 3.805638619477617*^9, 
   3.8056408805278835`*^9, 3.805641067458632*^9, 3.8056658300275936`*^9, 
   3.8072802222507005`*^9, 3.8072857810604343`*^9, 3.8072861091378965`*^9, 
   3.807287597900761*^9, 3.8073064927681594`*^9, 3.8073065497995353`*^9, 
   3.807307075159313*^9, 3.8073082112674522`*^9, 3.8073092258183374`*^9, 
   3.8078829541621103`*^9, 3.807884098794656*^9, 3.8078849065172997`*^9, 
   3.8100471226298943`*^9, 3.810047276237108*^9, 3.8100473684997063`*^9, 
   3.811071104507728*^9, 3.8124706069876547`*^9, 3.8124709305270023`*^9, 
   3.8124711809860306`*^9, 3.8124715422510357`*^9, 3.812736063311982*^9, 
   3.8128215897285156`*^9, 3.812969631722587*^9, 3.8129703984126015`*^9, 
   3.8129711142075624`*^9, 3.8129761585888443`*^9, 3.8129765433963137`*^9, 
   3.8139963159364243`*^9, 3.8139969161046968`*^9, 3.813998564072277*^9, 
   3.8139989515050445`*^9, 3.8139992492558403`*^9, 3.8139997075418053`*^9, 
   3.814026716842636*^9, 3.8140269084857855`*^9, 3.8140270800063124`*^9, 
   3.814830304092335*^9, 3.815477486190059*^9, 3.8154777913584905`*^9, 
   3.815477853228098*^9, 3.815478606986381*^9, 3.815775388624094*^9, 
   3.8170334471967115`*^9, 3.817033479371788*^9, 3.818801078518899*^9, 
   3.8254166069047904`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1777]=",ExpressionUUID->"fc98d4dc-4fae-424a-b70f-51f5c9962aec"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
  3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
  3.8048542553403563`*^9, 
  3.8048542677330275`*^9}},ExpressionUUID->"0d1da58d-1aa7-4703-9e86-\
87f82453e588"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qatu1", "-", "qatu0"}], ")"}], "100"}], "qatu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.804858784498994*^9, 3.8048587856866765`*^9}},
 CellLabel->
  "In[1778]:=",ExpressionUUID->"8550f87b-1995-4769-afe4-52aa757c92e5"],

Cell[BoxData[
 RowBox[{"-", "7.619771054614138`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.804858846717228*^9, 3.804858889770669*^9, 
   3.804859666387981*^9, 3.804859752807233*^9, 3.8048599669373083`*^9, 
   3.8048601139337645`*^9, 3.8048603832684374`*^9, 3.8048605402705026`*^9, 
   3.804860672204014*^9, 3.8048614919852467`*^9, 3.804865952357787*^9, 
   3.8048662760752697`*^9, 3.804866446665639*^9, 3.804867253070223*^9, 
   3.8048811933012834`*^9, 3.804895271690548*^9, 3.804896151124502*^9, 
   3.804896948690363*^9, 3.8050220325385337`*^9, 3.8050234817196984`*^9, 
   3.805023685651842*^9, 3.8050238499843435`*^9, 3.8050252244859548`*^9, 
   3.8056381012974787`*^9, 3.8056381974469175`*^9, 3.8056386196494894`*^9, 
   3.8056408807750745`*^9, 3.805641067755555*^9, 3.8056658302151337`*^9, 
   3.8072802224518557`*^9, 3.807285781251617*^9, 3.8072861093420553`*^9, 
   3.807287598137947*^9, 3.807306492926283*^9, 3.807306549989688*^9, 
   3.807307075355465*^9, 3.8073082114626074`*^9, 3.807309225981464*^9, 
   3.807882954334014*^9, 3.80788409899782*^9, 3.807884906736084*^9, 
   3.810047122797024*^9, 3.81004727643826*^9, 3.8100473687028637`*^9, 
   3.8110711047018814`*^9, 3.8124706071647935`*^9, 3.8124709307271595`*^9, 
   3.8124711811842265`*^9, 3.8124715424791822`*^9, 3.812736063492123*^9, 
   3.8128215899176507`*^9, 3.8129696319726844`*^9, 3.812970398662651*^9, 
   3.812971114488859*^9, 3.8129761588232336`*^9, 3.8129765437245035`*^9, 
   3.8139963161626005`*^9, 3.813996916293826*^9, 3.8139985642784395`*^9, 
   3.81399895173022*^9, 3.813999249491023*^9, 3.813999707762979*^9, 
   3.8140267170747733`*^9, 3.8140269086839395`*^9, 3.814027080237492*^9, 
   3.81483030438762*^9, 3.8154774864557285`*^9, 3.8154777916241593`*^9, 
   3.8154778534937663`*^9, 3.8154786071426563`*^9, 3.815775388953332*^9, 
   3.8170334472118125`*^9, 3.817033479383797*^9, 3.818801078535912*^9, 
   3.825416607120955*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1778]=",ExpressionUUID->"83e3549b-d9fa-4cd9-a71a-f09c20716cc0"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"64be1c49-a58d-4f9b-bf04-\
f2b3f67564ff"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"patp1", "-", "patp0"}], ")"}], "100"}], "patp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
  3.804858633427496*^9}, {3.804858743050418*^9, 3.8048587439411793`*^9}},
 CellLabel->
  "In[1779]:=",ExpressionUUID->"0033ad0d-1379-457a-9dc2-1a86231bb164"],

Cell[BoxData["6.717463310178176`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.804858846857889*^9, 3.804858889926943*^9, 3.804859666544263*^9, 
   3.8048597529478846`*^9, 3.804859967093587*^9, 3.804860114090042*^9, 
   3.804860383409086*^9, 3.80486054041115*^9, 3.8048606723602886`*^9, 
   3.8048614920947437`*^9, 3.8048659524671793`*^9, 3.804866276184663*^9, 
   3.8048664467594037`*^9, 3.804867253179615*^9, 3.8048811934106317`*^9, 
   3.804895271799943*^9, 3.8048961512338953`*^9, 3.8048969487997556`*^9, 
   3.805022032710436*^9, 3.8050234850014563`*^9, 3.805023685854998*^9, 
   3.8050238501655254`*^9, 3.805025224673488*^9, 3.805638101451598*^9, 
   3.8056381976031933`*^9, 3.805638619821391*^9, 3.8056408810212636`*^9, 
   3.805641068005595*^9, 3.8056658304182963`*^9, 3.8072802226460266`*^9, 
   3.807285781448735*^9, 3.8072861095342045`*^9, 3.8072875983120832`*^9, 
   3.8073064930874076`*^9, 3.80730655018283*^9, 3.8073070755486155`*^9, 
   3.8073082116557536`*^9, 3.8073092261586018`*^9, 3.807882954521545*^9, 
   3.807884099200974*^9, 3.8078849069236145`*^9, 3.8100471229691577`*^9, 
   3.8100472766464214`*^9, 3.810047368903019*^9, 3.811071104888028*^9, 
   3.812470607339931*^9, 3.812470930938325*^9, 3.812471181391348*^9, 
   3.8124715426863394`*^9, 3.8127360636762676`*^9, 3.812821590113804*^9, 
   3.8129696322382927`*^9, 3.812970398912701*^9, 3.812971114754529*^9, 
   3.8129761590732746`*^9, 3.812976544068266*^9, 3.8139963164107933`*^9, 
   3.813996916531064*^9, 3.8139985644876027`*^9, 3.8139989519543934`*^9, 
   3.813999249672164*^9, 3.8139997079871535`*^9, 3.8140267173049526`*^9, 
   3.81402690891612*^9, 3.8140270804746766`*^9, 3.814830304710817*^9, 
   3.81547748670577*^9, 3.8154777918898287`*^9, 3.815477853743808*^9, 
   3.815478607377071*^9, 3.8157753892305746`*^9, 3.8170334472278247`*^9, 
   3.8170334793958073`*^9, 3.8188010785519247`*^9, 3.8254166073521457`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1779]=",ExpressionUUID->"1a886082-c557-4ad5-b881-bcedf16e5f4a"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
  3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
  3.804854223908785*^9}, {3.8048542555122595`*^9, 
  3.804854280414089*^9}},ExpressionUUID->"1287b6cf-c7e5-4552-a2a6-\
c873534b38be"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qatp1", "-", "qatp0"}], ")"}], "100"}], "qatp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.8048587864211645`*^9, 3.804858787812003*^9}},
 CellLabel->
  "In[1780]:=",ExpressionUUID->"04e6fdef-ca93-4416-a1ff-70212c4de514"],

Cell[BoxData[
 RowBox[{"-", "7.1124806165254`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.804858846998521*^9, 3.8048588900675893`*^9, 3.8048596666849174`*^9, 
   3.8048597530885797`*^9, 3.8048599672342367`*^9, 3.804860114246319*^9, 
   3.804860383565363*^9, 3.8048605405830526`*^9, 3.8048606725165644`*^9, 
   3.804861492204033*^9, 3.804865952576572*^9, 3.804866276294055*^9, 
   3.804866446884424*^9, 3.804867253320263*^9, 3.8048811935200243`*^9, 
   3.8048952719093375`*^9, 3.8048961513589153`*^9, 3.8048969488935204`*^9, 
   3.805022032882337*^9, 3.805023485424994*^9, 3.805023686105037*^9, 
   3.8050238503416615`*^9, 3.805025224907903*^9, 3.8056381015958214`*^9, 
   3.805638197745079*^9, 3.8056386200089226`*^9, 3.805640881291472*^9, 
   3.80564106830252*^9, 3.805665830621447*^9, 3.80728022283115*^9, 
   3.8072857816949263`*^9, 3.807286109731368*^9, 3.8072875984872203`*^9, 
   3.8073064932825594`*^9, 3.8073065503729773`*^9, 3.807307075741765*^9, 
   3.807308211846902*^9, 3.807309226323736*^9, 3.807882954693449*^9, 
   3.8078840994041834`*^9, 3.8078849071267724`*^9, 3.8100471231432924`*^9, 
   3.8100472768435774`*^9, 3.81004736911018*^9, 3.811071105077177*^9, 
   3.8124706075240746`*^9, 3.8124709311414843`*^9, 3.812471181593502*^9, 
   3.812471542892499*^9, 3.812736063873436*^9, 3.8128215903029523`*^9, 
   3.812969632488332*^9, 3.8129703991627517`*^9, 3.8129711150201993`*^9, 
   3.812976159338943*^9, 3.812976544412074*^9, 3.8139963166509795`*^9, 
   3.8139969167121534`*^9, 3.81399856470277*^9, 3.813998952185574*^9, 
   3.8139992499073462`*^9, 3.813999708210327*^9, 3.8140267175401354`*^9, 
   3.81402690910927*^9, 3.8140270807058573`*^9, 3.814830304988053*^9, 
   3.815477486971439*^9, 3.815477792155498*^9, 3.8154778540094767`*^9, 
   3.8154786076271124`*^9, 3.8157753895277805`*^9, 3.8170334472428365`*^9, 
   3.8170334794068155`*^9, 3.8188010785659356`*^9, 3.825416607578294*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1780]=",ExpressionUUID->"3808d8c1-5a84-421f-b2cc-318074470401"]
}, Open  ]],

Cell[TextData[StyleBox["Bigeye Tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, {3.804858674828244*^9, 3.8048586759846716`*^9}, {
   3.805021921987334*^9, 3.8050219236606793`*^9}, 
   3.825287978936225*^9},ExpressionUUID->"0da5a705-ebaa-47a5-9c78-\
216be9b445f4"],

Cell["Percent change in price of unprocessed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}},ExpressionUUID->"d6dd7271-b8f9-4b87-8e07-\
d998adc6d6c9"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pbdu1", "-", "pbdu0"}], ")"}], "100"}], "pbdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
   3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
   3.8048585992018385`*^9}, {3.8048587486137724`*^9, 3.804858750004611*^9}, {
   3.805017872704455*^9, 3.805017872704455*^9}, 3.805020287887725*^9},
 CellLabel->
  "In[1781]:=",ExpressionUUID->"eac04235-9dae-4c9d-9d14-9beadbe1df28"],

Cell[BoxData["4.802157828318862`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.804858847139168*^9, 3.804858890192608*^9, 
   3.804859666825571*^9, 3.8048597532291985`*^9, 3.8048599673748865`*^9, 
   3.804860114402596*^9, 3.8048603837216387`*^9, 3.8048605407393417`*^9, 
   3.8048606726728387`*^9, 3.804861492313425*^9, 3.8048659526859646`*^9, 
   3.8048662764034476`*^9, 3.8048664469938164`*^9, 3.8048672534297056`*^9, 
   3.8048811936294165`*^9, 3.804895272018732*^9, 3.8048961514683075`*^9, 
   3.8048969490185413`*^9, 3.805022033054239*^9, 3.805023488706752*^9, 
   3.8050236863081937`*^9, 3.805023850498782*^9, 3.805025225095439*^9, 
   3.805638101752097*^9, 3.805638197915598*^9, 3.80563862057152*^9, 
   3.805640882167178*^9, 3.805641069162032*^9, 3.8056658318749647`*^9, 
   3.8072802233685694`*^9, 3.8072857822773824`*^9, 3.807286110315811*^9, 
   3.80728759901363*^9, 3.807306493858016*^9, 3.8073065509874554`*^9, 
   3.8073070763622475`*^9, 3.8073082120380507`*^9, 3.807309226494863*^9, 
   3.8078829548966074`*^9, 3.8078840996229196`*^9, 3.8078849073299303`*^9, 
   3.8100471233274355`*^9, 3.810047277038726*^9, 3.8100473693173404`*^9, 
   3.8110711052753325`*^9, 3.8124706077022142`*^9, 3.81247093134064*^9, 
   3.8124711817986617`*^9, 3.8124715431146717`*^9, 3.8127360640565653`*^9, 
   3.812821590489098*^9, 3.8129696327526293`*^9, 3.8129703994128017`*^9, 
   3.8129711152858686`*^9, 3.8129761596046147`*^9, 3.812976544740234*^9, 
   3.813996316879157*^9, 3.8139969169513407`*^9, 3.8139985649419556`*^9, 
   3.813998952408762*^9, 3.8139992501375704`*^9, 3.813999708438504*^9, 
   3.814026717765311*^9, 3.814026909383483*^9, 3.8140270809510503`*^9, 
   3.8148303052352533`*^9, 3.815477487237108*^9, 3.8154777924367948`*^9, 
   3.815477854259518*^9, 3.815478607877154*^9, 3.8157753898400245`*^9, 
   3.817033447258849*^9, 3.817033479418825*^9, 3.818801078580947*^9, 
   3.8254166078284903`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1781]=",ExpressionUUID->"892aeba7-243d-40b5-ae97-cf836e3ebbea"]
}, Open  ]],

Cell["Percent change in quantity of landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.807308034840155*^9},ExpressionUUID->"6ab2d942-3780-4d10-a84d-\
bca6c00b9067"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qbdu1", "-", "qbdu0"}], ")"}], "100"}], "qbdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.804858792627643*^9, 3.804858798896052*^9}, {3.8050173592553644`*^9, 
  3.8050173592553644`*^9}, {3.8050219270518637`*^9, 3.8050219271612563`*^9}},
 CellLabel->
  "In[1782]:=",ExpressionUUID->"699c7382-61c3-4087-9ac8-2d4750e55a95"],

Cell[BoxData["8.421472951266683`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.8048588472798543`*^9, 3.8048588903332553`*^9, 
   3.8048596669662247`*^9, 3.8048597533854685`*^9, 3.8048599675155373`*^9, 
   3.8048601145432453`*^9, 3.8048603838622866`*^9, 3.8048605408956027`*^9, 
   3.804860672829114*^9, 3.804861492438445*^9, 3.8048659527953568`*^9, 
   3.8048662765128403`*^9, 3.8048664471032095`*^9, 3.804867253539048*^9, 
   3.804881193738809*^9, 3.804895272128127*^9, 3.8048961515777006`*^9, 
   3.8048969491279335`*^9, 3.805022033194886*^9, 3.805023492051019*^9, 
   3.805023686589486*^9, 3.8050238507269583`*^9, 3.805025225267357*^9, 
   3.8056381019083724`*^9, 3.8056381981187563`*^9, 3.8056386207746763`*^9, 
   3.8056408824643764`*^9, 3.80564106941296*^9, 3.805665832062481*^9, 
   3.8072802235176907`*^9, 3.8072857824685326`*^9, 3.807286110522972*^9, 
   3.807287599254817*^9, 3.8073064940661683`*^9, 3.8073065511766033`*^9, 
   3.807307076555399*^9, 3.8073082122302*^9, 3.807309226664995*^9, 
   3.8078829550997667`*^9, 3.807884099857334*^9, 3.8078849075330877`*^9, 
   3.8100471235115786`*^9, 3.810047277238881*^9, 3.8100473695174956`*^9, 
   3.811071105460498*^9, 3.8124706078853917`*^9, 3.812470931539795*^9, 
   3.812471182010826*^9, 3.8124715433328485`*^9, 3.812736064244713*^9, 
   3.8128215906822476`*^9, 3.812969633002669*^9, 3.8129703996628513`*^9, 
   3.8129711155671663`*^9, 3.8129761598546515`*^9, 3.812976545068388*^9, 
   3.8139963171063337`*^9, 3.813996917134484*^9, 3.813998565157123*^9, 
   3.8139989526379433`*^9, 3.8139992503737087`*^9, 3.813999708673692*^9, 
   3.814026718008499*^9, 3.8140269095726423`*^9, 3.814027081186252*^9, 
   3.814830305489423*^9, 3.8154774875027776`*^9, 3.8154777927024636`*^9, 
   3.8154778545408154`*^9, 3.815478608111577*^9, 3.8157753901252985`*^9, 
   3.8170334472758617`*^9, 3.817033479430835*^9, 3.81880107859696*^9, 
   3.825416608197832*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1782]=",ExpressionUUID->"0a1bb08c-f42d-4ae8-9483-4ce8f90236ec"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 
  3.80485427153401*^9}},ExpressionUUID->"d2845b1f-67a4-4183-b6ef-\
b498601995fd"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pbdp1", "-", "pbdp0"}], ")"}], "100"}], "pbdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
   3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
   3.8048586124851284`*^9}, {3.804858750567197*^9, 3.8048587511610384`*^9}, {
   3.805018163895453*^9, 3.8050181639110804`*^9}, 3.805020631092285*^9},
 CellLabel->
  "In[1783]:=",ExpressionUUID->"7c1759df-3d72-4500-860c-2dd4c373c9a0"],

Cell[BoxData["8.185434885073594`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.804858847436088*^9, 3.8048588904739017`*^9, 
   3.8048596671068783`*^9, 3.804859753526121*^9, 3.804859967671815*^9, 
   3.804860114699522*^9, 3.80486038403419*^9, 3.8048605410518775`*^9, 
   3.8048606730010166`*^9, 3.8048614925478373`*^9, 3.80486595290475*^9, 
   3.804866276622233*^9, 3.8048664472126026`*^9, 3.8048672536484404`*^9, 
   3.8048811938325744`*^9, 3.8048952722375216`*^9, 3.804896151687093*^9, 
   3.8048969492373266`*^9, 3.805022033366787*^9, 3.805023495457796*^9, 
   3.8050236867770157`*^9, 3.8050238508691483`*^9, 3.805025225439246*^9, 
   3.805638102080275*^9, 3.805638198290659*^9, 3.805638620946581*^9, 
   3.8056408827305813`*^9, 3.8056410696473737`*^9, 3.8056658322416816`*^9, 
   3.8072802236958256`*^9, 3.8072857827127233`*^9, 3.807286110717123*^9, 
   3.8072875994329557`*^9, 3.8073064942292943`*^9, 3.8073065513657513`*^9, 
   3.807307076751552*^9, 3.8073082124863987`*^9, 3.807309226837178*^9, 
   3.8078829552716703`*^9, 3.8078841000604925`*^9, 3.8078849077518725`*^9, 
   3.8100471237027273`*^9, 3.810047277441038*^9, 3.810047369719653*^9, 
   3.8110711056566334`*^9, 3.8124706080695047`*^9, 3.812470931744954*^9, 
   3.812471182217987*^9, 3.812471543541006*^9, 3.812736064431859*^9, 
   3.8128215908733964`*^9, 3.8129696332683353`*^9, 3.812970399897274*^9, 
   3.812971115832836*^9, 3.8129761601203194`*^9, 3.8129765453809605`*^9, 
   3.813996317336512*^9, 3.813996917392685*^9, 3.81399856530626*^9, 
   3.8139989528621044`*^9, 3.8139992505488644`*^9, 3.8139997088988624`*^9, 
   3.8140267182456837`*^9, 3.814026909844842*^9, 3.814027081420418*^9, 
   3.814830305744621*^9, 3.815477487768446*^9, 3.815477792968133*^9, 
   3.815477854790857*^9, 3.8154786083616095`*^9, 3.8157753904475083`*^9, 
   3.8170334472919436`*^9, 3.8170334794433794`*^9, 3.818801078614974*^9, 
   3.825416608488016*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1783]=",ExpressionUUID->"5a9c72f5-e26a-4243-9117-e52cb166c3f8"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
  3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
  3.804854255481004*^9, 
  3.8048542778511686`*^9}},ExpressionUUID->"312e9735-b698-47d1-8a41-\
0d85b37f1f59"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qbdp1", "-", "qbdp0"}], ")"}], "100"}], "qbdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}, {
  3.8048587995680304`*^9, 3.8048588001931267`*^9}, {3.8050174161743164`*^9, 
  3.8050174161743164`*^9}, {3.805021931896407*^9, 3.805021932052683*^9}},
 CellLabel->
  "In[1784]:=",ExpressionUUID->"bf9dee48-da0c-4799-9b7a-a8cf2a44140f"],

Cell[BoxData["1.0225998138613122`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.8048588475923624`*^9, 3.8048588906145487`*^9, 
   3.8048596672475457`*^9, 3.8048597536824007`*^9, 3.8048599678124647`*^9, 
   3.8048601148557987`*^9, 3.8048603841904664`*^9, 3.804860541192525*^9, 
   3.804860673141664*^9, 3.80486149265723*^9, 3.804865953014142*^9, 
   3.8048662767316256`*^9, 3.8048664473219957`*^9, 3.804867253757833*^9, 
   3.8048811939419665`*^9, 3.804895272346916*^9, 3.8048961517964897`*^9, 
   3.804896949346719*^9, 3.8050220335386887`*^9, 3.805023495879737*^9, 
   3.8050236869645443`*^9, 3.8050238510266843`*^9, 3.8050252256111526`*^9, 
   3.805638102231194*^9, 3.8056381984469347`*^9, 3.805638621134112*^9, 
   3.8056408830548315`*^9, 3.805641069928669*^9, 3.8056658324292097`*^9, 
   3.8072802238329325`*^9, 3.8072857829068737`*^9, 3.807286110916298*^9, 
   3.8072875996160975`*^9, 3.8073064943854156`*^9, 3.807306551559904*^9, 
   3.807307076983734*^9, 3.8073082126815505`*^9, 3.807309227010263*^9, 
   3.8078829554592023`*^9, 3.807884100279341*^9, 3.8078849079394026`*^9, 
   3.8100471238889103`*^9, 3.8100472776491995`*^9, 3.81004736992181*^9, 
   3.811071105856791*^9, 3.8124706082456393`*^9, 3.812470931957119*^9, 
   3.812471182417142*^9, 3.81247154375117*^9, 3.8127360646300144`*^9, 
   3.8128215910745525`*^9, 3.812969633519594*^9, 3.812970400147324*^9, 
   3.8129711160985055`*^9, 3.8129761603547325`*^9, 3.8129765457247324`*^9, 
   3.8139963175746975`*^9, 3.813996917632871*^9, 3.813998565451352*^9, 
   3.813998953084278*^9, 3.813999250729985*^9, 3.8139997091210346`*^9, 
   3.814026718570936*^9, 3.814026910095036*^9, 3.8140270816516247`*^9, 
   3.814830306066924*^9, 3.815477488018488*^9, 3.815477793233802*^9, 
   3.8154778550565257`*^9, 3.8154786085960226`*^9, 3.815775390744752*^9, 
   3.8170334473073287`*^9, 3.817033479455953*^9, 3.818801078633989*^9, 
   3.8254166087142315`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1784]=",ExpressionUUID->"9454f3ab-1e20-49eb-bec6-35405f2aafbd"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.805638279440954*^9}, 3.8073075506223297`*^9, 
   3.8252882976099176`*^9},ExpressionUUID->"773a974e-774d-4a9d-8435-\
64c17db3bef1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmabu"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"pbdu1", " ", 
     RowBox[{"(", 
      RowBox[{"qbdu1", "-", "qbdue0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"pbdu0", " ", 
     RowBox[{"(", 
      RowBox[{"qbdu0", "-", "qbdue0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.8056384216076107`*^9, 3.8056384298283195`*^9}, {3.805638482271556*^9, 
  3.805638484475052*^9}, {3.8056411863774834`*^9, 3.8056411898406487`*^9}, {
  3.8128216387676725`*^9, 3.8128216515556264`*^9}, {3.825288299442346*^9, 
  3.825288301244772*^9}},
 CellLabel->
  "In[1785]:=",ExpressionUUID->"ae793997-7b92-411a-9d29-7b9ee3a4d0b7"],

Cell[BoxData["3.931110292794123`*^6"], "Output",
 CellChangeTimes->CompressedData["
1:eJwVx2kow3EYwPHJC5EjU1NzJYtSW1YMJfkNJcO0vGCYEJtbrpKSFqVcy9ES
Zm+UW9R48XfnBZljhiJKlDG/sRezckye58W3T9/wsgZZhRuLxYqDjNZj05Kc
krfjvR+06HSIswKqE5/5aETEaRLas8VPZ0CuK7D/rJgScadLfAEum/5qUN/C
gEgzKM+ylNyBsnN/JcoSbs+ifa4J0T2o8qg0oJ5rLTefCkoEjRqVE7QPdZ+g
tjb1MKecEqmSmUGPrlNXUbuGaLwq4LU+VoOSEuNHN3sdtOyahagf86dASwXc
3ngVJaL9l8xSMDljUIZe6RNG58DMDW8HKo/qz54HM27ZB4tglZA40MmCzSdd
NSUhrYxgGgzLM/yi1U3RfD24qFHI0AHeQh+6037DLIG3U0YzmpOf9IqmPEiC
RbWUXGs9Q5vqKFnriElDa6VWCepkB82j37zHEfd6SsZzrXdVjZT8fL0/oDrb
pfOwmZKxhNBYZRcl/9f04vg=
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1785]=",ExpressionUUID->"7f2a404f-d731-41d0-a0f0-6da8fa3f7753"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.8056382995792217`*^9}, 3.8073075741596465`*^9, 
   3.8252883035495996`*^9},ExpressionUUID->"e1448a62-8bb0-426d-80ca-\
985440bbf91e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmabp"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"pbdp1", " ", 
     RowBox[{"(", 
      RowBox[{"qbdp1", "-", "qbdpe0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"pbdp0", " ", 
     RowBox[{"(", 
      RowBox[{"qbdp0", "-", "qbdpe0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.805638311659393*^9, 3.805638322630473*^9}, {3.805638433988842*^9, 
  3.8056384793310328`*^9}, {3.805641192616592*^9, 3.8056411960702763`*^9}, {
  3.8128216652743025`*^9, 3.8128216801388693`*^9}, {3.82528830570125*^9, 
  3.8252883074876595`*^9}},
 CellLabel->
  "In[1786]:=",ExpressionUUID->"0d97cd81-1e03-4f9e-9ae3-c4e426e54006"],

Cell[BoxData["1.4196530160367603`*^6"], "Output",
 CellChangeTimes->{
  3.8056382863724117`*^9, 3.805638323678563*^9, {3.805638445362606*^9, 
   3.8056384571096716`*^9}, 3.805638622243674*^9, 3.805640884872235*^9, 
   3.8056410714757943`*^9, 3.805641196617241*^9, 3.8056658336169176`*^9, 
   3.807280224932789*^9, 3.807285784115813*^9, 3.8072861121692567`*^9, 
   3.8072876007860055`*^9, 3.8073064954222207`*^9, 3.8073065527448254`*^9, 
   3.8073070781746607`*^9, 3.8073082130688505`*^9, 3.807309227377615*^9, 
   3.8078829558186493`*^9, 3.8078841007012253`*^9, 3.8078849083457184`*^9, 
   3.8100471242601595`*^9, 3.8100472780615196`*^9, 3.810047370325133*^9, 
   3.8110711062400928`*^9, 3.8124706086029167`*^9, 3.8124709323564568`*^9, 
   3.812471182821456*^9, 3.812471544178505*^9, 3.8127360650223217`*^9, 
   3.812821591471861*^9, 3.812821681039569*^9, 3.812969634019672*^9, 
   3.812970400631796*^9, 3.8129711166611013`*^9, 3.812976160823559*^9, 
   3.812976546365411*^9, 3.8139963181141167`*^9, 3.813996918084222*^9, 
   3.8139985658086295`*^9, 3.8139989535486393`*^9, 3.8139992511843586`*^9, 
   3.8139997095743876`*^9, 3.814026719039301*^9, 3.814026910631455*^9, 
   3.8140270821289682`*^9, 3.8148303066763515`*^9, 3.8154774885498257`*^9, 
   3.815477793780768*^9, 3.815477855587864*^9, 3.8154786090804777`*^9, 
   3.8157753916904774`*^9, 3.8170334473523617`*^9, 3.817033479495036*^9, 
   3.818801078690032*^9, 3.82541660931465*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1786]=",ExpressionUUID->"8d49ed7f-fb79-4aa5-ac55-44cc3626d13d"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"44538c4e-1e32-4e62-83c8-\
b7718d9697ea"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pbtu1", "-", "pbtu0"}], ")"}], "100"}], "pbtu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
   3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
   3.8048586228946285`*^9}, {3.804858751489214*^9, 3.8048587520986824`*^9}, {
   3.805018113403982*^9, 3.8050181134196095`*^9}, 3.80502029645166*^9},
 CellLabel->
  "In[1787]:=",ExpressionUUID->"4b5f3777-f0ec-482e-99c6-1607ad258f3c"],

Cell[BoxData["13.096190461033347`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.8048588477330093`*^9, 3.8048588907551947`*^9, 
   3.8048596674038343`*^9, 3.804859753823053*^9, 3.8048599679531155`*^9, 
   3.804860114996448*^9, 3.8048603843467426`*^9, 3.8048605413487997`*^9, 
   3.804860673297939*^9, 3.8048614927666225`*^9, 3.8048659531235347`*^9, 
   3.8048662768410177`*^9, 3.804866447431389*^9, 3.804867253867225*^9, 
   3.804881194051359*^9, 3.804895272440683*^9, 3.804896151905878*^9, 
   3.804896949456112*^9, 3.805022033711192*^9, 3.8050234991864624`*^9, 
   3.805023687198978*^9, 3.805023851182804*^9, 3.8050252257830553`*^9, 
   3.8056381023874693`*^9, 3.80563819860321*^9, 3.805638621337271*^9, 
   3.8056408833710747`*^9, 3.805641070163082*^9, 3.805665832616743*^9, 
   3.8072802240120955`*^9, 3.807285783099023*^9, 3.807286111110485*^9, 
   3.8072875998022423`*^9, 3.807306494544539*^9, 3.807306551751053*^9, 
   3.807307077176885*^9, 3.8073082132609997`*^9, 3.807309227550683*^9, 
   3.807882956053048*^9, 3.807884100904384*^9, 3.807884908533248*^9, 
   3.8100471244463034`*^9, 3.8100472782656784`*^9, 3.810047370526279*^9, 
   3.811071106433245*^9, 3.8124706087840576`*^9, 3.8124709325575867`*^9, 
   3.8124711830356226`*^9, 3.8124715443946743`*^9, 3.812736065215495*^9, 
   3.8128215916650114`*^9, 3.8129696342853384`*^9, 3.8129704008818645`*^9, 
   3.8129711169267707`*^9, 3.812976161073599*^9, 3.812976546677952*^9, 
   3.8139963183402925`*^9, 3.813996918305393*^9, 3.813998566024798*^9, 
   3.8139989537278028`*^9, 3.8139992514095144`*^9, 3.813999709808569*^9, 
   3.814026719264476*^9, 3.8140269108826523`*^9, 3.8140270823681545`*^9, 
   3.814830306940558*^9, 3.8154774888154955`*^9, 3.8154777940464373`*^9, 
   3.8154778558535333`*^9, 3.815478609330518*^9, 3.8157753920727673`*^9, 
   3.8170334473673735`*^9, 3.817033479508046*^9, 3.8188010787100477`*^9, 
   3.825416609574859*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1787]=",ExpressionUUID->"61e404f5-e87f-4c9f-9fcf-798bef815cf1"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
  3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
  3.8048542553403563`*^9, 
  3.8048542677330275`*^9}},ExpressionUUID->"7d0cf9a0-3acd-42fb-ac58-\
b758e20e9bab"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qbtu1", "-", "qbtu0"}], ")"}], "100"}], "qbtu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.804858800630694*^9, 3.8048588012870445`*^9}, {3.8050174723410645`*^9, 
  3.8050174723410645`*^9}, {3.805021936100234*^9, 3.8050219362096276`*^9}},
 CellLabel->
  "In[1788]:=",ExpressionUUID->"5f50749e-a91c-4991-99cb-2687d628f86c"],

Cell[BoxData[
 RowBox[{"-", "10.788294766252244`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588478736553`*^9, 3.8048588909114695`*^9, 
   3.8048596675600967`*^9, 3.804859753963705*^9, 3.804859968109393*^9, 
   3.804860115168353*^9, 3.8048603844873915`*^9, 3.8048605415207024`*^9, 
   3.8048606734385867`*^9, 3.8048614928760147`*^9, 3.804865953232927*^9, 
   3.8048662769660378`*^9, 3.8048664475407825`*^9, 3.804867253961108*^9, 
   3.8048811941607513`*^9, 3.804895272550078*^9, 3.8048961520152717`*^9, 
   3.804896949565504*^9, 3.8050220339143486`*^9, 3.8050234996084023`*^9, 
   3.805023687417741*^9, 3.80502385132647*^9, 3.805025226017471*^9, 
   3.805638102543745*^9, 3.805638198775112*^9, 3.80563862154043*^9, 
   3.8056408836763105`*^9, 3.805641070397495*^9, 3.8056658328667865`*^9, 
   3.8072802241912193`*^9, 3.8072857832941747`*^9, 3.8072861113045797`*^9, 
   3.8072875999873857`*^9, 3.8073064947176733`*^9, 3.807306551940201*^9, 
   3.807307077370036*^9, 3.8073082134941807`*^9, 3.8073092277198157`*^9, 
   3.8078829562405787`*^9, 3.8078841011231704`*^9, 3.8078849087364063`*^9, 
   3.810047124630447*^9, 3.8100472784698367`*^9, 3.810047370728436*^9, 
   3.811071106626397*^9, 3.812470608960194*^9, 3.8124709327597446`*^9, 
   3.8124711832387805`*^9, 3.812471544599835*^9, 3.812736065404621*^9, 
   3.812821591855159*^9, 3.8129696345197496`*^9, 3.812970401116268*^9, 
   3.812971117176813*^9, 3.8129761613548946`*^9, 3.812976547021738*^9, 
   3.813996318578478*^9, 3.81399691854458*^9, 3.8139985662349615`*^9, 
   3.8139989539529533`*^9, 3.8139992516356916`*^9, 3.8139997100307417`*^9, 
   3.814026719492653*^9, 3.8140269111178365`*^9, 3.8140270826063395`*^9, 
   3.8148303071977577`*^9, 3.8154774890655375`*^9, 3.815477794312106*^9, 
   3.8154778561192026`*^9, 3.81547860956493*^9, 3.8157753923835735`*^9, 
   3.817033447383399*^9, 3.817033479521056*^9, 3.8188010787430744`*^9, 
   3.825416609807045*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1788]=",ExpressionUUID->"726ad14b-11bf-4912-8041-a9d9e20f0499"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"e745e36a-4f70-481c-8fb6-\
6bb8fe578131"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pbtp1", "-", "pbtp0"}], ")"}], "100"}], "pbtp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
   3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
   3.804858633427496*^9}, {3.804858752504995*^9, 3.804858754192754*^9}, {
   3.8050182855042944`*^9, 3.8050182855042944`*^9}, 3.8050206707402067`*^9},
 CellLabel->
  "In[1789]:=",ExpressionUUID->"305151c4-d677-4e89-8ccb-7d1d76c8b5ed"],

Cell[BoxData["14.101582083256076`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.8048588480143023`*^9, 3.8048588910677433`*^9, 3.8048596677007504`*^9, 
   3.8048597541199846`*^9, 3.804859968250043*^9, 3.804860115309002*^9, 
   3.8048603846436667`*^9, 3.804860541708233*^9, 3.804860673594861*^9, 
   3.804861492985408*^9, 3.804865953357947*^9, 3.8048662770754304`*^9, 
   3.804866447650175*^9, 3.804867254086011*^9, 3.8048811942701445`*^9, 
   3.8048952726594725`*^9, 3.8048961521246634`*^9, 3.8048969496748967`*^9, 
   3.8050220340862503`*^9, 3.805023502999552*^9, 3.805023687652151*^9, 
   3.8050238514882965`*^9, 3.8050252262050037`*^9, 3.8056381027156477`*^9, 
   3.805638198947016*^9, 3.8056386217123346`*^9, 3.8056408839465184`*^9, 
   3.8056410706319075`*^9, 3.8056658330543194`*^9, 3.8072802243723536`*^9, 
   3.8072857834863243`*^9, 3.8072861115017924`*^9, 3.8072876001755323`*^9, 
   3.8073064948767967`*^9, 3.8073065521783857`*^9, 3.807307077560218*^9, 
   3.807308213687332*^9, 3.8073092278959537`*^9, 3.807882956412481*^9, 
   3.8078841013263297`*^9, 3.8078849089395638`*^9, 3.810047124826599*^9, 
   3.8100472786860046`*^9, 3.8100473709335947`*^9, 3.8110711068205495`*^9, 
   3.8124706091513433`*^9, 3.81247093297091*^9, 3.812471183441938*^9, 
   3.812471544822009*^9, 3.8127360655967717`*^9, 3.812821592046307*^9, 
   3.8129696347697887`*^9, 3.812970401350696*^9, 3.812971117426855*^9, 
   3.8129761616518183`*^9, 3.8129765473499007`*^9, 3.813996318796647*^9, 
   3.8139969187687535`*^9, 3.8139985663950853`*^9, 3.813998954177128*^9, 
   3.813999251858904*^9, 3.8139997102559175`*^9, 3.814026719723832*^9, 
   3.8140269113790407`*^9, 3.8140270828445253`*^9, 3.814830307410924*^9, 
   3.815477489331206*^9, 3.815477794577775*^9, 3.8154778563848715`*^9, 
   3.815478609799362*^9, 3.815775392723835*^9, 3.817033447398483*^9, 
   3.817033479533066*^9, 3.8188010787590866`*^9, 3.825416610047253*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1789]=",ExpressionUUID->"0de90f9c-e7d6-4734-b6ab-443176c8b287"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
  3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
  3.804854223908785*^9}, {3.8048542555122595`*^9, 
  3.804854280414089*^9}},ExpressionUUID->"e36a07fd-56c3-4cfb-8912-\
9cdfc5e191d1"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qbtp1", "-", "qbtp0"}], ")"}], "100"}], "qbtp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.804858801740239*^9, 3.8048588038343105`*^9}, {3.805017523503875*^9, 
  3.805017523503875*^9}, {3.8050219403353195`*^9, 3.805021940413457*^9}},
 CellLabel->
  "In[1790]:=",ExpressionUUID->"8aa73854-3a13-4f13-ad44-e3ae30c9c42c"],

Cell[BoxData[
 RowBox[{"-", "11.94803847604678`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.804858848154949*^9, 3.804858891192762*^9, 3.8048596678726606`*^9, 
   3.804859754260637*^9, 3.80485996839496*^9, 3.804860115465279*^9, 
   3.804860384799943*^9, 3.80486054184888*^9, 3.80486067373553*^9, 
   3.80486149309489*^9, 3.804865953482967*^9, 3.804866277169195*^9, 
   3.804866447759568*^9, 3.804867254195405*^9, 3.8048811943795366`*^9, 
   3.804895272768914*^9, 3.8048961522340565`*^9, 3.8048969497842894`*^9, 
   3.805022034258152*^9, 3.8050235034371195`*^9, 3.8050236878709345`*^9, 
   3.8050238516521263`*^9, 3.805025226376909*^9, 3.8056381028719225`*^9, 
   3.805638199150173*^9, 3.8056386218842387`*^9, 3.805640884216727*^9, 
   3.805641070960086*^9, 3.805665833241892*^9, 3.8072802245655036`*^9, 
   3.807285783728512*^9, 3.807286111766942*^9, 3.807287600420722*^9, 
   3.8073064950689464`*^9, 3.8073065523675594`*^9, 3.8073070777513323`*^9, 
   3.8073082138814845`*^9, 3.8073092280710907`*^9, 3.8078829566000113`*^9, 
   3.8078841015607443`*^9, 3.807884909142721*^9, 3.8100471250117426`*^9, 
   3.8100472788911858`*^9, 3.810047371131748*^9, 3.8110711070227094`*^9, 
   3.8124706093294964`*^9, 3.812470933171067*^9, 3.812471183647109*^9, 
   3.8124715450281706`*^9, 3.812736065788962*^9, 3.8128215922404585`*^9, 
   3.812969635019828*^9, 3.812970401616369*^9, 3.812971117692525*^9, 
   3.812976161975587*^9, 3.812976547662438*^9, 3.8139963190358334`*^9, 
   3.8139969189458914`*^9, 3.813998566610252*^9, 3.8139989544123106`*^9, 
   3.8139992520790396`*^9, 3.813999710480091*^9, 3.8140267199520097`*^9, 
   3.814026911564184*^9, 3.8140270830877132`*^9, 3.814830307634097*^9, 
   3.8154774895812473`*^9, 3.815477794827817*^9, 3.8154778566505404`*^9, 
   3.815478610065011*^9, 3.8157753930320587`*^9, 3.8170334474144955`*^9, 
   3.817033479547603*^9, 3.818801078775099*^9, 3.8254166102984343`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1790]=",ExpressionUUID->"17481130-ba48-4198-9207-faf90af0c3a0"]
}, Open  ]],

Cell[TextData[StyleBox["Bluefin Tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, {3.804858674828244*^9, 3.8048586759846716`*^9}, {
   3.805021921987334*^9, 3.8050219236606793`*^9}, {3.805021961587508*^9, 
   3.80502196249391*^9}, 
   3.825287987736072*^9},ExpressionUUID->"4218ea7d-769b-45dd-93f1-\
47d55b74dca5"],

Cell["Percent change in price of unprocessed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}},ExpressionUUID->"450fdd62-51c3-4ecb-af6d-\
2332ff3da21c"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pfdu1", "-", "pfdu0"}], ")"}], "100"}], "pfdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
   3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
   3.8048585992018385`*^9}, {3.8048587486137724`*^9, 3.804858750004611*^9}, {
   3.805017872704455*^9, 3.805017872704455*^9}, 3.805020287887725*^9, {
   3.8050219705421343`*^9, 3.8050219718079715`*^9}},
 CellLabel->
  "In[1791]:=",ExpressionUUID->"56090cfd-1d7b-48fd-b0de-5dcca13a9788"],

Cell[BoxData["10.14989981206995`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.804858847139168*^9, 3.804858890192608*^9, 
   3.804859666825571*^9, 3.8048597532291985`*^9, 3.8048599673748865`*^9, 
   3.804860114402596*^9, 3.8048603837216387`*^9, 3.8048605407393417`*^9, 
   3.8048606726728387`*^9, 3.804861492313425*^9, 3.8048659526859646`*^9, 
   3.8048662764034476`*^9, 3.8048664469938164`*^9, 3.8048672534297056`*^9, 
   3.8048811936294165`*^9, 3.804895272018732*^9, 3.8048961514683075`*^9, 
   3.8048969490185413`*^9, 3.8050220344300537`*^9, 3.8050235068126426`*^9, 
   3.805023688074092*^9, 3.8050238518552823`*^9, 3.805025226548814*^9, 
   3.8056381030281982`*^9, 3.805638199306449*^9, 3.8056386224624605`*^9, 
   3.8056408851934795`*^9, 3.80564107169458*^9, 3.805665833820078*^9, 
   3.807280225072898*^9, 3.8072857843089623`*^9, 3.8072861123974433`*^9, 
   3.8072876009631796`*^9, 3.807306495618373*^9, 3.8073065529339724`*^9, 
   3.80730707836681*^9, 3.8073082140716333`*^9, 3.8073092282542343`*^9, 
   3.8078829567875423`*^9, 3.8078841017639027`*^9, 3.8078849093458796`*^9, 
   3.8100471251958857`*^9, 3.8100472790983243`*^9, 3.8100473713459144`*^9, 
   3.811071107217863*^9, 3.8124706095106244`*^9, 3.812470933370223*^9, 
   3.8124711838522573`*^9, 3.8124715452563715`*^9, 3.8127360659790707`*^9, 
   3.8128215924426155`*^9, 3.812969635254239*^9, 3.812970401850846*^9, 
   3.812971117958234*^9, 3.812976162239792*^9, 3.8129765479806967`*^9, 
   3.813996319263009*^9, 3.813996919165062*^9, 3.8139985667603693`*^9, 
   3.8139989546404877`*^9, 3.813999252302214*^9, 3.813999710700262*^9, 
   3.8140267201992025`*^9, 3.8140269117933626`*^9, 3.814027083337908*^9, 
   3.814830307846263*^9, 3.8154774898469167`*^9, 3.815477795093486*^9, 
   3.8154778569162097`*^9, 3.815478610299445*^9, 3.815775393302306*^9, 
   3.8170334474305077`*^9, 3.817033479560273*^9, 3.8188010787911105`*^9, 
   3.825416610600707*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1791]=",ExpressionUUID->"a98afb95-c4cc-4956-ad28-b745472914c6"]
}, Open  ]],

Cell["Percent change in quantity of landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.807308034849162*^9},ExpressionUUID->"24eb6752-0047-4e28-89e2-\
f95f91f72967"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qfdu1", "-", "qfdu0"}], ")"}], "100"}], "qfdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.804858792627643*^9, 3.804858798896052*^9}, {3.8050173592553644`*^9, 
  3.8050173592553644`*^9}, {3.8050219270518637`*^9, 3.8050219271612563`*^9}, {
  3.8050219723393106`*^9, 3.805021972995671*^9}},
 CellLabel->
  "In[1792]:=",ExpressionUUID->"94afbe0c-530f-4e5c-ac5d-c29ef322b4d6"],

Cell[BoxData["17.512397289750755`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.8048588472798543`*^9, 3.8048588903332553`*^9, 
   3.8048596669662247`*^9, 3.8048597533854685`*^9, 3.8048599675155373`*^9, 
   3.8048601145432453`*^9, 3.8048603838622866`*^9, 3.8048605408956027`*^9, 
   3.804860672829114*^9, 3.804861492438445*^9, 3.8048659527953568`*^9, 
   3.8048662765128403`*^9, 3.8048664471032095`*^9, 3.804867253539048*^9, 
   3.804881193738809*^9, 3.804895272128127*^9, 3.8048961515777006`*^9, 
   3.8048969491279335`*^9, 3.8050220346019554`*^9, 3.805023510345631*^9, 
   3.8050236882928762`*^9, 3.805023852039565*^9, 3.805025226736346*^9, 
   3.805638103200101*^9, 3.805638199447096*^9, 3.805638622634364*^9, 
   3.805640885474696*^9, 3.8056410719133654`*^9, 3.8056658340701213`*^9, 
   3.8072802252820597`*^9, 3.807285784502113*^9, 3.807286112604644*^9, 
   3.8072876011422825`*^9, 3.807306495828536*^9, 3.807306553125121*^9, 
   3.807307078555957*^9, 3.8073082142607813`*^9, 3.8073092284463844`*^9, 
   3.807882956975074*^9, 3.807884102029572*^9, 3.807884909533409*^9, 
   3.810047125384032*^9, 3.810047279300481*^9, 3.81004737154607*^9, 
   3.8110711074140177`*^9, 3.812470609693768*^9, 3.8124709335724316`*^9, 
   3.812471184067424*^9, 3.8124715454865294`*^9, 3.8127360661822305`*^9, 
   3.8128215926357656`*^9, 3.812969635488651*^9, 3.81297040208525*^9, 
   3.812971118208237*^9, 3.812976162500995*^9, 3.812976548333906*^9, 
   3.813996319488186*^9, 3.813996919344201*^9, 3.8139985669755363`*^9, 
   3.8139989548636613`*^9, 3.8139992525614157`*^9, 3.8139997109374466`*^9, 
   3.814026720432385*^9, 3.814026911988514*^9, 3.8140270835771055`*^9, 
   3.814830308092454*^9, 3.815477490096958*^9, 3.8154777953591547`*^9, 
   3.815477857181877*^9, 3.815478610549466*^9, 3.8157753936065073`*^9, 
   3.817033447448522*^9, 3.8170334795732837`*^9, 3.8188010788081236`*^9, 
   3.8254166108298388`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1792]=",ExpressionUUID->"7b3ce028-34e3-4397-bf46-7693635cf311"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 
  3.80485427153401*^9}},ExpressionUUID->"db0a1358-4a60-450f-b7cf-\
5f324b03ab1d"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pfdp1", "-", "pfdp0"}], ")"}], "100"}], "pfdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
   3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
   3.8048586124851284`*^9}, {3.804858750567197*^9, 3.8048587511610384`*^9}, {
   3.805018163895453*^9, 3.8050181639110804`*^9}, 3.805020631092285*^9, {
   3.805021973339478*^9, 3.8050219739802103`*^9}},
 CellLabel->
  "In[1793]:=",ExpressionUUID->"723820a5-12be-4dc4-87e2-370f42900cb2"],

Cell[BoxData["25.498988749851453`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.804858847436088*^9, 3.8048588904739017`*^9, 
   3.8048596671068783`*^9, 3.804859753526121*^9, 3.804859967671815*^9, 
   3.804860114699522*^9, 3.80486038403419*^9, 3.8048605410518775`*^9, 
   3.8048606730010166`*^9, 3.8048614925478373`*^9, 3.80486595290475*^9, 
   3.804866276622233*^9, 3.8048664472126026`*^9, 3.8048672536484404`*^9, 
   3.8048811938325744`*^9, 3.8048952722375216`*^9, 3.804896151687093*^9, 
   3.8048969492373266`*^9, 3.8050220347738743`*^9, 3.8050235138774276`*^9, 
   3.805023688480405*^9, 3.805023852186414*^9, 3.8050252269082675`*^9, 
   3.8056381033563952`*^9, 3.8056381996033716`*^9, 3.8056386228218966`*^9, 
   3.80564088576492*^9, 3.805641072194661*^9, 3.805665834257654*^9, 
   3.8072802254662027`*^9, 3.8072857847483044`*^9, 3.807286112879809*^9, 
   3.8072876013224225`*^9, 3.80730649598666*^9, 3.807306553360304*^9, 
   3.8073070787491064`*^9, 3.807308214451931*^9, 3.8073092286325293`*^9, 
   3.80788295719386*^9, 3.807884102232731*^9, 3.8078849097365675`*^9, 
   3.8100471255661736`*^9, 3.810047279508643*^9, 3.810047371748227*^9, 
   3.8110711076081705`*^9, 3.8124706098759108`*^9, 3.8124709337715373`*^9, 
   3.812471184269581*^9, 3.8124715456886883`*^9, 3.812736066378384*^9, 
   3.812821592839924*^9, 3.812969635723062*^9, 3.8129704023352633`*^9, 
   3.8129711184426513`*^9, 3.812976162765236*^9, 3.8129765486511583`*^9, 
   3.813996319714363*^9, 3.813996919579384*^9, 3.8139985671216497`*^9, 
   3.813998955089837*^9, 3.8139992527845893`*^9, 3.813999711119588*^9, 
   3.814026720660564*^9, 3.8140269122166915`*^9, 3.8140270838142877`*^9, 
   3.8148303084066987`*^9, 3.815477490378255*^9, 3.815477795640483*^9, 
   3.815477857431917*^9, 3.81547861078388*^9, 3.8157753939637876`*^9, 
   3.8170334474645343`*^9, 3.817033479587294*^9, 3.818801078824136*^9, 
   3.8254166110660505`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1793]=",ExpressionUUID->"7ae51b88-283f-430e-80a1-805e6d06fc88"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
  3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
  3.804854255481004*^9, 
  3.8048542778511686`*^9}},ExpressionUUID->"d63966ad-6121-4cf6-b01f-\
2fbdecdec67b"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qfdp1", "-", "qfdp0"}], ")"}], "100"}], "qfdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}, {
  3.8048587995680304`*^9, 3.8048588001931267`*^9}, {3.8050174161743164`*^9, 
  3.8050174161743164`*^9}, {3.805021931896407*^9, 3.805021932052683*^9}, {
  3.8050219743865285`*^9, 3.8050219750897713`*^9}},
 CellLabel->
  "In[1794]:=",ExpressionUUID->"68f53163-64e4-4bab-97c5-0be5b965d0c8"],

Cell[BoxData[
 RowBox[{"-", "35.023654356133406`"}]], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.8048588475923624`*^9, 3.8048588906145487`*^9, 
   3.8048596672475457`*^9, 3.8048597536824007`*^9, 3.8048599678124647`*^9, 
   3.8048601148557987`*^9, 3.8048603841904664`*^9, 3.804860541192525*^9, 
   3.804860673141664*^9, 3.80486149265723*^9, 3.804865953014142*^9, 
   3.8048662767316256`*^9, 3.8048664473219957`*^9, 3.804867253757833*^9, 
   3.8048811939419665`*^9, 3.804895272346916*^9, 3.8048961517964897`*^9, 
   3.804896949346719*^9, 3.8050220349770126`*^9, 3.805023514330623*^9, 
   3.805023688699188*^9, 3.8050238523270607`*^9, 3.8050252271426663`*^9, 
   3.8056381035126514`*^9, 3.805638199759647*^9, 3.8056386229938*^9, 
   3.805640886142211*^9, 3.8056410724134684`*^9, 3.8056658344608145`*^9, 
   3.8072802256213236`*^9, 3.8072857849424562`*^9, 3.807286113083967*^9, 
   3.80728760157662*^9, 3.8073064961437826`*^9, 3.8073065535514517`*^9, 
   3.8073070789382534`*^9, 3.8073082146841116`*^9, 3.8073092288066645`*^9, 
   3.8078829573813925`*^9, 3.80788410243589*^9, 3.807884909924097*^9, 
   3.8100471257523174`*^9, 3.8100472797288136`*^9, 3.8100473719533863`*^9, 
   3.811071107805326*^9, 3.8124706100560513`*^9, 3.8124709339837036`*^9, 
   3.8124711844737587`*^9, 3.8124715458848577`*^9, 3.8127360665745373`*^9, 
   3.8128215930340753`*^9, 3.8129696359887285`*^9, 3.812970402569685*^9, 
   3.8129711186926937`*^9, 3.812976163004326*^9, 3.812976548970505*^9, 
   3.813996319935536*^9, 3.813996919799555*^9, 3.813998567269765*^9, 
   3.8139989553150115`*^9, 3.813999253005761*^9, 3.8139997113397584`*^9, 
   3.814026720892746*^9, 3.8140269125239305`*^9, 3.814027084051462*^9, 
   3.81483030870393*^9, 3.8154774906282964`*^9, 3.8154777958904934`*^9, 
   3.815477857697585*^9, 3.8154786110339217`*^9, 3.815775394264022*^9, 
   3.817033447480547*^9, 3.8170334795993037`*^9, 3.818801078840149*^9, 
   3.825416611326228*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1794]=",ExpressionUUID->"4c651103-930f-4a22-8f9f-3a5ddedb108f"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.805638279440954*^9}, 3.807307550636341*^9, {3.8252883131700807`*^9, 
   3.825288313830598*^9}},ExpressionUUID->"7aaec84f-28ec-43dc-9c0d-\
7c24baf7c1d2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmafu"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"pfdu1", " ", 
     RowBox[{"(", 
      RowBox[{"qfdu1", "-", "qfdue0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"pfdu0", " ", 
     RowBox[{"(", 
      RowBox[{"qfdu0", "-", "qfdue0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.8056384216076107`*^9, 3.8056384298283195`*^9}, {3.805638482271556*^9, 
  3.805638484475052*^9}, {3.8056385455867786`*^9, 3.8056385532289257`*^9}, {
  3.805641159935579*^9, 3.805641170014205*^9}, {3.812821720747475*^9, 
  3.812821731161583*^9}, {3.8252883172682858`*^9, 3.8252883193629656`*^9}},
 CellLabel->
  "In[1795]:=",ExpressionUUID->"0f6d3918-5b7f-4641-bec4-b82597f6ff62"],

Cell[BoxData["445928.2961513961`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBOIXX1Os1ke9cSxyyHfdDaQvB4X0nI994/jjt53zJSAt
4eaaA6I5JvirXQbSbSvlE+4AaVHLwHQQvf/13xUgOuzhbbO7QPpl1vytIHq+
yaabX+OA+ouvZHwD0k1CR8+CaL7ufZPEkt84Lvn8dymIzvvUshFEf7hVP4Er
9Y1j5U/3V1vT3zhO/XRUaBuQPjBD1AhE+zx0igfR0jMjOswz3jgu8FX3TgTS
Ab/bY0D0D+X2KSuBtJt11BcQ/UHrvu8qIH1rceaRNUB6R9/KLyA62pX1ybys
N44Guxj05wPpewve/gHRM1YX6i4A0jbey4NANMviD90g+hy/yp61QFporcQV
EH3apfMliJ53cJ6MWc4bxz/SMXJFuUB7/7e4gOhvl+x8QLSVWOYqEL2IJ3gK
cx6Qf+f9ncwCoLoFnx+A6KrY299OFAP9oVBkkt7wxhEA9xLR7Q==
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1795]=",ExpressionUUID->"aa2896c3-55b5-49d5-ba06-f6ee9bd5dcdd"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.8056382995792217`*^9}, 3.8073075741686535`*^9, {3.8252883232109523`*^9, 
   3.825288323534256*^9}},ExpressionUUID->"9dee2c40-173a-42b9-aeeb-\
7e163ad84820"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmafp"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"pfdp1", " ", 
     RowBox[{"(", 
      RowBox[{"qfdp1", "-", "qfdpe0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"pfdp0", " ", 
     RowBox[{"(", 
      RowBox[{"qfdp0", "-", "qfdpe0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.805638311659393*^9, 3.805638322630473*^9}, {3.805638433988842*^9, 
  3.8056384793310328`*^9}, {3.8056385581946573`*^9, 3.805638565431512*^9}, {
  3.8056411773904*^9, 3.8056411807971945`*^9}, {3.812821746770728*^9, 
  3.812821761350078*^9}, {3.8252883270499783`*^9, 3.8252883294998684`*^9}},
 CellLabel->
  "In[1796]:=",ExpressionUUID->"bfde672c-99ff-4d1c-a60f-c070caec272f"],

Cell[BoxData[
 RowBox[{"-", "631282.6446020592`"}]], "Output",
 CellChangeTimes->{
  3.8056382863724117`*^9, 3.805638323678563*^9, {3.805638445362606*^9, 
   3.8056384571096716`*^9}, 3.805638624072034*^9, 3.8056408880827065`*^9, 
   3.8056410738355513`*^9, 3.805641181469179*^9, 3.8056658356641717`*^9, 
   3.8072802268222966`*^9, 3.8072857861614075`*^9, 3.807286114364963*^9, 
   3.8072876027275195`*^9, 3.8073064971855965`*^9, 3.8073065547273645`*^9, 
   3.807307080127177*^9, 3.807308215062405*^9, 3.807309229154935*^9, 
   3.8078829577720833`*^9, 3.80788410282658*^9, 3.807884910392951*^9, 
   3.810047126137616*^9, 3.8100472801391325`*^9, 3.810047372367708*^9, 
   3.811071108197652*^9, 3.8124706104303446`*^9, 3.812470934384017*^9, 
   3.812471184879054*^9, 3.812471546312215*^9, 3.8127360669628415`*^9, 
   3.812821593420375*^9, 3.8128217622217565`*^9, 3.812969636441924*^9, 
   3.8129704030541573`*^9, 3.8129711192084055`*^9, 3.812976163598177*^9, 
   3.812976549626857*^9, 3.813996320369898*^9, 3.813996920244901*^9, 
   3.813998567576003*^9, 3.8139989557723675`*^9, 3.813999253448104*^9, 
   3.813999711744074*^9, 3.8140267213661156`*^9, 3.8140269130233183`*^9, 
   3.8140270845438457`*^9, 3.8148303092113276`*^9, 3.8154774911440053`*^9, 
   3.8154777964218283`*^9, 3.8154778582289214`*^9, 3.8154786115183773`*^9, 
   3.815775395174733*^9, 3.81703344752659*^9, 3.817033479639335*^9, 
   3.8188010788851833`*^9, 3.825416611800596*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1796]=",ExpressionUUID->"ba091999-c29b-4628-99ca-000c4d5687b2"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"2090d4c0-b256-42fd-b0b9-\
855673c13eef"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pftu1", "-", "pftu0"}], ")"}], "100"}], "pftu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
   3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
   3.8048586228946285`*^9}, {3.804858751489214*^9, 3.8048587520986824`*^9}, {
   3.805018113403982*^9, 3.8050181134196095`*^9}, 3.80502029645166*^9, {
   3.8050219755586004`*^9, 3.805021976308726*^9}},
 CellLabel->
  "In[1797]:=",ExpressionUUID->"de86e58c-bebe-4284-aaa1-d0f138eda711"],

Cell[BoxData["27.912714381144216`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.8048588477330093`*^9, 3.8048588907551947`*^9, 
   3.8048596674038343`*^9, 3.804859753823053*^9, 3.8048599679531155`*^9, 
   3.804860114996448*^9, 3.8048603843467426`*^9, 3.8048605413487997`*^9, 
   3.804860673297939*^9, 3.8048614927666225`*^9, 3.8048659531235347`*^9, 
   3.8048662768410177`*^9, 3.804866447431389*^9, 3.804867253867225*^9, 
   3.804881194051359*^9, 3.804895272440683*^9, 3.804896151905878*^9, 
   3.804896949456112*^9, 3.8050220351489143`*^9, 3.8050235177999105`*^9, 
   3.805023688886718*^9, 3.8050238524833345`*^9, 3.8050252273301992`*^9, 
   3.805638103684554*^9, 3.805638199932612*^9, 3.805638623165704*^9, 
   3.8056408864944825`*^9, 3.805641072616604*^9, 3.805665834648348*^9, 
   3.807280225817476*^9, 3.807285785135625*^9, 3.807286113286124*^9, 
   3.8072876017587624`*^9, 3.8073064963009405`*^9, 3.8073065537426004`*^9, 
   3.8073070791274004`*^9, 3.807308215252553*^9, 3.807309229340087*^9, 
   3.8078829579752426`*^9, 3.8078841030766225`*^9, 3.807884910580452*^9, 
   3.8100471263247905`*^9, 3.8100472803432903`*^9, 3.810047372566862*^9, 
   3.811071108391788*^9, 3.8124706106084843`*^9, 3.81247093458117*^9, 
   3.812471185089218*^9, 3.8124715465193357`*^9, 3.812736067161998*^9, 
   3.8128215936295385`*^9, 3.812969636691964*^9, 3.812970403304208*^9, 
   3.812971119458448*^9, 3.8129761638794737`*^9, 3.8129765499549994`*^9, 
   3.813996320579039*^9, 3.813996920471076*^9, 3.8139985677971754`*^9, 
   3.813998955993539*^9, 3.8139992537133102`*^9, 3.8139997119852614`*^9, 
   3.8140267215942926`*^9, 3.814026913210464*^9, 3.8140270847830315`*^9, 
   3.814830309485547*^9, 3.8154774914096727`*^9, 3.815477796703124*^9, 
   3.815477858510218*^9, 3.8154786117527914`*^9, 3.8157753954659777`*^9, 
   3.8170334475546117`*^9, 3.817033479652897*^9, 3.8188010789011955`*^9, 
   3.8254166120348063`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1797]=",ExpressionUUID->"7ed31432-3ed0-4bdd-aaaa-14eaf120958b"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
  3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
  3.8048542553403563`*^9, 
  3.8048542677330275`*^9}},ExpressionUUID->"9b717b62-22c7-40d2-8555-\
3d175d47ea17"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qftu1", "-", "qftu0"}], ")"}], "100"}], "qftu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.804858800630694*^9, 3.8048588012870445`*^9}, {3.8050174723410645`*^9, 
  3.8050174723410645`*^9}, {3.805021936100234*^9, 3.8050219362096276`*^9}, {
  3.805021976793182*^9, 3.8050219775120525`*^9}},
 CellLabel->
  "In[1798]:=",ExpressionUUID->"80ee4855-2358-4c1e-8eb0-cfa9ea0d31e9"],

Cell[BoxData[
 RowBox[{"-", "42.883585987984006`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588478736553`*^9, 3.8048588909114695`*^9, 
   3.8048596675600967`*^9, 3.804859753963705*^9, 3.804859968109393*^9, 
   3.804860115168353*^9, 3.8048603844873915`*^9, 3.8048605415207024`*^9, 
   3.8048606734385867`*^9, 3.8048614928760147`*^9, 3.804865953232927*^9, 
   3.8048662769660378`*^9, 3.8048664475407825`*^9, 3.804867253961108*^9, 
   3.8048811941607513`*^9, 3.804895272550078*^9, 3.8048961520152717`*^9, 
   3.804896949565504*^9, 3.8050220353208165`*^9, 3.805023518253105*^9, 
   3.8050236890898733`*^9, 3.8050238526239815`*^9, 3.8050252275021043`*^9, 
   3.80563810384083*^9, 3.8056382001670246`*^9, 3.80563862335087*^9, 
   3.8056408867907104`*^9, 3.8056410728353896`*^9, 3.8056658348515077`*^9, 
   3.8072802260066223`*^9, 3.8072857853317966`*^9, 3.8072861134962873`*^9, 
   3.807287601940905*^9, 3.807306496458029*^9, 3.807306553932748*^9, 
   3.807307079357579*^9, 3.8073082154537086`*^9, 3.807309229518217*^9, 
   3.8078829582096562`*^9, 3.8078841032797813`*^9, 3.8078849107836103`*^9, 
   3.8100471265169106`*^9, 3.810047280551452*^9, 3.8100473727710204`*^9, 
   3.8110711085849404`*^9, 3.8124706107906275`*^9, 3.812470934778323*^9, 
   3.8124711852923756`*^9, 3.8124715467224936`*^9, 3.812736067364156*^9, 
   3.8128215938316965`*^9, 3.8129696369263783`*^9, 3.8129704035386295`*^9, 
   3.81297111970849*^9, 3.8129761641451426`*^9, 3.81297655028316*^9, 
   3.813996320783206*^9, 3.813996920702256*^9, 3.813998568012342*^9, 
   3.8139989562137103`*^9, 3.8139992539314923`*^9, 3.8139997122124395`*^9, 
   3.8140267218244715`*^9, 3.81402691344965*^9, 3.8140270850242186`*^9, 
   3.814830309752756*^9, 3.815477491659713*^9, 3.8154777969531636`*^9, 
   3.815477858760259*^9, 3.8154786120028324`*^9, 3.815775395788213*^9, 
   3.817033447569623*^9, 3.8170334796655197`*^9, 3.8188010789172087`*^9, 
   3.8254166122759657`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1798]=",ExpressionUUID->"1d4dbea0-1fac-493e-be4c-fb66c33396b8"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"80e05d25-81b9-4c74-8b36-\
582590678ca5"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pftp1", "-", "pftp0"}], ")"}], "100"}], "pftp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
   3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
   3.804858633427496*^9}, {3.804858752504995*^9, 3.804858754192754*^9}, {
   3.8050182855042944`*^9, 3.8050182855042944`*^9}, 3.8050206707402067`*^9, {
   3.8050219781371574`*^9, 3.8050219789810486`*^9}},
 CellLabel->
  "In[1799]:=",ExpressionUUID->"8de93699-9283-4fb5-8557-04fa7ddb7614"],

Cell[BoxData["22.17569723108303`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.8048588480143023`*^9, 3.8048588910677433`*^9, 3.8048596677007504`*^9, 
   3.8048597541199846`*^9, 3.804859968250043*^9, 3.804860115309002*^9, 
   3.8048603846436667`*^9, 3.804860541708233*^9, 3.804860673594861*^9, 
   3.804861492985408*^9, 3.804865953357947*^9, 3.8048662770754304`*^9, 
   3.804866447650175*^9, 3.804867254086011*^9, 3.8048811942701445`*^9, 
   3.8048952726594725`*^9, 3.8048961521246634`*^9, 3.8048969496748967`*^9, 
   3.805022035492718*^9, 3.805023521786112*^9, 3.805023689277403*^9, 
   3.8050238527802753`*^9, 3.8050252276740093`*^9, 3.8056381039971046`*^9, 
   3.8056382003233*^9, 3.8056386235563216`*^9, 3.805640887131996*^9, 
   3.8056410730385475`*^9, 3.805665835101551*^9, 3.807280226236801*^9, 
   3.807285785525913*^9, 3.8072861136984444`*^9, 3.8072876021220465`*^9, 
   3.8073064966161523`*^9, 3.807306554119893*^9, 3.8073070795517297`*^9, 
   3.807308215645858*^9, 3.8073092296943536`*^9, 3.807882958397188*^9, 
   3.8078841035141954`*^9, 3.807884910986768*^9, 3.810047126705057*^9, 
   3.8100472807636166`*^9, 3.810047372973178*^9, 3.811071108780094*^9, 
   3.8124706109717693`*^9, 3.8124709349754763`*^9, 3.812471185492531*^9, 
   3.8124715469306555`*^9, 3.812736067563312*^9, 3.8128215940268497`*^9, 
   3.8129696371607866`*^9, 3.81297040378868*^9, 3.8129711199897876`*^9, 
   3.812976164488949*^9, 3.8129765505956955`*^9, 3.813996320989358*^9, 
   3.8139969209224625`*^9, 3.813998568324585*^9, 3.813998956434882*^9, 
   3.8139992541506505`*^9, 3.8139997124336133`*^9, 3.8140267220556517`*^9, 
   3.8140269136828313`*^9, 3.8140270852564163`*^9, 3.8148303100069942`*^9, 
   3.815477491909753*^9, 3.8154777972188325`*^9, 3.8154778590259285`*^9, 
   3.8154786122372465`*^9, 3.815775396061426*^9, 3.817033447584652*^9, 
   3.81703347967953*^9, 3.818801078933221*^9, 3.8254166125422106`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1799]=",ExpressionUUID->"966993a9-24a0-41de-ae6c-cf09d3275779"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
  3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
  3.804854223908785*^9}, {3.8048542555122595`*^9, 
  3.804854280414089*^9}},ExpressionUUID->"ac46c285-8b93-4bb6-bcdb-\
f882303c7001"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qftp1", "-", "qftp0"}], ")"}], "100"}], "qftp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.804858801740239*^9, 3.8048588038343105`*^9}, {3.805017523503875*^9, 
  3.805017523503875*^9}, {3.8050219403353195`*^9, 3.805021940413457*^9}, {
  3.8050219796061535`*^9, 3.8050219820909452`*^9}},
 CellLabel->
  "In[1800]:=",ExpressionUUID->"a1c615de-cb31-4f3e-a739-b80014746c13"],

Cell[BoxData[
 RowBox[{"-", "23.580973592109455`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.804858848154949*^9, 3.804858891192762*^9, 3.8048596678726606`*^9, 
   3.804859754260637*^9, 3.80485996839496*^9, 3.804860115465279*^9, 
   3.804860384799943*^9, 3.80486054184888*^9, 3.80486067373553*^9, 
   3.80486149309489*^9, 3.804865953482967*^9, 3.804866277169195*^9, 
   3.804866447759568*^9, 3.804867254195405*^9, 3.8048811943795366`*^9, 
   3.804895272768914*^9, 3.8048961522340565`*^9, 3.8048969497842894`*^9, 
   3.8050220356646194`*^9, 3.8050235222393055`*^9, 3.8050236894805593`*^9, 
   3.805023852999039*^9, 3.805025227845913*^9, 3.8056381041690073`*^9, 
   3.805638200463972*^9, 3.8056386237282257`*^9, 3.8056408874221973`*^9, 
   3.805641073351098*^9, 3.805665835289084*^9, 3.80728022642795*^9, 
   3.8072857857711043`*^9, 3.807286113965652*^9, 3.80728760230519*^9, 
   3.807306496808303*^9, 3.8073065543070383`*^9, 3.8073070797418776`*^9, 
   3.8073082158780384`*^9, 3.8073092298714914`*^9, 3.807882958584756*^9, 
   3.807884103701727*^9, 3.80788491122118*^9, 3.810047126896205*^9, 
   3.8100472809707775`*^9, 3.810047373174334*^9, 3.811071108971245*^9, 
   3.812470611153911*^9, 3.8124709351856394`*^9, 3.812471185694743*^9, 
   3.812471547136816*^9, 3.8127360677554626`*^9, 3.8128215942240043`*^9, 
   3.812969637395198*^9, 3.81297040403873*^9, 3.81297112023983*^9, 
   3.8129761647702446`*^9, 3.8129765509238987`*^9, 3.8139963212105293`*^9, 
   3.8139969210975637`*^9, 3.8139985685857887`*^9, 3.813998956695126*^9, 
   3.8139992543698215`*^9, 3.813999712654786*^9, 3.8140267222938366`*^9, 
   3.814026913872979*^9, 3.8140270854915824`*^9, 3.8148303102621484`*^9, 
   3.8154774921597943`*^9, 3.8154777975001297`*^9, 3.8154778592915983`*^9, 
   3.8154786124872885`*^9, 3.8157753963636675`*^9, 3.817033447600308*^9, 
   3.81703347969254*^9, 3.8188010789482327`*^9, 3.8254166127754087`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1800]=",ExpressionUUID->"8e792a50-a874-4d37-992e-90ce5001bdc1"]
}, Open  ]],

Cell[TextData[StyleBox["Skipjack Tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, {3.8048586570286355`*^9, 
   3.8048586579193974`*^9}, {3.805021797773653*^9, 3.805021799900277*^9}, 
   3.825287998435383*^9},ExpressionUUID->"3c230a6e-b45f-406a-b862-\
d16c7d588e39"],

Cell["Percent change in price of unprocessed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}},ExpressionUUID->"d31b970b-01b3-4a91-a1a6-\
1f6a8fc987d5"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"psdu1", "-", "psdu0"}], ")"}], "100"}], "psdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
  3.8048585992018385`*^9}, {3.804858707793745*^9, 3.804858709669033*^9}, {
  3.8050178642655945`*^9, 3.8050178642655945`*^9}, {3.805020241988159*^9, 
  3.805020269539652*^9}, {3.805021810715742*^9, 3.805021814481985*^9}},
 CellLabel->
  "In[1801]:=",ExpressionUUID->"00ca3398-e60a-4f27-9f2f-ebb60f90afab"],

Cell[BoxData["2.118765333406307`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.8048588448373566`*^9, 3.8048588879266357`*^9, 
   3.8048596644969683`*^9, 3.804859750838105*^9, 3.804859965019943*^9, 
   3.804860111964675*^9, 3.8048603812524815`*^9, 3.8048605381920447`*^9, 
   3.804860670219321*^9, 3.804861490422487*^9, 3.8048659509044294`*^9, 
   3.8048662745594025`*^9, 3.8048664452122755`*^9, 3.8048672516168933`*^9, 
   3.8048811919729013`*^9, 3.8048952703465557`*^9, 3.804896149655515*^9, 
   3.804896947252631*^9, 3.805022030272558*^9, 3.80502345424335*^9, 
   3.8050236825107317`*^9, 3.80502384782094*^9, 3.8050252220151663`*^9, 
   3.8056380993724422`*^9, 3.805638195274688*^9, 3.8056386168788757`*^9, 
   3.8056408769231057`*^9, 3.8056410634725213`*^9, 3.8056658273584056`*^9, 
   3.807280219777773*^9, 3.8072857783052883`*^9, 3.807286106338717*^9, 
   3.8072875952777205`*^9, 3.807306490280222*^9, 3.807306546875255*^9, 
   3.807307072360133*^9, 3.807308207943865*^9, 3.8073092300526314`*^9, 
   3.8078829587722497`*^9, 3.8078841039048862`*^9, 3.8078849114243383`*^9, 
   3.810047127094374*^9, 3.8100472811759367`*^9, 3.8100473733854976`*^9, 
   3.811071109174404*^9, 3.8124706113451104`*^9, 3.8124709353868375`*^9, 
   3.8124711858968453`*^9, 3.812471547387012*^9, 3.8127360679496145`*^9, 
   3.81282159442216*^9, 3.8129696376296096`*^9, 3.8129704042731524`*^9, 
   3.812971120474244*^9, 3.81297616505154*^9, 3.812976551252042*^9, 
   3.8139963214337034`*^9, 3.8139969213177347`*^9, 3.813998568750919*^9, 
   3.8139989569182577`*^9, 3.813999254590993*^9, 3.813999712877961*^9, 
   3.8140267225330224`*^9, 3.814026914120171*^9, 3.8140270857758055`*^9, 
   3.8148303105423965`*^9, 3.8154774924254637`*^9, 3.8154777977501707`*^9, 
   3.815477859557267*^9, 3.8154786127373295`*^9, 3.8157753966659074`*^9, 
   3.8170334476163206`*^9, 3.817033479705551*^9, 3.8188010789642444`*^9, 
   3.82541661300558*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1801]=",ExpressionUUID->"6820c5c6-9515-4236-a689-735d7d84fae9"]
}, Open  ]],

Cell["Percent change in quantity of landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.807308034822141*^9},ExpressionUUID->"e62e74d7-9a4e-444a-8002-\
5e78b3fe9904"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qsdu1", "-", "qsdu0"}], ")"}], "100"}], "qsdu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.8048587148420916`*^9, 3.8048587164829683`*^9}, {3.805017337173911*^9, 
  3.805017337173911*^9}, {3.8050218183576193`*^9, 3.805021818437133*^9}},
 CellLabel->
  "In[1802]:=",ExpressionUUID->"ea07afa0-19bc-4d7b-a798-fbd50f5b1b9b"],

Cell[BoxData["10.481161347722363`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.80485884497801*^9, 3.804858888051656*^9, 
   3.804859664637623*^9, 3.804859750994385*^9, 3.8048599651660595`*^9, 
   3.8048601121053247`*^9, 3.8048603814087563`*^9, 3.804860538363948*^9, 
   3.804860670359969*^9, 3.804861490563135*^9, 3.8048659510138216`*^9, 
   3.804866274668795*^9, 3.8048664453372965`*^9, 3.8048672517262497`*^9, 
   3.8048811920666666`*^9, 3.8048952704403224`*^9, 3.8048961497805357`*^9, 
   3.8048969473620243`*^9, 3.805022030428833*^9, 3.805023457356555*^9, 
   3.8050236827920246`*^9, 3.8050238480084696`*^9, 3.8050252222026987`*^9, 
   3.80563809951309*^9, 3.805638195399708*^9, 3.8056386170507793`*^9, 
   3.8056408771722975`*^9, 3.805641063753812*^9, 3.8056658275459385`*^9, 
   3.807280219957913*^9, 3.8072857785014405`*^9, 3.807286106533869*^9, 
   3.80728759545586*^9, 3.807306490494388*^9, 3.807306547070408*^9, 
   3.8073070725733*^9, 3.8073082081570306`*^9, 3.8073092302287683`*^9, 
   3.8078829590066643`*^9, 3.807884104170555*^9, 3.807884911611868*^9, 
   3.8100471272855077`*^9, 3.810047281384098*^9, 3.8100473735836515`*^9, 
   3.811071109381568*^9, 3.812470611528202*^9, 3.81247093558395*^9, 
   3.8124711861030054`*^9, 3.812471547592184*^9, 3.8127360681467686`*^9, 
   3.812821594639328*^9, 3.812969637895276*^9, 3.812970404523202*^9, 
   3.812971120739914*^9, 3.812976165348463*^9, 3.8129765515689416`*^9, 
   3.813996321756954*^9, 3.8139969214949083`*^9, 3.813998569012122*^9, 
   3.8139989571404314`*^9, 3.813999254886222*^9, 3.813999713118148*^9, 
   3.814026722766204*^9, 3.8140269143063154`*^9, 3.8140270860079875`*^9, 
   3.814830310797603*^9, 3.8154774926911325`*^9, 3.8154777980158396`*^9, 
   3.815477859807309*^9, 3.815478612987371*^9, 3.815775396989195*^9, 
   3.817033447631361*^9, 3.817033479718561*^9, 3.8188010789802575`*^9, 
   3.825416613246734*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1802]=",ExpressionUUID->"32d840a5-5375-4981-b9aa-147eaf06b67a"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 
  3.80485427153401*^9}},ExpressionUUID->"74709d3e-c995-4aa7-a7fe-\
8d66933766b1"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"psdp1", "-", "psdp0"}], ")"}], "100"}], "psdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
  3.8048586124851284`*^9}, {3.8048587237965918`*^9, 3.804858725653945*^9}, {
  3.805018155002266*^9, 3.805018155002266*^9}, {3.80502060986779*^9, 
  3.8050206231378593`*^9}, {3.80502182287536*^9, 3.805021825703562*^9}},
 CellLabel->
  "In[1803]:=",ExpressionUUID->"a7b058b0-b67f-46ad-9eac-b1634f448551"],

Cell[BoxData["4.84059112503333`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.8048588451232333`*^9, 3.804858888207929*^9, 
   3.804859664778276*^9, 3.8048597511350365`*^9, 3.8048599653141775`*^9, 
   3.8048601122616014`*^9, 3.804860381565032*^9, 3.8048605385514774`*^9, 
   3.804860670516244*^9, 3.804861490656901*^9, 3.80486595112325*^9, 
   3.8048662747938147`*^9, 3.8048664454310617`*^9, 3.8048672518512707`*^9, 
   3.8048811921604753`*^9, 3.804895270549718*^9, 3.804896149889929*^9, 
   3.8048969474714165`*^9, 3.8050220306007347`*^9, 3.805023460435156*^9, 
   3.8050236830576897`*^9, 3.8050238481491156`*^9, 3.8050252224058585`*^9, 
   3.8056380996537375`*^9, 3.8056381955716143`*^9, 3.805638617222684*^9, 
   3.8056408773874636`*^9, 3.8056410640194798`*^9, 3.805665827733471*^9, 
   3.8072802200900154`*^9, 3.8072857786995945`*^9, 3.807286106731022*^9, 
   3.8072875956490107`*^9, 3.807306490653529*^9, 3.8073065472685633`*^9, 
   3.8073070727754736`*^9, 3.8073082083862085`*^9, 3.8073092304239197`*^9, 
   3.807882959178568*^9, 3.807884104373714*^9, 3.8078849118150263`*^9, 
   3.8100471274766555`*^9, 3.8100472815902586`*^9, 3.8100473737838483`*^9, 
   3.8110711096067457`*^9, 3.812470611713346*^9, 3.8124709357881107`*^9, 
   3.8124711862991576`*^9, 3.8124715477973332`*^9, 3.8127360683409204`*^9, 
   3.8128215948524942`*^9, 3.8129696381296873`*^9, 3.8129704047576246`*^9, 
   3.812971120989956*^9, 3.812976165629759*^9, 3.81297655188144*^9, 
   3.8139963219861326`*^9, 3.813996921722049*^9, 3.813998569297346*^9, 
   3.813998957364607*^9, 3.8139992551053925`*^9, 3.8139997133393197`*^9, 
   3.8140267229953814`*^9, 3.8140269145414987`*^9, 3.814027086237167*^9, 
   3.8148303110517845`*^9, 3.815477492941174*^9, 3.8154777982658815`*^9, 
   3.81547786005735*^9, 3.8154786132217855`*^9, 3.8157753972673855`*^9, 
   3.8170334476473446`*^9, 3.8170334797325716`*^9, 3.818801078995269*^9, 
   3.8254166134859133`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1803]=",ExpressionUUID->"849d5946-42dd-4a64-b30c-dcf7bdfb361b"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
  3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
  3.804854255481004*^9, 
  3.8048542778511686`*^9}},ExpressionUUID->"4eddad94-7d11-490a-a946-\
fa0004029ced"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qsdp1", "-", "qsdp0"}], ")"}], "100"}], "qsdp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}, {
  3.804858773231639*^9, 3.804858774231792*^9}, {3.8050173975775113`*^9, 
  3.8050173975775113`*^9}, {3.805021830157384*^9, 3.8050218302824044`*^9}},
 CellLabel->
  "In[1804]:=",ExpressionUUID->"3fb76938-949c-45e7-b678-fb85bf19b336"],

Cell[BoxData[
 RowBox[{"-", "1.0313538865886107`"}]], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.80485884526388*^9, 3.804858888348575*^9, 
   3.804859664934558*^9, 3.804859751291317*^9, 3.8048599654602933`*^9, 
   3.804860112417878*^9, 3.8048603817056828`*^9, 3.8048605386921253`*^9, 
   3.8048606706725187`*^9, 3.804861490766294*^9, 3.804865951232607*^9, 
   3.8048662749344625`*^9, 3.8048664455404553`*^9, 3.804867251960664*^9, 
   3.804881192269824*^9, 3.804895270643484*^9, 3.804896149999321*^9, 
   3.804896947580855*^9, 3.80502203080389*^9, 3.8050234611852717`*^9, 
   3.8050236832921095`*^9, 3.80502384830544*^9, 3.805025222640274*^9, 
   3.805638099794386*^9, 3.805638195727886*^9, 3.805638617394588*^9, 
   3.8056408776586723`*^9, 3.805641064366538*^9, 3.8056658279366317`*^9, 
   3.807280220258147*^9, 3.8072857788947473`*^9, 3.8072861069421854`*^9, 
   3.8072875958871956`*^9, 3.807306490811634*^9, 3.8073065475237627`*^9, 
   3.807307072971612*^9, 3.8073082085803595`*^9, 3.8073092306050615`*^9, 
   3.8078829594129815`*^9, 3.8078841046081285`*^9, 3.807884912018194*^9, 
   3.8100471276698055`*^9, 3.8100472818004217`*^9, 3.810047373983962*^9, 
   3.811071109804901*^9, 3.812470611895488*^9, 3.8124709359922705`*^9, 
   3.8124711864983287`*^9, 3.8124715480044956`*^9, 3.812736068550085*^9, 
   3.8128215950486465`*^9, 3.8129696383640985`*^9, 3.812970404992047*^9, 
   3.812971121239999*^9, 3.8129761659183283`*^9, 3.8129765522252398`*^9, 
   3.8139963222453346`*^9, 3.8139969219442215`*^9, 3.813998569583599*^9, 
   3.813998957587782*^9, 3.813999255285533*^9, 3.8139997135574894`*^9, 
   3.8140267232345676`*^9, 3.8140269147746797`*^9, 3.8140270864713497`*^9, 
   3.814830311275937*^9, 3.8154774932068434`*^9, 3.815477798531551*^9, 
   3.815477860323019*^9, 3.8154786134562073`*^9, 3.815775397565617*^9, 
   3.817033447662356*^9, 3.8170334797455945`*^9, 3.818801079011282*^9, 
   3.8254166137421284`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1804]=",ExpressionUUID->"2ed6bafe-cc9b-4214-84c3-140d17808717"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.805638279440954*^9}, 3.8073075506013136`*^9, {3.8252883380745554`*^9, 
   3.825288338639017*^9}},ExpressionUUID->"21f30dff-389c-44ba-9ac3-\
942bc15fb559"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmasu"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"psdu1", " ", 
     RowBox[{"(", 
      RowBox[{"qsdu1", "-", "qsdue0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"psdu0", " ", 
     RowBox[{"(", 
      RowBox[{"qsdu0", "-", "qsdue0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.8056383460882015`*^9, 3.8056383532743115`*^9}, {3.8056385033293953`*^9, 
  3.805638505829816*^9}, {3.8056412172638407`*^9, 3.8056412203593426`*^9}, {
  3.812821795028287*^9, 3.8128218059748096`*^9}, {3.825288344118322*^9, 
  3.82528834646313*^9}},
 CellLabel->
  "In[1805]:=",ExpressionUUID->"0f1339f8-ac6f-44a9-b767-3bba2bc1a9be"],

Cell[BoxData["30382.305258265234`"], "Output",
 CellChangeTimes->CompressedData["
1:eJwVzU0ow3Ecx/E/SloKiai12kG5zCTNQws/TeQpdpiH2Dz9zYwRKQdqbUua
Jc1CLBykkYUDU1MuhtBkxKap/8HB1q8mTErk+z18ep0+vYVdQ3I2hmEYCew6
fHXrbKWEG1EFUX9+9Q+61/qUtgteRIpEaBOzXIbWmVZkbvA0yTFz006JJnGi
3AcqLye16Lh1KesOFNrHVEGwfX62Fy03lzjQnqMMyTNoyw4coL0FH4GokhJW
n6n5AmVpCV7U5P2xpndT4hKVbaLVL559NPn8ZI7HUmLWGsIHakraGuNTD8Gn
FkUe+mqfUqFdocXpgj5KFp7VNZ3gMednUYHHZ9sCq0odn2hPjrh+G1QKz053
wH5pShTlGetfVvspacirEK+BxmbpL2rguUXr4FHTmxz9ey+0oPYz3bETZHI7
7lH+xkMIdX1H+JIBSnyCXcHIICXe2IAMNSmstagl07WNVtnctjgd/J3RoGYY
+pXfHMo+cl8Xo5QUh0/y1XpK/gEXc+Rn
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1805]=",ExpressionUUID->"5c01e074-29cd-4704-8c13-1b86db204613"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.8056382995792217`*^9}, 3.807307574139631*^9, 
   3.825288341432191*^9},ExpressionUUID->"5a3a5221-9287-4570-9eb8-\
c2c85a6bdac6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmasp"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"psdp1", " ", 
     RowBox[{"(", 
      RowBox[{"qsdp1", "-", "qsdpe0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"psdp0", " ", 
     RowBox[{"(", 
      RowBox[{"qsdp0", "-", "qsdpe0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.805638311659393*^9, 3.805638322630473*^9}, {3.805638356669798*^9, 
  3.805638367128154*^9}, {3.8056385080645676`*^9, 3.805638510488124*^9}, {
  3.805641223483641*^9, 3.8056412269529533`*^9}, {3.8072876229282436`*^9, 
  3.80728766997086*^9}, {3.8128218281010303`*^9, 3.8128218381908813`*^9}, {
  3.8252883481915236`*^9, 3.825288351952424*^9}},
 CellLabel->
  "In[1806]:=",ExpressionUUID->"07a48ead-29e0-4de5-88d7-a45a5169bb31"],

Cell[BoxData["1.4098035625903925`*^6"], "Output",
 CellChangeTimes->CompressedData["
1:eJwVz00ow3Ecx/HJXKQdPF0sDwcXjyUZB+k3fxLz0KSWPGu2MfMUBw6EsjzU
anMYNaQWa0jZJELysGxtHlc0bJpi/ZID85SH7/fw6XX5XN5xDW1CcQCLxcqC
2XzW06VKSo7N3U50vy3chYaaSr/R9A5vxAqY2c4ko/l/CoLq2XPMJugcWR5z
VFNSWD7IPwPlmuEW9HptNv4c/HDnJqJNL5xU9Ou+r9YFnhRrm1D7LrOA3j1H
Z9yAA9ZbE2rgfV691VBiZMXK/KBykmNHpTRAHdlIieYwX4+Omm2rKHfrQBUs
poQvUvpMEkqCN0LCzKBwoyoNPRiZqEVdBTolTwp94YqierB/2SND5XnXmkXQ
uLPyim6n8EoMoHfSvm/Ef3bUGypIqvDqmimpixekzoC9D8wPWhW0lzwL+oXv
QnT+N2ccZSt6tpZAUYzsAu1R3z2hZV/v3Aw5JQkx69GdreCQh0HdzikBeqvd
NqDsIIcmUEGJZdrvkrVT8jj66UbHLj1+SxclKulRumSAkn/OVvcQ
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1806]=",ExpressionUUID->"8b3506e3-8934-4303-8a42-b270bbf38da9"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"dea2e921-ee46-4743-ab05-\
a7e3945b6a26"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pstu1", "-", "pstu0"}], ")"}], "100"}], "pstu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
  3.8048586228946285`*^9}, {3.8048587279378014`*^9, 3.804858729797462*^9}, {
  3.8050181010897365`*^9, 3.8050181010897365`*^9}, {3.8050202543496056`*^9, 
  3.805020277744152*^9}, {3.8050218338142357`*^9, 3.8050218364865456`*^9}},
 CellLabel->
  "In[1807]:=",ExpressionUUID->"f484b1cf-f337-48dc-b352-e79d65e44fd2"],

Cell[BoxData["4.862122436444168`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.804858845404583*^9, 3.8048588885048494`*^9, 
   3.804859665075212*^9, 3.8048597514319687`*^9, 3.804859965603407*^9, 
   3.804860112558527*^9, 3.804860381877582*^9, 3.8048605388484*^9, 
   3.8048606708287935`*^9, 3.8048614909069424`*^9, 3.804865951357627*^9, 
   3.8048662750438547`*^9, 3.804866445649886*^9, 3.804867252070057*^9, 
   3.8048811923635893`*^9, 3.804895270768507*^9, 3.8048961501087136`*^9, 
   3.8048969476902018`*^9, 3.8050220309757924`*^9, 3.8050234641701083`*^9, 
   3.8050236835108857`*^9, 3.805023848467813*^9, 3.8050252228278065`*^9, 
   3.8056380999506607`*^9, 3.8056381959154167`*^9, 3.80563861758212*^9, 
   3.8056408779298816`*^9, 3.805641064622828*^9, 3.8056658281085367`*^9, 
   3.807280220439288*^9, 3.8072857790899*^9, 3.8072861071363363`*^9, 
   3.8072875960573277`*^9, 3.8073064909687567`*^9, 3.8073065477159133`*^9, 
   3.8073070731657643`*^9, 3.8073082092068453`*^9, 3.80730923113948*^9, 
   3.807882959975576*^9, 3.807884105265752*^9, 3.807884912658927*^9, 
   3.8100471282572613`*^9, 3.8100472824239054`*^9, 3.810047374597438*^9, 
   3.8110711103683496`*^9, 3.8124706124569254`*^9, 3.812470936592741*^9, 
   3.8124711870977783`*^9, 3.812471548629986*^9, 3.812736069143547*^9, 
   3.8128215956431074`*^9, 3.8129696390534554`*^9, 3.812970405726569*^9, 
   3.812971122005753*^9, 3.8129761667269893`*^9, 3.812976553179371*^9, 
   3.813996322873822*^9, 3.8139969226007357`*^9, 3.8139985703251457`*^9, 
   3.813998958280323*^9, 3.8139992559990873`*^9, 3.8139997142650394`*^9, 
   3.814026723935112*^9, 3.81402691552429*^9, 3.8140270872249355`*^9, 
   3.8148303119814873`*^9, 3.815477493972595*^9, 3.81547779931293*^9, 
   3.815477861088771*^9, 3.815478614190696*^9, 3.81577539876654*^9, 
   3.817033447721528*^9, 3.8170334798112164`*^9, 3.81880107907333*^9, 
   3.825416614467758*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1807]=",ExpressionUUID->"ceba8b7c-c8c4-46be-8e60-fbe01bf97b5c"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
  3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
  3.8048542553403563`*^9, 
  3.8048542677330275`*^9}},ExpressionUUID->"9a48f72c-e683-4eef-a766-\
d6eafcb44256"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qstu1", "-", "qstu0"}], ")"}], "100"}], "qstu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.8048587746537323`*^9, 3.8048587754194756`*^9}, {3.8050174603547196`*^9, 
  3.8050174603547196`*^9}, {3.805021840377807*^9, 3.8050218405184546`*^9}},
 CellLabel->
  "In[1808]:=",ExpressionUUID->"17d0570a-d752-44e3-b70f-5ed7e347d13e"],

Cell[BoxData[
 RowBox[{"-", "4.542988087314904`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588455608006`*^9, 3.8048588886454954`*^9, 
   3.804859665231494*^9, 3.804859751588249*^9, 3.8048599657555275`*^9, 
   3.8048601127148046`*^9, 3.8048603820338573`*^9, 3.804860539004675*^9, 
   3.804860670985069*^9, 3.8048614911257286`*^9, 3.8048659514670196`*^9, 
   3.804866275153248*^9, 3.804866445790497*^9, 3.804867252195078*^9, 
   3.8048811924886093`*^9, 3.804895270877902*^9, 3.8048961502181063`*^9, 
   3.804896947799594*^9, 3.805022031147694*^9, 3.8050234645764217`*^9, 
   3.8050236837296696`*^9, 3.805023848662756*^9, 3.80502522301534*^9, 
   3.8056381000913086`*^9, 3.8056381960873194`*^9, 3.8056386177540436`*^9, 
   3.8056408781530533`*^9, 3.805641064888511*^9, 3.8056658283116965`*^9, 
   3.8072802206254873`*^9, 3.80728577929506*^9, 3.8072861073334894`*^9, 
   3.8072875962345133`*^9, 3.807306491124877*^9, 3.807306547908064*^9, 
   3.8073070733579144`*^9, 3.8073082094330215`*^9, 3.807309231319621*^9, 
   3.8078829601474795`*^9, 3.8078841054532833`*^9, 3.8078849128464413`*^9, 
   3.8100471284524126`*^9, 3.8100472826290646`*^9, 3.810047374797594*^9, 
   3.811071110569504*^9, 3.8124706126470747`*^9, 3.812470936791897*^9, 
   3.8124711873049393`*^9, 3.812471548842152*^9, 3.8127360693437386`*^9, 
   3.812821595850269*^9, 3.8129696392878666`*^9, 3.812970405960991*^9, 
   3.8129711222401676`*^9, 3.812976166988549*^9, 3.8129765534762373`*^9, 
   3.8139963230849867`*^9, 3.813996922829916*^9, 3.8139985706073656`*^9, 
   3.8139989585015445`*^9, 3.813999256226264*^9, 3.8139997144852104`*^9, 
   3.814026724170295*^9, 3.8140269157134323`*^9, 3.8140270874691257`*^9, 
   3.814830312198717*^9, 3.815477494238265*^9, 3.8154777995629716`*^9, 
   3.8154778613544407`*^9, 3.815478614378227*^9, 3.815775399148878*^9, 
   3.8170334477365394`*^9, 3.8170334798252277`*^9, 3.8188010790883417`*^9, 
   3.825416614706893*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1808]=",ExpressionUUID->"df8a3041-efac-46d4-b62f-ee316e17fd6f"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"6f46316a-26e2-4291-a63f-\
5ef5c6a7794c"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pstp1", "-", "pstp0"}], ")"}], "100"}], "pstp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
  3.804858633427496*^9}, {3.804858731626238*^9, 3.804858732688901*^9}, {
  3.805018278409396*^9, 3.805018278409396*^9}, {3.805020655565849*^9, 
  3.8050206633639984`*^9}, {3.805021844206562*^9, 3.8050218469101295`*^9}},
 CellLabel->
  "In[1809]:=",ExpressionUUID->"db586c54-20d0-41e4-9765-405464a7d02b"],

Cell[BoxData["5.376720926718625`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.804858845701447*^9, 3.80485888880177*^9, 3.804859665387776*^9, 
   3.804859751728901*^9, 3.8048599659046464`*^9, 3.8048601128710814`*^9, 
   3.8048603821901336`*^9, 3.8048605391609497`*^9, 3.804860671141344*^9, 
   3.8048614912663765`*^9, 3.8048659515764117`*^9, 3.804866275262643*^9, 
   3.804866445884262*^9, 3.804867252304471*^9, 3.804881192582374*^9, 
   3.804895270971669*^9, 3.8048961503431263`*^9, 3.804896947924615*^9, 
   3.8050220313039675`*^9, 3.8050234676862774`*^9, 3.805023683948454*^9, 
   3.8050238488229685`*^9, 3.8050252231888547`*^9, 3.8056381002319565`*^9, 
   3.805638196243595*^9, 3.805638617957183*^9, 3.8056408783732233`*^9, 
   3.8056410651541643`*^9, 3.8056658284992294`*^9, 3.807280220813582*^9, 
   3.8072857794872313`*^9, 3.8072861075396495`*^9, 3.807287596410607*^9, 
   3.807306491299013*^9, 3.8073065480671873`*^9, 3.8073070735530653`*^9, 
   3.8073082096341786`*^9, 3.8073092315177917`*^9, 3.8078829603350115`*^9, 
   3.8078841056720695`*^9, 3.807884913049599*^9, 3.810047128640563*^9, 
   3.81004728284223*^9, 3.8100473749987497`*^9, 3.811071110762656*^9, 
   3.81247061283222*^9, 3.8124709369920535`*^9, 3.8124711875050945`*^9, 
   3.8124715490463114`*^9, 3.812736069536853*^9, 3.8128215960524263`*^9, 
   3.812969639522279*^9, 3.8129704062110767`*^9, 3.8129711224902096`*^9, 
   3.812976167254217*^9, 3.8129765538043985`*^9, 3.813996323316166*^9, 
   3.813996923046085*^9, 3.8139985709086385`*^9, 3.813998958720665*^9, 
   3.813999256452443*^9, 3.8139997147063828`*^9, 3.8140267244054775`*^9, 
   3.8140269159526014`*^9, 3.814027087704308*^9, 3.814830312447853*^9, 
   3.815477494503934*^9, 3.815477799828641*^9, 3.8154778616201096`*^9, 
   3.8154786146282682`*^9, 3.815775399426071*^9, 3.817033447751551*^9, 
   3.817033479838237*^9, 3.8188010791043544`*^9, 3.825416614980087*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1809]=",ExpressionUUID->"f46d0ad3-0c78-4f0d-a662-88c150fefb3a"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
  3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
  3.804854223908785*^9}, {3.8048542555122595`*^9, 
  3.804854280414089*^9}},ExpressionUUID->"c0839bdc-fe31-4602-a763-\
d373a33c6f16"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qstp1", "-", "qstp0"}], ")"}], "100"}], "qstp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.804858776153962*^9, 3.804858777294763*^9}, {3.8050175127677307`*^9, 
  3.8050175127677307`*^9}, {3.805021850488841*^9, 3.80502185062949*^9}},
 CellLabel->
  "In[1810]:=",ExpressionUUID->"837a0856-9802-469c-8aee-bc228d453609"],

Cell[BoxData[
 RowBox[{"-", "5.206518314208114`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.8048588458420935`*^9, 3.804858888926789*^9, 3.8048596655284295`*^9, 
   3.8048597518851805`*^9, 3.804859966064773*^9, 3.8048601130273585`*^9, 
   3.804860382346409*^9, 3.8048605393172245`*^9, 3.804860671281991*^9, 
   3.80486149137577*^9, 3.8048659516858044`*^9, 3.804866275372032*^9, 
   3.804866446009283*^9, 3.804867252413864*^9, 3.8048811926917667`*^9, 
   3.8048952710810633`*^9, 3.8048961504525194`*^9, 3.804896948034007*^9, 
   3.805022031491497*^9, 3.805023468092591*^9, 3.8050236842453737`*^9, 
   3.805023848988509*^9, 3.8050252233763876`*^9, 3.8056381003726044`*^9, 
   3.805638196384244*^9, 3.80563861814472*^9, 3.8056408785963945`*^9, 
   3.8056410655448523`*^9, 3.805665828672367*^9, 3.807280220998727*^9, 
   3.8072857796803627`*^9, 3.8072861077327995`*^9, 3.807287596589741*^9, 
   3.8073064915141797`*^9, 3.8073065482623386`*^9, 3.8073070737962546`*^9, 
   3.8073082098273296`*^9, 3.807309231698927*^9, 3.80788296053817*^9, 
   3.807884105875229*^9, 3.807884913284012*^9, 3.810047128834709*^9, 
   3.8100472830463886`*^9, 3.8100473752009068`*^9, 3.811071110956809*^9, 
   3.8124706130724077`*^9, 3.812470937190209*^9, 3.81247118770525*^9, 
   3.8124715492644815`*^9, 3.812736069747016*^9, 3.8128215962475777`*^9, 
   3.812969639772317*^9, 3.8129704064610915`*^9, 3.8129711227402515`*^9, 
   3.812976167519885*^9, 3.8129765541169486`*^9, 3.813996323526329*^9, 
   3.8139969232242227`*^9, 3.8139985711728053`*^9, 3.813998958979867*^9, 
   3.8139992566756144`*^9, 3.8139997149235506`*^9, 3.8140267246406603`*^9, 
   3.8140269161477523`*^9, 3.814027087937489*^9, 3.814830312694046*^9, 
   3.815477494753975*^9, 3.8154778000786824`*^9, 3.815477861885779*^9, 
   3.81547861487831*^9, 3.815775399730293*^9, 3.8170334477665634`*^9, 
   3.8170334798512907`*^9, 3.8188010791193657`*^9, 3.825416615244302*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1810]=",ExpressionUUID->"e34e7018-c26f-44ff-84fe-fe17bb057363"]
}, Open  ]],

Cell[TextData[StyleBox["Yellowfin Tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, {3.8050217474964285`*^9, 3.805021750496922*^9}, 
   3.805638178490944*^9, 
   3.825288006345523*^9},ExpressionUUID->"fa466ce1-cea8-4a8d-9b00-\
4b42818ede2f"],

Cell["Percent change in price of unprocessed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}},ExpressionUUID->"37b6f62e-ab42-474a-883b-\
a789278bd2e7"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pydu1", "-", "pydu0"}], ")"}], "100"}], "pydu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
   3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
   3.8048585992018385`*^9}, {3.8050178536701374`*^9, 3.8050178536701374`*^9}, 
   3.805020241988159*^9},
 CellLabel->
  "In[1811]:=",ExpressionUUID->"7851d6b9-66dd-4b24-bb64-9b1361450660"],

Cell[BoxData["0.9829941036824956`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.804858843696556*^9, 3.8048588867233257`*^9, 
   3.804859663324854*^9, 3.804859749619121*^9, 3.804859963843249*^9, 
   3.804860110717795*^9, 3.804860380033531*^9, 3.8048605369574723`*^9, 
   3.8048606690003757`*^9, 3.8048614895786*^9, 3.8048659499980345`*^9, 
   3.8048662735904975`*^9, 3.8048664443215075`*^9, 3.804867250694828*^9, 
   3.8048811911602716`*^9, 3.8048952696276765`*^9, 3.804896148764747*^9, 
   3.8048969463462353`*^9, 3.8050220289442277`*^9, 3.8050234384041944`*^9, 
   3.8050236804166565`*^9, 3.8050238465394917`*^9, 3.805025220561788*^9, 
   3.805638098243934*^9, 3.8056381939463477`*^9, 3.805638615088058*^9, 
   3.8056408746683674`*^9, 3.8056410602569456`*^9, 3.8056658255455894`*^9, 
   3.807280217996389*^9, 3.8072857763027334`*^9, 3.8072861043231463`*^9, 
   3.807287593484353*^9, 3.8073064884988546`*^9, 3.807306544888713*^9, 
   3.8073070704006114`*^9, 3.8073082059312963`*^9, 3.807309231876054*^9, 
   3.8078829607257013`*^9, 3.807884106078388*^9, 3.8078849134871693`*^9, 
   3.8100471290268583`*^9, 3.810047283251547*^9, 3.810047375414072*^9, 
   3.8110711111549654`*^9, 3.812470613329609*^9, 3.8124709374003735`*^9, 
   3.8124711879094086`*^9, 3.8124715494786477`*^9, 3.8127360699441705`*^9, 
   3.8128215964487343`*^9, 3.812969640006728*^9, 3.812970406695513*^9, 
   3.8129711230215497`*^9, 3.812976167801199*^9, 3.812976554429502*^9, 
   3.8139963237415023`*^9, 3.813996923441392*^9, 3.81399857146004*^9, 
   3.813998959197036*^9, 3.8139992568987865`*^9, 3.8139997151457396`*^9, 
   3.814026724880847*^9, 3.8140269164399805`*^9, 3.8140270882257137`*^9, 
   3.814830312922224*^9, 3.8154774950040445`*^9, 3.815477800344352*^9, 
   3.8154778621358204`*^9, 3.8154786151127243`*^9, 3.815775400001505*^9, 
   3.8170334477815742`*^9, 3.817033479865905*^9, 3.818801079135378*^9, 
   3.825416615494552*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1811]=",ExpressionUUID->"fa67851f-118d-480e-89ad-bf54a80c6078"]
}, Open  ]],

Cell["Percent change in quantity of landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.807308034813134*^9},ExpressionUUID->"ff34ab77-1d9f-4ec0-ba1d-\
cae076d2ebb1"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qydu1", "-", "qydu0"}], ")"}], "100"}], "qydu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.805017322701576*^9, 3.805017322701576*^9}, {3.8050217635649242`*^9, 
  3.8050217672842827`*^9}},
 CellLabel->
  "In[1812]:=",ExpressionUUID->"12284875-4e6e-4aaf-8a4e-b74c3485c4eb"],

Cell[BoxData["4.8891978803433265`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.804858843837203*^9, 3.8048588868952274`*^9, 
   3.8048596634655075`*^9, 3.804859749775401*^9, 3.804859963983899*^9, 
   3.804860110889693*^9, 3.804860380189807*^9, 3.8048605370981197`*^9, 
   3.804860669156651*^9, 3.804861489672364*^9, 3.8048659501230545`*^9, 
   3.804866273731145*^9, 3.8048664444309*^9, 3.804867250819849*^9, 
   3.8048811912696643`*^9, 3.804895269705816*^9, 3.80489614887414*^9, 
   3.8048969464556475`*^9, 3.80502202911613*^9, 3.8050234413118887`*^9, 
   3.8050236807292056`*^9, 3.805023846727021*^9, 3.805025220749321*^9, 
   3.8056380984098864`*^9, 3.805638194118269*^9, 3.80563861527559*^9, 
   3.8056408748705235`*^9, 3.8056410606995664`*^9, 3.8056658257487497`*^9, 
   3.807280218181534*^9, 3.807285776511896*^9, 3.8072861045323105`*^9, 
   3.8072875937165155`*^9, 3.8073064887070045`*^9, 3.807306545114888*^9, 
   3.8073070706017675`*^9, 3.807308206135454*^9, 3.8073092320531917`*^9, 
   3.8078829609132333`*^9, 3.8078841063284297`*^9, 3.8078849136903267`*^9, 
   3.8100471292170057`*^9, 3.8100472834557056`*^9, 3.810047375616229*^9, 
   3.8110711113581257`*^9, 3.812470613529766*^9, 3.8124709376075497`*^9, 
   3.8124711881105647`*^9, 3.812471549688811*^9, 3.8127360701473293`*^9, 
   3.8128215966428847`*^9, 3.812969640272395*^9, 3.8129704069455633`*^9, 
   3.8129711232559633`*^9, 3.8129761680824757`*^9, 3.8129765547576437`*^9, 
   3.813996323949659*^9, 3.8139969236185293`*^9, 3.8139985717242327`*^9, 
   3.8139989594182076`*^9, 3.8139992571629915`*^9, 3.8139997154129314`*^9, 
   3.8140267251160297`*^9, 3.81402691663313*^9, 3.814027088460896*^9, 
   3.8148303131594296`*^9, 3.8154774952696857`*^9, 3.8154778005943933`*^9, 
   3.815477862417117*^9, 3.8154786153627653`*^9, 3.815775400286728*^9, 
   3.8170334477976665`*^9, 3.8170334798789153`*^9, 3.8188010791503897`*^9, 
   3.8254166157376785`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1812]=",ExpressionUUID->"e9471998-3eca-492a-a2af-a9a6023ef4e2"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 
  3.80485427153401*^9}},ExpressionUUID->"fc388840-19e8-4dd3-9747-\
f8ff5f18cc62"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pydp1", "-", "pydp0"}], ")"}], "100"}], "pydp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
   3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
   3.8048586124851284`*^9}, {3.805018145220993*^9, 3.805018145220993*^9}, 
   3.80502060986779*^9},
 CellLabel->
  "In[1813]:=",ExpressionUUID->"c01ee3c4-d5c4-4b0f-ad48-10861ea850e0"],

Cell[BoxData["4.559935657127753`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.8048588439778495`*^9, 3.8048588870515013`*^9, 
   3.804859663606161*^9, 3.804859749916053*^9, 3.804859964124549*^9, 
   3.8048601110426407`*^9, 3.8048603803304553`*^9, 3.8048605372700224`*^9, 
   3.804860669297299*^9, 3.8048614897661295`*^9, 3.8048659502480745`*^9, 
   3.8048662738718495`*^9, 3.804866444540292*^9, 3.804867250929243*^9, 
   3.804881191363453*^9, 3.8048952697839546`*^9, 3.804896148983532*^9, 
   3.8048969465650415`*^9, 3.805022029272404*^9, 3.8050234442607517`*^9, 
   3.805023680979244*^9, 3.805023846867667*^9, 3.8050252209212255`*^9, 
   3.805638098512967*^9, 3.8056381942901535`*^9, 3.8056386154474936`*^9, 
   3.805640875074681*^9, 3.8056410609964895`*^9, 3.805665825920655*^9, 
   3.80728021838269*^9, 3.807285776708048*^9, 3.8072861047444763`*^9, 
   3.807287593828591*^9, 3.807306488885155*^9, 3.807306545309039*^9, 
   3.80730707079792*^9, 3.807308206355625*^9, 3.8073092322323303`*^9, 
   3.8078829611164074`*^9, 3.8078841065628443`*^9, 3.807884913877857*^9, 
   3.8100471294191628`*^9, 3.8100472836538596`*^9, 3.8100473758163843`*^9, 
   3.8110711115502768`*^9, 3.8124706137229176`*^9, 3.812470937810692*^9, 
   3.812471188319727*^9, 3.8124715498989744`*^9, 3.8127360703454847`*^9, 
   3.8128215968640842`*^9, 3.812969640506807*^9, 3.812970407179985*^9, 
   3.812971123506006*^9, 3.812976168395027*^9, 3.8129765550702143`*^9, 
   3.8139963241568193`*^9, 3.813996923849709*^9, 3.8139985718953667`*^9, 
   3.813998959635376*^9, 3.813999257386166*^9, 3.8139997156331425`*^9, 
   3.8140267253482122`*^9, 3.814026916861308*^9, 3.814027088693076*^9, 
   3.814830313385585*^9, 3.815477495535355*^9, 3.8154778008600626`*^9, 
   3.815477862667158*^9, 3.8154786155971794`*^9, 3.8157754005849686`*^9, 
   3.817033447812711*^9, 3.817033479891925*^9, 3.8188010791654015`*^9, 
   3.8254166160138917`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1813]=",ExpressionUUID->"1b8bab22-92c6-4d6a-aa26-278e41754f53"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
  3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
  3.804854255481004*^9, 
  3.8048542778511686`*^9}},ExpressionUUID->"7abf6cfa-d615-4f2a-b170-\
479ece4c4f53"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qydp1", "-", "qydp0"}], ")"}], "100"}], "qydp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}, {
  3.8050173894042873`*^9, 3.8050173894042873`*^9}, {3.8050217793800144`*^9, 
  3.805021779817588*^9}},
 CellLabel->
  "In[1814]:=",ExpressionUUID->"3b33f5e5-576c-4782-ba04-8feac09ec40f"],

Cell[BoxData[
 RowBox[{"-", "2.1101902592667097`"}]], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.8048588441185026`*^9, 3.804858887207775*^9, 
   3.804859663746849*^9, 3.804859750072333*^9, 3.8048599642808266`*^9, 
   3.8048601111989183`*^9, 3.8048603804867315`*^9, 3.804860537426297*^9, 
   3.804860669453575*^9, 3.804861489891162*^9, 3.804865950357467*^9, 
   3.804866273981185*^9, 3.804866444665313*^9, 3.8048672510230074`*^9, 
   3.8048811914728217`*^9, 3.804895269877722*^9, 3.8048961490929246`*^9, 
   3.8048969466744184`*^9, 3.805022029428681*^9, 3.8050234446472797`*^9, 
   3.8050236812136564`*^9, 3.805023847023942*^9, 3.805025221093131*^9, 
   3.805638098647914*^9, 3.805638194462056*^9, 3.805638615628666*^9, 
   3.8056408753228717`*^9, 3.805641061293412*^9, 3.8056658261238146`*^9, 
   3.807280218503784*^9, 3.807285776917225*^9, 3.807286104943632*^9, 
   3.8072875939927177`*^9, 3.8073064890432615`*^9, 3.8073065455041904`*^9, 
   3.80730707099107*^9, 3.8073082065507774`*^9, 3.8073092324274826`*^9, 
   3.8078829613039227`*^9, 3.8078841067503753`*^9, 3.8078849140810156`*^9, 
   3.8100471296113124`*^9, 3.810047283862021*^9, 3.8100473760145383`*^9, 
   3.811071111755438*^9, 3.812470613911065*^9, 3.8124709380078597`*^9, 
   3.8124711885218844`*^9, 3.8124715501061354`*^9, 3.812736070545695*^9, 
   3.812821597064212*^9, 3.812969640756894*^9, 3.8129704074300356`*^9, 
   3.8129711237404203`*^9, 3.812976168738833*^9, 3.8129765553983355`*^9, 
   3.8139963243849974`*^9, 3.8139969240658765`*^9, 3.813998572184592*^9, 
   3.813998959814515*^9, 3.8139992576083393`*^9, 3.8139997158532743`*^9, 
   3.8140267255763903`*^9, 3.8140269170924873`*^9, 3.814027088926258*^9, 
   3.814830313620767*^9, 3.815477495801024*^9, 3.8154778011257315`*^9, 
   3.8154778629172*^9, 3.8154786158472214`*^9, 3.815775400866181*^9, 
   3.817033447827721*^9, 3.817033479904936*^9, 3.8188010791814137`*^9, 
   3.825416616251086*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1814]=",ExpressionUUID->"9c39f8c4-5e31-46a6-b1f7-2c3fb5ad23d1"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.805638279440954*^9}, 3.8073075505913057`*^9, {3.8252883718189487`*^9, 
   3.825288372662648*^9}},ExpressionUUID->"66e3d8bf-0da9-4845-95b9-\
8b8bf770b527"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmayu"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"pydu1", " ", 
     RowBox[{"(", 
      RowBox[{"qydu1", "-", "qydue0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"pydu0", " ", 
     RowBox[{"(", 
      RowBox[{"qydu0", "-", "qydue0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.805638515113145*^9, 3.8056385175665255`*^9}, {3.805641232235357*^9, 
  3.8056412347513914`*^9}, {3.8128218463302174`*^9, 3.8128218574839*^9}, {
  3.825288359594446*^9, 3.8252883612517166`*^9}},
 CellLabel->
  "In[1815]:=",ExpressionUUID->"f293df65-97a3-435d-a196-54d89d1d73ff"],

Cell[BoxData["704277.2113402152`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBeIzr05fXBv1xtFxvsBvEH1kY4/oeiD9K+umDoj+xp3m
BKK7v8e77AbSdVNzu8/HvnGcfsbG6RKQvuBglw2il7XEql4G0vMSbeLvAOkX
Lf5pILpA8f9yEO1y7rrpXSDNdkV4G4jm2mVw62vcG8cQ5rjMb0D6j7jXORBt
vc9ysljyG8cvbxqXgei4c2ybQHSJ178JXKlvHHtUDr/amg50z3Q34W1A+oDQ
dCMQrfztZDyIjlW/0WGeAbQ/ZIV3IpA24k/MAdE1O+SnrgTSLoe/fgHRCjsb
/FYB6VtL5I+uAdLr9pd9BdFaKpOfzMsC6hfr1J8PpNuu9/0F0RLWTHoLgLRO
s1UwiF4Z2dQDotn379yzFkhXtay6AqJbtVRfgehjnNayZjlvHKOUmOSLct84
hrHpuIJogVtPfUD0mTnMq0H0xhcqU5nz3jhWvv91J7MAGJ7xfx+AaDnPZ99O
FL9xlP/Fb5re8MYRAIjZ3dE=
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1815]=",ExpressionUUID->"0bd8d140-b3bb-4b3c-8b1d-a4b5486ce2b7"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.8056382995792217`*^9}, 3.807307574130624*^9, 
   3.8252883690838037`*^9},ExpressionUUID->"db3b94e6-86c3-414a-9d12-\
e26f74e4477b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmayp"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"pydp1", " ", 
     RowBox[{"(", 
      RowBox[{"qydp1", "-", "qydpe0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"pydp0", " ", 
     RowBox[{"(", 
      RowBox[{"qydp0", "-", "qydpe0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.805638311659393*^9, 3.805638322630473*^9}, {3.805638520521709*^9, 
  3.80563852300506*^9}, {3.8056412376424875`*^9, 3.8056412402690125`*^9}, {
  3.8128218787634583`*^9, 3.8128218885400705`*^9}, {3.825288363140168*^9, 
  3.8252883663806925`*^9}},
 CellLabel->
  "In[1816]:=",ExpressionUUID->"992179d1-aebe-4b12-9fee-6993afcb01e9"],

Cell[BoxData["856432.1282914302`"], "Output",
 CellChangeTimes->CompressedData["
1:eJwVxUsow3EcAPDJK9Yuk0kRW7SLR9l/+4/L+tlcmDXPA9ka/mxeG3KR1kRj
DVlaKI8p5j0hS1FyUF55joOQg8j6xcVb5Pc9fPrwy435TACLxZIQh/6D08US
jPa9LZdw5zjvB7ZynJFLZMvYQxKsjuHJ4ZMPRrFBpkOb7cdlGLHN8swzcrZL
UQt/0xWJ52SlK1N7TZZsFFXBBfrgGbjYeCu+IRd2RXvhvAz66k2D0UhHpeGd
jIbUR3Ajlg3wKjDyibrdsDuRswKXOoIc4QxGk/w9/1o1RlReboSX7NONpsFp
TydaeNp8203rMWLsnhwdOb5NZII9UqFzlrwq/3uFzek21RxZNCXcWSC/brW/
wRnPw/djNRj1CfpTx8mtvYO/cEJKWIqLPGFFBbCKsfXAjevbm4tkaemqD+Z+
JfthDSWPldRhtCwIj2uqx2jFSmXB9SXPSlgwyp6HbQapM7ABo5CLn2uDCaNP
6u8O5soe33ebMXo5ixJXWzD6B6Qz3Z0=
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1816]=",ExpressionUUID->"dcf32726-5b55-4128-b2c5-9eb765b8f608"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"5ed542e3-d498-4e4c-a4dd-\
1b360d55e7d3"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pytu1", "-", "pytu0"}], ")"}], "100"}], "pytu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
   3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
   3.8048586228946285`*^9}, {3.8050180911664543`*^9, 3.8050180911664543`*^9}, 
   3.8050202543496056`*^9},
 CellLabel->
  "In[1817]:=",ExpressionUUID->"a7a9764c-bf66-49ef-939e-40c84233ba43"],

Cell[BoxData["6.891076220359295`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.804858844259143*^9, 3.8048588873484216`*^9, 
   3.8048596638874693`*^9, 3.8048597502286253`*^9, 3.8048599644214773`*^9, 
   3.804860111339567*^9, 3.80486038062738*^9, 3.8048605375982*^9, 
   3.804860669609849*^9, 3.8048614900161695`*^9, 3.80486595046686*^9, 
   3.804866274106205*^9, 3.804866444774705*^9, 3.804867251163656*^9, 
   3.8048811915822144`*^9, 3.8048952699714885`*^9, 3.804896149217945*^9, 
   3.8048969467994328`*^9, 3.8050220296005793`*^9, 3.805023447562844*^9, 
   3.805023681463694*^9, 3.8050238471802163`*^9, 3.8050252212806635`*^9, 
   3.8056380988041887`*^9, 3.805638194618332*^9, 3.8056386158318243`*^9, 
   3.8056408755740657`*^9, 3.8056410615808296`*^9, 3.80566582629572*^9, 
   3.8072802186749167`*^9, 3.8072857771113625`*^9, 3.8072861051427884`*^9, 
   3.8072875941628504`*^9, 3.8073064891993823`*^9, 3.8073065456963396`*^9, 
   3.8073070711852207`*^9, 3.8073082071492457`*^9, 3.8073092329759083`*^9, 
   3.8078829619133997`*^9, 3.8078841074223623`*^9, 3.807884914721743*^9, 
   3.81004713018876*^9, 3.8100472844534807`*^9, 3.810047376620008*^9, 
   3.8110711123348947`*^9, 3.8124706144705005`*^9, 3.8124709386123586`*^9, 
   3.8124711891193485`*^9, 3.812471550733627*^9, 3.8127360711511154`*^9, 
   3.8128215976576786`*^9, 3.812969641475708*^9, 3.8129704081801863`*^9, 
   3.812971124522682*^9, 3.81297616947333*^9, 3.8129765563672314`*^9, 
   3.8139963250234976`*^9, 3.813996924721386*^9, 3.81399857295419*^9, 
   3.8139989604660215`*^9, 3.813999258315895*^9, 3.813999716554819*^9, 
   3.8140267262959538`*^9, 3.8140269178310614`*^9, 3.814027089672838*^9, 
   3.8148303143413315`*^9, 3.815477496582404*^9, 3.8154778018914833`*^9, 
   3.81547786369858*^9, 3.815478616597346*^9, 3.815775402064125*^9, 
   3.8170334478847785`*^9, 3.817033479957548*^9, 3.818801079242461*^9, 
   3.825416616984665*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1817]=",ExpressionUUID->"cf168140-4e07-47dc-a4b7-55eaf253a623"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
  3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
  3.8048542553403563`*^9, 
  3.8048542677330275`*^9}},ExpressionUUID->"82273b4d-e264-45a3-9a5a-\
0b30019357d7"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qytu1", "-", "qytu0"}], ")"}], "100"}], "qytu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.8050174498061085`*^9, 3.8050174498061085`*^9}, {3.805021785865451*^9, 
  3.805021786224886*^9}},
 CellLabel->
  "In[1818]:=",ExpressionUUID->"0d15ba49-a590-43d3-aca9-29acdb783728"],

Cell[BoxData[
 RowBox[{"-", "9.525731745105835`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588444154167`*^9, 3.804858887504696*^9, 
   3.804859664043751*^9, 3.804859750369265*^9, 3.804859964562127*^9, 
   3.8048601114958444`*^9, 3.8048603807992835`*^9, 3.8048605377544746`*^9, 
   3.804860669766124*^9, 3.8048614901255617`*^9, 3.804865950576252*^9, 
   3.8048662742155976`*^9, 3.804866444899753*^9, 3.8048672512730494`*^9, 
   3.804881191675979*^9, 3.8048952700652666`*^9, 3.804896149327338*^9, 
   3.804896946908837*^9, 3.8050220297724805`*^9, 3.8050234479568844`*^9, 
   3.805023681745041*^9, 3.805023847320863*^9, 3.8050252214682283`*^9, 
   3.8056380989604635`*^9, 3.805638194805862*^9, 3.8056386160037284`*^9, 
   3.805640875804243*^9, 3.8056410618768563`*^9, 3.8056658264519978`*^9, 
   3.8072802188500986`*^9, 3.8072857773085146`*^9, 3.807286105341943*^9, 
   3.8072875943269777`*^9, 3.8073064893675127`*^9, 3.8073065458934927`*^9, 
   3.807307071391381*^9, 3.8073082073674164`*^9, 3.807309233156048*^9, 
   3.807882962116559*^9, 3.8078841076411495`*^9, 3.8078849149092894`*^9, 
   3.8100471303729033`*^9, 3.8100472846496353`*^9, 3.810047376820163*^9, 
   3.81107111253205*^9, 3.8124706146636505`*^9, 3.812470938814474*^9, 
   3.812471189330512*^9, 3.8124715509407887`*^9, 3.812736071357277*^9, 
   3.812821597857831*^9, 3.8129696416944923`*^9, 3.812970408430237*^9, 
   3.812971124772724*^9, 3.8129761697233725`*^9, 3.8129765566797423`*^9, 
   3.813996325233662*^9, 3.813996924952566*^9, 3.813998573120318*^9, 
   3.813998960680188*^9, 3.8139992585350647`*^9, 3.81399971677499*^9, 
   3.814026726530135*^9, 3.814026918024212*^9, 3.8140270899040174`*^9, 
   3.8148303146065445`*^9, 3.815477496848073*^9, 3.81547780211027*^9, 
   3.8154778639486213`*^9, 3.8154786168473873`*^9, 3.815775402420423*^9, 
   3.81703344790036*^9, 3.8170334799705725`*^9, 3.8188010792584734`*^9, 
   3.8254166172488713`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1818]=",ExpressionUUID->"a9850047-07f9-4539-ae88-b2de51bac895"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"e23a3c21-0a78-47af-802c-\
c364f4f91f5f"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pytp1", "-", "pytp0"}], ")"}], "100"}], "pytp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
   3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
   3.804858633427496*^9}, {3.8050182696893077`*^9, 3.8050182696893077`*^9}, 
   3.805020655565849*^9},
 CellLabel->
  "In[1819]:=",ExpressionUUID->"ec6af1d0-396f-4dba-8cea-a3941b570226"],

Cell[BoxData["7.396061099453664`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.8048588445560637`*^9, 3.8048588876453424`*^9, 3.8048596642000327`*^9, 
   3.8048597505412283`*^9, 3.8048599647027774`*^9, 3.8048601116364937`*^9, 
   3.8048603809555593`*^9, 3.804860537895122*^9, 3.8048606699223995`*^9, 
   3.804861490219328*^9, 3.804865950685644*^9, 3.8048662743249903`*^9, 
   3.8048664449934893`*^9, 3.8048672513824425`*^9, 3.804881191769744*^9, 
   3.8048952701590223`*^9, 3.804896149436783*^9, 3.804896947018218*^9, 
   3.8050220299443827`*^9, 3.805023450896061*^9, 3.8050236819950266`*^9, 
   3.8050238474927645`*^9, 3.805025221655735*^9, 3.8056380991011114`*^9, 
   3.805638194977765*^9, 3.8056386161756325`*^9, 3.805640876001395*^9, 
   3.80564106217365*^9, 3.8056658266239023`*^9, 3.807280219037198*^9, 
   3.8072857775046663`*^9, 3.8072861055410976`*^9, 3.8072875945101204`*^9, 
   3.8073064895286713`*^9, 3.807306546062624*^9, 3.807307071584531*^9, 
   3.8073082075575695`*^9, 3.807309233333185*^9, 3.8078829623040905`*^9, 
   3.807884107844308*^9, 3.807884915096803*^9, 3.8100471305650525`*^9, 
   3.8100472848487873`*^9, 3.8100473770213194`*^9, 3.8110711127272034`*^9, 
   3.812470614851797*^9, 3.812470939011629*^9, 3.81247118953067*^9, 
   3.812471551142974*^9, 3.8127360715584345`*^9, 3.8128215980669947`*^9, 
   3.812969641928903*^9, 3.8129704086646585`*^9, 3.8129711250227666`*^9, 
   3.8129761699577866`*^9, 3.812976556996931*^9, 3.813996325457837*^9, 
   3.813996925167734*^9, 3.8139985733595047`*^9, 3.813998960861329*^9, 
   3.813999258753234*^9, 3.8139997169951615`*^9, 3.814026726760315*^9, 
   3.8140269182543907`*^9, 3.8140270901402016`*^9, 3.8148303149007835`*^9, 
   3.8154774970981145`*^9, 3.815477802360312*^9, 3.8154778642142906`*^9, 
   3.8154786170818014`*^9, 3.8157754027396917`*^9, 3.8170334479173737`*^9, 
   3.817033479983616*^9, 3.8188010792744865`*^9, 3.8254166175060797`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1819]=",ExpressionUUID->"d3e499d1-224f-4590-be49-6254cf99aea2"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
  3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
  3.804854223908785*^9}, {3.8048542555122595`*^9, 
  3.804854280414089*^9}},ExpressionUUID->"f799dbdf-4080-49d8-a20e-\
90387fa96e77"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qytp1", "-", "qytp0"}], ")"}], "100"}], "qytp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.8050175026566935`*^9, 3.8050175026566935`*^9}, {3.8050217915695124`*^9, 
  3.8050217919602027`*^9}},
 CellLabel->
  "In[1820]:=",ExpressionUUID->"efe2e1f7-5f4b-4f80-a068-3179b4d26ead"],

Cell[BoxData[
 RowBox[{"-", "9.35906979749322`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.80485884469671*^9, 3.804858887785989*^9, 3.8048596643406863`*^9, 
   3.8048597506974525`*^9, 3.804859964859055*^9, 3.8048601117927704`*^9, 
   3.8048603810962067`*^9, 3.8048605380513973`*^9, 3.804860670063046*^9, 
   3.804861490328724*^9, 3.804865950795037*^9, 3.8048662744343824`*^9, 
   3.8048664451185102`*^9, 3.8048672515074635`*^9, 3.804881191863509*^9, 
   3.8048952702527895`*^9, 3.8048961495461226`*^9, 3.804896947143239*^9, 
   3.8050220301006565`*^9, 3.8050234512856274`*^9, 3.8050236822763195`*^9, 
   3.8050238476646657`*^9, 3.805025221843261*^9, 3.8056380992417593`*^9, 
   3.805638195102785*^9, 3.805638616347536*^9, 3.8056408761955442`*^9, 
   3.805641062513013*^9, 3.805665826811435*^9, 3.8072802192483625`*^9, 
   3.807285777703821*^9, 3.80728610574926*^9, 3.807287594749307*^9, 
   3.80730648972479*^9, 3.8073065462817955`*^9, 3.8073070717806835`*^9, 
   3.8073082077497144`*^9, 3.8073092335133257`*^9, 3.8078829624916215`*^9, 
   3.8078841080318394`*^9, 3.8078849153312163`*^9, 3.8100471307501965`*^9, 
   3.810047285052945*^9, 3.8100473772184725`*^9, 3.8110711129313784`*^9, 
   3.8124706150409436`*^9, 3.8124709392087836`*^9, 3.8124711897258196`*^9, 
   3.812471551382135*^9, 3.8127360717706013`*^9, 3.812821598272156*^9, 
   3.812969642178942*^9, 3.8129704089147415`*^9, 3.812971125272809*^9, 
   3.8129761702078285`*^9, 3.8129765573451414`*^9, 3.8139963256740055`*^9, 
   3.8139969253459005`*^9, 3.8139985735716696`*^9, 3.813998961118529*^9, 
   3.813999258973406*^9, 3.813999717215334*^9, 3.8140267269904933`*^9, 
   3.814026918443537*^9, 3.8140270903783865`*^9, 3.814830315184991*^9, 
   3.815477497363784*^9, 3.815477802610353*^9, 3.8154778644955873`*^9, 
   3.8154786173474703`*^9, 3.815775403017865*^9, 3.8170334479323854`*^9, 
   3.8170334799966006`*^9, 3.8188010792894974`*^9, 3.8254166177463007`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1820]=",ExpressionUUID->"31a84d9d-59ed-4847-8624-83c2e1547e0d"]
}, Open  ]],

Cell[TextData[StyleBox["Other Tuna",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, {3.804858674828244*^9, 3.8048586759846716`*^9}, {
   3.805021921987334*^9, 3.8050219236606793`*^9}, {3.805021990843542*^9, 
   3.805021993390811*^9}, 
   3.8252880142766857`*^9},ExpressionUUID->"cfdf10cf-34a8-40d8-b0b1-\
39725aa5bbd3"],

Cell["Percent change in price of unprocessed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}},ExpressionUUID->"87808b10-38b2-412a-a34f-\
6e65d6b3752c"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"podu1", "-", "podu0"}], ")"}], "100"}], "podu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
   3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
   3.8048585992018385`*^9}, {3.8048587486137724`*^9, 3.804858750004611*^9}, {
   3.805017872704455*^9, 3.805017872704455*^9}, 3.805020287887725*^9, {
   3.8050220006263056`*^9, 3.8050220011576376`*^9}},
 CellLabel->
  "In[1821]:=",ExpressionUUID->"56d3ee65-2e64-4653-9ce7-3699a45d9e92"],

Cell[BoxData["0.5149522773763273`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.804858847139168*^9, 3.804858890192608*^9, 
   3.804859666825571*^9, 3.8048597532291985`*^9, 3.8048599673748865`*^9, 
   3.804860114402596*^9, 3.8048603837216387`*^9, 3.8048605407393417`*^9, 
   3.8048606726728387`*^9, 3.804861492313425*^9, 3.8048659526859646`*^9, 
   3.8048662764034476`*^9, 3.8048664469938164`*^9, 3.8048672534297056`*^9, 
   3.8048811936294165`*^9, 3.804895272018732*^9, 3.8048961514683075`*^9, 
   3.8048969490185413`*^9, 3.805022035836521*^9, 3.8050235258023567`*^9, 
   3.805023689652461*^9, 3.805023853170941*^9, 3.8050252280334463`*^9, 
   3.805638104340911*^9, 3.805638200620223*^9, 3.8056386242595654`*^9, 
   3.8056408884620004`*^9, 3.805641074038709*^9, 3.80566583586731*^9, 
   3.8072802270114026`*^9, 3.807285786356559*^9, 3.8072861145621176`*^9, 
   3.8072876029106617`*^9, 3.8073064973747425`*^9, 3.8073065549185133`*^9, 
   3.807307080318325*^9, 3.807308216068198*^9, 3.8073092337075367`*^9, 
   3.8078829626947803`*^9, 3.8078841082349987`*^9, 3.807884915534374*^9, 
   3.8100471309414*^9, 3.8100472852521005`*^9, 3.8100473774206295`*^9, 
   3.81107111312953*^9, 3.812470615232093*^9, 3.8124709394049373`*^9, 
   3.812471189923973*^9, 3.812471551598304*^9, 3.81273607197478*^9, 
   3.8128215984703107`*^9, 3.812969642397726*^9, 3.812970409149131*^9, 
   3.812971125507249*^9, 3.8129761704578686`*^9, 3.8129765576493673`*^9, 
   3.8139963258881717`*^9, 3.813996925561039*^9, 3.8139985737818346`*^9, 
   3.8139989613336964`*^9, 3.813999259192587*^9, 3.8139997174365315`*^9, 
   3.8140267272366843`*^9, 3.8140269187167497`*^9, 3.8140270906556034`*^9, 
   3.814830315447242*^9, 3.8154774976294527`*^9, 3.8154778028760223`*^9, 
   3.815477864761256*^9, 3.8154786175975122`*^9, 3.815775403321096*^9, 
   3.8170334479473968`*^9, 3.8170334800106006`*^9, 3.818801079306511*^9, 
   3.8254166179934416`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1821]=",ExpressionUUID->"e24a1c98-371b-4e4c-bc5c-6dc831fcbec5"]
}, Open  ]],

Cell["Percent change in quantity of landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.8073080348581696`*^9},ExpressionUUID->"340dbded-46cb-42bc-b420-\
65dd828b0c5b"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qodu1", "-", "qodu0"}], ")"}], "100"}], "qodu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.804858792627643*^9, 3.804858798896052*^9}, {3.8050173592553644`*^9, 
  3.8050173592553644`*^9}, {3.8050219270518637`*^9, 3.8050219271612563`*^9}, {
  3.8050220013295393`*^9, 3.805022001657715*^9}},
 CellLabel->
  "In[1822]:=",ExpressionUUID->"97a2aaff-8b6f-4bc3-b744-39d4f05435f7"],

Cell[BoxData["2.568133479433995`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.8048588472798543`*^9, 3.8048588903332553`*^9, 
   3.8048596669662247`*^9, 3.8048597533854685`*^9, 3.8048599675155373`*^9, 
   3.8048601145432453`*^9, 3.8048603838622866`*^9, 3.8048605408956027`*^9, 
   3.804860672829114*^9, 3.804861492438445*^9, 3.8048659527953568`*^9, 
   3.8048662765128403`*^9, 3.8048664471032095`*^9, 3.804867253539048*^9, 
   3.804881193738809*^9, 3.804895272128127*^9, 3.8048961515777006`*^9, 
   3.8048969491279335`*^9, 3.8050220360396776`*^9, 3.805023529474801*^9, 
   3.805023689902499*^9, 3.805023853342844*^9, 3.805025228267862*^9, 
   3.8056381044928074`*^9, 3.8056382007608705`*^9, 3.805638624431469*^9, 
   3.8056408887682347`*^9, 3.805641074241867*^9, 3.8056658361017256`*^9, 
   3.8072802271655226`*^9, 3.8072857865577154`*^9, 3.807286114758275*^9, 
   3.807287603094805*^9, 3.807306497533867*^9, 3.807306555106662*^9, 
   3.80730708055451*^9, 3.8073082162593346`*^9, 3.8073092338886194`*^9, 
   3.8078829629291945`*^9, 3.80788410848504*^9, 3.8078849157375317`*^9, 
   3.8100471311314917`*^9, 3.810047285449253*^9, 3.8100473776307926`*^9, 
   3.8110711133276772`*^9, 3.8124706154192395`*^9, 3.812470939605094*^9, 
   3.812471190126192*^9, 3.812471551808469*^9, 3.8127360721809225`*^9, 
   3.812821598673483*^9, 3.812969642647765*^9, 3.8129704093835535`*^9, 
   3.812971125772893*^9, 3.8129761706922817`*^9, 3.8129765579697404`*^9, 
   3.8139963260993357`*^9, 3.813996925741179*^9, 3.813998573994001*^9, 
   3.8139989615508647`*^9, 3.8139992594587827`*^9, 3.813999717700715*^9, 
   3.814026727471867*^9, 3.814026918905897*^9, 3.8140270908867846`*^9, 
   3.8148303157234154`*^9, 3.8154774978794947`*^9, 3.815477803141691*^9, 
   3.815477865026925*^9, 3.8154786178319254`*^9, 3.815775403637355*^9, 
   3.8170334479634094`*^9, 3.817033480023611*^9, 3.8188010793225236`*^9, 
   3.825416618261719*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1822]=",ExpressionUUID->"f752fbfe-dcc2-49b3-86a1-a2631f036ac3"]
}, Open  ]],

Cell["Percent change in price of processed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8043453569347744`*^9, 3.8043453626552224`*^9}, {3.8048542238150196`*^9, 
  3.8048542238306465`*^9}, {3.8048542554028664`*^9, 
  3.80485427153401*^9}},ExpressionUUID->"65d42bae-b5c3-4483-b02f-\
77a2a2d19e21"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"podp1", "-", "podp0"}], ")"}], "100"}], "podp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
   3.804345314282593*^9, 3.804345320976801*^9}, {3.804858608922081*^9, 
   3.8048586124851284`*^9}, {3.804858750567197*^9, 3.8048587511610384`*^9}, {
   3.805018163895453*^9, 3.8050181639110804`*^9}, 3.805020631092285*^9, {
   3.805022001845244*^9, 3.805022002157792*^9}},
 CellLabel->
  "In[1823]:=",ExpressionUUID->"ec89fe8d-c64b-4802-9fa0-5fda4fec5080"],

Cell[BoxData["6.372020617210919`"], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394450070834*^9, 
   3.8033947921611457`*^9, 3.803394902183303*^9, 3.803397317788436*^9, 
   3.8033974330324726`*^9, 3.8033980555809436`*^9, 3.8033984220176916`*^9, 
   3.803398583128417*^9, 3.803509619956543*^9, 3.803510328750601*^9, 
   3.8035117202646694`*^9, 3.8035121798260965`*^9, 3.8043454968236103`*^9, 
   3.8043455349983096`*^9, 3.804345568678513*^9, 3.8043459769659524`*^9, 
   3.8043469004970655`*^9, 3.804347743828827*^9, {3.804347844647253*^9, 
   3.804347858560099*^9}, 3.804347890605002*^9, 3.804347928448488*^9, {
   3.8043482359682803`*^9, 3.8043482579934206`*^9}, 3.804348937046932*^9, 
   3.8043490063008647`*^9, 3.8043490999507318`*^9, 3.804519988130829*^9, 
   3.804520290805539*^9, 3.8045204190908566`*^9, 3.8045205648767223`*^9, 
   3.804521042149852*^9, 3.8045210806206036`*^9, 3.8045211597119155`*^9, 
   3.804521393082096*^9, 3.80452147118884*^9, 3.8045458084595966`*^9, 
   3.8045458829935436`*^9, 3.804546096889273*^9, 3.804546195674606*^9, 
   3.804587350250157*^9, 3.804590445433812*^9, 3.8045917108444138`*^9, 
   3.804591818462738*^9, 3.804858847436088*^9, 3.8048588904739017`*^9, 
   3.8048596671068783`*^9, 3.804859753526121*^9, 3.804859967671815*^9, 
   3.804860114699522*^9, 3.80486038403419*^9, 3.8048605410518775`*^9, 
   3.8048606730010166`*^9, 3.8048614925478373`*^9, 3.80486595290475*^9, 
   3.804866276622233*^9, 3.8048664472126026`*^9, 3.8048672536484404`*^9, 
   3.8048811938325744`*^9, 3.8048952722375216`*^9, 3.804896151687093*^9, 
   3.8048969492373266`*^9, 3.8050220362115784`*^9, 3.8050235331784983`*^9, 
   3.805023690074402*^9, 3.805023853499117*^9, 3.8050252284397664`*^9, 
   3.80563810466471*^9, 3.805638200932774*^9, 3.80563862465195*^9, 
   3.805640889080476*^9, 3.805641074507535*^9, 3.805665836312825*^9, 
   3.8072802273566723`*^9, 3.8072857868019047`*^9, 3.8072861150154724`*^9, 
   3.807287603278948*^9, 3.807306497688987*^9, 3.807306555294808*^9, 
   3.8073070807446585`*^9, 3.8073082164585114`*^9, 3.8073092340707617`*^9, 
   3.807882963132354*^9, 3.807884108688199*^9, 3.807884915925062*^9, 
   3.810047131324685*^9, 3.81004728565141*^9, 3.8100473778299465`*^9, 
   3.8110711135248322`*^9, 3.812470615611393*^9, 3.8124709398062515`*^9, 
   3.8124711903262863`*^9, 3.812471552009626*^9, 3.8127360723830805`*^9, 
   3.812821598878628*^9, 3.8129696428821774`*^9, 3.812970409633603*^9, 
   3.8129711260073075`*^9, 3.812976170934929*^9, 3.812976558297901*^9, 
   3.8139963263165045`*^9, 3.813996925968356*^9, 3.8139985742081685`*^9, 
   3.8139989618130693`*^9, 3.8139992596829567`*^9, 3.8139997179298944`*^9, 
   3.8140267277040477`*^9, 3.8140269191370764`*^9, 3.8140270911229696`*^9, 
   3.8148303159926195`*^9, 3.8154774981295366`*^9, 3.8154778033917327`*^9, 
   3.815477865276967*^9, 3.8154786180820055`*^9, 3.8157754039015474`*^9, 
   3.8170334479794216`*^9, 3.817033480036621*^9, 3.8188010793385363`*^9, 
   3.825416618521916*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1823]=",ExpressionUUID->"6981019d-c31a-45f0-a3f8-0ccc678c890e"]
}, Open  ]],

Cell["Percent change in quantity of processed domestic product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487438985057`*^9, 
  3.7998487447580204`*^9}, {3.7998488316665626`*^9, 3.79984883180721*^9}, {
  3.8033946223927174`*^9, 3.8033946223927174`*^9}, {3.80434542736657*^9, 
  3.804345432043209*^9}, {3.8048542238775296`*^9, 3.804854223893157*^9}, {
  3.804854255481004*^9, 
  3.8048542778511686`*^9}},ExpressionUUID->"9d2d41d9-d662-4692-b0f9-\
275af69086a3"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qodp1", "-", "qodp0"}], ")"}], "100"}], "qodp0"]], "Input",
 CellChangeTimes->{{3.7998487575895195`*^9, 3.799848762715358*^9}, {
  3.803393873678847*^9, 3.8033938774605455`*^9}, {3.8043454341418457`*^9, 
  3.804345442530369*^9}, {3.8048586142197695`*^9, 3.8048586179407425`*^9}, {
  3.8048587995680304`*^9, 3.8048588001931267`*^9}, {3.8050174161743164`*^9, 
  3.8050174161743164`*^9}, {3.805021931896407*^9, 3.805021932052683*^9}, {
  3.8050220023296947`*^9, 3.805022002689125*^9}},
 CellLabel->
  "In[1824]:=",ExpressionUUID->"c68f8a88-0d37-4eca-8a0f-53c6953ed701"],

Cell[BoxData[
 RowBox[{"-", "11.34227165652875`"}]], "Output",
 CellChangeTimes->{
  3.7998487670910683`*^9, 3.799849590771021*^9, 3.7998508737975636`*^9, 
   3.799851091646703*^9, 3.7998552204132013`*^9, 3.7998552586249037`*^9, 
   3.799856732481576*^9, 3.7998567774963803`*^9, 3.7998571940427775`*^9, {
   3.799857409581526*^9, 3.799857480344475*^9}, 3.7998575208543262`*^9, {
   3.7998576227991343`*^9, 3.799857664791382*^9}, 3.7998577579465623`*^9, {
   3.801660848386731*^9, 3.8016608615465293`*^9}, 3.8016627628143077`*^9, 
   3.8016634649965544`*^9, 3.801664262246231*^9, {3.8016643119635444`*^9, 
   3.8016643341983447`*^9}, 3.801664458635042*^9, 3.8016653459408455`*^9, 
   3.8016653965846252`*^9, 3.801665427700101*^9, {3.801666721049012*^9, 
   3.8016667501935325`*^9}, 3.8016667851013055`*^9, {3.801666958497096*^9, 
   3.8016669835185027`*^9}, 3.801667112547183*^9, 3.8016672261999207`*^9, 
   3.8016673961784225`*^9, 3.8016675825461254`*^9, 3.8016677821312337`*^9, {
   3.8016678463034973`*^9, 3.801667862196479*^9}, 3.801667932965206*^9, {
   3.801668181989745*^9, 3.801668203549836*^9}, {3.8016682674911523`*^9, 
   3.8016682945451846`*^9}, {3.8016683441501203`*^9, 3.801668369218362*^9}, 
   3.801668419882379*^9, 3.8016684518587646`*^9, 3.801668486440892*^9, 
   3.801668540162654*^9, 3.801692585952631*^9, 3.8016926397320037`*^9, 
   3.801692745425068*^9, 3.801692951090439*^9, 3.801693229016182*^9, 
   3.801693284348688*^9, 3.8016933946149426`*^9, 3.8016934879308796`*^9, 
   3.8017769822110043`*^9, 3.8017771996039686`*^9, 3.801777272739045*^9, 
   3.801777649910834*^9, 3.801778004446041*^9, 3.8017780732339706`*^9, 
   3.801778311646883*^9, 3.801778343410018*^9, 3.8017786539186954`*^9, 
   3.8017791370205827`*^9, 3.801779247144907*^9, 3.8017795049175644`*^9, 
   3.8017795484760995`*^9, 3.8017796202260094`*^9, 3.8017797084207597`*^9, 
   3.801779816038394*^9, 3.8017798527352915`*^9, 3.8017798985756803`*^9, {
   3.8017799390858173`*^9, 3.801779966465494*^9}, 3.8017802536885977`*^9, 
   3.8017803053504963`*^9, 3.8017803431487336`*^9, {3.8017804425012507`*^9, 
   3.801780470741673*^9}, 3.8017805388875856`*^9, 3.8017805790595284`*^9, 
   3.8017806641126976`*^9, 3.801781175412726*^9, 3.801781214445956*^9, 
   3.801781684735606*^9, {3.8017819948226943`*^9, 3.8017820331932487`*^9}, 
   3.801782085418224*^9, {3.8017822276876097`*^9, 3.8017822452842636`*^9}, 
   3.803075085365659*^9, 3.8030751524591475`*^9, 3.803075259060295*^9, 
   3.803075403285635*^9, 3.8030755053122687`*^9, 3.803113963238315*^9, 
   3.8031140830729084`*^9, 3.803114145635852*^9, 3.8031141909562154`*^9, 
   3.8031142975193906`*^9, 3.8031143934882584`*^9, 3.803118569004241*^9, 
   3.803118638048128*^9, 3.8031187019189796`*^9, {3.803118747212332*^9, 
   3.803118768913271*^9}, 3.8031188083180265`*^9, 3.8031205928117514`*^9, 
   3.8031206306432943`*^9, 3.8031244160764737`*^9, 3.8031245167730494`*^9, 
   3.8031249101550198`*^9, 3.8031249913833537`*^9, 3.803125758899518*^9, 
   3.803126253219862*^9, 3.8031284824623203`*^9, 3.803128668968882*^9, 
   3.8032924986361675`*^9, 3.8033030725290556`*^9, 3.8033032656276693`*^9, 
   3.8033104020663195`*^9, 3.8033128936695013`*^9, 3.803313220085433*^9, 
   3.803391639546876*^9, 3.8033920569063816`*^9, 3.8033921209922647`*^9, 
   3.8033925127358894`*^9, 3.803392624371758*^9, 3.803394460416421*^9, 
   3.803394800304357*^9, 3.8033949153537226`*^9, 3.803397328459818*^9, 
   3.8033974466278133`*^9, 3.8033980702099037`*^9, 3.8033984382279863`*^9, 
   3.8033985945895414`*^9, 3.8035096210035877`*^9, 3.803510329844529*^9, 
   3.8035117213898525`*^9, 3.803512180920024*^9, 3.804345497055791*^9, 
   3.804345535238497*^9, 3.8043455689187*^9, 3.8043459772161465`*^9, 
   3.8043469007452583`*^9, 3.804347744076019*^9, {3.804347844897449*^9, 
   3.804347858900341*^9}, 3.8043478908521976`*^9, 3.804347928686673*^9, {
   3.804348236238492*^9, 3.804348258242614*^9}, 3.8043489372540927`*^9, 
   3.8043490064499817`*^9, 3.804349100094843*^9, 3.8045199882871017`*^9, 
   3.8045202909461884`*^9, 3.804520419231505*^9, 3.804520565017369*^9, 
   3.80452104235301*^9, 3.804521080776879*^9, 3.804521159930702*^9, 
   3.8045213933008804`*^9, 3.8045214713451147`*^9, 3.804545808662755*^9, 
   3.8045458831967*^9, 3.804546097076805*^9, 3.804546195940275*^9, 
   3.804587350437683*^9, 3.8045904456057167`*^9, 3.8045917110006866`*^9, 
   3.80459181861901*^9, 3.8048588475923624`*^9, 3.8048588906145487`*^9, 
   3.8048596672475457`*^9, 3.8048597536824007`*^9, 3.8048599678124647`*^9, 
   3.8048601148557987`*^9, 3.8048603841904664`*^9, 3.804860541192525*^9, 
   3.804860673141664*^9, 3.80486149265723*^9, 3.804865953014142*^9, 
   3.8048662767316256`*^9, 3.8048664473219957`*^9, 3.804867253757833*^9, 
   3.8048811939419665`*^9, 3.804895272346916*^9, 3.8048961517964897`*^9, 
   3.804896949346719*^9, 3.8050220363991084`*^9, 3.8050235340536337`*^9, 
   3.805023690246303*^9, 3.805023853639764*^9, 3.8050252286272993`*^9, 
   3.805638104820986*^9, 3.805638201089049*^9, 3.8056386248238406`*^9, 
   3.805640889450761*^9, 3.805641074710693*^9, 3.8056658365069833`*^9, 
   3.8072802275107927`*^9, 3.8072857869960556`*^9, 3.807286115208623*^9, 
   3.8072876034650927`*^9, 3.8073064978461094`*^9, 3.8073065554839563`*^9, 
   3.807307080935809*^9, 3.807308216649639*^9, 3.8073092342499022`*^9, 
   3.807882963335513*^9, 3.8078841088913584`*^9, 3.8078849161125917`*^9, 
   3.810047131520794*^9, 3.810047285855568*^9, 3.8100473780271*^9, 
   3.8110711137219877`*^9, 3.8124706158125477`*^9, 3.812470940002405*^9, 
   3.812471190532446*^9, 3.8124715522097816`*^9, 3.81273607258624*^9, 
   3.8128215990957966`*^9, 3.8129696431165895`*^9, 3.8129704098680243`*^9, 
   3.8129711262573557`*^9, 3.81297617118497*^9, 3.812976558626068*^9, 
   3.81399632654168*^9, 3.8139969261865253`*^9, 3.813998574430374*^9, 
   3.813998962027235*^9, 3.8139992599031277`*^9, 3.8139997181500654`*^9, 
   3.8140267279362288`*^9, 3.8140269193702583`*^9, 3.8140270913611565`*^9, 
   3.8148303162768693`*^9, 3.8154774983795776`*^9, 3.815477803657402*^9, 
   3.8154778655426364`*^9, 3.8154786183320065`*^9, 3.8157754042248216`*^9, 
   3.817033447997012*^9, 3.817033480049664*^9, 3.8188010793545485`*^9, 
   3.8254166187630763`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1824]=",ExpressionUUID->"1ae9e60b-4b07-4b8b-a76f-4764de9aff93"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.805638279440954*^9}, 3.807307550649351*^9, 
   3.8252883797551527`*^9},ExpressionUUID->"3a1d09b7-e021-4be5-9440-\
183f46789866"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmaou"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"podu1", " ", 
     RowBox[{"(", 
      RowBox[{"qodu1", "-", "qodue0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"podu0", " ", 
     RowBox[{"(", 
      RowBox[{"qodu0", "-", "qodue0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.8056384216076107`*^9, 3.8056384298283195`*^9}, {3.805638482271556*^9, 
  3.805638484475052*^9}, {3.8056385728292103`*^9, 3.805638582553885*^9}, {
  3.805641139929985*^9, 3.8056411496359625`*^9}, {3.8128219230719447`*^9, 
  3.812821931960862*^9}, {3.825288384630022*^9, 3.8252883866615524`*^9}},
 CellLabel->
  "In[1825]:=",ExpressionUUID->"f13aef5f-971b-4fd5-973c-dd47a644d343"],

Cell[BoxData["8962.041880482544`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBGKdmLfm66PeOE5r3+i6G0hzfJ3ccz72jWODXaPzJSAd
dak9B0TPPd6ndhlIRz8MTbgDpDW6+9NBtNo025Ugmme3jPldIC172ncbiL62
p+DW17g3jl5sizO/AelVUt3nQHSWUvlkseQ3ji7Wh5aBaHdT900gmqXKdiJX
6hvH9XoMr7emv3E0KG4T3gak11ReNwLRTGK8CSBaealkp3nGG8eegpfeiUD6
z9tZpSA62zp76kog7Xbc+SuInrLngt8qID0tO/foGiAtyHnvK4je/O/6k3lZ
bxzDmk7rzwfSBf1X/oLomhpPvQVAuuJmczCIPnHhdA+IZihh3bsWSCepfb4C
os/pFr8C0QWNE2XNct44PlINlS/KfeN4nLPWFUTPi7X0BdEKC4JWg+hl5hOn
Mue9cdSKZribWfDG8TYj00MQXXj59bcTxW8cRWISTNMb3jgCAHv8yPc=
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1825]=",ExpressionUUID->"1cf6ce2d-48f6-4ff5-b84d-34e00374a7f3"]
}, Open  ]],

Cell["Change ($) in operating income, processed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.8056382995792217`*^9}, 3.8073075741796618`*^9, 
   3.825288382706482*^9},ExpressionUUID->"94b7fb62-ff27-41b0-b6cf-\
9ff2d7401e61"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmaop"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"podp1", " ", 
     RowBox[{"(", 
      RowBox[{"qodp1", "-", "qodpe0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"podp0", " ", 
     RowBox[{"(", 
      RowBox[{"qodp0", "-", "qodpe0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.805638311659393*^9, 3.805638322630473*^9}, {3.805638433988842*^9, 
  3.8056384793310328`*^9}, {3.805638585596484*^9, 3.8056385956233883`*^9}, {
  3.805641132394824*^9, 3.805641135817252*^9}, {3.8128219358028517`*^9, 
  3.8128219452041707`*^9}, {3.825288388498*^9, 3.825288390795789*^9}},
 CellLabel->
  "In[1826]:=",ExpressionUUID->"c3180513-ab60-4ec9-8f7d-e65b660c3a99"],

Cell[BoxData[
 RowBox[{"-", "35.57329831169651`"}]], "Output",
 CellChangeTimes->{
  3.8056382863724117`*^9, 3.805638323678563*^9, {3.805638445362606*^9, 
   3.8056384571096716`*^9}, 3.8056386259021473`*^9, 3.805640891530364*^9, 
   3.805641076054661*^9, 3.8056411369424357`*^9, 3.8056658377454967`*^9, 
   3.8072802288938704`*^9, 3.807285788233017*^9, 3.8072861164425898`*^9, 
   3.807287604647011*^9, 3.8073064988759084`*^9, 3.807306556676886*^9, 
   3.8073070821177287`*^9, 3.8073082170859804`*^9, 3.807309234611184*^9, 
   3.807882963726202*^9, 3.8078841092820487`*^9, 3.8078849165501623`*^9, 
   3.8100471319181023`*^9, 3.8100472862718916`*^9, 3.810047378422407*^9, 
   3.811071114143384*^9, 3.8124706161958475`*^9, 3.812470940398715*^9, 
   3.812471190942765*^9, 3.8124715526211014`*^9, 3.812736073004567*^9, 
   3.8128215994921045`*^9, 3.8128219461048737`*^9, 3.812969643585411*^9, 
   3.8129704103524976`*^9, 3.8129711267887106`*^9, 3.8129761716069126`*^9, 
   3.812976559266763*^9, 3.8139963269630075`*^9, 3.8139969265367975`*^9, 
   3.8139985748526716`*^9, 3.813998962512615*^9, 3.813999260339467*^9, 
   3.813999718589407*^9, 3.814026728410597*^9, 3.81402691987465*^9, 
   3.81402709188056*^9, 3.8148303168112583`*^9, 3.8154774989109154`*^9, 
   3.815477804173113*^9, 3.815477866042719*^9, 3.815478618832086*^9, 
   3.815775405123502*^9, 3.8170334480411525`*^9, 3.8170334800887628`*^9, 
   3.8188010793995843`*^9, 3.8254166192724743`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1826]=",ExpressionUUID->"cdd877d1-be09-4753-941c-936e8597116e"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"db4d22e8-f123-44d4-bff8-\
821aad05b9af"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"potu1", "-", "potu0"}], ")"}], "100"}], "potu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
   3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
   3.8048586228946285`*^9}, {3.804858751489214*^9, 3.8048587520986824`*^9}, {
   3.805018113403982*^9, 3.8050181134196095`*^9}, 3.80502029645166*^9, {
   3.805022002845399*^9, 3.8050220032048297`*^9}},
 CellLabel->
  "In[1827]:=",ExpressionUUID->"7b735c7b-feec-43a8-8952-9518e3c43679"],

Cell[BoxData["8.826471596040077`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.8048588477330093`*^9, 3.8048588907551947`*^9, 
   3.8048596674038343`*^9, 3.804859753823053*^9, 3.8048599679531155`*^9, 
   3.804860114996448*^9, 3.8048603843467426`*^9, 3.8048605413487997`*^9, 
   3.804860673297939*^9, 3.8048614927666225`*^9, 3.8048659531235347`*^9, 
   3.8048662768410177`*^9, 3.804866447431389*^9, 3.804867253867225*^9, 
   3.804881194051359*^9, 3.804895272440683*^9, 3.804896151905878*^9, 
   3.804896949456112*^9, 3.8050220365710096`*^9, 3.8050235376791954`*^9, 
   3.8050236904025784`*^9, 3.8050238537980585`*^9, 3.805025228799204*^9, 
   3.8056381049772606`*^9, 3.805638201323462*^9, 3.8056386249957447`*^9, 
   3.805640889845065*^9, 3.805641074913851*^9, 3.805665836704134*^9, 
   3.8072802277339673`*^9, 3.8072857871922083`*^9, 3.807286115403782*^9, 
   3.807287603663246*^9, 3.80730649801524*^9, 3.8073065557311497`*^9, 
   3.807307081126958*^9, 3.807308217279173*^9, 3.807309234800331*^9, 
   3.807882963960614*^9, 3.8078841095789733`*^9, 3.807884916737692*^9, 
   3.810047132117257*^9, 3.8100472864790525`*^9, 3.8100473786205606`*^9, 
   3.8110711143464794`*^9, 3.8124706163900614`*^9, 3.8124709405918655`*^9, 
   3.8124711911459227`*^9, 3.812471552819256*^9, 3.8127360732067413`*^9, 
   3.8128215996912594`*^9, 3.81296964383545*^9, 3.8129704106025476`*^9, 
   3.8129711270387316`*^9, 3.8129761718569536`*^9, 3.8129765595793004`*^9, 
   3.813996327175172*^9, 3.813996926751965*^9, 3.813998575065837*^9, 
   3.8139989627327876`*^9, 3.813999260605674*^9, 3.813999718846614*^9, 
   3.8140267286427774`*^9, 3.814026920065834*^9, 3.8140270921207466`*^9, 
   3.814830317074481*^9, 3.8154774991609573`*^9, 3.8154778044231715`*^9, 
   3.815477866308386*^9, 3.8154786190664997`*^9, 3.8157754054437733`*^9, 
   3.817033448057164*^9, 3.817033480101757*^9, 3.8188010794165974`*^9, 
   3.825416619530649*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1827]=",ExpressionUUID->"e2fde703-2f2f-4f00-929e-f6ceb5cf88c9"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
  3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
  3.8048542553403563`*^9, 
  3.8048542677330275`*^9}},ExpressionUUID->"4a4ee525-f758-4e09-8791-\
db558dedf73d"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qotu1", "-", "qotu0"}], ")"}], "100"}], "qotu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.804858800630694*^9, 3.8048588012870445`*^9}, {3.8050174723410645`*^9, 
  3.8050174723410645`*^9}, {3.805021936100234*^9, 3.8050219362096276`*^9}, {
  3.8050220033611035`*^9, 3.8050220037373953`*^9}},
 CellLabel->
  "In[1828]:=",ExpressionUUID->"573d1fcc-bc54-41d7-b61c-dd7a0174e352"],

Cell[BoxData[
 RowBox[{"-", "12.543446233117097`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588478736553`*^9, 3.8048588909114695`*^9, 
   3.8048596675600967`*^9, 3.804859753963705*^9, 3.804859968109393*^9, 
   3.804860115168353*^9, 3.8048603844873915`*^9, 3.8048605415207024`*^9, 
   3.8048606734385867`*^9, 3.8048614928760147`*^9, 3.804865953232927*^9, 
   3.8048662769660378`*^9, 3.8048664475407825`*^9, 3.804867253961108*^9, 
   3.8048811941607513`*^9, 3.804895272550078*^9, 3.8048961520152717`*^9, 
   3.804896949565504*^9, 3.8050220367429113`*^9, 3.8050235381636443`*^9, 
   3.8050236905744786`*^9, 3.8050238539344997`*^9, 3.8050252289867373`*^9, 
   3.8056381051335363`*^9, 3.8056382014953647`*^9, 3.805638625183276*^9, 
   3.805640890159307*^9, 3.8056410751170087`*^9, 3.80566583690129*^9, 
   3.807280227924116*^9, 3.807285787389361*^9, 3.8072861156039305`*^9, 
   3.8072876039054346`*^9, 3.8073064981723623`*^9, 3.807306555918296*^9, 
   3.8073070813161063`*^9, 3.8073082174692802`*^9, 3.8073092349835033`*^9, 
   3.807882964148145*^9, 3.8078841097665043`*^9, 3.807884916925222*^9, 
   3.8100471323074045`*^9, 3.810047286679208*^9, 3.810047378832725*^9, 
   3.811071114549639*^9, 3.812470616580149*^9, 3.812470940803029*^9, 
   3.8124711913450775`*^9, 3.8124715530184107`*^9, 3.8127360734098983`*^9, 
   3.8128215999064264`*^9, 3.8129696440854893`*^9, 3.8129704108369694`*^9, 
   3.8129711272887745`*^9, 3.812976172100631*^9, 3.81297655990749*^9, 
   3.813996327387348*^9, 3.813996926983144*^9, 3.8139985752830057`*^9, 
   3.81399896295296*^9, 3.8139992608208413`*^9, 3.813999719065777*^9, 
   3.814026728876959*^9, 3.814026920382081*^9, 3.8140270923689404`*^9, 
   3.8148303173556843`*^9, 3.815477499410999*^9, 3.815477804673196*^9, 
   3.815477866558426*^9, 3.8154786193165703`*^9, 3.815775405760044*^9, 
   3.817033448073177*^9, 3.817033480114767*^9, 3.8188010794346113`*^9, 
   3.825416619773877*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1828]=",ExpressionUUID->"679d20ac-7b15-42c5-8a13-2a04b019208e"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"d0b7c15b-ffd6-480e-aaae-\
f85490456529"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"potp1", "-", "potp0"}], ")"}], "100"}], "potp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
   3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
   3.804858633427496*^9}, {3.804858752504995*^9, 3.804858754192754*^9}, {
   3.8050182855042944`*^9, 3.8050182855042944`*^9}, 3.8050206707402067`*^9, {
   3.805022004034316*^9, 3.805022004518766*^9}},
 CellLabel->
  "In[1829]:=",ExpressionUUID->"fdb2e803-a85d-4f0e-8038-c45ff26d0bf6"],

Cell[BoxData["11.882750764919095`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.8048588480143023`*^9, 3.8048588910677433`*^9, 3.8048596677007504`*^9, 
   3.8048597541199846`*^9, 3.804859968250043*^9, 3.804860115309002*^9, 
   3.8048603846436667`*^9, 3.804860541708233*^9, 3.804860673594861*^9, 
   3.804861492985408*^9, 3.804865953357947*^9, 3.8048662770754304`*^9, 
   3.804866447650175*^9, 3.804867254086011*^9, 3.8048811942701445`*^9, 
   3.8048952726594725`*^9, 3.8048961521246634`*^9, 3.8048969496748967`*^9, 
   3.8050220369148164`*^9, 3.80502354188297*^9, 3.80502369074638*^9, 
   3.8050238541532726`*^9, 3.805025229158642*^9, 3.805638105305439*^9, 
   3.805638201667282*^9, 3.80563862535518*^9, 3.805640890476551*^9, 
   3.8056410753201666`*^9, 3.805665837150487*^9, 3.807280228115266*^9, 
   3.807285787585513*^9, 3.8072861157960796`*^9, 3.807287604090578*^9, 
   3.8073064983284836`*^9, 3.8073065561084433`*^9, 3.8073070815012503`*^9, 
   3.807308217658427*^9, 3.807309235173621*^9, 3.807882964351302*^9, 
   3.8078841099852915`*^9, 3.8078849171283803`*^9, 3.8100471324985523`*^9, 
   3.810047286882365*^9, 3.810047379029878*^9, 3.8110711147487965`*^9, 
   3.81247061677332*^9, 3.8124709410131927`*^9, 3.81247119155424*^9, 
   3.8124715532165723`*^9, 3.8127360736120434`*^9, 3.8128216001165895`*^9, 
   3.8129696443199015`*^9, 3.8129704110713997`*^9, 3.8129711275544443`*^9, 
   3.812976172338708*^9, 3.8129765602512674`*^9, 3.8139963276145134`*^9, 
   3.81399692719631*^9, 3.8139985755111837`*^9, 3.813998963171131*^9, 
   3.813999261041012*^9, 3.8139997192849474`*^9, 3.8140267291021338`*^9, 
   3.8140269206122255`*^9, 3.8140270926101274`*^9, 3.814830317634904*^9, 
   3.8154774996922956`*^9, 3.8154778049389563`*^9, 3.815477866824094*^9, 
   3.815478619566582*^9, 3.8157754060582476`*^9, 3.817033448089222*^9, 
   3.8170334801287775`*^9, 3.818801079450624*^9, 3.8254166200270863`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1829]=",ExpressionUUID->"ba5c3bd8-219b-4e77-bd40-8b7e3c9c47a8"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
  3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
  3.804854223908785*^9}, {3.8048542555122595`*^9, 
  3.804854280414089*^9}},ExpressionUUID->"041c5226-fdfa-4c79-81a8-\
519a191d2372"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qotp1", "-", "qotp0"}], ")"}], "100"}], "qotp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.804858801740239*^9, 3.8048588038343105`*^9}, {3.805017523503875*^9, 
  3.805017523503875*^9}, {3.8050219403353195`*^9, 3.805021940413457*^9}, {
  3.805022004690667*^9, 3.8050220065659575`*^9}},
 CellLabel->
  "In[1830]:=",ExpressionUUID->"5f9ee1b1-28df-43c7-a49e-dc5c6e8a2f98"],

Cell[BoxData[
 RowBox[{"-", "19.885679400889536`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.804858848154949*^9, 3.804858891192762*^9, 3.8048596678726606`*^9, 
   3.804859754260637*^9, 3.80485996839496*^9, 3.804860115465279*^9, 
   3.804860384799943*^9, 3.80486054184888*^9, 3.80486067373553*^9, 
   3.80486149309489*^9, 3.804865953482967*^9, 3.804866277169195*^9, 
   3.804866447759568*^9, 3.804867254195405*^9, 3.8048811943795366`*^9, 
   3.804895272768914*^9, 3.8048961522340565`*^9, 3.8048969497842894`*^9, 
   3.8050220371335964`*^9, 3.8050235423517923`*^9, 3.805023690980791*^9, 
   3.8050238543227386`*^9, 3.805025229393057*^9, 3.8056381055242243`*^9, 
   3.8056382018079295`*^9, 3.8056386255270844`*^9, 3.805640890791795*^9, 
   3.80564107561709*^9, 3.8056658373486643`*^9, 3.8072802284325123`*^9, 
   3.8072857878427134`*^9, 3.8072861160532794`*^9, 3.807287604275722*^9, 
   3.8073064985226345`*^9, 3.8073065562975903`*^9, 3.8073070817324295`*^9, 
   3.8073082178485746`*^9, 3.807309235356763*^9, 3.8078829645544605`*^9, 
   3.8078841101728225`*^9, 3.8078849173159437`*^9, 3.8100471326897016`*^9, 
   3.810047287099534*^9, 3.810047379230034*^9, 3.811071114947953*^9, 
   3.812470616978461*^9, 3.8124709412093744`*^9, 3.8124711917513933`*^9, 
   3.8124715534427423`*^9, 3.812736073839221*^9, 3.812821600319747*^9, 
   3.8129696445543127`*^9, 3.8129704113370695`*^9, 3.8129711278044863`*^9, 
   3.812976172588749*^9, 3.8129765605638046`*^9, 3.8139963278276787`*^9, 
   3.813996927372449*^9, 3.8139985757234077`*^9, 3.8139989634413404`*^9, 
   3.813999261259182*^9, 3.8139997195061193`*^9, 3.814026729325308*^9, 
   3.8140269208013735`*^9, 3.814027092891346*^9, 3.814830317899109*^9, 
   3.8154774999423366`*^9, 3.81547780522016*^9, 3.8154778670741687`*^9, 
   3.8154786198166237`*^9, 3.815775406361468*^9, 3.817033448105361*^9, 
   3.8170334801417885`*^9, 3.8188010794676375`*^9, 3.8254166202972417`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1830]=",ExpressionUUID->"65af7469-3d31-4aff-8edb-e09bef8f6827"]
}, Open  ]],

Cell[TextData[StyleBox["Bonito",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.7998488592686234`*^9, 
   3.7998488783519864`*^9}, {3.79984892891759*^9, 3.7998489382474413`*^9}, {
   3.7998490166229935`*^9, 3.799849022359763*^9}, {3.804348823401332*^9, 
   3.8043488341637087`*^9}, {3.804854223643115*^9, 3.804854223658743*^9}, {
   3.8048542552153363`*^9, 3.804854255230964*^9}, {3.80485849323055*^9, 
   3.8048584943088517`*^9}, {3.804858674828244*^9, 3.8048586759846716`*^9}, {
   3.805021921987334*^9, 3.8050219236606793`*^9}, {3.805021990843542*^9, 
   3.805021993390811*^9}, {3.807308014995708*^9, 3.8073080157342844`*^9}, 
   3.825288023512868*^9},ExpressionUUID->"d1fed075-77fe-46ed-87e4-\
911852b50b0d"],

Cell["Percent change in price of unprocessed domestic production", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
  3.799848828683051*^9}, {3.8043453480438595`*^9, 3.8043453654023633`*^9}, {
  3.804854223658743*^9, 3.8048542236743703`*^9}, {3.8048542552465916`*^9, 
  3.804854262169608*^9}},ExpressionUUID->"cd5bd462-f8d6-4d2f-918a-\
4dc30842ea81"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pndu1", "-", "pndu0"}], ")"}], "100"}], "pndu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
   3.804345303826458*^9, 3.804345310313504*^9}, {3.8048585961544952`*^9, 
   3.8048585992018385`*^9}, {3.8048587486137724`*^9, 3.804858750004611*^9}, {
   3.805017872704455*^9, 3.805017872704455*^9}, 3.805020287887725*^9, {
   3.8050220006263056`*^9, 3.8050220011576376`*^9}, {3.8056407576932087`*^9, 
   3.805640759415536*^9}},
 CellLabel->
  "In[1831]:=",ExpressionUUID->"d044afb3-4c1a-4e50-b6b3-432f63f7f1ec"],

Cell[BoxData["1.88554295231671`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944493988967`*^9, 
   3.8033947909578247`*^9, 3.8033949008683414`*^9, 3.8033973169558887`*^9, 
   3.8033974320336943`*^9, 3.8033980551121173`*^9, 3.80339842081437*^9, 
   3.803398581538791*^9, 3.8035096198627777`*^9, 3.8035103286568356`*^9, 
   3.803511720170905*^9, 3.8035121797323313`*^9, 3.8043454967735705`*^9, 
   3.804345534949273*^9, 3.8043455686314764`*^9, 3.8043459769139137`*^9, 
   3.804346900446025*^9, 3.8043477437757854`*^9, {3.8043478445962133`*^9, 
   3.804347858488022*^9}, 3.804347890554963*^9, 3.804347928403453*^9, {
   3.804348235913237*^9, 3.804348257945382*^9}, 3.8043489367446976`*^9, 
   3.804349006022649*^9, 3.8043490996504984`*^9, 3.8045199878807864`*^9, 
   3.8045202905398693`*^9, 3.8045204188251886`*^9, 3.804520564595425*^9, 
   3.8045210417904205`*^9, 3.804521080354935*^9, 3.8045211594149933`*^9, 
   3.8045213927539186`*^9, 3.804521470907544*^9, 3.8045458080837293`*^9, 
   3.8045458826341124`*^9, 3.804546096467331*^9, 3.8045461953308024`*^9, 
   3.8045873499844947`*^9, 3.8045904451056285`*^9, 3.804591710531866*^9, 
   3.8045918181814427`*^9, 3.804858847139168*^9, 3.804858890192608*^9, 
   3.804859666825571*^9, 3.8048597532291985`*^9, 3.8048599673748865`*^9, 
   3.804860114402596*^9, 3.8048603837216387`*^9, 3.8048605407393417`*^9, 
   3.8048606726728387`*^9, 3.804861492313425*^9, 3.8048659526859646`*^9, 
   3.8048662764034476`*^9, 3.8048664469938164`*^9, 3.8048672534297056`*^9, 
   3.8048811936294165`*^9, 3.804895272018732*^9, 3.8048961514683075`*^9, 
   3.8048969490185413`*^9, 3.805022035836521*^9, 3.8050235258023567`*^9, 
   3.805023689652461*^9, 3.805023853170941*^9, 3.8050252280334463`*^9, 
   3.805638104340911*^9, 3.805638200620223*^9, 3.8056386242595654`*^9, 
   3.8056408918986483`*^9, 3.805641076242191*^9, 3.805665837948658*^9, 
   3.807280229084018*^9, 3.807285788430169*^9, 3.80728611663875*^9, 
   3.807287604831169*^9, 3.807306499081068*^9, 3.80730655693111*^9, 
   3.807307082309878*^9, 3.8073082180817556`*^9, 3.8073092355429077`*^9, 
   3.807882964773247*^9, 3.8078841103759813`*^9, 3.8078849175503225`*^9, 
   3.8100471328958616`*^9, 3.8100472872966866`*^9, 3.8100473794341917`*^9, 
   3.811071115162122*^9, 3.8124706171746144`*^9, 3.8124709414155054`*^9, 
   3.8124711919495473`*^9, 3.8124715536609135`*^9, 3.8127360740453825`*^9, 
   3.8128216005239058`*^9, 3.8129696447887244`*^9, 3.8129704115714917`*^9, 
   3.812971128054571*^9, 3.81297617283881*^9, 3.812976560876363*^9, 
   3.813996328044848*^9, 3.8139969275866175`*^9, 3.8139985759405165`*^9, 
   3.813998963656508*^9, 3.8139992614753494`*^9, 3.8139997197262907`*^9, 
   3.814026729557488*^9, 3.814026921072586*^9, 3.8140270931325336`*^9, 
   3.814830318135293*^9, 3.815477500208004*^9, 3.8154778054701996`*^9, 
   3.815477867324175*^9, 3.8154786200666656`*^9, 3.815775406673751*^9, 
   3.817033448121374*^9, 3.817033480153859*^9, 3.8188010794836493`*^9, 
   3.825416620563487*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1831]=",ExpressionUUID->"82549a06-c670-49b2-a305-5091a3567b3e"]
}, Open  ]],

Cell["Percent change in quantity of landings ", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848828589285*^9, 
   3.799848828683051*^9}, {3.80339462237709*^9, 3.80339462237709*^9}, {
   3.80434540679557*^9, 3.804345410458417*^9}, {3.804854223736881*^9, 
   3.804854223752509*^9}, {3.804854255324729*^9, 3.8048542553403563`*^9}, 
   3.807308034867176*^9},ExpressionUUID->"e973c32a-c384-4e66-88e8-\
77ac0cf1dbb7"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qndu1", "-", "qndu0"}], ")"}], "100"}], "qndu0"]], "Input",
 CellChangeTimes->{{3.79984870896197*^9, 3.799848721377509*^9}, {
  3.803393864225988*^9, 3.8033938707725306`*^9}, {3.804345412753205*^9, 
  3.8043454208665133`*^9}, {3.804858603546255*^9, 3.804858606187286*^9}, {
  3.804858792627643*^9, 3.804858798896052*^9}, {3.8050173592553644`*^9, 
  3.8050173592553644`*^9}, {3.8050219270518637`*^9, 3.8050219271612563`*^9}, {
  3.8050220013295393`*^9, 3.805022001657715*^9}, {3.805640764781672*^9, 
  3.8056407660316353`*^9}},
 CellLabel->
  "In[1832]:=",ExpressionUUID->"9d6cb6fd-c852-414c-93c3-707ac678a576"],

Cell[BoxData["9.339174439698114`"], "Output",
 CellChangeTimes->{
  3.799848765434549*^9, 3.7998495906303587`*^9, 3.7998508735944057`*^9, 
   3.7998510915216465`*^9, 3.799855220225684*^9, 3.799855258545581*^9, 
   3.79985673224722*^9, 3.799856777308849*^9, 3.7998571939177523`*^9, {
   3.79985740945651*^9, 3.7998574802819653`*^9}, 3.7998575207449303`*^9, {
   3.799857622720996*^9, 3.7998576647132444`*^9}, 3.799857757837169*^9, {
   3.801660843698538*^9, 3.80166086131212*^9}, 3.801662762689275*^9, 
   3.8016634647777677`*^9, 3.801664262136839*^9, {3.8016643118541517`*^9, 
   3.801664334104562*^9}, 3.801664458228727*^9, 3.8016653434873257`*^9, 
   3.801665396475232*^9, 3.8016654275907083`*^9, {3.8016667205958147`*^9, 
   3.8016667497090793`*^9}, 3.8016667849919133`*^9, {3.8016669583877044`*^9, 
   3.801666983393482*^9}, 3.8016671123752804`*^9, 3.801667225668567*^9, 
   3.801667396069028*^9, 3.8016675816866074`*^9, 3.801667782006216*^9, {
   3.801667845772169*^9, 3.8016678620714545`*^9}, 3.8016679324963875`*^9, {
   3.801668181895981*^9, 3.8016682034248166`*^9}, {3.8016682673661327`*^9, 
   3.8016682944514203`*^9}, {3.8016683439938436`*^9, 3.801668369093341*^9}, 
   3.801668419757352*^9, 3.801668451749371*^9, 3.801668486330226*^9, 
   3.80166854005326*^9, 3.8016925857651014`*^9, 3.801692639169413*^9, 
   3.8016927448155947`*^9, 3.801692950918535*^9, 3.801693228875534*^9, 
   3.801693284208041*^9, 3.8016933933803835`*^9, 3.801693487758977*^9, 
   3.8017769817516036`*^9, 3.8017771994164386`*^9, 3.8017772722136374`*^9, 
   3.8017776493951235`*^9, 3.801778004274138*^9, 3.8017780726870146`*^9, 
   3.801778311474981*^9, 3.801778342898621*^9, 3.8017786537624207`*^9, 
   3.8017791368955617`*^9, 3.801779247004259*^9, 3.8017795047612906`*^9, 
   3.80177954835108*^9, 3.8017796197728148`*^9, 3.801779707967576*^9, 
   3.8017798155539484`*^9, 3.8017798525790167`*^9, 3.8017798984506593`*^9, {
   3.8017799389607897`*^9, 3.8017799663092184`*^9}, 3.8017802525165267`*^9, 
   3.8017803051942177`*^9, 3.8017803426630507`*^9, {3.801780441891771*^9, 
   3.801780470225959*^9}, 3.801780538340616*^9, 3.8017805789188805`*^9, 
   3.8017806639720488`*^9, 3.801781175272077*^9, 3.8017812143521914`*^9, 
   3.801781684485566*^9, {3.8017819946195383`*^9, 3.801782033099483*^9}, 
   3.8017820852619624`*^9, {3.801782226812477*^9, 3.8017822448154354`*^9}, 
   3.8030750852324686`*^9, 3.803075152325042*^9, 3.8030752590462837`*^9, 
   3.8030754032746267`*^9, 3.8030755053012605`*^9, 3.8031139630621758`*^9, 
   3.803114082936801*^9, 3.8031141454997454`*^9, 3.803114190943205*^9, 
   3.8031142975083623`*^9, 3.80311439347725*^9, 3.803118568976219*^9, 
   3.80311863803712*^9, 3.8031187019079714`*^9, {3.803118747199321*^9, 
   3.8031187689022627`*^9}, 3.8031188083070183`*^9, 3.8031205927867327`*^9, 
   3.8031206306322856`*^9, 3.8031244160504537`*^9, 3.8031245167610397`*^9, 
   3.803124910145012*^9, 3.8031249913713446`*^9, 3.803125758884506*^9, 
   3.803126253206852*^9, 3.803128482093029*^9, 3.803128668956873*^9, 
   3.8032924986201553`*^9, 3.803303071203088*^9, 3.803303265190098*^9, 
   3.8033104014568043`*^9, 3.8033128930610037`*^9, 3.803313219132153*^9, 
   3.803391638984284*^9, 3.8033920567032237`*^9, 3.8033921207734833`*^9, 
   3.8033925120951595`*^9, 3.803392621886979*^9, 3.8033944591818423`*^9, 
   3.8033947993351855`*^9, 3.8033949148848963`*^9, 3.803397327175394*^9, 
   3.8033974450328417`*^9, 3.803398069256624*^9, 3.8033984377255435`*^9, 
   3.8033985919745092`*^9, 3.8035096209254503`*^9, 3.803510329750763*^9, 
   3.8035117212960873`*^9, 3.8035121808418865`*^9, 3.8043454970057516`*^9, 
   3.8043455351904593`*^9, 3.8043455688706636`*^9, 3.804345977166108*^9, 
   3.804346900698222*^9, 3.8043477440259805`*^9, {3.8043478448484106`*^9, 
   3.8043478588292866`*^9}, 3.804347890804165*^9, 3.8043479286396365`*^9, {
   3.80434823618445*^9, 3.804348258193575*^9}, 3.8043489369488554`*^9, 
   3.804349006197785*^9, 3.804349099851654*^9, 3.8045199880370617`*^9, 
   3.8045202906961455`*^9, 3.804520418981464*^9, 3.8045205647673283`*^9, 
   3.804521042009207*^9, 3.804521080511212*^9, 3.804521159602523*^9, 
   3.804521392972704*^9, 3.804521471079446*^9, 3.8045458083203707`*^9, 
   3.8045458828685236`*^9, 3.804546096701744*^9, 3.804546195565214*^9, 
   3.8045873501407666`*^9, 3.804590445324417*^9, 3.8045917107350206`*^9, 
   3.8045918183533454`*^9, 3.8048588472798543`*^9, 3.8048588903332553`*^9, 
   3.8048596669662247`*^9, 3.8048597533854685`*^9, 3.8048599675155373`*^9, 
   3.8048601145432453`*^9, 3.8048603838622866`*^9, 3.8048605408956027`*^9, 
   3.804860672829114*^9, 3.804861492438445*^9, 3.8048659527953568`*^9, 
   3.8048662765128403`*^9, 3.8048664471032095`*^9, 3.804867253539048*^9, 
   3.804881193738809*^9, 3.804895272128127*^9, 3.8048961515777006`*^9, 
   3.8048969491279335`*^9, 3.8050220360396776`*^9, 3.805023529474801*^9, 
   3.805023689902499*^9, 3.805023853342844*^9, 3.805025228267862*^9, 
   3.8056381044928074`*^9, 3.8056382007608705`*^9, 3.805638624431469*^9, 
   3.805640892263945*^9, 3.8056410764453487`*^9, 3.805665838198701*^9, 
   3.807280229311195*^9, 3.807285788667353*^9, 3.8072861168328843`*^9, 
   3.8072876050803504`*^9, 3.8073064992792234`*^9, 3.807306557120246*^9, 
   3.807307082501026*^9, 3.8073082182709026`*^9, 3.807309235725049*^9, 
   3.807882965023288*^9, 3.807884110657279*^9, 3.807884917753481*^9, 
   3.810047133094015*^9, 3.8100472875078506`*^9, 3.8100473796323457`*^9, 
   3.8110711153812947`*^9, 3.8124706173657665`*^9, 3.812470941616663*^9, 
   3.812471192149702*^9, 3.8124715538710775`*^9, 3.812736074251566*^9, 
   3.812821600734069*^9, 3.812969645038763*^9, 3.8129704118059134`*^9, 
   3.81297112830457*^9, 3.812976173073202*^9, 3.81297656122015*^9, 
   3.8139963282670207`*^9, 3.8139969277627554`*^9, 3.813998576156685*^9, 
   3.8139989638736763`*^9, 3.8139992617425575`*^9, 3.8139997199874935`*^9, 
   3.8140267297796607`*^9, 3.8140269212607946`*^9, 3.814027093370719*^9, 
   3.8148303183694754`*^9, 3.815477500458044*^9, 3.8154778057202396`*^9, 
   3.8154778675898447`*^9, 3.8154786203167067`*^9, 3.8157754069609356`*^9, 
   3.8170334481383867`*^9, 3.8170334801665387`*^9, 3.8188010795006633`*^9, 
   3.825416620819682*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1832]=",ExpressionUUID->"b789f513-1fff-4419-ac94-26150a21d627"]
}, Open  ]],

Cell["Change ($) in operating income, unprocessed product", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
   3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
   3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
   3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
   3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
   3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
   3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
   3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
   3.804854223908785*^9}, {3.8048542555122595`*^9, 3.804854280414089*^9}, {
   3.8056382232594132`*^9, 3.8056382247127733`*^9}, {3.805638271840131*^9, 
   3.805638279440954*^9}, 3.8073075506633625`*^9, 
   3.8252883976401405`*^9},ExpressionUUID->"10e14ef7-7dbb-4c4f-89b4-\
1f5f447cbacb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "/", "sigmanu"}], ")"}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"pndu1", " ", 
     RowBox[{"(", 
      RowBox[{"qndu1", "-", "qndue0"}], ")"}]}], " ", "-", " ", 
    RowBox[{"pndu0", " ", 
     RowBox[{"(", 
      RowBox[{"qndu0", "-", "qndue0"}], ")"}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.805638227729192*^9, 3.8056382668865757`*^9}, {
  3.8056384216076107`*^9, 3.8056384298283195`*^9}, {3.805638482271556*^9, 
  3.805638484475052*^9}, {3.8056385728292103`*^9, 3.805638582553885*^9}, {
  3.8056408054360065`*^9, 3.8056408074635687`*^9}, {3.805641123295667*^9, 
  3.8056411271908617`*^9}, {3.8128219003672724`*^9, 3.812821912779934*^9}, {
  3.8252884010348034`*^9, 3.8252884028101892`*^9}},
 CellLabel->
  "In[1833]:=",ExpressionUUID->"ddfc108a-8f62-4b98-9b7a-68f0eff4fd65"],

Cell[BoxData["7407.000974722554`"], "Output",
 CellChangeTimes->CompressedData["
1:eJwVxVkow3EcAPAtQ1muZDw48mJe3GbyID8Myc0DynKkIccaD1oR44EamrX2
YnObjaUco7H/MmRyk5IrlFrzU3uwKbl+34dPn4i69tIGOo1G4xDH9qMLfRVG
bD73G1Zu3AYtk3MzqBg4a/wzCT6v/uBtkd+9D6Vn1RgVaw2Zl2Rx5HYLHN2z
G3lFTvEcqLknLwXvCeATebsWNm4Wch/IrOZuAxxo1tw6+RitDd41uciWEOoU
TivRyln1GP1oXPOwT794BfaTi2ReDRjNvMS/rQswGus2BhjIXgnMRFgqzKiB
y1WFQ9xGjEbDwvJryTsHnA74xrSg0JL38vqccL3Zv0hHplfo9pfIEma8Cw5Q
+r6qmzFKVf3FTpAZj8xfuNEhiZkk51BUGZw95zEMq9npJj15xxR7DfeUrdph
S/pVaHILRnNRynBRK0YjUjMPrnwSF8DWadkiHNdpU7i1YTRrYzw0CTHSGdyf
4YEuh8vagdH01xRH0IvRPw6l4OA=
  "],
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1833]=",ExpressionUUID->"736c6c8d-ee74-4a67-9cb3-24788db667b3"]
}, Open  ]],

Cell["Percent change in price of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.8043453732404575`*^9, 3.8043453753471007`*^9}, {3.8048542236899986`*^9, 
  3.8048542237056255`*^9}, {3.8048542552778463`*^9, 
  3.8048542642949595`*^9}},ExpressionUUID->"27f9766d-32e7-416f-a633-\
017ac3931911"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pntu1", "-", "pntu0"}], ")"}], "100"}], "pntu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
   3.8043453249659014`*^9, 3.804345332792992*^9}, {3.8048586198472853`*^9, 
   3.8048586228946285`*^9}, {3.804858751489214*^9, 3.8048587520986824`*^9}, {
   3.805018113403982*^9, 3.8050181134196095`*^9}, 3.80502029645166*^9, {
   3.805022002845399*^9, 3.8050220032048297`*^9}, {3.805640784660994*^9, 
   3.8056407859109573`*^9}},
 CellLabel->
  "In[1834]:=",ExpressionUUID->"748f9f28-5aa8-4afa-850f-690ecd11219f"],

Cell[BoxData["5.329639232499832`"], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.80339445072719*^9, 
   3.8033947923955584`*^9, 3.80339490299594*^9, 3.803397318819847*^9, 
   3.8033974344615884`*^9, 3.803398056846775*^9, 3.803398422345869*^9, 
   3.8033985837222633`*^9, 3.8035096200034256`*^9, 3.803510328844366*^9, 
   3.8035117203584347`*^9, 3.803512179919862*^9, 3.804345496866643*^9, 
   3.8043455350453463`*^9, 3.8043455687255497`*^9, 3.804345977014991*^9, 
   3.804346900550107*^9, 3.804347743876865*^9, {3.804347844696292*^9, 
   3.804347858627165*^9}, 3.8043478906560416`*^9, 3.8043479284965253`*^9, {
   3.804348236021322*^9, 3.804348258041457*^9}, 3.8043489368477774`*^9, 
   3.804349006094705*^9, 3.804349099750577*^9, 3.8045199879432974`*^9, 
   3.8045202905867524`*^9, 3.804520418887697*^9, 3.804520564673563*^9, 
   3.8045210418841867`*^9, 3.804521080401819*^9, 3.8045211594931307`*^9, 
   3.804521392847683*^9, 3.804521470954426*^9, 3.804545808208748*^9, 
   3.804545882712249*^9, 3.804546096576723*^9, 3.804546195440194*^9, 
   3.8045873500470037`*^9, 3.8045904451993933`*^9, 3.8045917105943737`*^9, 
   3.8045918182439528`*^9, 3.8048588477330093`*^9, 3.8048588907551947`*^9, 
   3.8048596674038343`*^9, 3.804859753823053*^9, 3.8048599679531155`*^9, 
   3.804860114996448*^9, 3.8048603843467426`*^9, 3.8048605413487997`*^9, 
   3.804860673297939*^9, 3.8048614927666225`*^9, 3.8048659531235347`*^9, 
   3.8048662768410177`*^9, 3.804866447431389*^9, 3.804867253867225*^9, 
   3.804881194051359*^9, 3.804895272440683*^9, 3.804896151905878*^9, 
   3.804896949456112*^9, 3.8050220365710096`*^9, 3.8050235376791954`*^9, 
   3.8050236904025784`*^9, 3.8050238537980585`*^9, 3.805025228799204*^9, 
   3.8056381049772606`*^9, 3.805638201323462*^9, 3.8056386249957447`*^9, 
   3.8056408934238234`*^9, 3.8056410770704503`*^9, 3.805665838776927*^9, 
   3.807280229463313*^9, 3.807285788894532*^9, 3.807286117091085*^9, 
   3.8072876052725005`*^9, 3.8073064994413476`*^9, 3.807306557310377*^9, 
   3.8073070826881714`*^9, 3.8073082186572027`*^9, 3.8073092361103487`*^9, 
   3.807882965445234*^9, 3.807884111047969*^9, 3.807884918144169*^9, 
   3.8100471334913235`*^9, 3.810047287915167*^9, 3.810047380031656*^9, 
   3.811071115782611*^9, 3.812470617752067*^9, 3.812470942025984*^9, 
   3.8124711925470114`*^9, 3.812471554278398*^9, 3.8127360746618657`*^9, 
   3.812821601157398*^9, 3.8129696455075865`*^9, 3.812970412290386*^9, 
   3.812971128789027*^9, 3.812976173573283*^9, 3.8129765618452234`*^9, 
   3.8139963287183714`*^9, 3.813996928205101*^9, 3.813998576602031*^9, 
   3.8139989643090153`*^9, 3.8139992621758947`*^9, 3.813999720431839*^9, 
   3.814026730240019*^9, 3.8140269217210913`*^9, 3.814027093836088*^9, 
   3.8148303188298326`*^9, 3.815477500989379*^9, 3.8154778062359495`*^9, 
   3.8154778680899277`*^9, 3.8154786208011627`*^9, 3.8157754078976994`*^9, 
   3.817033448185939*^9, 3.817033480202567*^9, 3.8188010795466995`*^9, 
   3.825416621344062*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1834]=",ExpressionUUID->"5a61d8ce-9622-4d5e-93d7-142ca9bf91a0"]
}, Open  ]],

Cell["Percent change in quantity of unprocessed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.7998487765322647`*^9, 
  3.79984878065254*^9}, {3.799848834260734*^9, 3.799848834432638*^9}, {
  3.803394622408345*^9, 3.803394622408345*^9}, {3.8043454610798006`*^9, 
  3.804345463334556*^9}, {3.8048542237681365`*^9, 3.804854223783764*^9}, {
  3.8048542553403563`*^9, 
  3.8048542677330275`*^9}},ExpressionUUID->"58eaa9d5-5768-4a72-a526-\
8c40c186a85a"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qntu1", "-", "qntu0"}], ")"}], "100"}], "qntu0"]], "Input",
 CellChangeTimes->{{3.7998487866910887`*^9, 3.7998487922857533`*^9}, {
  3.803393880385415*^9, 3.8033938845581613`*^9}, {3.8043454494237304`*^9, 
  3.8043454556946144`*^9}, {3.804858624582388*^9, 3.804858627520339*^9}, {
  3.804858800630694*^9, 3.8048588012870445`*^9}, {3.8050174723410645`*^9, 
  3.8050174723410645`*^9}, {3.805021936100234*^9, 3.8050219362096276`*^9}, {
  3.8050220033611035`*^9, 3.8050220037373953`*^9}, {3.805640790263313*^9, 
  3.8056407913951845`*^9}},
 CellLabel->
  "In[1835]:=",ExpressionUUID->"756e82fd-3ce4-48f4-9968-fe09331933d8"],

Cell[BoxData[
 RowBox[{"-", "17.439783962716145`"}]], "Output",
 CellChangeTimes->{
  3.7998487939266443`*^9, 3.799849590864766*^9, 3.7998508739225855`*^9, 
   3.799851091756056*^9, 3.7998552205069666`*^9, 3.799855258718669*^9, 
   3.7998567326065965`*^9, 3.799856777590147*^9, 3.799857194167791*^9, {
   3.7998574099878407`*^9, 3.799857480406985*^9}, 3.7998575212450085`*^9, {
   3.79985762293978*^9, 3.799857664853892*^9}, 3.7998577592905207`*^9, {
   3.8016608491993513`*^9, 3.801660861671548*^9}, 3.8016627629236903`*^9, 
   3.801663465137203*^9, 3.8016642623712516`*^9, {3.801664312072937*^9, 
   3.8016643343546023`*^9}, 3.801664459119495*^9, 3.801665347362949*^9, 
   3.8016653966783905`*^9, 3.8016654282470636`*^9, {3.8016667215647206`*^9, 
   3.8016667503654346`*^9}, 3.801666785226326*^9, {3.801666959028432*^9, 
   3.8016669836278954`*^9}, 3.801667112672204*^9, 3.8016672263405514`*^9, 
   3.801667396303444*^9, 3.8016675826711464`*^9, 3.8016677826625586`*^9, {
   3.801667846772317*^9, 3.8016678623214912`*^9}, 3.801667933090225*^9, {
   3.8016681820991383`*^9, 3.8016682036436005`*^9}, {3.801668267616172*^9, 
   3.8016682946389494`*^9}, {3.8016683442751412`*^9, 3.801668369327756*^9}, 
   3.801668420351198*^9, 3.8016684519994135`*^9, 3.8016684865659137`*^9, 
   3.8016685402564197`*^9, 3.8016925861245337`*^9, 3.801692639888279*^9, 
   3.8016927455969706`*^9, 3.8016929512623425`*^9, 3.801693229125574*^9, 
   3.801693284895647*^9, 3.8016933948337274`*^9, 3.8016934881027822`*^9, 
   3.801776982767399*^9, 3.8017771997758713`*^9, 3.8017772729001703`*^9, 
   3.8017776500514827`*^9, 3.8017780046648273`*^9, 3.8017780734215*^9, 
   3.8017783125532794`*^9, 3.8017783435120974`*^9, 3.8017786540593433`*^9, 
   3.8017791371456037`*^9, 3.8017792475981045`*^9, 3.8017795050582266`*^9, 
   3.8017795485542364`*^9, 3.8017796206792045`*^9, 3.801779708592661*^9, 
   3.801779816163415*^9, 3.8017798528603115`*^9, 3.801779898653818*^9, {
   3.8017799392264585`*^9, 3.801779966590515*^9}, 3.801780254188681*^9, 
   3.801780305491147*^9, 3.8017803433050375`*^9, {3.8017804426731567`*^9, 
   3.8017804712324047`*^9}, 3.801780539340789*^9, 3.801780579184549*^9, 
   3.8017806642846003`*^9, 3.8017811755534*^9, 3.801781215227336*^9, 
   3.801781684860626*^9, {3.801781994963343*^9, 3.8017820333338976`*^9}, 
   3.801782086262114*^9, {3.8017822278438845`*^9, 3.8017822454405394`*^9}, 
   3.803075085501938*^9, 3.8030751526072645`*^9, 3.803075259073305*^9, 
   3.8030754032976446`*^9, 3.803075505324279*^9, 3.8031139633724213`*^9, 
   3.803114083277069*^9, 3.8031141457729597`*^9, 3.8031141909682245`*^9, 
   3.8031142975303793`*^9, 3.803114393498266*^9, 3.8031185690312624`*^9, 
   3.8031186380581365`*^9, 3.803118701930989*^9, {3.803118747224341*^9, 
   3.8031187689252806`*^9}, 3.803118808330036*^9, 3.803120592837772*^9, 
   3.8031206306553044`*^9, 3.803124416101493*^9, 3.803124516785059*^9, 
   3.8031249101660285`*^9, 3.8031249913963633`*^9, 3.80312575891453*^9, 
   3.8031262532318716`*^9, 3.803128482495346*^9, 3.803128668980891*^9, 
   3.803292498650179*^9, 3.8033030734507227`*^9, 3.8033032677998962`*^9, 
   3.8033104032852325`*^9, 3.8033128943414855`*^9, 3.8033132210701838`*^9, 
   3.8033916401250944`*^9, 3.803392057109539*^9, 3.8033921215236015`*^9, 
   3.80339251300156*^9, 3.8033926248718386`*^9, 3.803394461197801*^9, 
   3.8033948011953173`*^9, 3.8033949159631968`*^9, 3.8033973296475105`*^9, 
   3.803397447456073*^9, 3.8033980732887936`*^9, 3.803398439181267*^9, 
   3.803398596104046*^9, 3.803509621097353*^9, 3.8035103299226665`*^9, 
   3.80351172146799*^9, 3.8035121809981613`*^9, 3.804345497102827*^9, 
   3.8043455352865343`*^9, 3.80434556896774*^9, 3.804345977272191*^9, 
   3.804346900793296*^9, 3.804347744125058*^9, {3.804347844947489*^9, 
   3.804347858970395*^9}, 3.804347890901232*^9, 3.8043479287367115`*^9, {
   3.8043482362905335`*^9, 3.804348258291651*^9}, 3.8043489369938912`*^9, 
   3.804349006248826*^9, 3.804349099901693*^9, 3.8045199880839453`*^9, 
   3.8045202907586555`*^9, 3.804520419028346*^9, 3.8045205648298388`*^9, 
   3.8045210420560875`*^9, 3.804521080558093*^9, 3.8045211596650333`*^9, 
   3.8045213930195875`*^9, 3.8045214711263285`*^9, 3.804545808397087*^9, 
   3.804545882931034*^9, 3.8045460968111362`*^9, 3.804546195627725*^9, 
   3.804587350203275*^9, 3.8045904453712997`*^9, 3.8045917107819023`*^9, 
   3.804591818400226*^9, 3.8048588478736553`*^9, 3.8048588909114695`*^9, 
   3.8048596675600967`*^9, 3.804859753963705*^9, 3.804859968109393*^9, 
   3.804860115168353*^9, 3.8048603844873915`*^9, 3.8048605415207024`*^9, 
   3.8048606734385867`*^9, 3.8048614928760147`*^9, 3.804865953232927*^9, 
   3.8048662769660378`*^9, 3.8048664475407825`*^9, 3.804867253961108*^9, 
   3.8048811941607513`*^9, 3.804895272550078*^9, 3.8048961520152717`*^9, 
   3.804896949565504*^9, 3.8050220367429113`*^9, 3.8050235381636443`*^9, 
   3.8050236905744786`*^9, 3.8050238539344997`*^9, 3.8050252289867373`*^9, 
   3.8056381051335363`*^9, 3.8056382014953647`*^9, 3.805638625183276*^9, 
   3.8056408937580805`*^9, 3.8056410772423534`*^9, 3.8056658389800873`*^9, 
   3.807280229618434*^9, 3.8072857891277137`*^9, 3.8072861172872934`*^9, 
   3.80728760546666*^9, 3.8073064995954676`*^9, 3.807306557498523*^9, 
   3.8073070829183507`*^9, 3.807308218845349*^9, 3.8073092362994947`*^9, 
   3.8078829656483927`*^9, 3.807884111251128*^9, 3.807884918331699*^9, 
   3.8100471336904783`*^9, 3.810047288124329*^9, 3.8100473802318296`*^9, 
   3.811071115982769*^9, 3.81247061794722*^9, 3.812470942218148*^9, 
   3.8124711927531714`*^9, 3.8124715544885616`*^9, 3.8127360748810625`*^9, 
   3.812821601364559*^9, 3.8129696457419977`*^9, 3.8129704125404367`*^9, 
   3.812971129041025*^9, 3.8129761738076963`*^9, 3.8129765621421013`*^9, 
   3.8139963289385424`*^9, 3.813996928420267*^9, 3.813998576818199*^9, 
   3.813998964528186*^9, 3.8139992623960657`*^9, 3.813999720657014*^9, 
   3.8140267304691987`*^9, 3.814026921952301*^9, 3.8140270941162972`*^9, 
   3.8148303190820293`*^9, 3.8154775012550488`*^9, 3.8154778064859905`*^9, 
   3.815477868339969*^9, 3.8154786210512037`*^9, 3.815775408211921*^9, 
   3.817033448202594*^9, 3.8170334802145767`*^9, 3.818801079563712*^9, 
   3.8254166215862827`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1835]=",ExpressionUUID->"13eebacd-2621-4a9f-8f32-d55f003f7a61"]
}, Open  ]],

Cell["Percent change in price of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.804345379581396*^9, 3.804345381776102*^9}, {
  3.8048542238306465`*^9, 3.8048542238462744`*^9}, {3.8048542554341216`*^9, 
  3.8048542744563646`*^9}},ExpressionUUID->"f51167a7-0925-470f-aa71-\
0bd2425567b5"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pntp1", "-", "pntp0"}], ")"}], "100"}], "pntp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
   3.8043453363277426`*^9, 3.804345343426265*^9}, {3.804858629645665*^9, 
   3.804858633427496*^9}, {3.804858752504995*^9, 3.804858754192754*^9}, {
   3.8050182855042944`*^9, 3.8050182855042944`*^9}, 3.8050206707402067`*^9, {
   3.805022004034316*^9, 3.805022004518766*^9}, {3.805640795127061*^9, 
   3.8056407962199035`*^9}},
 CellLabel->
  "In[1836]:=",ExpressionUUID->"1be97816-01c7-4c98-ac9b-647deefa1959"],

Cell[BoxData["10.701704018235926`"], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394451664847*^9, 3.803394793053144*^9, 
   3.803394903243591*^9, 3.8033973192105317`*^9, 3.803397434738804*^9, 
   3.8033980581294556`*^9, 3.803398423689625*^9, 3.8033985843773165`*^9, 
   3.803509620097191*^9, 3.8035103289225035`*^9, 3.803511720436573*^9, 
   3.803512179997999*^9, 3.8043454969126787`*^9, 3.804345535094385*^9, 
   3.804345568773588*^9, 3.8043459770630274`*^9, 3.8043469005981436`*^9, 
   3.8043477439259024`*^9, {3.804347844745331*^9, 3.8043478586951966`*^9}, 
   3.8043478907030783`*^9, 3.8043479285445623`*^9, {3.8043482360733624`*^9, 
   3.8043482580914974`*^9}, 3.8043489370969715`*^9, 3.8043490063509035`*^9, 
   3.804349099998769*^9, 3.804519988177709*^9, 3.8045202908524213`*^9, 
   3.80452041913774*^9, 3.8045205649236035`*^9, 3.804521042243617*^9, 
   3.804521080667487*^9, 3.8045211597744265`*^9, 3.8045213931289797`*^9, 
   3.8045214712357225`*^9, 3.8045458085064793`*^9, 3.804545883056052*^9, 
   3.804546096951784*^9, 3.804546195768371*^9, 3.804587350312666*^9, 
   3.804590445480694*^9, 3.8045917108912945`*^9, 3.8045918185096493`*^9, 
   3.8048588480143023`*^9, 3.8048588910677433`*^9, 3.8048596677007504`*^9, 
   3.8048597541199846`*^9, 3.804859968250043*^9, 3.804860115309002*^9, 
   3.8048603846436667`*^9, 3.804860541708233*^9, 3.804860673594861*^9, 
   3.804861492985408*^9, 3.804865953357947*^9, 3.8048662770754304`*^9, 
   3.804866447650175*^9, 3.804867254086011*^9, 3.8048811942701445`*^9, 
   3.8048952726594725`*^9, 3.8048961521246634`*^9, 3.8048969496748967`*^9, 
   3.8050220369148164`*^9, 3.80502354188297*^9, 3.80502369074638*^9, 
   3.8050238541532726`*^9, 3.805025229158642*^9, 3.805638105305439*^9, 
   3.805638201667282*^9, 3.80563862535518*^9, 3.805640894104348*^9, 
   3.8056410774298844`*^9, 3.805665839230131*^9, 3.8072802297805595`*^9, 
   3.8072857893219285`*^9, 3.8072861174883933`*^9, 3.807287605666809*^9, 
   3.807306499754609*^9, 3.807306557685668*^9, 3.8073070831104994`*^9, 
   3.8073082190344954`*^9, 3.8073092364876413`*^9, 3.80788296586718*^9, 
   3.8078841114542866`*^9, 3.8078849185661116`*^9, 3.810047133896638*^9, 
   3.8100472883264866`*^9, 3.8100473804299703`*^9, 3.8110711162960153`*^9, 
   3.81247061815339*^9, 3.8124709424102845`*^9, 3.812471192951354*^9, 
   3.8124715546987267`*^9, 3.8127360750881996`*^9, 3.8128216015707254`*^9, 
   3.812969645976409*^9, 3.812970412775818*^9, 3.81297112927544*^9, 
   3.8129761740733643`*^9, 3.812976562470317*^9, 3.8139963291567116`*^9, 
   3.8139969286344347`*^9, 3.813998577034367*^9, 3.813998964746355*^9, 
   3.813999262612235*^9, 3.813999720877185*^9, 3.8140267307143917`*^9, 
   3.814026922218478*^9, 3.814027094353525*^9, 3.8148303193582444`*^9, 
   3.81547750150509*^9, 3.8154778067516594`*^9, 3.8154778686056385`*^9, 
   3.8154786213012457`*^9, 3.8157754085201626`*^9, 3.8170334482186055`*^9, 
   3.8170334802275867`*^9, 3.8188010795787244`*^9, 3.8254166218444924`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1836]=",ExpressionUUID->"252063ba-417f-4a18-a860-d459dcebae3c"]
}, Open  ]],

Cell["Percent change in quantity of processed imports", "Text",
 CellChangeTimes->{{3.7998001355559998`*^9, 3.7998002007000437`*^9}, {
  3.7998004090311604`*^9, 3.799800431078953*^9}, {3.799800640776052*^9, 
  3.7998006446473494`*^9}, {3.799800862818862*^9, 3.799800870469303*^9}, {
  3.7998012033891764`*^9, 3.799801247248581*^9}, {3.7998017886789412`*^9, 
  3.799801808439082*^9}, {3.799848496881614*^9, 3.799848522730923*^9}, {
  3.799848668948449*^9, 3.799848700818249*^9}, {3.799848815570673*^9, 
  3.799848836667656*^9}, {3.803394622423974*^9, 3.803394622423974*^9}, {
  3.8043454672536063`*^9, 3.8043454691240597`*^9}, {3.804854223893157*^9, 
  3.804854223908785*^9}, {3.8048542555122595`*^9, 
  3.804854280414089*^9}},ExpressionUUID->"8855e30c-c6f6-458b-b3d2-\
920dbf090d93"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"qntp1", "-", "qntp0"}], ")"}], "100"}], "qntp0"]], "Input",
 CellChangeTimes->{{3.799848804083187*^9, 3.7998488090383563`*^9}, {
  3.803393887828924*^9, 3.8033938913609514`*^9}, {3.80434547115364*^9, 
  3.804345478164096*^9}, {3.80485863514651*^9, 3.804858638681849*^9}, {
  3.804858801740239*^9, 3.8048588038343105`*^9}, {3.805017523503875*^9, 
  3.805017523503875*^9}, {3.8050219403353195`*^9, 3.805021940413457*^9}, {
  3.805022004690667*^9, 3.8050220065659575`*^9}, {3.8056408002079763`*^9, 
  3.8056408013198338`*^9}},
 CellLabel->
  "In[1837]:=",ExpressionUUID->"74d2b000-985d-4abd-8bbe-245671d7af2e"],

Cell[BoxData[
 RowBox[{"-", "17.294744274364366`"}]], "Output",
 CellChangeTimes->{
  3.7998488111011906`*^9, 3.799849590958533*^9, 3.7998508740319767`*^9, 
   3.799851091881076*^9, 3.7998552206163597`*^9, 3.7998552587968082`*^9, 
   3.7998567326847353`*^9, 3.7998567776839123`*^9, 3.799857194292813*^9, {
   3.799857410097232*^9, 3.7998574804538665`*^9}, 3.7998575213387737`*^9, {
   3.7998576230179186`*^9, 3.799857664916416*^9}, 3.7998577593999133`*^9, {
   3.8016608494025064`*^9, 3.801660862202876*^9}, 3.801662763033085*^9, 
   3.8016634656060314`*^9, 3.801664262496271*^9, {3.8016643121823297`*^9, 
   3.801664334448367*^9}, 3.8016644592445154`*^9, 3.80166534880068*^9, 
   3.801665396756527*^9, 3.801665428356456*^9, {3.8016667224242334`*^9, 
   3.8016667504748273`*^9}, 3.801666785335719*^9, {3.8016669592159624`*^9, 
   3.8016669837372875`*^9}, 3.801667112797224*^9, 3.8016672264811983`*^9, 
   3.801667396412835*^9, 3.801667583468155*^9, {3.801667846897336*^9, 
   3.8016678624621377`*^9}, 3.8016679332152433`*^9, {3.8016681825054493`*^9, 
   3.8016682037530117`*^9}, {3.8016682680850134`*^9, 3.801668295123399*^9}, {
   3.801668344712716*^9, 3.801668369437148*^9}, 3.80166842049185*^9, 
   3.80166845215569*^9, 3.801668486675353*^9, 3.801668540725275*^9, 
   3.8016925862964363`*^9, 3.8016926404352417`*^9, 3.8016927457532463`*^9, 
   3.801692951481129*^9, 3.8016932292193394`*^9, 3.801693285380097*^9, 
   3.801693396115184*^9, 3.8016934883059397`*^9, 3.801776982944538*^9, 
   3.801777199916519*^9, 3.80177727305429*^9, 3.801777650567194*^9, 
   3.801778004838135*^9, 3.801778073562149*^9, 3.801778312709554*^9, 
   3.8017783436181793`*^9, 3.801778654215618*^9, 3.80177913730188*^9, 
   3.8017792477387524`*^9, 3.801779505198858*^9, 3.801779548648001*^9, 
   3.801779620788596*^9, 3.8017797089497743`*^9, 3.801779816304063*^9, 
   3.8017798530009584`*^9, 3.8017798987632113`*^9, {3.8017799396640296`*^9, 
   3.801779966715536*^9}, 3.801780254360585*^9, 3.801780306335049*^9, 
   3.801780343430032*^9, {3.801780443173243*^9, 3.801780471685609*^9}, 
   3.801780539465816*^9, 3.8017805793251967`*^9, 3.8017806647690535`*^9, 
   3.801781175694023*^9, 3.801781215321102*^9, 3.801781684970019*^9, {
   3.801781995447799*^9, 3.8017820334745474`*^9}, 3.801782086715315*^9, {
   3.8017822279689045`*^9, 3.801782245596816*^9}, 3.803075085634988*^9, 
   3.80307515274037*^9, 3.8030752590873156`*^9, 3.8030754033096533`*^9, 
   3.8030755053362875`*^9, 3.8031139635075283`*^9, 3.803114083414178*^9, 
   3.803114145934085*^9, 3.803114190980234*^9, 3.803114297541388*^9, 
   3.803114393510276*^9, 3.803118569058283*^9, 3.803118638068144*^9, 
   3.803118701942999*^9, {3.8031187472363796`*^9, 3.80311876893629*^9}, 
   3.8031188083420453`*^9, 3.8031205928637924`*^9, 3.8031206306683135`*^9, 
   3.8031244164897966`*^9, 3.8031245167970686`*^9, 3.8031249101770926`*^9, 
   3.8031249914063716`*^9, 3.8031257589295416`*^9, 3.80312625324288*^9, 
   3.8031284825223675`*^9, 3.8031286689919004`*^9, 3.8032924986651897`*^9, 
   3.80330307441963*^9, 3.8033032687062936`*^9, 3.8033104035352726`*^9, 
   3.803312894575898*^9, 3.8033132223516307`*^9, 3.8033916406408234`*^9, 
   3.8033920576852856`*^9, 3.8033921217707224`*^9, 3.803392513213996*^9, 
   3.803392625465459*^9, 3.803394461807275*^9, 3.803394802476775*^9, 
   3.803394916541416*^9, 3.803397330526899*^9, 3.8033974481266856`*^9, 
   3.8033980741972427`*^9, 3.8033984397907405`*^9, 3.8033985966978917`*^9, 
   3.803509621175491*^9, 3.803510330000804*^9, 3.803511721561755*^9, 
   3.803512181076299*^9, 3.8043454971498632`*^9, 3.80434553533257*^9, 
   3.804345569016777*^9, 3.8043459773222294`*^9, 3.8043469008413334`*^9, 
   3.804347744173094*^9, {3.8043478449965277`*^9, 3.804347859021435*^9}, 
   3.8043478909482684`*^9, 3.804347928784749*^9, {3.8043482363425736`*^9, 
   3.8043482583406906`*^9}, 3.804348937303131*^9, 3.8043490064970183`*^9, 
   3.804349100143882*^9, 3.8045199883339844`*^9, 3.8045202910086966`*^9, 
   3.8045204192783885`*^9, 3.804520565064252*^9, 3.8045210423998923`*^9, 
   3.80452108083939*^9, 3.8045211599932103`*^9, 3.804521393363391*^9, 
   3.8045214713919973`*^9, 3.8045458087096357`*^9, 3.804545883243582*^9, 
   3.8045460971549435`*^9, 3.8045461960027847`*^9, 3.8045873505001917`*^9, 
   3.804590445668228*^9, 3.8045917110475683`*^9, 3.8045918186815205`*^9, 
   3.804858848154949*^9, 3.804858891192762*^9, 3.8048596678726606`*^9, 
   3.804859754260637*^9, 3.80485996839496*^9, 3.804860115465279*^9, 
   3.804860384799943*^9, 3.80486054184888*^9, 3.80486067373553*^9, 
   3.80486149309489*^9, 3.804865953482967*^9, 3.804866277169195*^9, 
   3.804866447759568*^9, 3.804867254195405*^9, 3.8048811943795366`*^9, 
   3.804895272768914*^9, 3.8048961522340565`*^9, 3.8048969497842894`*^9, 
   3.8050220371335964`*^9, 3.8050235423517923`*^9, 3.805023690980791*^9, 
   3.8050238543227386`*^9, 3.805025229393057*^9, 3.8056381055242243`*^9, 
   3.8056382018079295`*^9, 3.8056386255270844`*^9, 3.8056408944856415`*^9, 
   3.8056410777111793`*^9, 3.8056658394332914`*^9, 3.8072802300427628`*^9, 
   3.8072857895120144`*^9, 3.807286117683545*^9, 3.8072876058569975`*^9, 
   3.8073064999467406`*^9, 3.8073065578738146`*^9, 3.8073070832996464`*^9, 
   3.807308219266676*^9, 3.807309236673787*^9, 3.8078829661328487`*^9, 
   3.807884111751211*^9, 3.80788491876927*^9, 3.8100471341007967`*^9, 
   3.8100472885236387`*^9, 3.8100473806281185`*^9, 3.8110711165021777`*^9, 
   3.812470618349533*^9, 3.812470942605448*^9, 3.81247119314948*^9, 
   3.8124715549078903`*^9, 3.812736075294365*^9, 3.8128216017748775`*^9, 
   3.812969646226448*^9, 3.8129704130102215`*^9, 3.8129711295098543`*^9, 
   3.8129761743234053`*^9, 3.8129765627672167`*^9, 3.8139963293738813`*^9, 
   3.813996928810571*^9, 3.8139985772885647`*^9, 3.8139989649655256`*^9, 
   3.813999262875441*^9, 3.813999721142391*^9, 3.8140267309495754`*^9, 
   3.8140269224036217`*^9, 3.8140270945866632`*^9, 3.814830319668513*^9, 
   3.815477501770759*^9, 3.815477807001701*^9, 3.81547786885568*^9, 
   3.81547862153566*^9, 3.815775408789365*^9, 3.817033448234618*^9, 
   3.8170334802395964`*^9, 3.818801079594737*^9, 3.825416622102662*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1837]=",ExpressionUUID->"f52ae4cd-f873-4c4b-9dcb-03c4a6397cd2"]
}, Open  ]],

Cell[TextData[StyleBox["Price index",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8154791589057446`*^9, 3.815479163250188*^9}, 
   3.825288031333954*^9},ExpressionUUID->"157379bd-193a-4699-a443-\
a2fe967aacb4"],

Cell["\<\
Unprocessed products - yellowfin, skipjack, albacore, bonito, NEI nest\
\>", "Text",
 CellChangeTimes->{{3.8154792142270765`*^9, 3.8154792413407803`*^9}, {
  3.825288055892071*^9, 
  3.8252880720275927`*^9}},ExpressionUUID->"65b57b8f-bd6e-41f0-be18-\
fe78cf11b17e"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{"100", 
   RowBox[{"(", 
    RowBox[{"P1u1", "-", "P1u0"}], ")"}]}], "P1u0"]], "Input",
 CellChangeTimes->{{3.815479168516654*^9, 3.815479210804655*^9}, {
  3.815479248091858*^9, 3.815479251264239*^9}},
 CellLabel->
  "In[1838]:=",ExpressionUUID->"fe899fe6-10eb-42a1-b58b-f24433330ac5"],

Cell[BoxData["4.972349408433899`"], "Output",
 CellChangeTimes->{3.8154792609064035`*^9, 3.815775409117629*^9, 
  3.81703344824963*^9, 3.8170334802521467`*^9, 3.818801079607747*^9, 
  3.825416622430932*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1838]=",ExpressionUUID->"a951d4fa-8a50-471d-abad-02f3ac824bf1"]
}, Open  ]],

Cell["Unprocessed products - bigeye, bluefin nest", "Text",
 CellChangeTimes->{{3.8154792142270765`*^9, 3.8154792442318664`*^9}, {
  3.8252880772536745`*^9, 
  3.8252880858963804`*^9}},ExpressionUUID->"20694b68-a4e5-4dda-9d30-\
c0b59281e996"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{"100", 
   RowBox[{"(", 
    RowBox[{"P2u1", "-", "P2u0"}], ")"}]}], "P2u0"]], "Input",
 CellChangeTimes->{{3.815479168516654*^9, 3.8154792577809043`*^9}},
 CellLabel->
  "In[1839]:=",ExpressionUUID->"55d2d145-a49a-41b8-844e-ef16273d11d5"],

Cell[BoxData["12.54951716014966`"], "Output",
 CellChangeTimes->{3.8154792612814636`*^9, 3.815775409398842*^9, 
  3.817033448264642*^9, 3.8170334802647943`*^9, 3.8188010796237593`*^9, 
  3.8254166227992153`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1839]=",ExpressionUUID->"8b5e8d9c-c2d1-4858-a053-f3e3c3a83760"]
}, Open  ]],

Cell["Canning price index", "Text",
 CellChangeTimes->{{3.8154792142270765`*^9, 3.8154792204468193`*^9}, 
   3.8252880930639505`*^9},ExpressionUUID->"7c3c83c0-2a97-48d5-b489-\
edd3d825d4b2"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{"100", 
   RowBox[{"(", 
    RowBox[{"P1p1", "-", "P1p0"}], ")"}]}], "P1p0"]], "Input",
 CellChangeTimes->{{3.815479168516654*^9, 3.815479210804655*^9}},
 CellLabel->
  "In[1840]:=",ExpressionUUID->"59d9d4ce-6349-490d-97df-44ca5dbf843e"],

Cell[BoxData["5.924887976627938`"], "Output",
 CellChangeTimes->{3.8154792615471306`*^9, 3.81577540967408*^9, 
  3.817033448278652*^9, 3.8170334802778044`*^9, 3.8188010796477785`*^9, 
  3.8254166230463986`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1840]=",ExpressionUUID->"04f8fc96-686f-4fd8-b697-f830199adc24"]
}, Open  ]],

Cell["Bigeye-bluefin processed products price index", "Text",
 CellChangeTimes->{{3.8154792142270765`*^9, 3.815479228182429*^9}, {
  3.8252880960553155`*^9, 
  3.8252881018338037`*^9}},ExpressionUUID->"604ae140-3207-416c-be2b-\
36c603a86805"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{"100", 
   RowBox[{"(", 
    RowBox[{"P2p1", "-", "P2p0"}], ")"}]}], "P2p0"]], "Input",
 CellChangeTimes->{{3.815479168516654*^9, 3.815479234245897*^9}},
 CellLabel->
  "In[1841]:=",ExpressionUUID->"72bbc640-5df5-4f09-9e19-2adf7b86f64d"],

Cell[BoxData["13.900707322687328`"], "Output",
 CellChangeTimes->{3.815479261812798*^9, 3.815775409945299*^9, 
  3.817033448292718*^9, 3.8170334802908154`*^9, 3.8188010796627903`*^9, 
  3.8254166232925997`*^9},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "Out[1841]=",ExpressionUUID->"c13c5779-f1d0-46b3-8654-e1a5bf0291e8"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{880, 888},
WindowMargins->{{-3, Automatic}, {32, Automatic}},
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 1676, 31, 196, "Title",ExpressionUUID->"2abf6fd9-002f-4185-871b-88add9eaf8e9"],
Cell[2259, 55, 4794, 70, 334, "Text",ExpressionUUID->"d7c26f78-d972-4d0f-9a31-d7e886f36279"],
Cell[7056, 127, 231, 5, 28, "Input",ExpressionUUID->"0c777ea8-191a-4659-be18-f91ea0d0ffda"],
Cell[CellGroupData[{
Cell[7312, 136, 404, 7, 62, "Section",ExpressionUUID->"517e06c5-2c61-4dfb-8aa4-4255270c5ce4"],
Cell[CellGroupData[{
Cell[7741, 147, 422, 7, 43, "Subsubsection",ExpressionUUID->"03237029-5661-4427-a540-f97f18ade571"],
Cell[8166, 156, 524, 7, 30, "Text",ExpressionUUID->"3f36d597-7089-46be-8bb4-f60d80facfed"],
Cell[8693, 165, 1026, 17, 34, "Text",ExpressionUUID->"f278dafb-b0a3-47f2-b42a-c6740bad2fe6"],
Cell[9722, 184, 1784, 26, 44, "Input",ExpressionUUID->"0d44e1c6-e9d4-484e-888a-97e11d7e3438"],
Cell[11509, 212, 1026, 17, 34, "Text",ExpressionUUID->"305da441-e4b2-4c88-a30a-0f4485fe70b0"],
Cell[12538, 231, 1760, 26, 44, "Input",ExpressionUUID->"68e3b805-5eb8-437a-a7f8-432c5dc38fa6"],
Cell[14301, 259, 1076, 18, 34, "Text",ExpressionUUID->"cd852049-49e8-4d96-85f5-0073c5261f5a"],
Cell[15380, 279, 1738, 26, 44, "Input",ExpressionUUID->"8ce1a048-b83e-4f20-84d6-e5ec15b6f8ef"],
Cell[17121, 307, 1074, 18, 34, "Text",ExpressionUUID->"068bf186-8ce7-4a16-8c9b-ab0065f645fe"],
Cell[18198, 327, 1723, 26, 44, "Input",ExpressionUUID->"055efbdb-f3e0-4860-881d-c7aa622d1cfb"],
Cell[19924, 355, 1076, 18, 34, "Text",ExpressionUUID->"99d6af54-25a6-4f2f-9804-c57eac0a6168"],
Cell[21003, 375, 1825, 27, 44, "Input",ExpressionUUID->"736de165-bccb-4534-80f2-371fc7549bff"],
Cell[22831, 404, 1088, 18, 34, "Text",ExpressionUUID->"a4660fac-a3ed-4d1d-9dcb-7d8476dde418"],
Cell[23922, 424, 1758, 26, 44, "Input",ExpressionUUID->"5fa0e8dd-4806-45d0-b98b-4ec2bc340d09"],
Cell[25683, 452, 1076, 18, 34, "Text",ExpressionUUID->"41262d7e-860c-4b62-9eb7-6e2dec4210a3"],
Cell[26762, 472, 1834, 27, 44, "Input",ExpressionUUID->"a4d05cc6-db6e-481b-a738-0d8a052a4bd8"],
Cell[28599, 501, 1074, 18, 34, "Text",ExpressionUUID->"4ea1a8bf-4a19-43ca-a0e3-ec4ba042a21b"],
Cell[29676, 521, 1601, 24, 44, "Input",ExpressionUUID->"c017ae61-50e3-4e2b-95bf-5feaa1a06257"],
Cell[31280, 547, 1074, 18, 34, "Text",ExpressionUUID->"21ff44cf-7e4a-471f-a380-85b4996c402f"],
Cell[32357, 567, 1601, 24, 44, "Input",ExpressionUUID->"533415a2-f3ea-4ef5-85ba-7748e917b5c2"],
Cell[33961, 593, 1120, 18, 34, "Text",ExpressionUUID->"1081b860-73e1-40b0-8e00-de2e82acab7d"],
Cell[35084, 613, 1583, 24, 44, "Input",ExpressionUUID->"a8f7002f-56e2-4375-9543-6dc993f93f6b"],
Cell[36670, 639, 1120, 18, 34, "Text",ExpressionUUID->"c3fdf390-356d-4cc6-8d85-6440cd02d47e"],
Cell[37793, 659, 1575, 24, 44, "Input",ExpressionUUID->"8dd6a94f-4fc4-4e80-ab90-562d9f76b879"],
Cell[39371, 685, 1118, 18, 34, "Text",ExpressionUUID->"41003bd7-61eb-44f3-877d-50672c5544bc"],
Cell[40492, 705, 1597, 24, 44, "Input",ExpressionUUID->"57daa648-c088-4e52-bcaf-7fd6e60f3c95"],
Cell[42092, 731, 1132, 18, 34, "Text",ExpressionUUID->"3e4064cc-9d82-48ab-8bf9-7623327d68d5"],
Cell[43227, 751, 1572, 24, 44, "Input",ExpressionUUID->"5450ec01-cd65-490d-ae15-228cbfd00b31"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44836, 780, 400, 7, 43, "Subsubsection",ExpressionUUID->"3531cf0e-4bdb-47e5-a3b9-150e2b2fb400"],
Cell[45239, 789, 554, 8, 30, "Text",ExpressionUUID->"f243d91d-e511-408d-bee1-61c634cee729"],
Cell[45796, 799, 1172, 21, 33, "Text",ExpressionUUID->"3fc7ed24-77c5-455b-8ca4-f0c589a68f88"],
Cell[46971, 822, 1643, 25, 44, "Input",ExpressionUUID->"4fd17059-e35b-4fb4-a35c-25e07440d9a4"],
Cell[48617, 849, 1223, 21, 33, "Text",ExpressionUUID->"56f7e9fc-6e92-4f88-a28d-81abff6d4228"],
Cell[49843, 872, 1594, 24, 44, "Input",ExpressionUUID->"db89f93a-949b-46ca-894d-70d3b9066f1e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51474, 901, 494, 7, 43, "Subsubsection",ExpressionUUID->"4a3c1059-a976-4ef7-99b8-2bf766b2ed1f"],
Cell[51971, 910, 510, 7, 30, "Text",ExpressionUUID->"597e6432-cce0-4c12-a0ae-e809c370a5e3"],
Cell[52484, 919, 949, 15, 34, "Text",ExpressionUUID->"082b57cb-ebe3-4204-9d92-61c87951f3dc"],
Cell[53436, 936, 1088, 18, 44, "Input",ExpressionUUID->"ef0cd2cc-52e7-4867-9480-1d37f54c21bb"],
Cell[54527, 956, 815, 13, 34, "Text",ExpressionUUID->"5504e614-8769-4076-8e8b-fce7daf050a8"],
Cell[55345, 971, 1087, 18, 44, "Input",ExpressionUUID->"7cf74d41-9cc5-4d57-8fe6-2b581b7d2fab"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56469, 994, 541, 8, 43, "Subsubsection",ExpressionUUID->"20964efa-eaca-4fe6-a533-46d0e1979dda"],
Cell[57013, 1004, 823, 11, 30, "Text",ExpressionUUID->"77231342-2d17-438f-bc05-f5b32cebff9d"],
Cell[57839, 1017, 1197, 20, 34, "Text",ExpressionUUID->"c1cdbe04-4f74-42c7-a18c-3f5f31a57dd5"],
Cell[59039, 1039, 3269, 48, 44, "Input",ExpressionUUID->"e71883ba-93a1-4219-bd68-67879f88fe63"],
Cell[62311, 1089, 1195, 20, 34, "Text",ExpressionUUID->"60932962-a7e4-4584-a2ea-aab5ab59a767"],
Cell[63509, 1111, 3288, 47, 44, "Input",ExpressionUUID->"3570a921-8175-4c5b-ac71-ad5fa82485de"],
Cell[66800, 1160, 1249, 21, 34, "Text",ExpressionUUID->"bb2b7b0d-5f40-49bc-9c52-bd9acea698b1"],
Cell[68052, 1183, 3297, 47, 44, "Input",ExpressionUUID->"8084d100-1196-49fa-a6db-fe6657cbfd2a"],
Cell[71352, 1232, 1245, 21, 34, "Text",ExpressionUUID->"97fd0de6-9d1f-4bff-b3cc-094d217cb0e6"],
Cell[72600, 1255, 3343, 48, 44, "Input",ExpressionUUID->"c1974cde-0bee-4337-89d4-4d8be79bede4"],
Cell[75946, 1305, 1242, 21, 34, "Text",ExpressionUUID->"d3130cb4-ccc7-411c-95d4-c4e0d7d022cc"],
Cell[77191, 1328, 3204, 46, 44, "Input",ExpressionUUID->"8416828b-6e0d-4043-b421-691ce31c4cb1"],
Cell[80398, 1376, 1257, 21, 34, "Text",ExpressionUUID->"18f9d4cc-f423-4f9b-bfde-cb646d233bfe"],
Cell[81658, 1399, 3224, 47, 44, "Input",ExpressionUUID->"917179e3-d8df-4f69-a8d3-384801ef2ab8"],
Cell[84885, 1448, 1243, 21, 34, "Text",ExpressionUUID->"4edb0494-743d-45cb-be98-609276a5f31e"],
Cell[86131, 1471, 3174, 45, 44, "Input",ExpressionUUID->"9cb39eff-cb75-4584-a370-05a9a0eb76bd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[89342, 1521, 588, 9, 43, "Subsubsection",ExpressionUUID->"247b77ac-4517-4ce7-b8fd-80480d652892"],
Cell[89933, 1532, 554, 8, 30, "Text",ExpressionUUID->"cb882b65-e83f-4d39-9f9f-3a71b35a4671"],
Cell[90490, 1542, 998, 15, 34, "Text",ExpressionUUID->"946e3f97-19ba-4835-9754-6a3bc7578743"],
Cell[91491, 1559, 2214, 32, 44, "Input",ExpressionUUID->"0e61cea0-3282-45a7-bd8e-9e8e785d69eb"],
Cell[93708, 1593, 1047, 15, 34, "Text",ExpressionUUID->"6a761702-15e0-4505-997b-cda1d7a880f8"],
Cell[94758, 1610, 2286, 33, 44, "Input",ExpressionUUID->"daaf0596-c33a-4587-81b3-e028c2d51607"],
Cell[97047, 1645, 1047, 15, 34, "Text",ExpressionUUID->"41e025eb-3bca-41ea-bf88-d4109d5be917"],
Cell[98097, 1662, 2266, 33, 44, "Input",ExpressionUUID->"61c0c99e-cd47-4677-a666-19e1cd12c8f5"],
Cell[100366, 1697, 1043, 15, 34, "Text",ExpressionUUID->"8fda4d45-d175-4b46-918a-e2f53c2bb0c7"],
Cell[101412, 1714, 2437, 36, 44, "Input",ExpressionUUID->"c77200e6-564e-48a4-9d46-75e553d26040"],
Cell[103852, 1752, 1044, 15, 34, "Text",ExpressionUUID->"0594a634-5a80-47a5-b3c3-a9af9333c6c8"],
Cell[104899, 1769, 2409, 36, 44, "Input",ExpressionUUID->"91ca236f-1de5-4270-b969-bd269e28ac56"],
Cell[107311, 1807, 1050, 15, 34, "Text",ExpressionUUID->"3ce5464a-aa90-48d7-8b09-71e943c24616"],
Cell[108364, 1824, 2322, 34, 44, "Input",ExpressionUUID->"3e57279e-e33a-4cae-870a-123d34efdc5f"],
Cell[110689, 1860, 1040, 15, 34, "Text",ExpressionUUID->"4d3bfae3-c892-471b-9ae9-9b61e1a1558f"],
Cell[111732, 1877, 2372, 34, 44, "Input",ExpressionUUID->"964c7e7e-ddcb-4310-9a59-ed47f40d7af9"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[114153, 1917, 445, 7, 62, "Section",ExpressionUUID->"6c4dde34-c4f1-4c62-93c5-887546d1f4ff"],
Cell[CellGroupData[{
Cell[114623, 1928, 392, 6, 43, "Subsubsection",ExpressionUUID->"7ed18dcf-dd31-41da-8f64-8738eabac76d"],
Cell[115018, 1936, 745, 11, 66, "Text",ExpressionUUID->"28d290be-5290-456a-a5b7-2cc9f92874b9"],
Cell[115766, 1949, 201, 4, 34, "Text",ExpressionUUID->"dc721d55-ea86-4677-9331-9b4436aa4166"],
Cell[115970, 1955, 1262, 21, 44, "Input",ExpressionUUID->"400c8e39-93cb-4fef-a9fb-41930d195d3f"],
Cell[117235, 1978, 1803, 29, 47, "Input",ExpressionUUID->"cfe43c25-be78-4227-bac0-674e47880d70"],
Cell[119041, 2009, 299, 5, 34, "Text",ExpressionUUID->"0c142a9d-c94f-42aa-ba3b-c88cdc29bab3"],
Cell[119343, 2016, 1233, 21, 44, "Input",ExpressionUUID->"4ecde827-d0a5-44ad-8f2a-1ab84264d7b8"],
Cell[120579, 2039, 1806, 29, 47, "Input",ExpressionUUID->"fc8eb168-ab40-4abf-a2f7-a6c4a5fe0448"],
Cell[122388, 2070, 253, 5, 34, "Text",ExpressionUUID->"ea2bcdfb-c99f-4c31-8987-54cb12f71abf"],
Cell[122644, 2077, 1209, 20, 44, "Input",ExpressionUUID->"6682d775-94cf-4a53-8c9a-592c4584bd42"],
Cell[123856, 2099, 1807, 29, 47, "Input",ExpressionUUID->"5c93ef97-317b-45bc-930c-7ed4a5083bcf"],
Cell[125666, 2130, 249, 5, 34, "Text",ExpressionUUID->"0112fdff-5a16-4d00-b5e1-58d3d225a468"],
Cell[125918, 2137, 1276, 21, 44, "Input",ExpressionUUID->"aba9680d-c0d7-4bcf-aed7-0787606061b0"],
Cell[127197, 2160, 1846, 30, 47, "Input",ExpressionUUID->"a81323c0-f581-4d29-94ee-cd5c44c14b81"],
Cell[129046, 2192, 248, 5, 34, "Text",ExpressionUUID->"e6e92c8c-da3d-4093-8cb2-2878fa5aa703"],
Cell[129297, 2199, 1147, 19, 44, "Input",ExpressionUUID->"1f90fa36-e1a2-4518-ba97-444f0e6e14ef"],
Cell[130447, 2220, 1868, 30, 47, "Input",ExpressionUUID->"39683c2b-cd55-4bab-afc2-f50ad5743fba"],
Cell[132318, 2252, 254, 5, 34, "Text",ExpressionUUID->"db516c3a-2383-4a18-b0ae-cdf3bfcdf90d"],
Cell[132575, 2259, 1203, 20, 44, "Input",ExpressionUUID->"c3fb319a-7734-4450-9427-c60dc29e2cdb"],
Cell[133781, 2281, 1942, 31, 47, "Input",ExpressionUUID->"977552a6-aaf5-4f0f-b57e-a052f10a9db2"],
Cell[135726, 2314, 241, 5, 34, "Text",ExpressionUUID->"f7f4d95d-36f3-45ef-94ff-c9078a0590fc"],
Cell[135970, 2321, 1319, 22, 44, "Input",ExpressionUUID->"b1879f2c-a15e-4873-afdc-0b80bdeb3b6c"],
Cell[137292, 2345, 2018, 32, 47, "Input",ExpressionUUID->"d203fae2-8213-4deb-b593-2dcc4473e4c1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[139347, 2382, 459, 8, 43, "Subsubsection",ExpressionUUID->"e09c3dc8-b140-4b90-bf99-ef3e06a1c9c4"],
Cell[139809, 2392, 1083, 15, 138, "Text",ExpressionUUID->"a63ef450-5c34-4c49-ae25-47beaa37a7c8"],
Cell[140895, 2409, 915, 14, 34, "Text",ExpressionUUID->"48711c42-2516-4e45-b84b-93f4c0b85e8b"],
Cell[141813, 2425, 1279, 21, 44, "Input",ExpressionUUID->"24e0d001-9c3c-4664-b4e5-84955a14c169"],
Cell[143095, 2448, 1377, 24, 47, "Input",ExpressionUUID->"f518a895-fc64-4c1b-8016-df1a33c9f6f1"],
Cell[144475, 2474, 966, 15, 34, "Text",ExpressionUUID->"d9dbbeaf-c762-4a09-a777-925a2ade2183"],
Cell[145444, 2491, 1307, 21, 44, "Input",ExpressionUUID->"6561412e-06fd-4c57-ae93-47270a6df98e"],
Cell[146754, 2514, 1343, 23, 47, "Input",ExpressionUUID->"09c8ff30-42fd-4efc-951c-d2cfbedd4dcc"],
Cell[148100, 2539, 966, 15, 34, "Text",ExpressionUUID->"b1963b6b-e39f-4658-9673-3eccc76f66c3"],
Cell[149069, 2556, 1223, 20, 44, "Input",ExpressionUUID->"abd93098-806c-4525-be8c-4d88e9e76f05"],
Cell[150295, 2578, 1300, 23, 47, "Input",ExpressionUUID->"c11b0971-44f2-457e-a56f-d2e8e07d9df7"],
Cell[151598, 2603, 964, 15, 34, "Text",ExpressionUUID->"c8c70d6c-84d7-4491-a4ad-3b7e6cff5294"],
Cell[152565, 2620, 1282, 21, 44, "Input",ExpressionUUID->"99c6e44e-061a-4ff5-961c-12a04ff14f1d"],
Cell[153850, 2643, 1373, 24, 47, "Input",ExpressionUUID->"b2da8702-0316-46b8-9356-5aa032c6c832"],
Cell[155226, 2669, 965, 15, 34, "Text",ExpressionUUID->"d49fdc00-6dd6-4870-a223-211f32fdc395"],
Cell[156194, 2686, 1310, 21, 44, "Input",ExpressionUUID->"afc8f065-ee22-4e37-948b-934b709956c4"],
Cell[157507, 2709, 1375, 24, 47, "Input",ExpressionUUID->"bffbf241-e5a3-4e32-be55-4013deb3732d"],
Cell[158885, 2735, 970, 15, 34, "Text",ExpressionUUID->"a91c91e4-620c-485b-a666-91eb8e1a799d"],
Cell[159858, 2752, 1371, 22, 44, "Input",ExpressionUUID->"e1ddfe9a-548c-4dc9-bd0f-2b29fc1ca0ae"],
Cell[161232, 2776, 1341, 23, 47, "Input",ExpressionUUID->"ecb360a1-d972-4160-8e9f-525353ea954d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[162610, 2804, 463, 7, 43, "Subsubsection",ExpressionUUID->"24bc1583-a9ae-4346-bc8b-b41eef6a8229"],
Cell[163076, 2813, 543, 8, 30, "Text",ExpressionUUID->"823d90d3-c0ab-4612-a986-7fb16fe609fc"],
Cell[163622, 2823, 823, 12, 34, "Text",ExpressionUUID->"0bf8ee30-2366-4a46-937b-dcce0f4b07bd"],
Cell[164448, 2837, 322, 5, 34, "Text",ExpressionUUID->"4833965b-09d4-4d61-ba29-576776789caf"],
Cell[164773, 2844, 1624, 30, 44, "Input",ExpressionUUID->"ae10a51e-203c-49fc-b34c-3bab85f2f593"],
Cell[166400, 2876, 1568, 26, 47, "Input",ExpressionUUID->"bbe25b2d-bbf5-45c8-98c1-b268a76c3c79"],
Cell[167971, 2904, 167, 3, 34, "Text",ExpressionUUID->"1e6fa944-248c-42ea-9f68-d8c262e947b5"],
Cell[168141, 2909, 1622, 30, 44, "Input",ExpressionUUID->"9485f714-e9cc-42a5-989a-eec3da2d3d9d"],
Cell[169766, 2941, 1680, 27, 47, "Input",ExpressionUUID->"780be44e-d362-41c6-bc75-eb26841e8c10"],
Cell[171449, 2970, 159, 3, 34, "Text",ExpressionUUID->"b810cbd4-8a2b-4e92-b4f6-2f8f241d689b"],
Cell[171611, 2975, 1610, 26, 44, "Input",ExpressionUUID->"ef17bc6d-a4c5-40a9-85a0-e1e90d4683ba"],
Cell[173224, 3003, 1640, 27, 44, "Input",ExpressionUUID->"5869e936-4b85-417d-9535-9acd134d3627"],
Cell[174867, 3032, 876, 13, 34, "Text",ExpressionUUID->"2a63f4da-eb85-4c6b-a533-22b5c1dddd8b"],
Cell[175746, 3047, 322, 5, 34, "Text",ExpressionUUID->"5ebdd3af-807f-46ba-907f-369f547773cd"],
Cell[176071, 3054, 1544, 29, 44, "Input",ExpressionUUID->"4f31d8a3-142a-4e41-9984-1a88a6f968f4"],
Cell[177618, 3085, 1558, 26, 47, "Input",ExpressionUUID->"3ff847f8-e519-4d22-a466-267ec672c9ff"],
Cell[179179, 3113, 167, 3, 34, "Text",ExpressionUUID->"3c70026f-6cbc-4bb3-8069-6d167beb218b"],
Cell[179349, 3118, 1612, 30, 44, "Input",ExpressionUUID->"29350a81-3a4a-4b4b-a909-8f3dc67795fb"],
Cell[180964, 3150, 1659, 27, 47, "Input",ExpressionUUID->"6af3a0db-6bd1-4bd8-b13c-06058f2aad81"],
Cell[182626, 3179, 157, 3, 34, "Text",ExpressionUUID->"a56c7ed1-8d22-43ab-b414-6e87c5d3693c"],
Cell[182786, 3184, 1534, 25, 44, "Input",ExpressionUUID->"49bbfc31-81e6-46c1-a11b-7bf50613d980"],
Cell[184323, 3211, 1645, 27, 44, "Input",ExpressionUUID->"21327809-8401-4b20-ae5b-310e4df12604"],
Cell[185971, 3240, 876, 13, 34, "Text",ExpressionUUID->"57d9ff1a-ea87-44cc-a887-0d6d017211d4"],
Cell[186850, 3255, 322, 5, 34, "Text",ExpressionUUID->"ddc87626-191a-4861-8414-1a700a9cabd5"],
Cell[187175, 3262, 1511, 28, 44, "Input",ExpressionUUID->"8ccfd944-c19b-49ca-bd97-ae7982c4c14d"],
Cell[188689, 3292, 1541, 25, 47, "Input",ExpressionUUID->"8b465579-3011-4468-9c89-a2f6795256be"],
Cell[190233, 3319, 169, 3, 34, "Text",ExpressionUUID->"b84af873-ac36-4ec3-868a-1ffaad1bbaba"],
Cell[190405, 3324, 1587, 30, 44, "Input",ExpressionUUID->"e01165ce-f1d5-466c-bd97-2cfeb5fb52a7"],
Cell[191995, 3356, 1627, 26, 47, "Input",ExpressionUUID->"cf846bbd-4358-4ded-a3bd-51431faf16f0"],
Cell[193625, 3384, 159, 3, 34, "Text",ExpressionUUID->"f2be6bbb-96fd-4dbc-8a3c-7a8c9d5303e8"],
Cell[193787, 3389, 1495, 25, 44, "Input",ExpressionUUID->"adf09bb8-ba09-42d4-8fa1-3851ed8f03f8"],
Cell[195285, 3416, 1651, 28, 44, "Input",ExpressionUUID->"eecac173-9bd3-4c06-b1be-e9c182499ee0"],
Cell[196939, 3446, 869, 13, 34, "Text",ExpressionUUID->"e03dd20a-f0ad-4f2a-a960-e82685438b09"],
Cell[197811, 3461, 322, 5, 34, "Text",ExpressionUUID->"3ca59a7a-92d7-4ee5-a3a1-70ddbd3d7a5e"],
Cell[198136, 3468, 1641, 31, 44, "Input",ExpressionUUID->"371d9049-7ce7-40f7-b41b-29c4bc91fb4b"],
Cell[199780, 3501, 1506, 25, 47, "Input",ExpressionUUID->"aac04036-7655-40bb-aad7-1dc7991d1003"],
Cell[201289, 3528, 167, 3, 34, "Text",ExpressionUUID->"63d56b7a-c375-443d-94af-b937d9617e22"],
Cell[201459, 3533, 1578, 29, 44, "Input",ExpressionUUID->"fc53ee63-8e40-4683-b321-8821e0a01696"],
Cell[203040, 3564, 1670, 27, 47, "Input",ExpressionUUID->"a19c8c06-1203-453b-97b9-81d7697dca09"],
Cell[204713, 3593, 159, 3, 34, "Text",ExpressionUUID->"fd59724b-d4d7-48f5-94e7-da3322d79cb4"],
Cell[204875, 3598, 1508, 25, 44, "Input",ExpressionUUID->"7d33a6af-ed15-4356-8e81-ee1b51ecb618"],
Cell[206386, 3625, 1636, 27, 44, "Input",ExpressionUUID->"35bf12f1-9497-43a8-93f9-a343c7e57c0a"],
Cell[208025, 3654, 873, 13, 34, "Text",ExpressionUUID->"9ac45ad9-bf21-4008-a758-786c7ed6b0fa"],
Cell[208901, 3669, 322, 5, 34, "Text",ExpressionUUID->"ffe82adc-fd6a-424b-bf03-086e92c0fa26"],
Cell[209226, 3676, 1650, 30, 44, "Input",ExpressionUUID->"e3583c1c-0b7d-498c-9dc9-be43612a7e2d"],
Cell[210879, 3708, 1492, 25, 47, "Input",ExpressionUUID->"8abd3c2c-fa5f-4fa9-b775-f67376897e53"],
Cell[212374, 3735, 167, 3, 34, "Text",ExpressionUUID->"f6c7bd60-e494-47f6-9024-c6db127d3f58"],
Cell[212544, 3740, 1639, 30, 44, "Input",ExpressionUUID->"aaf62327-53e1-464d-9269-855cd6a8d47e"],
Cell[214186, 3772, 1663, 27, 47, "Input",ExpressionUUID->"830979a0-2024-4f7e-94ef-e6fd5d545f12"],
Cell[215852, 3801, 159, 3, 34, "Text",ExpressionUUID->"402de0e1-f804-4c84-9030-4cc90722e61c"],
Cell[216014, 3806, 1532, 25, 44, "Input",ExpressionUUID->"d335b394-b7ba-460c-8916-2bfed61ddef4"],
Cell[217549, 3833, 1636, 27, 44, "Input",ExpressionUUID->"5c57897c-e6e0-4547-adec-f264f983fc1c"],
Cell[219188, 3862, 879, 13, 34, "Text",ExpressionUUID->"068f0a4b-0c8d-4f61-b575-95776c4129e2"],
Cell[220070, 3877, 322, 5, 34, "Text",ExpressionUUID->"4aceaba7-6a60-4554-863d-dd84089e35c2"],
Cell[220395, 3884, 1628, 33, 44, "Input",ExpressionUUID->"9e84867b-f9b9-42cf-9eed-4e824f4a1706"],
Cell[222026, 3919, 1480, 25, 47, "Input",ExpressionUUID->"98eaeb8e-715e-43ab-ab2b-514540ca6fbe"],
Cell[223509, 3946, 167, 3, 34, "Text",ExpressionUUID->"1567bd46-d040-4da0-b773-798f28cbadeb"],
Cell[223679, 3951, 1581, 29, 44, "Input",ExpressionUUID->"d0c9dc2b-643a-4c85-b86d-881765c9c441"],
Cell[225263, 3982, 1614, 27, 47, "Input",ExpressionUUID->"97a149fc-08a4-4fe9-88c3-c69289bd6ca6"],
Cell[226880, 4011, 157, 3, 34, "Text",ExpressionUUID->"4b79b523-99b6-43b1-bb28-30c46d43bab0"],
Cell[227040, 4016, 1519, 25, 44, "Input",ExpressionUUID->"43dbadf4-e672-4f76-9011-c2105e6d5cee"],
Cell[228562, 4043, 1614, 27, 44, "Input",ExpressionUUID->"deeacab3-4398-4bbd-8b8a-420ec18f72de"],
Cell[230179, 4072, 872, 13, 34, "Text",ExpressionUUID->"741a7d08-dd5e-44d5-816a-9860128f4512"],
Cell[231054, 4087, 322, 5, 34, "Text",ExpressionUUID->"80679306-7315-447f-8853-cb9a606afce3"],
Cell[231379, 4094, 1519, 29, 44, "Input",ExpressionUUID->"4478c4b2-9dca-4c70-9a3e-09d649c678a6"],
Cell[232901, 4125, 1631, 27, 47, "Input",ExpressionUUID->"59e87d4e-a875-4e1f-973d-449d82a95dd9"],
Cell[234535, 4154, 167, 3, 34, "Text",ExpressionUUID->"730c05e4-fbd5-45c9-a667-9fa4c34cb3e8"],
Cell[234705, 4159, 1686, 31, 44, "Input",ExpressionUUID->"67db23b1-1ee2-4480-abd2-735099b48a51"],
Cell[236394, 4192, 1716, 28, 47, "Input",ExpressionUUID->"4f385778-3f43-40ed-921c-7c0e04fb9a01"],
Cell[238113, 4222, 157, 3, 34, "Text",ExpressionUUID->"3a58bab2-ea6a-4da8-9acd-f8f1973f108e"],
Cell[238273, 4227, 1581, 26, 44, "Input",ExpressionUUID->"b4652dbd-baa0-483b-80d4-bed59ea1e685"],
Cell[239857, 4255, 1734, 28, 44, "Input",ExpressionUUID->"71c82659-8137-4bc9-8885-d62034d062ab"],
Cell[241594, 4285, 396, 6, 34, "Text",ExpressionUUID->"cd6f868f-52a1-4b7d-bdd8-1e0c25075729"],
Cell[241993, 4293, 743, 13, 28, "Input",ExpressionUUID->"411685ec-4e7e-4e82-ae79-6c9d904a1b83"],
Cell[242739, 4308, 641, 11, 28, "Input",ExpressionUUID->"34e10a13-0897-4126-a042-cb29ac11441b"],
Cell[243383, 4321, 743, 13, 28, "Input",ExpressionUUID->"6db908f8-9ec3-41b6-8085-74a4b5f16e26"],
Cell[244129, 4336, 643, 11, 28, "Input",ExpressionUUID->"47372b87-46e4-4e84-abb6-b4b18d167dd3"],
Cell[244775, 4349, 667, 12, 28, "Input",ExpressionUUID->"5cef1721-b569-43ee-b7b4-73bb1e65ec8f"],
Cell[245445, 4363, 597, 11, 28, "Input",ExpressionUUID->"72241c77-9f0f-489b-8a81-f6b0d3b357f1"],
Cell[246045, 4376, 789, 13, 28, "Input",ExpressionUUID->"7642a00a-7e5c-4224-8711-9ffc11e1be68"],
Cell[246837, 4391, 692, 12, 28, "Input",ExpressionUUID->"912b37a4-b188-4750-8262-c62c624d05cf"],
Cell[247532, 4405, 841, 14, 28, "Input",ExpressionUUID->"b2292b82-0665-4f04-80e1-a2dee86e9765"],
Cell[248376, 4421, 693, 12, 28, "Input",ExpressionUUID->"2f08f5a1-311d-43ce-870b-fb2dfac7f219"],
Cell[249072, 4435, 841, 14, 28, "Input",ExpressionUUID->"b10de096-9726-4741-8e0d-30b85301d56f"],
Cell[249916, 4451, 748, 13, 28, "Input",ExpressionUUID->"fc71cdd8-ff97-488c-8f54-4ec2ef85e7be"],
Cell[250667, 4466, 893, 15, 28, "Input",ExpressionUUID->"f7595b6e-ef48-47d8-acbf-73a66b10338d"],
Cell[251563, 4483, 828, 14, 28, "Input",ExpressionUUID->"10a406bd-eaec-4da3-ae56-d57cd82e65f3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[252428, 4502, 473, 7, 43, "Subsubsection",ExpressionUUID->"5c4b7dbf-3a8e-45b2-9b5e-e78045930657"],
Cell[252904, 4511, 669, 9, 48, "Text",ExpressionUUID->"dd88b4bf-a98e-4046-be0f-da118062aa96"],
Cell[253576, 4522, 919, 16, 44, "Input",ExpressionUUID->"d36c758b-7ed8-4713-92ae-51ee7315a7bf"],
Cell[254498, 4540, 593, 12, 44, "Input",ExpressionUUID->"f5a00f2e-1382-4412-b39c-d22462e02472"],
Cell[255094, 4554, 965, 17, 44, "Input",ExpressionUUID->"ebbcdefa-e8b4-418d-bbcc-8a1406b8ea24"],
Cell[256062, 4573, 673, 13, 44, "Input",ExpressionUUID->"3302594c-3311-486c-975d-02c4f6420f26"],
Cell[256738, 4588, 942, 17, 44, "Input",ExpressionUUID->"1673fb4d-d680-490d-a146-b94de2c1ce9e"],
Cell[257683, 4607, 651, 13, 44, "Input",ExpressionUUID->"6a1cb2bd-9ccd-4c6e-a7ca-0c0cc8e3fd86"],
Cell[258337, 4622, 965, 17, 44, "Input",ExpressionUUID->"778b1d34-2b16-4641-afe4-958ffaa66eba"],
Cell[259305, 4641, 681, 13, 44, "Input",ExpressionUUID->"17bf2afb-74a4-4899-a403-1ee2cb2495d4"],
Cell[259989, 4656, 1040, 18, 44, "Input",ExpressionUUID->"7f003a9b-1f8b-4d9e-a4a9-1aca2619de06"],
Cell[261032, 4676, 679, 13, 44, "Input",ExpressionUUID->"37bb7d17-06ad-414f-a3a0-68314fec7d91"],
Cell[261714, 4691, 905, 16, 44, "Input",ExpressionUUID->"e1812860-5f1c-4169-94a1-19394261051f"],
Cell[262622, 4709, 681, 13, 44, "Input",ExpressionUUID->"afaa7c76-91eb-4a00-b049-87075744925a"],
Cell[263306, 4724, 957, 17, 44, "Input",ExpressionUUID->"69d4f5bc-3302-4d76-83a8-e6b4cab670f2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[264300, 4746, 495, 8, 43, "Subsubsection",ExpressionUUID->"c16170aa-44a3-4c71-a07e-95c8ef6a135c"],
Cell[264798, 4756, 197, 4, 34, "Text",ExpressionUUID->"252f8968-7724-41d3-aa7c-1192b882b8c2"],
Cell[264998, 4762, 539, 9, 30, "Text",ExpressionUUID->"5c4f00af-1b9c-424c-bca5-ccdf8213e40f"],
Cell[265540, 4773, 1431, 23, 44, "Input",ExpressionUUID->"802c6b9b-1962-431d-b17b-a621193520c7"],
Cell[266974, 4798, 198, 4, 34, "Text",ExpressionUUID->"744d9f40-2552-4822-8e73-7184611bd5a6"],
Cell[267175, 4804, 539, 9, 30, "Text",ExpressionUUID->"da8032ca-080c-4486-b6d1-c13f60b65389"],
Cell[267717, 4815, 1329, 22, 44, "Input",ExpressionUUID->"cb959750-59dd-405b-8ff0-098877582c11"],
Cell[269049, 4839, 198, 4, 34, "Text",ExpressionUUID->"0212caa3-1cbe-4b2c-a8b1-fd9e031ae510"],
Cell[269250, 4845, 539, 9, 30, "Text",ExpressionUUID->"b910205f-395a-47e4-911a-4e3c4f7e50e9"],
Cell[269792, 4856, 1298, 21, 44, "Input",ExpressionUUID->"63bde8db-8dca-4231-b99b-9dc06652c0ae"],
Cell[271093, 4879, 247, 5, 34, "Text",ExpressionUUID->"4ce19111-9aa0-48c9-9d17-047166ecea6c"],
Cell[271343, 4886, 1684, 27, 228, "Text",ExpressionUUID->"6414f3cf-0fb4-4612-ad56-bfff509d639e"],
Cell[273030, 4915, 1382, 23, 44, "Input",ExpressionUUID->"fc85e40d-813d-4459-9fa3-8bef78a8fce4"],
Cell[274415, 4940, 298, 5, 34, "Text",ExpressionUUID->"e6a985b5-a2fc-4e0c-b2c6-02cdb4a64566"],
Cell[274716, 4947, 1100, 18, 120, "Text",ExpressionUUID->"862ed9af-b18f-4dcb-b850-008a4cefc1be"],
Cell[275819, 4967, 1420, 23, 44, "Input",ExpressionUUID->"422e32a6-79a0-4a83-9eca-a130a7bfd0fe"],
Cell[277242, 4992, 250, 5, 34, "Text",ExpressionUUID->"94271768-293d-486c-9851-1796d0c241bc"],
Cell[277495, 4999, 539, 9, 30, "Text",ExpressionUUID->"a05273ab-4645-4f43-a5e8-6c11b8a01e71"],
Cell[278037, 5010, 1403, 23, 44, "Input",ExpressionUUID->"8a6ec7a1-47a4-4e5f-837b-ec8dc5daca28"],
Cell[279443, 5035, 242, 5, 34, "Text",ExpressionUUID->"dff70f9d-5747-4325-9939-2385c520a77f"],
Cell[279688, 5042, 539, 9, 30, "Text",ExpressionUUID->"3c253ed7-03fb-4278-b739-5661b9c265fe"],
Cell[280230, 5053, 1445, 23, 44, "Input",ExpressionUUID->"ea8d8b41-c0db-4621-8a2a-96bd5e38c84b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[281712, 5081, 335, 5, 43, "Subsubsection",ExpressionUUID->"11ce761c-6bc0-4ca5-9f3f-a2d2d30f962c"],
Cell[CellGroupData[{
Cell[282072, 5090, 305, 7, 28, "Input",ExpressionUUID->"65c383af-0e3a-41f5-8344-899c12a2520c"],
Cell[282380, 5099, 886, 13, 32, "Output",ExpressionUUID->"326087ce-2f60-4c51-bfc6-a4d27b5ab246"]
}, Open  ]],
Cell[CellGroupData[{
Cell[283303, 5117, 303, 7, 28, "Input",ExpressionUUID->"c426af25-e96e-4958-9fee-83f26408e112"],
Cell[283609, 5126, 914, 13, 32, "Output",ExpressionUUID->"df002371-bd5c-4724-8896-3bb749161c78"]
}, Open  ]],
Cell[CellGroupData[{
Cell[284560, 5144, 303, 7, 28, "Input",ExpressionUUID->"732c0ddb-fdad-48f7-94f5-56a73e10b068"],
Cell[284866, 5153, 915, 13, 32, "Output",ExpressionUUID->"85952ffd-90c3-4a3d-9c58-66b08ca16776"]
}, Open  ]],
Cell[CellGroupData[{
Cell[285818, 5171, 355, 8, 28, "Input",ExpressionUUID->"47edc215-7f91-4a09-8d92-d251aff27f2c"],
Cell[286176, 5181, 918, 13, 32, "Output",ExpressionUUID->"1aa178e7-154f-42f3-9828-4778a0da8c62"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287131, 5199, 356, 8, 28, "Input",ExpressionUUID->"7dbb8992-dd6e-4107-9b77-adfe7650b76e"],
Cell[287490, 5209, 902, 13, 32, "Output",ExpressionUUID->"baf2af1e-f805-4832-aa31-a46332b7f41e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[288429, 5227, 356, 8, 28, "Input",ExpressionUUID->"9eaa2753-1be0-43c2-935b-9544a2ace27d"],
Cell[288788, 5237, 910, 13, 32, "Output",ExpressionUUID->"4405fcc1-7ac5-44cc-a3fb-bdde98a82932"]
}, Open  ]],
Cell[CellGroupData[{
Cell[289735, 5255, 356, 8, 28, "Input",ExpressionUUID->"38d65750-b852-42a0-bb25-7482c68f75cc"],
Cell[290094, 5265, 917, 13, 32, "Output",ExpressionUUID->"e025ec69-ffbe-4aa0-aba9-dde83841c55a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[291048, 5283, 405, 9, 28, "Input",ExpressionUUID->"05511a5f-0a7e-45c1-bf3d-c37a2cc52924"],
Cell[291456, 5294, 937, 14, 32, "Output",ExpressionUUID->"33c8c216-fe08-43d8-b1e2-9514e25d9eb6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[292430, 5313, 407, 9, 28, "Input",ExpressionUUID->"ebc2b054-f985-4e96-9b60-8e2dec5952c8"],
Cell[292840, 5324, 970, 15, 32, "Output",ExpressionUUID->"616d42cc-05e6-435a-906e-057bb121a26d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[293847, 5344, 405, 9, 28, "Input",ExpressionUUID->"51f69870-456a-4e85-a6be-8d6a3c74cbbe"],
Cell[294255, 5355, 996, 15, 32, "Output",ExpressionUUID->"921e98f3-0476-426a-8ce3-6d1c9665d269"]
}, Open  ]],
Cell[CellGroupData[{
Cell[295288, 5375, 455, 9, 28, "Input",ExpressionUUID->"95ef8fe1-5218-4f52-a9c4-d2cfc1066f0e"],
Cell[295746, 5386, 1005, 15, 32, "Output",ExpressionUUID->"cad18d76-b14a-4120-8c5d-0fc4bbf86e00"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[296812, 5408, 446, 7, 62, "Section",ExpressionUUID->"030c91d2-5273-48bd-b7f2-94f6c286661c"],
Cell[297261, 5417, 917, 15, 28, "Input",ExpressionUUID->"9d5a52cf-3316-4cb2-80ab-9c9bede1d617"],
Cell[298181, 5434, 987, 16, 28, "Input",ExpressionUUID->"563be225-6049-49ee-806a-d676b042abd2"],
Cell[299171, 5452, 917, 15, 28, "Input",ExpressionUUID->"586a9c09-4290-443b-bf7d-c0d9a9d73e0a"],
Cell[300091, 5469, 985, 16, 28, "Input",ExpressionUUID->"64e92a99-a9c8-424b-ad08-340b3749b512"],
Cell[301079, 5487, 843, 14, 28, "Input",ExpressionUUID->"d41b583f-dae0-48e9-b4c3-be318f3fd670"],
Cell[301925, 5503, 917, 15, 28, "Input",ExpressionUUID->"4ff425df-281f-4ea5-98ba-80b9dac98a0d"],
Cell[302845, 5520, 915, 15, 28, "Input",ExpressionUUID->"bcd1b8c2-12df-4a34-b46e-55c2ab4cc24e"],
Cell[303763, 5537, 987, 16, 28, "Input",ExpressionUUID->"7ba43ca5-42d7-4dd1-9e4d-54130dec78d9"],
Cell[304753, 5555, 945, 16, 28, "Input",ExpressionUUID->"a670896e-3a79-4021-8343-54a5ece8d061"],
Cell[305701, 5573, 1013, 16, 28, "Input",ExpressionUUID->"e277d6ca-3f55-4be1-9d33-c1ff6a01c5a3"],
Cell[306717, 5591, 943, 16, 28, "Input",ExpressionUUID->"d10dcd0c-1bec-4815-805a-88cd35a2b449"],
Cell[307663, 5609, 1013, 16, 28, "Input",ExpressionUUID->"53646c65-6bf2-44ab-80e9-9a7f3d2e9934"],
Cell[308679, 5627, 993, 16, 28, "Input",ExpressionUUID->"78d80331-eb25-4316-8bfc-a56ea14d3fe2"],
Cell[309675, 5645, 1063, 17, 28, "Input",ExpressionUUID->"447b75a5-cd59-441a-a64d-140c9dd7fec3"],
Cell[310741, 5664, 1647, 28, 28, "Input",ExpressionUUID->"a3ab304f-2aee-4fbd-bfd7-6f5a12f02f88"],
Cell[312391, 5694, 1293, 23, 28, "Input",ExpressionUUID->"3f3f71a9-fce2-4be4-b505-60d2d9a2083c"],
Cell[313687, 5719, 1706, 28, 28, "Input",ExpressionUUID->"719d6bd9-ab83-433d-bc57-a6b508965f6b"],
Cell[315396, 5749, 1301, 23, 28, "Input",ExpressionUUID->"ca4a1562-a6dc-469b-905d-0d39aef96b5a"],
Cell[316700, 5774, 1531, 26, 28, "Input",ExpressionUUID->"12c30e9d-754a-45e0-8c39-1b72a9f6c4ad"],
Cell[318234, 5802, 1211, 22, 28, "Input",ExpressionUUID->"288ea92c-c9be-4ba0-82d7-1acdbbeb49ee"],
Cell[319448, 5826, 1654, 28, 28, "Input",ExpressionUUID->"b2ccd627-d7eb-4881-8b69-b0a9aa854d3c"],
Cell[321105, 5856, 1327, 23, 28, "Input",ExpressionUUID->"07cb80e4-b70d-4a54-9c85-400d2cb9ea9b"],
Cell[322435, 5881, 1772, 29, 28, "Input",ExpressionUUID->"c58f1e24-fc21-48b5-a52b-8ef5b76fd29a"],
Cell[324210, 5912, 1353, 24, 28, "Input",ExpressionUUID->"58ea194b-8382-4059-9a56-4bd3f7863104"],
Cell[325566, 5938, 1725, 29, 28, "Input",ExpressionUUID->"452c9f24-2134-4294-98c5-98d220bcf96c"],
Cell[327294, 5969, 1352, 24, 28, "Input",ExpressionUUID->"ebbbcfd0-9681-4755-aac2-3374db013fbe"],
Cell[328649, 5995, 1749, 29, 28, "Input",ExpressionUUID->"151f7240-9f23-4bf6-aab8-426e1b4f1a4c"],
Cell[CellGroupData[{
Cell[330423, 6028, 223, 4, 44, "Subsubsection",ExpressionUUID->"f8be89da-e224-495e-93d3-82ef70496628"],
Cell[330649, 6034, 1010, 19, 48, "Input",ExpressionUUID->"251b4ab0-22c0-46e3-b8e5-e9aa3e6836c2"],
Cell[331662, 6055, 1808, 29, 28, "Input",ExpressionUUID->"84a21240-2395-4207-a627-0bd1de0b1bd2",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[333473, 6086, 952, 18, 48, "Input",ExpressionUUID->"ddefb4fb-ed0b-41c9-b34f-815fdb269d09"],
Cell[334428, 6106, 1788, 29, 28, "Input",ExpressionUUID->"9804a220-ad8a-4ea2-b0a3-d983552dacc8",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[336219, 6137, 836, 16, 48, "Input",ExpressionUUID->"f305acde-6487-41d5-8850-a22925249eb5"],
Cell[337058, 6155, 1670, 27, 28, "Input",ExpressionUUID->"f5232fbe-62d7-4e00-986d-f2c32840b136",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[338731, 6184, 963, 18, 48, "Input",ExpressionUUID->"ac224861-1ffc-4908-a6d4-f00c1b91f388"],
Cell[339697, 6204, 1794, 29, 28, "Input",ExpressionUUID->"22c1ee31-aa92-4f38-bac8-c199f7968ae9",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[341494, 6235, 1015, 19, 48, "Input",ExpressionUUID->"2c6e2342-421a-4708-b8b8-5c667135aa12"],
Cell[342512, 6256, 1844, 29, 28, "Input",ExpressionUUID->"e4a181ee-069f-4237-bdb1-e29ece128f2d",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[344359, 6287, 1017, 19, 48, "Input",ExpressionUUID->"745d2426-5f4e-4ea4-8d95-2cd7241500ec"],
Cell[345379, 6308, 1844, 29, 28, "Input",ExpressionUUID->"94b6edbf-8c1e-4ac1-9ae1-85e6f5b9f009",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[347226, 6339, 1065, 19, 48, "Input",ExpressionUUID->"41deddaa-e5e1-4a31-984a-bf30677cca86"],
Cell[348294, 6360, 1898, 30, 28, "Input",ExpressionUUID->"ce02a34d-707c-477f-b9f3-80a7e49f1cfc",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[350229, 6395, 247, 4, 44, "Subsubsection",ExpressionUUID->"d43bc1bc-6db0-47cd-9c1e-e695e7782ff4"],
Cell[350479, 6401, 2516, 40, 49, "Input",ExpressionUUID->"1bd69a31-8d5e-4be7-ac7b-526a6a7dc4b5"],
Cell[352998, 6443, 1030, 22, 41, "Input",ExpressionUUID->"bfe09279-c02a-4e14-b37a-2ead85213dd7"],
Cell[354031, 6467, 2564, 40, 49, "Input",ExpressionUUID->"d2ca5df3-78b6-49e1-b854-f20b9894de8a"],
Cell[356598, 6509, 1051, 22, 41, "Input",ExpressionUUID->"e9996e19-c9e2-4bad-80d6-e5d1f107f50b"],
Cell[357652, 6533, 2372, 38, 49, "Input",ExpressionUUID->"385ca98f-830d-4059-a353-b4dd92eaff40"],
Cell[360027, 6573, 900, 20, 41, "Input",ExpressionUUID->"11633740-7877-4529-9267-5101c3b28f3f"],
Cell[360930, 6595, 2560, 40, 49, "Input",ExpressionUUID->"387dcf33-3dbb-4670-99ab-85ffff228603"],
Cell[363493, 6637, 1098, 23, 41, "Input",ExpressionUUID->"764696a7-2ccb-4e84-8698-455b1318fc9e"],
Cell[364594, 6662, 2613, 41, 49, "Input",ExpressionUUID->"7e8bc4a9-59b5-4213-a12b-64692d4817e6"],
Cell[367210, 6705, 1152, 24, 41, "Input",ExpressionUUID->"6881808e-6ee8-4fbf-a097-67964535b9e6"],
Cell[368365, 6731, 2615, 41, 49, "Input",ExpressionUUID->"973e0b37-8182-4fda-9e0f-5a79f4428a28"],
Cell[370983, 6774, 1154, 24, 41, "Input",ExpressionUUID->"47fa4eb1-e757-4dc0-863e-a3881a527a94"],
Cell[372140, 6800, 2664, 42, 49, "Input",ExpressionUUID->"6f5e7dc2-ad0f-4179-ae72-c51b53d6c9bd"],
Cell[374807, 6844, 1206, 25, 41, "Input",ExpressionUUID->"b90f7656-9533-4e23-8b30-fff3e1d43867"],
Cell[376016, 6871, 852, 19, 49, "Input",ExpressionUUID->"62eabe97-1954-43ae-855a-7d2c54b35cbd"],
Cell[376871, 6892, 696, 17, 49, "Input",ExpressionUUID->"4d9b0a1f-c966-472a-b552-6af5401f68b8"],
Cell[377570, 6911, 900, 19, 49, "Input",ExpressionUUID->"f941036b-720f-480c-b55f-675c0c274d1d"],
Cell[378473, 6932, 950, 20, 49, "Input",ExpressionUUID->"9f1ce122-1da6-4467-859b-c911e0fbf274"],
Cell[379426, 6954, 948, 20, 46, "Input",ExpressionUUID->"2bd131a2-c9c0-49aa-a8ac-c0ffda5dda8c"],
Cell[380377, 6976, 1534, 34, 39, "Input",ExpressionUUID->"e6724399-0426-4abd-bb4b-27370550b482"],
Cell[381914, 7012, 618, 17, 39, "Input",ExpressionUUID->"27fb513c-94bf-41fe-917f-d84a14538a41"],
Cell[382535, 7031, 2570, 40, 49, "Input",ExpressionUUID->"379bd8ba-b8f0-4369-b43e-b6613eb75c99"],
Cell[385108, 7073, 1078, 23, 41, "Input",ExpressionUUID->"1ed764e9-1c8e-4b4d-9273-7c8f56f9b844"],
Cell[386189, 7098, 2565, 40, 49, "Input",ExpressionUUID->"29fbc036-d510-40fe-8daf-9600259594f0"],
Cell[388757, 7140, 1102, 23, 41, "Input",ExpressionUUID->"d597280d-cf66-4efd-a4df-e8e3cfc822e5"],
Cell[389862, 7165, 2417, 38, 49, "Input",ExpressionUUID->"046a6855-34da-4a95-a501-75e89b292345"],
Cell[392282, 7205, 952, 21, 41, "Input",ExpressionUUID->"d22c127a-b4b1-4a89-8bd5-9291c05be00a"],
Cell[393237, 7228, 2618, 41, 49, "Input",ExpressionUUID->"93b2d3b9-f4dc-4bec-b540-3dc836afe09b"],
Cell[395858, 7271, 1147, 24, 41, "Input",ExpressionUUID->"ad032d2a-ff52-44d7-8d69-ecdf737d464c"],
Cell[397008, 7297, 2667, 42, 49, "Input",ExpressionUUID->"d89a45b1-455b-4c84-bfb2-4d419410a0cb"],
Cell[399678, 7341, 1197, 24, 41, "Input",ExpressionUUID->"e0dfef6b-9095-46bd-b1db-493e8ded06e6"],
Cell[400878, 7367, 2666, 42, 49, "Input",ExpressionUUID->"251ab582-9b64-4b8f-8f2a-b01aa1edb46b"],
Cell[403547, 7411, 1195, 24, 41, "Input",ExpressionUUID->"10c092d2-c064-4dbd-b087-f6d73fab8a94"],
Cell[404745, 7437, 852, 19, 49, "Input",ExpressionUUID->"8305e50c-adba-4ce2-96df-65790eba427b"],
Cell[405600, 7458, 743, 17, 49, "Input",ExpressionUUID->"54f686b0-44db-4784-8a4e-7cfac2c72f32"],
Cell[406346, 7477, 946, 20, 49, "Input",ExpressionUUID->"f8f4cffc-2e08-4013-8cd5-e151588c3e2e"],
Cell[407295, 7499, 1021, 21, 49, "Input",ExpressionUUID->"19f80ec7-4361-4557-abb4-76d7665e3fd6"],
Cell[408319, 7522, 1044, 21, 49, "Input",ExpressionUUID->"d45e55d8-cf88-4b9a-97a8-b5feb88adfba"],
Cell[409366, 7545, 1619, 35, 41, "Input",ExpressionUUID->"a4a909b7-206c-40c9-bf6f-7340e63204b5"],
Cell[410988, 7582, 594, 16, 41, "Input",ExpressionUUID->"df2f5467-8409-48bb-9ef1-7c6e5b1ee99f"],
Cell[411585, 7600, 1894, 32, 50, "Input",ExpressionUUID->"0f3e7553-f6e2-4c16-ad42-a622b32f2bcb"],
Cell[413482, 7634, 634, 15, 47, "Input",ExpressionUUID->"c419041f-0db1-4067-a99f-0107c1d5fb81"],
Cell[414119, 7651, 1006, 20, 50, "Input",ExpressionUUID->"3ef16ad7-9288-471b-b407-adece8171bc8"],
Cell[415128, 7673, 613, 15, 50, "Input",ExpressionUUID->"7b4f3f13-cb36-44aa-add5-05e9e2122d1a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[415790, 7694, 509, 8, 62, "Section",ExpressionUUID->"5033ec64-9fb0-47a7-80a9-2acecbefbedd"],
Cell[416302, 7704, 1051, 22, 41, "Input",ExpressionUUID->"ef893d96-bd08-4069-9c34-459925ad7abd"],
Cell[417356, 7728, 1079, 23, 41, "Input",ExpressionUUID->"8ed78591-642f-4073-ae37-f3504a3aa756"],
Cell[418438, 7753, 927, 21, 41, "Input",ExpressionUUID->"ce99f432-061e-4019-ad09-c149f12ad464"],
Cell[419368, 7776, 1127, 23, 41, "Input",ExpressionUUID->"885540a3-c558-4d46-8645-7a9b84d95c48"],
Cell[420498, 7801, 1181, 24, 41, "Input",ExpressionUUID->"26e7f073-06b1-4e5a-8eff-d9badcd29a3b"],
Cell[421682, 7827, 1177, 24, 41, "Input",ExpressionUUID->"46b47e41-b29a-438d-a4f1-ca328fe5a8e2"],
Cell[422862, 7853, 1229, 25, 41, "Input",ExpressionUUID->"c57bda11-d8d5-4640-b6e9-81ea62f804c0"],
Cell[424094, 7880, 1571, 34, 39, "Input",ExpressionUUID->"fcad075f-b133-4c8a-bbfe-1247200c7621"],
Cell[425668, 7916, 517, 15, 39, "Input",ExpressionUUID->"99823b00-635f-49cc-9e3d-c2e6132f7bbb"],
Cell[426188, 7933, 392, 9, 48, "Input",ExpressionUUID->"da0aff7c-7b14-4aa8-b92e-a0eed3b6c7f9"],
Cell[426583, 7944, 335, 8, 45, "Input",ExpressionUUID->"119302ff-62d4-4ee6-b157-93f9af95b567"],
Cell[426921, 7954, 341, 8, 45, "Input",ExpressionUUID->"595b2566-2755-435c-b60f-85d1074d0b10"],
Cell[427265, 7964, 340, 8, 45, "Input",ExpressionUUID->"a637258c-e1d7-4776-97e4-1054436d77b6"],
Cell[427608, 7974, 286, 7, 45, "Input",ExpressionUUID->"328f6603-63df-4175-8a38-3d6f30379a3e"],
Cell[427897, 7983, 288, 7, 45, "Input",ExpressionUUID->"eee623c3-a5d5-4047-9310-aee616ffb0c9"],
Cell[428188, 7992, 1125, 23, 41, "Input",ExpressionUUID->"9d050bb0-c02a-4827-8832-d05de9cd5771"],
Cell[429316, 8017, 1157, 24, 41, "Input",ExpressionUUID->"a48f174d-0b4e-4016-89cb-12950409eed7"],
Cell[430476, 8043, 1005, 22, 41, "Input",ExpressionUUID->"d25cd3d4-d9b3-4009-ac7e-4fadd097d429"],
Cell[431484, 8067, 1194, 24, 41, "Input",ExpressionUUID->"32ef4bb7-8042-4bd0-bd2d-98b82f2e0275"],
Cell[432681, 8093, 1246, 25, 41, "Input",ExpressionUUID->"08466a49-25b4-495a-aed9-6e7b567f6770"],
Cell[433930, 8120, 1248, 25, 41, "Input",ExpressionUUID->"4534289d-cc08-4831-a2b9-f2744c2fce2a"],
Cell[435181, 8147, 1604, 35, 41, "Input",ExpressionUUID->"f0685b32-fed0-4748-827d-4b13ae9f2b4c"],
Cell[436788, 8184, 546, 16, 41, "Input",ExpressionUUID->"666f492e-57b8-4ad9-9d7c-03dd39cfe112"],
Cell[437337, 8202, 206, 4, 34, "Text",ExpressionUUID->"b2546a53-d4ee-4a9e-b3a4-5655bc44c153"],
Cell[437546, 8208, 494, 9, 34, "Text",ExpressionUUID->"a73e3fe0-db97-486d-b715-1d3b31d8449a"],
Cell[438043, 8219, 1566, 31, 28, "Input",ExpressionUUID->"7054bfa1-6724-4536-94f8-428722fa9818"],
Cell[439612, 8252, 1673, 32, 28, "Input",ExpressionUUID->"8d9a5d54-6195-4864-9379-ebaa47dda552"],
Cell[441288, 8286, 1376, 28, 28, "Input",ExpressionUUID->"b0114ba0-c557-4d16-ae5b-21ff20f003b6"],
Cell[442667, 8316, 1798, 34, 28, "Input",ExpressionUUID->"b96827f8-268f-402a-b86f-72a53198ccf1"],
Cell[444468, 8352, 1828, 34, 28, "Input",ExpressionUUID->"0968519c-053b-4dae-becf-1dda4af898b0"],
Cell[446299, 8388, 1890, 35, 28, "Input",ExpressionUUID->"c2996b52-8c55-4eee-9698-15dc1c36aea2"],
Cell[448192, 8425, 1943, 36, 28, "Input",ExpressionUUID->"5a095dd6-2bc6-48a6-afb7-e9e725444647"],
Cell[450138, 8463, 632, 11, 34, "Text",ExpressionUUID->"f2222292-c02a-4dff-bfb0-5253e658f6aa"],
Cell[450773, 8476, 1195, 24, 28, "Input",ExpressionUUID->"791f993f-332f-45c9-b74d-5610bfc47b08"],
Cell[451971, 8502, 1277, 25, 28, "Input",ExpressionUUID->"e0970f00-5295-4a08-929a-eb9fdaf290f2"],
Cell[453251, 8529, 1083, 23, 28, "Input",ExpressionUUID->"ff7b668f-42fc-496d-9711-68ef3214bd65"],
Cell[454337, 8554, 1374, 27, 28, "Input",ExpressionUUID->"d16e2950-660f-43e2-895a-44af17fb0b6a"],
Cell[455714, 8583, 1330, 26, 28, "Input",ExpressionUUID->"cfe54ccf-0db7-4801-88fa-6007d3fcd471"],
Cell[457047, 8611, 1384, 27, 28, "Input",ExpressionUUID->"63d14fc8-2bcf-4006-bdcb-7b8b710e0c35"],
Cell[458434, 8640, 1438, 28, 28, "Input",ExpressionUUID->"5d990e3e-9816-4f52-bc72-4ce73d582557"],
Cell[459875, 8670, 678, 11, 34, "Text",ExpressionUUID->"aee4aa60-9cad-4f3f-8312-69ed87061370"],
Cell[460556, 8683, 1065, 22, 28, "Input",ExpressionUUID->"dc442f99-2bf6-4cb3-b474-ca34a001692e"],
Cell[461624, 8707, 1149, 23, 28, "Input",ExpressionUUID->"8fd0c066-a41d-4bb3-8941-1c1ea14cc382"],
Cell[462776, 8732, 971, 21, 28, "Input",ExpressionUUID->"97c8f4b3-e25d-4002-9d3d-bf446eb05265"],
Cell[463750, 8755, 1237, 24, 28, "Input",ExpressionUUID->"0940c008-f167-45b0-8f67-f75f70a7d4aa"],
Cell[464990, 8781, 1181, 23, 28, "Input",ExpressionUUID->"4a6d51bc-ab93-4cda-be00-59be19085ebe"],
Cell[466174, 8806, 1187, 24, 28, "Input",ExpressionUUID->"0f1f16ba-f3a9-433f-bc3f-db13778a6b2c"],
Cell[467364, 8832, 1194, 23, 28, "Input",ExpressionUUID->"4ee84eba-03d6-4839-abf7-1d5dedd77b46"],
Cell[CellGroupData[{
Cell[468583, 8859, 3385, 74, 105, "Input",ExpressionUUID->"6340c5ef-1fdf-4a1b-8913-8de97b421861"],
Cell[471971, 8935, 2912, 47, 71, "Output",ExpressionUUID->"5b6dbb66-7a0c-4475-8df5-c300c0adb493"]
}, Open  ]],
Cell[474898, 8985, 417, 8, 28, "Input",ExpressionUUID->"946f9cfe-6f47-48dd-8266-de1998056519"],
Cell[475318, 8995, 416, 8, 28, "Input",ExpressionUUID->"43559586-6a2c-42e9-a31e-8d54a991c323"],
Cell[475737, 9005, 411, 8, 28, "Input",ExpressionUUID->"fe6319c4-183f-4cb1-8921-13252519ec27"],
Cell[476151, 9015, 469, 9, 28, "Input",ExpressionUUID->"9dc9d079-0605-42cf-9fae-d970b8bf9b15"],
Cell[476623, 9026, 466, 9, 28, "Input",ExpressionUUID->"52280ee1-ca06-46e2-8fd2-1ee3bf86a7bf"],
Cell[477092, 9037, 470, 9, 28, "Input",ExpressionUUID->"16577354-fa8c-4ba9-a552-6e3f71acfce3"],
Cell[477565, 9048, 373, 8, 28, "Input",ExpressionUUID->"d8dba8ef-0920-4505-bdb4-adc27f532b87"],
Cell[477941, 9058, 422, 8, 28, "Input",ExpressionUUID->"bd09eadf-153e-4b02-a931-f9871574b095"],
Cell[478366, 9068, 417, 8, 28, "Input",ExpressionUUID->"dbbea929-f638-498e-b75b-52c8fc05722d"],
Cell[478786, 9078, 471, 9, 28, "Input",ExpressionUUID->"ec51b3fd-7e7d-4c61-9972-2d851b2142ff"],
Cell[479260, 9089, 521, 10, 28, "Input",ExpressionUUID->"2d72f4c8-4704-4135-89b4-ae65638945c4"],
Cell[479784, 9101, 524, 10, 28, "Input",ExpressionUUID->"e4ae86d0-0ecf-4d01-9a43-638ff4316501"],
Cell[480311, 9113, 523, 10, 28, "Input",ExpressionUUID->"363b0dc2-9fe4-4ac6-8270-075099442dc1"],
Cell[480837, 9125, 572, 10, 28, "Input",ExpressionUUID->"f468faf8-f8bd-4c10-ac7a-f2bb158e1dcd"],
Cell[481412, 9137, 575, 10, 28, "Input",ExpressionUUID->"cea7b54e-c772-47bd-897d-57c5f521d92a"],
Cell[481990, 9149, 526, 10, 28, "Input",ExpressionUUID->"ed362b77-6bc1-4448-880e-83a403e1ad8b"],
Cell[482519, 9161, 575, 10, 28, "Input",ExpressionUUID->"2d3ae847-e6b2-47f7-9486-932bdc12b0a0"],
Cell[483097, 9173, 580, 10, 28, "Input",ExpressionUUID->"693b0175-b716-4b97-b073-d664939f0ede"],
Cell[483680, 9185, 577, 10, 28, "Input",ExpressionUUID->"891700e6-5502-4e18-85da-fb1626e937b3"],
Cell[484260, 9197, 631, 11, 28, "Input",ExpressionUUID->"70ea8773-9cf2-413c-82f5-942bb4cd6084"],
Cell[484894, 9210, 634, 11, 28, "Input",ExpressionUUID->"001d8a12-b4b4-44d8-9731-59bdec8b5ca0"],
Cell[485531, 9223, 1108, 23, 41, "Input",ExpressionUUID->"827b48b7-cd55-4505-a89a-8bea05d601f9"],
Cell[486642, 9248, 1136, 24, 41, "Input",ExpressionUUID->"10e0a844-12f0-4717-ae97-7bb0e70d876c"],
Cell[487781, 9274, 976, 21, 41, "Input",ExpressionUUID->"88b75a07-2f21-4492-b2d3-ed45dee10998"],
Cell[488760, 9297, 1176, 24, 41, "Input",ExpressionUUID->"36baead3-72a4-46ae-9e7b-357bd3170f22"],
Cell[489939, 9323, 1230, 25, 41, "Input",ExpressionUUID->"0571bbc8-e10f-4994-b3a9-b9907a4032d9"],
Cell[491172, 9350, 1230, 25, 41, "Input",ExpressionUUID->"25c9e9ad-6c6b-4a6e-badf-d81bcb918d0d"],
Cell[492405, 9377, 1278, 25, 41, "Input",ExpressionUUID->"393bc706-f2d6-4c09-8627-1d1a4ef1aa2b"],
Cell[493686, 9404, 1560, 34, 39, "Input",ExpressionUUID->"2cf42da1-537d-47cf-a868-6ac8425005fa"],
Cell[495249, 9440, 523, 15, 39, "Input",ExpressionUUID->"4ee6446c-deec-472a-a7f0-b874c8cab3a5"],
Cell[495775, 9457, 1174, 24, 41, "Input",ExpressionUUID->"6968501f-a00f-4eb4-b7de-e4b7523cd5a7"],
Cell[496952, 9483, 1206, 24, 41, "Input",ExpressionUUID->"50b2217b-a0f5-4ef2-a665-089b684d852b"],
Cell[498161, 9509, 1056, 22, 41, "Input",ExpressionUUID->"ca99b36d-0784-4f5c-abb4-899421699bbc"],
Cell[499220, 9533, 1251, 25, 41, "Input",ExpressionUUID->"cd104c3f-d515-420d-85d0-6d5fe0acf9eb"],
Cell[500474, 9560, 1301, 26, 41, "Input",ExpressionUUID->"b91acc9e-d0f7-4343-901b-85eb5f9b4f67"],
Cell[501778, 9588, 1302, 26, 41, "Input",ExpressionUUID->"f6513031-5cad-4928-be8c-84291667fb4f"],
Cell[503083, 9616, 1661, 35, 41, "Input",ExpressionUUID->"cf3a49b1-b3f6-48a3-98f1-2b28e692992d"],
Cell[504747, 9653, 516, 15, 41, "Input",ExpressionUUID->"9d2e5d99-8e49-4609-836e-375792498d54"],
Cell[505266, 9670, 444, 9, 48, "Input",ExpressionUUID->"06d36353-dfc7-4d1c-8143-aa54104266a5"],
Cell[505713, 9681, 388, 9, 45, "Input",ExpressionUUID->"9f53e977-679b-4ef3-9e59-bf6aa0ba9873"],
Cell[506104, 9692, 392, 9, 45, "Input",ExpressionUUID->"dae049e8-3b29-4344-a004-4d713b364504"],
Cell[506499, 9703, 393, 9, 45, "Input",ExpressionUUID->"211d406d-7e71-4e2b-bd2c-464cd41305c3"],
Cell[506895, 9714, 493, 10, 45, "Input",ExpressionUUID->"166ed68f-39a4-4ea5-874e-b306310def3d"],
Cell[507391, 9726, 495, 10, 45, "Input",ExpressionUUID->"5e05c1c6-59cc-451a-bbbe-4e3cc433f17f"],
Cell[507889, 9738, 610, 13, 28, "Input",ExpressionUUID->"da2c9595-e3fc-4efc-8340-7fcfa41ee32f"],
Cell[508502, 9753, 552, 11, 28, "Input",ExpressionUUID->"968cd914-3f2c-4fc0-8be1-87db76fa5032"],
Cell[509057, 9766, 514, 10, 28, "Input",ExpressionUUID->"5d201a59-15f3-4a9f-b1d9-6ab7b8e60249"],
Cell[509574, 9778, 921, 19, 28, "Input",ExpressionUUID->"c5d80009-058b-43b9-95a0-97be06ff345a"],
Cell[510498, 9799, 633, 13, 28, "Input",ExpressionUUID->"3e642ed7-8a2a-4a7c-84b1-61256cf803c8"],
Cell[511134, 9814, 595, 11, 28, "Input",ExpressionUUID->"14ae33cb-8dc4-47b0-bd6d-02367efb45db"],
Cell[511732, 9827, 564, 11, 28, "Input",ExpressionUUID->"9653b559-0a51-4e27-a205-737b01a7f79d"],
Cell[512299, 9840, 1055, 21, 28, "Input",ExpressionUUID->"c8f582d1-1442-4d78-8704-4de7307105c1"],
Cell[513357, 9863, 484, 11, 28, "Input",ExpressionUUID->"f9613ae5-8b16-4e0c-b27c-4a183e59636d"],
Cell[513844, 9876, 499, 10, 28, "Input",ExpressionUUID->"11243cd2-b796-4e01-8542-850f98f840aa"],
Cell[514346, 9888, 493, 10, 28, "Input",ExpressionUUID->"b63af19c-402b-4a43-8c33-41d4f5396395"],
Cell[514842, 9900, 857, 18, 28, "Input",ExpressionUUID->"7ee696d2-f285-433f-80dc-784d4d3d5c14"],
Cell[515702, 9920, 632, 13, 28, "Input",ExpressionUUID->"888e3a2d-d307-4c7b-a13a-f42ecd52ab55"],
Cell[516337, 9935, 591, 11, 28, "Input",ExpressionUUID->"78166c8f-0a9e-4e78-90eb-12cf3e75d5d0"],
Cell[516931, 9948, 570, 11, 28, "Input",ExpressionUUID->"bff7468d-1892-44a1-ab13-c7d9e1e5d3b5"],
Cell[517504, 9961, 1063, 21, 28, "Input",ExpressionUUID->"e5ee9f38-34c7-48ba-a642-b690f9fd2ef6"],
Cell[518570, 9984, 684, 14, 28, "Input",ExpressionUUID->"9ee139f8-dd61-49ba-9e44-ef070c835f9e"],
Cell[519257, 10000, 647, 12, 28, "Input",ExpressionUUID->"a3abd642-d5c4-4b76-b2bc-df6d735ad759"],
Cell[519907, 10014, 619, 12, 28, "Input",ExpressionUUID->"2b79f586-f40a-4ad1-9e25-ed319fec9286"],
Cell[520529, 10028, 1097, 21, 28, "Input",ExpressionUUID->"d1c876fb-bac7-4a69-a62f-408a82bf20b3"],
Cell[521629, 10051, 684, 14, 28, "Input",ExpressionUUID->"5663a682-3868-430c-b51e-543109457dcf"],
Cell[522316, 10067, 641, 12, 28, "Input",ExpressionUUID->"9e71b931-d617-428a-9a63-c9b1b171e286"],
Cell[522960, 10081, 620, 12, 28, "Input",ExpressionUUID->"a86a308e-d31b-4462-92c0-2bbe06ed4ed8"],
Cell[523583, 10095, 1098, 21, 28, "Input",ExpressionUUID->"b5432474-f281-45eb-9d5c-d18a453cd9e5"],
Cell[524684, 10118, 734, 15, 28, "Input",ExpressionUUID->"662f2a76-02c9-4540-8bca-997f98d98216"],
Cell[525421, 10135, 693, 13, 28, "Input",ExpressionUUID->"6c412690-e9a1-4070-b320-5ff264b7d718"],
Cell[526117, 10150, 667, 12, 28, "Input",ExpressionUUID->"3c62f9d9-0709-4c50-8aa7-ab005e09122d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[526821, 10167, 544, 9, 62, "Section",ExpressionUUID->"f7f455d9-0fe1-41b8-9366-995ae7cc18de"],
Cell[527368, 10178, 1025, 15, 34, "Text",ExpressionUUID->"0ba7f740-1ccf-4c0a-8976-8f2466cded3a"],
Cell[528396, 10195, 798, 11, 34, "Text",ExpressionUUID->"3d66264f-629c-44c5-9dbd-5d67f5927cbd"],
Cell[CellGroupData[{
Cell[529219, 10210, 429, 9, 48, "Input",ExpressionUUID->"2a02d074-8b67-4ef2-97ac-70841c84a99d"],
Cell[529651, 10221, 6326, 88, 48, "Output",ExpressionUUID->"4af06576-122d-47b7-9d15-61fe68e44f1e"]
}, Open  ]],
Cell[535992, 10312, 799, 11, 34, "Text",ExpressionUUID->"0fe098be-b29f-4ce6-bab0-f04522167f30"],
Cell[CellGroupData[{
Cell[536816, 10327, 473, 10, 48, "Input",ExpressionUUID->"7d4c9a37-f057-46db-b5c4-4cfdb1bc79f0"],
Cell[537292, 10339, 6323, 88, 48, "Output",ExpressionUUID->"53916a7a-e430-41e6-b331-569482a3f830"]
}, Open  ]],
Cell[543630, 10430, 800, 11, 34, "Text",ExpressionUUID->"7de371d5-81f7-476d-9f31-0363bd80cce3"],
Cell[CellGroupData[{
Cell[544455, 10445, 426, 9, 48, "Input",ExpressionUUID->"505233e9-3de1-4a29-9d0e-86ea14ae24b7"],
Cell[544884, 10456, 6338, 88, 48, "Output",ExpressionUUID->"bf94bd58-d152-4fb4-b1b0-44d2951063e8"]
}, Open  ]],
Cell[551237, 10547, 847, 12, 34, "Text",ExpressionUUID->"8ae1ed5b-0ea8-45f8-946d-944ec7d06db1"],
Cell[CellGroupData[{
Cell[552109, 10563, 483, 10, 48, "Input",ExpressionUUID->"5fd82f32-b684-4fbb-930c-804e026d4a08"],
Cell[552595, 10575, 6334, 89, 48, "Output",ExpressionUUID->"3cef5a96-011e-4323-a3ec-f5920da5eec4"]
}, Open  ]],
Cell[558944, 10667, 969, 13, 34, "Text",ExpressionUUID->"f7c8ac24-1772-44a2-8fd4-34926eabe768"],
Cell[CellGroupData[{
Cell[559938, 10684, 742, 18, 28, "Input",ExpressionUUID->"f59586ff-0f98-4466-8cbf-e8037d2facd9"],
Cell[560683, 10704, 724, 14, 48, "Output",ExpressionUUID->"3221fdcc-4fcd-44d2-93d2-b67da0a4e6bc"]
}, Open  ]],
Cell[561422, 10721, 946, 13, 34, "Text",ExpressionUUID->"dcbbb31f-19e7-44bd-a931-55852205923a"],
Cell[CellGroupData[{
Cell[562393, 10738, 784, 18, 28, "Input",ExpressionUUID->"c8061686-4796-4f70-a3b4-31ba8b7b2d73"],
Cell[563180, 10758, 740, 14, 48, "Output",ExpressionUUID->"67aeff48-cff3-49ff-a9c0-8323e0c9b80d"]
}, Open  ]],
Cell[563935, 10775, 789, 11, 34, "Text",ExpressionUUID->"595cd19d-1187-4444-8116-3c5f95c9094e"],
Cell[CellGroupData[{
Cell[564749, 10790, 436, 9, 47, "Input",ExpressionUUID->"54ef8831-e826-4661-bf9d-4173471e7600"],
Cell[565188, 10801, 6316, 88, 48, "Output",ExpressionUUID->"fc98d4dc-4fae-424a-b70f-51f5c9962aec"]
}, Open  ]],
Cell[571519, 10892, 837, 12, 34, "Text",ExpressionUUID->"0d1da58d-1aa7-4703-9e86-87f82453e588"],
Cell[CellGroupData[{
Cell[572381, 10908, 483, 10, 47, "Input",ExpressionUUID->"8550f87b-1995-4769-afe4-52aa757c92e5"],
Cell[572867, 10920, 6324, 89, 48, "Output",ExpressionUUID->"83e3549b-d9fa-4cd9-a71a-f09c20716cc0"]
}, Open  ]],
Cell[579206, 11012, 733, 10, 34, "Text",ExpressionUUID->"64be1c49-a58d-4f9b-bf04-f2b3f67564ff"],
Cell[CellGroupData[{
Cell[579964, 11026, 428, 9, 47, "Input",ExpressionUUID->"0033ad0d-1379-457a-9dc2-1a86231bb164"],
Cell[580395, 11037, 6262, 87, 48, "Output",ExpressionUUID->"1a886082-c557-4ad5-b881-bcedf16e5f4a"]
}, Open  ]],
Cell[586672, 11127, 783, 11, 34, "Text",ExpressionUUID->"1287b6cf-c7e5-4552-a2a6-c873534b38be"],
Cell[CellGroupData[{
Cell[587480, 11142, 475, 10, 47, "Input",ExpressionUUID->"04e6fdef-ca93-4416-a1ff-70212c4de514"],
Cell[587958, 11154, 6273, 88, 48, "Output",ExpressionUUID->"3808d8c1-5a84-421f-b2cc-318074470401"]
}, Open  ]],
Cell[594246, 11245, 1025, 15, 34, "Text",ExpressionUUID->"0da5a705-ebaa-47a5-9c78-216be9b445f4"],
Cell[595274, 11262, 747, 10, 34, "Text",ExpressionUUID->"d6dd7271-b8f9-4b87-8e07-d998adc6d6c9"],
Cell[CellGroupData[{
Cell[596046, 11276, 501, 10, 48, "Input",ExpressionUUID->"eac04235-9dae-4c9d-9d14-9beadbe1df28"],
Cell[596550, 11288, 6323, 88, 48, "Output",ExpressionUUID->"892aeba7-243d-40b5-ae97-cf836e3ebbea"]
}, Open  ]],
Cell[602888, 11379, 799, 11, 34, "Text",ExpressionUUID->"6ab2d942-3780-4d10-a84d-bca6c00b9067"],
Cell[CellGroupData[{
Cell[603712, 11394, 577, 11, 48, "Input",ExpressionUUID->"699c7382-61c3-4087-9ac8-2d4750e55a95"],
Cell[604292, 11407, 6316, 88, 48, "Output",ExpressionUUID->"0a1bb08c-f42d-4ae8-9483-4ce8f90236ec"]
}, Open  ]],
Cell[610623, 11498, 800, 11, 34, "Text",ExpressionUUID->"d2845b1f-67a4-4183-b6ef-b498601995fd"],
Cell[CellGroupData[{
Cell[611448, 11513, 504, 10, 48, "Input",ExpressionUUID->"7c1759df-3d72-4500-860c-2dd4c373c9a0"],
Cell[611955, 11525, 6326, 88, 48, "Output",ExpressionUUID->"5a9c72f5-e26a-4243-9117-e52cb166c3f8"]
}, Open  ]],
Cell[618296, 11616, 847, 12, 34, "Text",ExpressionUUID->"312e9735-b698-47d1-8a41-0d85b37f1f59"],
Cell[CellGroupData[{
Cell[619168, 11632, 584, 11, 48, "Input",ExpressionUUID->"bf9dee48-da0c-4799-9b7a-a8cf2a44140f"],
Cell[619755, 11645, 6318, 88, 48, "Output",ExpressionUUID->"9454f3ab-1e20-49eb-bec6-35405f2aafbd"]
}, Open  ]],
Cell[626088, 11736, 948, 13, 34, "Text",ExpressionUUID->"773a974e-774d-4a9d-8435-64c17db3bef1"],
Cell[CellGroupData[{
Cell[627061, 11753, 742, 18, 28, "Input",ExpressionUUID->"ae793997-7b92-411a-9d29-7b9ee3a4d0b7"],
Cell[627806, 11773, 726, 14, 48, "Output",ExpressionUUID->"7f2a404f-d731-41d0-a0f0-6da8fa3f7753"]
}, Open  ]],
Cell[628547, 11790, 948, 13, 34, "Text",ExpressionUUID->"e1448a62-8bb0-426d-80ca-985440bbf91e"],
Cell[CellGroupData[{
Cell[629520, 11807, 739, 18, 28, "Input",ExpressionUUID->"0d97cd81-1e03-4f9e-9ae3-c4e426e54006"],
Cell[630262, 11827, 1561, 23, 48, "Output",ExpressionUUID->"8d49ed7f-fb79-4aa5-ac55-44cc3626d13d"]
}, Open  ]],
Cell[631838, 11853, 789, 11, 34, "Text",ExpressionUUID->"44538c4e-1e32-4e62-83c8-b7718d9697ea"],
Cell[CellGroupData[{
Cell[632652, 11868, 509, 10, 48, "Input",ExpressionUUID->"4b5f3777-f0ec-482e-99c6-1607ad258f3c"],
Cell[633164, 11880, 6305, 88, 48, "Output",ExpressionUUID->"61e404f5-e87f-4c9f-9fcf-798bef815cf1"]
}, Open  ]],
Cell[639484, 11971, 837, 12, 34, "Text",ExpressionUUID->"7d0cf9a0-3acd-42fb-ac58-b758e20e9bab"],
Cell[CellGroupData[{
Cell[640346, 11987, 584, 11, 48, "Input",ExpressionUUID->"5f50749e-a91c-4991-99cb-2687d628f86c"],
Cell[640933, 12000, 6331, 89, 48, "Output",ExpressionUUID->"726ad14b-11bf-4912-8041-a9d9e20f0499"]
}, Open  ]],
Cell[647279, 12092, 733, 10, 34, "Text",ExpressionUUID->"e745e36a-4f70-481c-8fb6-6bb8fe578131"],
Cell[CellGroupData[{
Cell[648037, 12106, 506, 10, 48, "Input",ExpressionUUID->"305151c4-d677-4e89-8ccb-7d1d76c8b5ed"],
Cell[648546, 12118, 6272, 87, 48, "Output",ExpressionUUID->"0de90f9c-e7d6-4734-b6ab-443176c8b287"]
}, Open  ]],
Cell[654833, 12208, 783, 11, 34, "Text",ExpressionUUID->"e36a07fd-56c3-4cfb-8912-9cdfc5e191d1"],
Cell[CellGroupData[{
Cell[655641, 12223, 572, 11, 48, "Input",ExpressionUUID->"8aa73854-3a13-4f13-ad44-e3ae30c9c42c"],
Cell[656216, 12236, 6270, 88, 48, "Output",ExpressionUUID->"17481130-ba48-4198-9207-faf90af0c3a0"]
}, Open  ]],
Cell[662501, 12327, 1075, 16, 34, "Text",ExpressionUUID->"4218ea7d-769b-45dd-93f1-47d55b74dca5"],
Cell[663579, 12345, 747, 10, 34, "Text",ExpressionUUID->"450fdd62-51c3-4ecb-af6d-2332ff3da21c"],
Cell[CellGroupData[{
Cell[664351, 12359, 555, 11, 48, "Input",ExpressionUUID->"56090cfd-1d7b-48fd-b0de-5dcca13a9788"],
Cell[664909, 12372, 6330, 88, 48, "Output",ExpressionUUID->"a98afb95-c4cc-4956-ad28-b745472914c6"]
}, Open  ]],
Cell[671254, 12463, 799, 11, 34, "Text",ExpressionUUID->"24eb6752-0047-4e28-89e2-f95f91f72967"],
Cell[CellGroupData[{
Cell[672078, 12478, 628, 12, 48, "Input",ExpressionUUID->"94afbe0c-530f-4e5c-ac5d-c29ef322b4d6"],
Cell[672709, 12492, 6309, 88, 48, "Output",ExpressionUUID->"7b3ce028-34e3-4397-bf46-7693635cf311"]
}, Open  ]],
Cell[679033, 12583, 800, 11, 34, "Text",ExpressionUUID->"db0a1358-4a60-450f-b7cf-5f324b03ab1d"],
Cell[CellGroupData[{
Cell[679858, 12598, 556, 11, 48, "Input",ExpressionUUID->"723820a5-12be-4dc4-87e2-370f42900cb2"],
Cell[680417, 12611, 6322, 88, 48, "Output",ExpressionUUID->"7ae51b88-283f-430e-80a1-805e6d06fc88"]
}, Open  ]],
Cell[686754, 12702, 847, 12, 34, "Text",ExpressionUUID->"d63966ad-6121-4cf6-b01f-2fbdecdec67b"],
Cell[CellGroupData[{
Cell[687626, 12718, 637, 12, 48, "Input",ExpressionUUID->"68f53163-64e4-4bab-97c5-0be5b965d0c8"],
Cell[688266, 12732, 6338, 89, 48, "Output",ExpressionUUID->"4c651103-930f-4a22-8f9f-3a5ddedb108f"]
}, Open  ]],
Cell[694619, 12824, 970, 13, 34, "Text",ExpressionUUID->"7aaec84f-28ec-43dc-9c0d-7c24baf7c1d2"],
Cell[CellGroupData[{
Cell[695614, 12841, 788, 18, 28, "Input",ExpressionUUID->"0f6d3918-5b7f-4641-bec4-b82597f6ff62"],
Cell[696405, 12861, 690, 13, 48, "Output",ExpressionUUID->"aa2896c3-55b5-49d5-ba06-f6ee9bd5dcdd"]
}, Open  ]],
Cell[697110, 12877, 972, 13, 34, "Text",ExpressionUUID->"9dee2c40-173a-42b9-aeeb-7e163ad84820"],
Cell[CellGroupData[{
Cell[698107, 12894, 784, 18, 28, "Input",ExpressionUUID->"bfde672c-99ff-4d1c-a60f-c070caec272f"],
Cell[698894, 12914, 1565, 24, 48, "Output",ExpressionUUID->"ba091999-c29b-4628-99ca-000c4d5687b2"]
}, Open  ]],
Cell[700474, 12941, 789, 11, 34, "Text",ExpressionUUID->"2090d4c0-b256-42fd-b0b9-855673c13eef"],
Cell[CellGroupData[{
Cell[701288, 12956, 561, 11, 48, "Input",ExpressionUUID->"de86e58c-bebe-4284-aaa1-d0f138eda711"],
Cell[701852, 12969, 6307, 88, 48, "Output",ExpressionUUID->"7ed31432-3ed0-4bdd-aaaa-14eaf120958b"]
}, Open  ]],
Cell[708174, 13060, 837, 12, 34, "Text",ExpressionUUID->"9b717b62-22c7-40d2-8555-3d175d47ea17"],
Cell[CellGroupData[{
Cell[709036, 13076, 635, 12, 48, "Input",ExpressionUUID->"80ee4855-2358-4c1e-8eb0-cfa9ea0d31e9"],
Cell[709674, 13090, 6340, 89, 48, "Output",ExpressionUUID->"1d4dbea0-1fac-493e-be4c-fb66c33396b8"]
}, Open  ]],
Cell[716029, 13182, 733, 10, 34, "Text",ExpressionUUID->"80e05d25-81b9-4c74-8b36-582590678ca5"],
Cell[CellGroupData[{
Cell[716787, 13196, 560, 11, 48, "Input",ExpressionUUID->"8de93699-9283-4fb5-8557-04fa7ddb7614"],
Cell[717350, 13209, 6264, 87, 48, "Output",ExpressionUUID->"966993a9-24a0-41de-ae6c-cf09d3275779"]
}, Open  ]],
Cell[723629, 13299, 783, 11, 34, "Text",ExpressionUUID->"ac46c285-8b93-4bb6-bcdb-f882303c7001"],
Cell[CellGroupData[{
Cell[724437, 13314, 625, 12, 48, "Input",ExpressionUUID->"a1c615de-cb31-4f3e-a739-b80014746c13"],
Cell[725065, 13328, 6267, 88, 48, "Output",ExpressionUUID->"8e792a50-a874-4d37-992e-90ce5001bdc1"]
}, Open  ]],
Cell[731347, 13419, 1027, 15, 34, "Text",ExpressionUUID->"3c230a6e-b45f-406a-b862-d16c7d588e39"],
Cell[732377, 13436, 747, 10, 34, "Text",ExpressionUUID->"d31b970b-01b3-4a91-a1a6-1f6a8fc987d5"],
Cell[CellGroupData[{
Cell[733149, 13450, 573, 11, 48, "Input",ExpressionUUID->"00ca3398-e60a-4f27-9f2f-ebb60f90afab"],
Cell[733725, 13463, 6327, 88, 48, "Output",ExpressionUUID->"6820c5c6-9515-4236-a689-735d7d84fae9"]
}, Open  ]],
Cell[740067, 13554, 799, 11, 34, "Text",ExpressionUUID->"e62e74d7-9a4e-444a-8002-5e78b3fe9904"],
Cell[CellGroupData[{
Cell[740891, 13569, 575, 11, 48, "Input",ExpressionUUID->"ea07afa0-19bc-4d7b-a798-fbd50f5b1b9b"],
Cell[741469, 13582, 6297, 88, 48, "Output",ExpressionUUID->"32d840a5-5375-4981-b9aa-147eaf06b67a"]
}, Open  ]],
Cell[747781, 13673, 800, 11, 34, "Text",ExpressionUUID->"74709d3e-c995-4aa7-a7fe-8d66933766b1"],
Cell[CellGroupData[{
Cell[748606, 13688, 572, 11, 48, "Input",ExpressionUUID->"a7b058b0-b67f-46ad-9eac-b1634f448551"],
Cell[749181, 13701, 6345, 88, 48, "Output",ExpressionUUID->"849d5946-42dd-4a64-b30c-dcf7bdfb361b"]
}, Open  ]],
Cell[755541, 13792, 847, 12, 34, "Text",ExpressionUUID->"4eddad94-7d11-490a-a946-fa0004029ced"],
Cell[CellGroupData[{
Cell[756413, 13808, 582, 11, 48, "Input",ExpressionUUID->"3fb76938-949c-45e7-b678-fb85bf19b336"],
Cell[756998, 13821, 6329, 89, 48, "Output",ExpressionUUID->"2ed6bafe-cc9b-4214-84c3-140d17808717"]
}, Open  ]],
Cell[763342, 13913, 972, 13, 34, "Text",ExpressionUUID->"21f30dff-389c-44ba-9ac3-942bc15fb559"],
Cell[CellGroupData[{
Cell[764339, 13930, 741, 18, 28, "Input",ExpressionUUID->"0f1339f8-ac6f-44a9-b767-3bba2bc1a9be"],
Cell[765083, 13950, 732, 14, 48, "Output",ExpressionUUID->"5c01e074-29cd-4704-8c13-1b86db204613"]
}, Open  ]],
Cell[765830, 13967, 944, 13, 34, "Text",ExpressionUUID->"5a3a5221-9287-4570-9eb8-c2c85a6bdac6"],
Cell[CellGroupData[{
Cell[766799, 13984, 836, 19, 28, "Input",ExpressionUUID->"07a48ead-29e0-4de5-88d7-a45a5169bb31"],
Cell[767638, 14005, 755, 14, 48, "Output",ExpressionUUID->"8b3506e3-8934-4303-8a42-b270bbf38da9"]
}, Open  ]],
Cell[768408, 14022, 789, 11, 34, "Text",ExpressionUUID->"dea2e921-ee46-4743-ab05-a7e3945b6a26"],
Cell[CellGroupData[{
Cell[769222, 14037, 588, 11, 47, "Input",ExpressionUUID->"f484b1cf-f337-48dc-b352-e79d65e44fd2"],
Cell[769813, 14050, 6295, 88, 48, "Output",ExpressionUUID->"ceba8b7c-c8c4-46be-8e60-fbe01bf97b5c"]
}, Open  ]],
Cell[776123, 14141, 837, 12, 34, "Text",ExpressionUUID->"9a48f72c-e683-4eef-a766-d6eafcb44256"],
Cell[CellGroupData[{
Cell[776985, 14157, 586, 11, 47, "Input",ExpressionUUID->"17d0570a-d752-44e3-b70f-5ed7e347d13e"],
Cell[777574, 14170, 6336, 89, 48, "Output",ExpressionUUID->"df8a3041-efac-46d4-b62f-ee316e17fd6f"]
}, Open  ]],
Cell[783925, 14262, 733, 10, 34, "Text",ExpressionUUID->"6f46316a-26e2-4291-a63f-5ef5c6a7794c"],
Cell[CellGroupData[{
Cell[784683, 14276, 574, 11, 47, "Input",ExpressionUUID->"db586c54-20d0-41e4-9765-405464a7d02b"],
Cell[785260, 14289, 6261, 87, 48, "Output",ExpressionUUID->"f46d0ad3-0c78-4f0d-a662-88c150fefb3a"]
}, Open  ]],
Cell[791536, 14379, 783, 11, 34, "Text",ExpressionUUID->"c0839bdc-fe31-4602-a763-d373a33c6f16"],
Cell[CellGroupData[{
Cell[792344, 14394, 571, 11, 47, "Input",ExpressionUUID->"837a0856-9802-469c-8aee-bc228d453609"],
Cell[792918, 14407, 6277, 88, 48, "Output",ExpressionUUID->"e34e7018-c26f-44ff-84fe-fe17bb057363"]
}, Open  ]],
Cell[799210, 14498, 1002, 15, 34, "Text",ExpressionUUID->"fa466ce1-cea8-4a8d-9b00-4b42818ede2f"],
Cell[800215, 14515, 747, 10, 34, "Text",ExpressionUUID->"37b6f62e-ab42-474a-883b-a789278bd2e7"],
Cell[CellGroupData[{
Cell[800987, 14529, 457, 10, 48, "Input",ExpressionUUID->"7851d6b9-66dd-4b24-bb64-9b1361450660"],
Cell[801447, 14541, 6324, 88, 48, "Output",ExpressionUUID->"fa67851f-118d-480e-89ad-bf54a80c6078"]
}, Open  ]],
Cell[807786, 14632, 799, 11, 34, "Text",ExpressionUUID->"ff34ab77-1d9f-4ec0-ba1d-cae076d2ebb1"],
Cell[CellGroupData[{
Cell[808610, 14647, 527, 11, 48, "Input",ExpressionUUID->"12284875-4e6e-4aaf-8a4e-b74c3485c4eb"],
Cell[809140, 14660, 6323, 88, 48, "Output",ExpressionUUID->"e9471998-3eca-492a-a2af-a9a6023ef4e2"]
}, Open  ]],
Cell[815478, 14751, 800, 11, 34, "Text",ExpressionUUID->"fc388840-19e8-4dd3-9747-f8ff5f18cc62"],
Cell[CellGroupData[{
Cell[816303, 14766, 453, 10, 48, "Input",ExpressionUUID->"c01ee3c4-d5c4-4b0f-ad48-10861ea850e0"],
Cell[816759, 14778, 6323, 88, 48, "Output",ExpressionUUID->"1b8bab22-92c6-4d6a-aa26-278e41754f53"]
}, Open  ]],
Cell[823097, 14869, 847, 12, 34, "Text",ExpressionUUID->"7abf6cfa-d615-4f2a-b170-479ece4c4f53"],
Cell[CellGroupData[{
Cell[823969, 14885, 536, 11, 48, "Input",ExpressionUUID->"3b33f5e5-576c-4782-ba04-8feac09ec40f"],
Cell[824508, 14898, 6329, 89, 48, "Output",ExpressionUUID->"9c39f8c4-5e31-46a6-b1f7-2c3fb5ad23d1"]
}, Open  ]],
Cell[830852, 14990, 972, 13, 34, "Text",ExpressionUUID->"66e3d8bf-0da9-4845-95b9-8b8bf770b527"],
Cell[CellGroupData[{
Cell[831849, 15007, 687, 17, 28, "Input",ExpressionUUID->"f293df65-97a3-435d-a196-54d89d1d73ff"],
Cell[832539, 15026, 723, 14, 48, "Output",ExpressionUUID->"0bd8d140-b3bb-4b3c-8b1d-a4b5486ce2b7"]
}, Open  ]],
Cell[833277, 15043, 946, 13, 34, "Text",ExpressionUUID->"db3b94e6-86c3-414a-9d12-e26f74e4477b"],
Cell[CellGroupData[{
Cell[834248, 15060, 739, 18, 28, "Input",ExpressionUUID->"992179d1-aebe-4b12-9fee-6993afcb01e9"],
Cell[834990, 15080, 731, 14, 48, "Output",ExpressionUUID->"dcf32726-5b55-4128-b2c5-9eb765b8f608"]
}, Open  ]],
Cell[835736, 15097, 789, 11, 34, "Text",ExpressionUUID->"5ed542e3-d498-4e4c-a4dd-1b360d55e7d3"],
Cell[CellGroupData[{
Cell[836550, 15112, 466, 10, 47, "Input",ExpressionUUID->"a7a9764c-bf66-49ef-939e-40c84233ba43"],
Cell[837019, 15124, 6306, 88, 48, "Output",ExpressionUUID->"cf168140-4e07-47dc-a4b7-55eaf253a623"]
}, Open  ]],
Cell[843340, 15215, 837, 12, 34, "Text",ExpressionUUID->"82273b4d-e264-45a3-9a5a-0b30019357d7"],
Cell[CellGroupData[{
Cell[844202, 15231, 534, 11, 47, "Input",ExpressionUUID->"0d15ba49-a590-43d3-aca9-29acdb783728"],
Cell[844739, 15244, 6324, 89, 48, "Output",ExpressionUUID->"a9850047-07f9-4539-ae88-b2de51bac895"]
}, Open  ]],
Cell[851078, 15336, 733, 10, 34, "Text",ExpressionUUID->"e23a3c21-0a78-47af-802c-c364f4f91f5f"],
Cell[CellGroupData[{
Cell[851836, 15350, 458, 10, 47, "Input",ExpressionUUID->"ec6af1d0-396f-4dba-8cea-a3941b570226"],
Cell[852297, 15362, 6276, 87, 48, "Output",ExpressionUUID->"d3e499d1-224f-4590-be49-6254cf99aea2"]
}, Open  ]],
Cell[858588, 15452, 783, 11, 34, "Text",ExpressionUUID->"f799dbdf-4080-49d8-a20e-90387fa96e77"],
Cell[CellGroupData[{
Cell[859396, 15467, 530, 11, 47, "Input",ExpressionUUID->"efe2e1f7-5f4b-4f80-a068-3179b4d26ead"],
Cell[859929, 15480, 6292, 88, 48, "Output",ExpressionUUID->"31a84d9d-59ed-4847-8624-83c2e1547e0d"]
}, Open  ]],
Cell[866236, 15571, 1076, 16, 34, "Text",ExpressionUUID->"cfdf10cf-34a8-40d8-b0b1-39725aa5bbd3"],
Cell[867315, 15589, 747, 10, 34, "Text",ExpressionUUID->"87808b10-38b2-412a-a34f-6e65d6b3752c"],
Cell[CellGroupData[{
Cell[868087, 15603, 555, 11, 48, "Input",ExpressionUUID->"56d3ee65-2e64-4653-9ce7-3699a45d9e92"],
Cell[868645, 15616, 6326, 88, 48, "Output",ExpressionUUID->"e24a1c98-371b-4e4c-bc5c-6dc831fcbec5"]
}, Open  ]],
Cell[874986, 15707, 801, 11, 34, "Text",ExpressionUUID->"340dbded-46cb-42bc-b420-65dd828b0c5b"],
Cell[CellGroupData[{
Cell[875812, 15722, 628, 12, 48, "Input",ExpressionUUID->"97a2aaff-8b6f-4bc3-b744-39d4f05435f7"],
Cell[876443, 15736, 6318, 88, 48, "Output",ExpressionUUID->"f752fbfe-dcc2-49b3-86a1-a2631f036ac3"]
}, Open  ]],
Cell[882776, 15827, 800, 11, 34, "Text",ExpressionUUID->"65d42bae-b5c3-4483-b02f-77a2a2d19e21"],
Cell[CellGroupData[{
Cell[883601, 15842, 554, 11, 48, "Input",ExpressionUUID->"ec89fe8d-c64b-4802-9fa0-5fda4fec5080"],
Cell[884158, 15855, 6328, 88, 48, "Output",ExpressionUUID->"6981019d-c31a-45f0-a3f8-0ccc678c890e"]
}, Open  ]],
Cell[890501, 15946, 847, 12, 34, "Text",ExpressionUUID->"9d2d41d9-d662-4692-b0f9-275af69086a3"],
Cell[CellGroupData[{
Cell[891373, 15962, 635, 12, 48, "Input",ExpressionUUID->"c68f8a88-0d37-4eca-8a0f-53c6953ed701"],
Cell[892011, 15976, 6339, 89, 48, "Output",ExpressionUUID->"1ae9e60b-4b07-4b8b-a76f-4764de9aff93"]
}, Open  ]],
Cell[898365, 16068, 946, 13, 34, "Text",ExpressionUUID->"3a1d09b7-e021-4be5-9440-183f46789866"],
Cell[CellGroupData[{
Cell[899336, 16085, 788, 18, 28, "Input",ExpressionUUID->"f13aef5f-971b-4fd5-973c-dd47a644d343"],
Cell[900127, 16105, 694, 13, 48, "Output",ExpressionUUID->"1cf6ce2d-48f6-4ff5-b84d-34e00374a7f3"]
}, Open  ]],
Cell[900836, 16121, 946, 13, 34, "Text",ExpressionUUID->"94b7fb62-ff27-41b0-b6cf-9ff2d7401e61"],
Cell[CellGroupData[{
Cell[901807, 16138, 781, 18, 28, "Input",ExpressionUUID->"c3180513-ab60-4ec9-8f7d-e65b660c3a99"],
Cell[902591, 16158, 1571, 24, 48, "Output",ExpressionUUID->"cdd877d1-be09-4753-941c-936e8597116e"]
}, Open  ]],
Cell[904177, 16185, 789, 11, 34, "Text",ExpressionUUID->"db4d22e8-f123-44d4-bff8-821aad05b9af"],
Cell[CellGroupData[{
Cell[904991, 16200, 561, 11, 47, "Input",ExpressionUUID->"7b735c7b-feec-43a8-8952-9518e3c43679"],
Cell[905555, 16213, 6307, 88, 48, "Output",ExpressionUUID->"e2fde703-2f2f-4f00-929e-f6ceb5cf88c9"]
}, Open  ]],
Cell[911877, 16304, 837, 12, 34, "Text",ExpressionUUID->"4a4ee525-f758-4e09-8791-db558dedf73d"],
Cell[CellGroupData[{
Cell[912739, 16320, 637, 12, 47, "Input",ExpressionUUID->"573d1fcc-bc54-41d7-b61c-dd7a0174e352"],
Cell[913379, 16334, 6330, 89, 48, "Output",ExpressionUUID->"679d20ac-7b15-42c5-8a13-2a04b019208e"]
}, Open  ]],
Cell[919724, 16426, 733, 10, 34, "Text",ExpressionUUID->"d0b7c15b-ffd6-480e-aaae-f85490456529"],
Cell[CellGroupData[{
Cell[920482, 16440, 556, 11, 47, "Input",ExpressionUUID->"fdb2e803-a85d-4f0e-8038-c45ff26d0bf6"],
Cell[921041, 16453, 6263, 87, 48, "Output",ExpressionUUID->"ba5c3bd8-219b-4e77-bd40-8b7e3c9c47a8"]
}, Open  ]],
Cell[927319, 16543, 783, 11, 34, "Text",ExpressionUUID->"041c5226-fdfa-4c79-81a8-519a191d2372"],
Cell[CellGroupData[{
Cell[928127, 16558, 623, 12, 47, "Input",ExpressionUUID->"5f9ee1b1-28df-43c7-a49e-dc5c6e8a2f98"],
Cell[928753, 16572, 6281, 88, 48, "Output",ExpressionUUID->"65af7469-3d31-4aff-8edb-e09bef8f6827"]
}, Open  ]],
Cell[935049, 16663, 1118, 16, 34, "Text",ExpressionUUID->"d1fed075-77fe-46ed-87e4-911852b50b0d"],
Cell[936170, 16681, 747, 10, 34, "Text",ExpressionUUID->"cd5bd462-f8d6-4d2f-918a-4dc30842ea81"],
Cell[CellGroupData[{
Cell[936942, 16695, 607, 12, 48, "Input",ExpressionUUID->"d044afb3-4c1a-4e50-b6b3-432f63f7f1ec"],
Cell[937552, 16709, 6318, 88, 48, "Output",ExpressionUUID->"82549a06-c670-49b2-a305-5091a3567b3e"]
}, Open  ]],
Cell[943885, 16800, 799, 11, 34, "Text",ExpressionUUID->"e973c32a-c384-4e66-88e8-77ac0cf1dbb7"],
Cell[CellGroupData[{
Cell[944709, 16815, 679, 13, 48, "Input",ExpressionUUID->"9d6cb6fd-c852-414c-93c3-707ac678a576"],
Cell[945391, 16830, 6320, 88, 48, "Output",ExpressionUUID->"b789f513-1fff-4419-ac94-26150a21d627"]
}, Open  ]],
Cell[951726, 16921, 948, 13, 34, "Text",ExpressionUUID->"10e14ef7-7dbb-4c4f-89b4-1f5f447cbacb"],
Cell[CellGroupData[{
Cell[952699, 16938, 843, 19, 28, "Input",ExpressionUUID->"ddfc108a-8f62-4b98-9b7a-68f0eff4fd65"],
Cell[953545, 16959, 727, 14, 48, "Output",ExpressionUUID->"736c6c8d-ee74-4a67-9cb3-24788db667b3"]
}, Open  ]],
Cell[954287, 16976, 789, 11, 34, "Text",ExpressionUUID->"27f9766d-32e7-416f-a633-017ac3931911"],
Cell[CellGroupData[{
Cell[955101, 16991, 613, 12, 47, "Input",ExpressionUUID->"748f9f28-5aa8-4afa-850f-690ecd11219f"],
Cell[955717, 17005, 6305, 88, 48, "Output",ExpressionUUID->"5a61d8ce-9622-4d5e-93d7-142ca9bf91a0"]
}, Open  ]],
Cell[962037, 17096, 837, 12, 34, "Text",ExpressionUUID->"58eaa9d5-5768-4a72-a526-8c40c186a85a"],
Cell[CellGroupData[{
Cell[962899, 17112, 688, 13, 47, "Input",ExpressionUUID->"756e82fd-3ce4-48f4-9968-fe09331933d8"],
Cell[963590, 17127, 6343, 89, 48, "Output",ExpressionUUID->"13eebacd-2621-4a9f-8f32-d55f003f7a61"]
}, Open  ]],
Cell[969948, 17219, 733, 10, 34, "Text",ExpressionUUID->"f51167a7-0925-470f-aa71-0bd2425567b5"],
Cell[CellGroupData[{
Cell[970706, 17233, 608, 12, 47, "Input",ExpressionUUID->"1be97816-01c7-4c98-ac9b-647deefa1959"],
Cell[971317, 17247, 6264, 87, 48, "Output",ExpressionUUID->"252063ba-417f-4a18-a860-d459dcebae3c"]
}, Open  ]],
Cell[977596, 17337, 783, 11, 34, "Text",ExpressionUUID->"8855e30c-c6f6-458b-b3d2-920dbf090d93"],
Cell[CellGroupData[{
Cell[978404, 17352, 676, 13, 47, "Input",ExpressionUUID->"74d2b000-985d-4abd-8bbe-245671d7af2e"],
Cell[979083, 17367, 6273, 88, 48, "Output",ExpressionUUID->"f52ae4cd-f873-4c4b-9dcb-03c4a6397cd2"]
}, Open  ]],
Cell[985371, 17458, 219, 4, 34, "Text",ExpressionUUID->"157379bd-193a-4699-a443-a2fe967aacb4"],
Cell[985593, 17464, 275, 6, 34, "Text",ExpressionUUID->"65b57b8f-bd6e-41f0-be18-fe78cf11b17e"],
Cell[CellGroupData[{
Cell[985893, 17474, 324, 8, 44, "Input",ExpressionUUID->"fe899fe6-10eb-42a1-b58b-f24433330ac5"],
Cell[986220, 17484, 328, 6, 48, "Output",ExpressionUUID->"a951d4fa-8a50-471d-abad-02f3ac824bf1"]
}, Open  ]],
Cell[986563, 17493, 242, 4, 34, "Text",ExpressionUUID->"20694b68-a4e5-4dda-9d30-c0b59281e996"],
Cell[CellGroupData[{
Cell[986830, 17501, 277, 7, 44, "Input",ExpressionUUID->"55d2d145-a49a-41b8-844e-ef16273d11d5"],
Cell[987110, 17510, 333, 6, 48, "Output",ExpressionUUID->"8b5e8d9c-c2d1-4858-a053-f3e3c3a83760"]
}, Open  ]],
Cell[987458, 17519, 190, 3, 34, "Text",ExpressionUUID->"7c3c83c0-2a97-48d5-b489-edd3d825d4b2"],
Cell[CellGroupData[{
Cell[987673, 17526, 275, 7, 47, "Input",ExpressionUUID->"59d9d4ce-6349-490d-97df-44ca5dbf843e"],
Cell[987951, 17535, 332, 6, 48, "Output",ExpressionUUID->"04f8fc96-686f-4fd8-b697-f830199adc24"]
}, Open  ]],
Cell[988298, 17544, 242, 4, 34, "Text",ExpressionUUID->"604ae140-3207-416c-be2b-36c603a86805"],
Cell[CellGroupData[{
Cell[988565, 17552, 275, 7, 47, "Input",ExpressionUUID->"72bbc640-5df5-4f09-9e19-2adf7b86f64d"],
Cell[988843, 17561, 332, 6, 81, "Output",ExpressionUUID->"c13c5779-f1d0-46b3-8654-e1a5bf0291e8"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

